(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[   2493673,      65514]
NotebookOptionsPosition[   2460629,      64527]
NotebookOutlinePosition[   2464330,      64629]
CellTagsIndexPosition[   2463341,      64604]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Example Notebook: SUtree", "Title",
 CellChangeTimes->{{3.526206461806625*^9, 3.526206472731598*^9}}],

Cell["\<\
NOTE:
-You might want to copy this file to a secure place before using it, in order \
to save it as future reference and manual. 
-In order to avoid overlapping definitions, interferences with other \
processes, and similar issues, please quit the MathKernel before you load \
SUtree.\
\>", "Section",
 CellChangeTimes->{{3.527144405672575*^9, 3.527144477045123*^9}, {
   3.527261163978153*^9, 3.527261165079729*^9}, {3.52726982516649*^9, 
   3.527269890242148*^9}, {3.527269986512392*^9, 3.527270043584688*^9}, 
   3.5316282035383587`*^9}],

Cell[CellGroupData[{

Cell["Preparation:", "Section",
 CellChangeTimes->{{3.526206478773539*^9, 3.5262064823553953`*^9}}],

Cell[CellGroupData[{

Cell["\<\
set the directory in which you have put the extracted package:\
\>", "Subsection",
 CellChangeTimes->{{3.526206489813367*^9, 3.526206509130754*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"NotebookDirectory", "[", "]"}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.526206526099724*^9, 3.526206535755846*^9}, {
  3.527094696903983*^9, 3.527094701580699*^9}, {3.531628163156678*^9, 
  3.531628188804309*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["increase the recursion limit (due to long lists):", "Subsection",
 CellChangeTimes->{{3.5263857400302677`*^9, 3.526385748812525*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"$RecursionLimit", "=", "300"}], ";"}]], "Input",
 CellChangeTimes->{{3.526621242152944*^9, 3.526621242264242*^9}, {
  3.526795151795232*^9, 3.526795152296611*^9}, {3.53157261322431*^9, 
  3.53157261457517*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["load the actual package (may take a minute or longer!!):", "Subsection",
 CellChangeTimes->{{3.526206541876061*^9, 3.526206554865601*^9}, {
  3.527087173067772*^9, 3.527087195408853*^9}, {3.5272696990970707`*^9, 
  3.527269700431712*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"<<", "SUtree.m"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData["\<\"This is SUtree 1.1, which accompanies arXiv:1110.4891 \
[hep-ph].\"\>"], "Print",
 CellChangeTimes->{3.531573347935679*^9}],

Cell[BoxData["\<\"Copyright \[Copyright] 2011: Alexander Merle & Roman \
Zwicky.\"\>"], "Print",
 CellChangeTimes->{3.531573347943531*^9}],

Cell[BoxData["\<\"Program is loading. This may take some time.\"\>"], "Print",
 CellChangeTimes->{3.53157334794816*^9}],

Cell[BoxData["\<\"Program loaded.\"\>"], "Print",
 CellChangeTimes->{3.53157343638395*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["What is SUtree?", "Subsection",
 CellChangeTimes->{{3.526206567203889*^9, 3.526206570609591*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "SUtree"}]], "Input",
 CellChangeTimes->{{3.5262065730388327`*^9, 3.5262065751381893`*^9}}],

Cell[BoxData[
 StyleBox["\<\"SUtree 1.1: a package to investigate the invariants of finite \
SU(3) subgroups\\nAvailable at: \
http://theophys.kth.se/~amerle/SUtree/SUtree.html\\n(accompanies \
arXiv:1110.4891 [hep-ph])\\n\\nCopyright \[Copyright] 2011: Alexander Merle & \
Roman Zwicky\\n\\nThis program is free software: you can redistribute it \
and/or modify\\nit under the terms of the GNU General Public License as \
published by\\nthe Free Software Foundation, either version 3 of the License, \
or\\n(at your option) any later version.\\n\\nThis program is distributed in \
the hope that it will be useful,\\nbut WITHOUT ANY WARRANTY; without even the \
implied warranty of\\nMERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  \
See the\\nGNU General Public License for more details.\\n\\nFor a copy of the \
GNU General Public License, please \
see\\n<http://www.gnu.org/licenses/>.\\n\\nPlease report errors to: \
amerle(AT)kth.se\\n\\nNote that the user him/herself has to check the \
correctness of the \\nresults obtained with SUtree. The authors take no \
responsibility\\nfor wrong results. Please report them instead of blaming us.\
\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.531573441796731*^9},
 CellTags->"Info3531577041-8153022"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Group names and identification:", "Section",
 CellChangeTimes->{{3.5262065929867563`*^9, 3.526206600448295*^9}}],

Cell[CellGroupData[{

Cell["display the numerical group lists:", "Subsection",
 CellChangeTimes->{{3.526206616065112*^9, 3.526206621911886*^9}, {
  3.526227145231358*^9, 3.526227147566368*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "Group"}]], "Input",
 CellChangeTimes->{{3.526206624607328*^9, 3.52620662574468*^9}}],

Cell[BoxData[
 StyleBox["\<\"Group['name'], Group[n], and Group[g,j] return a numerical \
list of all\\ngroup elements of the group 'name', the group with group number \
n, or the\\ngroup labeled by the GAP numbers [g,j].\"\>", "MSG"]], "Print", \
"PrintUsage",
 CellChangeTimes->{3.527143722671134*^9},
 CellTags->"Info3527150922-9962282"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "example: ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["A", "4"], TraditionalForm]],
  FormatType->"TraditionalForm"]
}], "Subsubsection",
 CellChangeTimes->{{3.526206648952364*^9, 3.52620665346734*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Group", "[", "\"\<\!\(\*SubscriptBox[\(A\), \(4\)]\)\>\"", 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Group", "[", "\"\<T\>\"", "]"}], "\[IndentingNewLine]", 
 RowBox[{"Group", "[", 
  "\"\<\[CapitalDelta](3\[CenterDot]\!\(\*SuperscriptBox[\(2\), \
\(2\)]\))\>\"", "]"}], "\[IndentingNewLine]", 
 RowBox[{"Group", "[", "\"\<\[CapitalDelta](12)\>\"", 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Group", "[", "1", "]"}], "\[IndentingNewLine]", 
 RowBox[{"Group", "[", 
  RowBox[{"12", ",", "3"}], "]"}]}], "Input",
 CellChangeTimes->{{3.526206668848668*^9, 3.5262066761210537`*^9}, {
  3.526206912450966*^9, 3.526206924003605*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1.`", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1.`", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1.`"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "1.`", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"-", "1.`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1.`"}], ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"-", "1.`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.`", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1.`"}], ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1.`", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1.`"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"-", "1.`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.`", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1.`", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "1.`", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.`", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1.`"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1.`"}], ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"-", "1.`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1.`"}], ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1.`", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1.`"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"-", "1.`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.`", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1.`"}], ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1.`"}], ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1.`"}], ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1.`"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1.`"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1.`"}], ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1.`", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"-", "1.`"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.52620667712547*^9, 3.526206924700327*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1.`", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1.`", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1.`"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "1.`", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"-", "1.`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1.`"}], ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"-", "1.`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.`", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1.`"}], ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1.`", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1.`"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"-", "1.`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.`", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1.`", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "1.`", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.`", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1.`"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1.`"}], ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"-", "1.`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1.`"}], ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1.`", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1.`"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"-", "1.`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.`", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1.`"}], ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1.`"}], ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1.`"}], ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1.`"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1.`"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1.`"}], ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1.`", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"-", "1.`"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.52620667712547*^9, 3.526206924706992*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1.`", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1.`", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1.`"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "1.`", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"-", "1.`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1.`"}], ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"-", "1.`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.`", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1.`"}], ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1.`", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1.`"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"-", "1.`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.`", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1.`", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "1.`", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.`", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1.`"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1.`"}], ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"-", "1.`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1.`"}], ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1.`", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1.`"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"-", "1.`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.`", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1.`"}], ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1.`"}], ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1.`"}], ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1.`"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1.`"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1.`"}], ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1.`", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"-", "1.`"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.52620667712547*^9, 3.526206924710705*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1.`", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1.`", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1.`"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "1.`", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"-", "1.`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1.`"}], ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"-", "1.`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.`", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1.`"}], ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1.`", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1.`"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"-", "1.`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.`", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1.`", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "1.`", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.`", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1.`"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1.`"}], ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"-", "1.`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1.`"}], ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1.`", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1.`"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"-", "1.`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.`", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1.`"}], ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1.`"}], ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1.`"}], ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1.`"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1.`"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1.`"}], ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1.`", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"-", "1.`"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.52620667712547*^9, 3.526206924714285*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1.`", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1.`", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1.`"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "1.`", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"-", "1.`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1.`"}], ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"-", "1.`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.`", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1.`"}], ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1.`", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1.`"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"-", "1.`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.`", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1.`", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "1.`", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.`", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1.`"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1.`"}], ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"-", "1.`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1.`"}], ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1.`", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1.`"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"-", "1.`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.`", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1.`"}], ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1.`"}], ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1.`"}], ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1.`"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1.`"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1.`"}], ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1.`", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"-", "1.`"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.52620667712547*^9, 3.526206924717848*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1.`", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1.`", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1.`"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "1.`", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"-", "1.`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1.`"}], ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"-", "1.`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.`", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1.`"}], ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1.`", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1.`"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"-", "1.`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.`", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1.`", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "1.`", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.`", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1.`"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1.`"}], ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"-", "1.`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1.`"}], ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1.`", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1.`"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"-", "1.`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.`", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1.`"}], ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1.`"}], ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1.`"}], ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1.`"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1.`"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1.`"}], ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1.`", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"-", "1.`"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.52620667712547*^9, 3.526206924721385*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["example: PSL(2,7)", "Subsubsection",
 CellChangeTimes->{{3.526206648952364*^9, 3.52620665346734*^9}, {
  3.526206696441083*^9, 3.526206703789927*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Group", "[", "\"\<PSL(2,7)\>\"", "]"}], "\[IndentingNewLine]", 
 RowBox[{"Group", "[", "\"\<\[CapitalSigma](168)\>\"", 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Group", "[", "24", "]"}], "\[IndentingNewLine]", 
 RowBox[{"Group", "[", 
  RowBox[{"168", ",", "42"}], "]"}]}], "Input",
 CellChangeTimes->{{3.526206668848668*^9, 3.5262066761210537`*^9}, {
  3.526206710800664*^9, 3.526206734910297*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1.`", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1.`", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1.`"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.32798527760568197`", ",", 
       RowBox[{"0.16399263880284023`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636859`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978864`"}], "+", 
        RowBox[{"0.46206948054554764`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.163992638802842`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636859`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061041`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305207`"}], "-", 
        RowBox[{"0.1423074786230634`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497906`"}], "-", 
        RowBox[{"0.4620694805455465`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530519`"}], "+", 
        RowBox[{"0.14230747862306387`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995795`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.532480753352631`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181378`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305257`"}], "-", 
        RowBox[{"0.14230747862306348`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028424`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224825`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694893`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181387`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558939`"}], "-", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497903`"}], "-", 
        RowBox[{"0.46206948054554675`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1639926388028401`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636864`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1315118854502103`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406225`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673661`"}], "+", 
        RowBox[{"0.3197620019224835`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526295`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813727`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694843`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181378`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028396`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636846`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530518`"}], "+", 
        RowBox[{"0.14230747862306284`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558927`"}], "+", 
        RowBox[{"0.5761912177406203`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1315118854502099`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406212`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028407`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248155`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978964`"}], "+", 
        RowBox[{"0.46206948054554553`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673687`"}], "-", 
        RowBox[{"0.3197620019224824`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9009688679024193`"}], "+", 
        RowBox[{"0.4338837391175599`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.6234898018587329`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.781831482468033`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.2225209339563179`"}], "-", 
        RowBox[{"0.9749279121818252`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9009688679024177`"}], "-", 
        RowBox[{"0.4338837391175591`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.6234898018587303`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824680297`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395631686`"}], "+", 
        RowBox[{"0.9749279121818207`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5910090485061039`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673793`"}], "-", 
        RowBox[{"0.3197620019224834`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589405`"}], "-", 
        RowBox[{"0.5761912177406212`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673707`"}], "+", 
        RowBox[{"0.3197620019224835`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995792`"}], ",", 
       RowBox[{"0.5324807533526303`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181398`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558922`"}], "+", 
        RowBox[{"0.5761912177406228`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526311`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813793`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568225`"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.6234898018587351`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824680299`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.2225209339563134`"}], "+", 
        RowBox[{"0.9749279121818247`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9009688679024204`"}], "-", 
        RowBox[{"0.4338837391175575`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024188`"}], "+", 
        RowBox[{"0.4338837391175568`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6234898018587338`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7818314824680282`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.222520933956313`"}], "-", 
        RowBox[{"0.9749279121818231`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497888`"}], "+", 
        RowBox[{"0.46206948054554786`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568214`", ",", 
       RowBox[{"0.16399263880283974`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636864`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305246`"}], "-", 
        RowBox[{"0.1423074786230631`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028424`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636857`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061045`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995795`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454979097`"}], "-", 
        RowBox[{"0.46206948054554686`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.295504524253052`"}], "+", 
        RowBox[{"0.14230747862306445`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497879`"}], "-", 
        RowBox[{"0.46206948054554686`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305185`"}], "+", 
        RowBox[{"0.14230747862306276`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995768`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3279852776056816`", ",", 
       RowBox[{"0.16399263880284182`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636836`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497895`"}], "+", 
        RowBox[{"0.46206948054554514`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1639926388028393`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636842`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061027`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530508`"}], "-", 
        RowBox[{"0.14230747862306395`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558924`"}], "+", 
        RowBox[{"0.5761912177406229`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526307`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813816`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568214`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5910090485061048`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673814`"}], "-", 
        RowBox[{"0.3197620019224838`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558947`"}], "-", 
        RowBox[{"0.5761912177406218`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673633`"}], "+", 
        RowBox[{"0.3197620019224841`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.73697622909958`"}], ",", 
       RowBox[{"0.5324807533526306`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181407`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589133`"}], "-", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061024`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673612`"}], "-", 
        RowBox[{"0.3197620019224825`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526297`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813777`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673801`"}], "+", 
        RowBox[{"0.3197620019224825`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995765`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3279852776056815`", ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589294`"}], "+", 
        RowBox[{"0.5761912177406195`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.532480753352628`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181396`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6234898018587334`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.781831482468031`", " ", "\[ImaginaryI]"}]}], ",", "0", ",",
        "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395631517`"}], "-", 
        RowBox[{"0.974927912181824`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024195`"}], "+", 
        RowBox[{"0.4338837391175594`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6234898018587323`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824680297`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395631495`"}], "+", 
        RowBox[{"0.974927912181823`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024179`"}], "-", 
        RowBox[{"0.4338837391175586`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395631306`"}], "+", 
        RowBox[{"0.9749279121818255`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024217`"}], "-", 
        RowBox[{"0.4338837391175567`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.623489801858735`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824680295`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.6234898018587341`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7818314824680284`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.22252093395631237`"}], "-", 
        RowBox[{"0.9749279121818225`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024187`"}], "+", 
        RowBox[{"0.43388373911755523`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673782`"}], "-", 
        RowBox[{"0.3197620019224833`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589233`"}], "+", 
        RowBox[{"0.5761912177406227`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454979`"}], "-", 
        RowBox[{"0.46206948054554675`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1639926388028402`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636859`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526303`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813943`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673777`"}], "-", 
        RowBox[{"0.31976200192248344`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526302`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181395`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305235`"}], "-", 
        RowBox[{"0.14230747862306314`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558923`"}], "+", 
        RowBox[{"0.576191217740623`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673776`"}], "+", 
        RowBox[{"0.31976200192248283`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028399`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636846`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526292`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813904`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558915`"}], "-", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526292`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181389`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530517`"}], "+", 
        RowBox[{"0.14230747862306287`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978936`"}], "+", 
        RowBox[{"0.4620694805455459`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673768`"}], "+", 
        RowBox[{"0.31976200192248266`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558912`"}], "-", 
        RowBox[{"0.5761912177406215`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.900968867902421`"}], "-", 
        RowBox[{"0.43388373911755745`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.6234898018587359`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824680298`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.22252093395631362`"}], "+", 
        RowBox[{"0.9749279121818246`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395631325`"}], "-", 
        RowBox[{"0.9749279121818231`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9009688679024185`"}], "+", 
        RowBox[{"0.43388373911755623`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.623489801858734`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7818314824680275`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.22252093395631362`"}], "+", 
        RowBox[{"0.9749279121818244`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.900968867902421`"}], "-", 
        RowBox[{"0.4338837391175573`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.6234898018587363`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824680298`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.22252093395631334`"}], "-", 
        RowBox[{"0.9749279121818233`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024186`"}], "+", 
        RowBox[{"0.4338837391175561`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.6234898018587341`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7818314824680271`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.2044954757469485`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813843`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558932`"}], "-", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978964`"}], "-", 
        RowBox[{"0.46206948054554664`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284018`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.718498696363686`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1315118854502104`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406225`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673704`"}], "+", 
        RowBox[{"0.3197620019224836`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526311`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813793`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530524`"}], "-", 
        RowBox[{"0.14230747862306312`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028423`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224823`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694843`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181384`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880283987`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636845`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526298`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181372`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558929`"}], "+", 
        RowBox[{"0.576191217740621`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020998`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406212`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305157`"}], "+", 
        RowBox[{"0.14230747862306276`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497894`"}], "+", 
        RowBox[{"0.46206948054554625`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673679`"}], "-", 
        RowBox[{"0.3197620019224827`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028404`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248155`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "1.0000000000000013`", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1.0000000000000016`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.0000000000000007`", ",", "0", ",", "0"}], "}"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0.9999999999999993`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999999987`", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0.9999999999999984`", ",", "0"}], "}"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.623489801858733`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7818314824680325`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395631756`"}], "-", 
        RowBox[{"0.9749279121818253`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9009688679024195`"}], "+", 
        RowBox[{"0.43388373911756023`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024173`"}], "-", 
        RowBox[{"0.4338837391175592`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6234898018587308`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824680297`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395631653`"}], "+", 
        RowBox[{"0.9749279121818207`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.6234898018587381`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824680295`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.22252093395631212`"}], "+", 
        RowBox[{"0.9749279121818261`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024235`"}], "-", 
        RowBox[{"0.43388373911755596`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395631128`"}], "-", 
        RowBox[{"0.9749279121818224`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024181`"}], "+", 
        RowBox[{"0.43388373911755335`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6234898018587349`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7818314824680254`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558937`"}], "-", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978897`"}], "+", 
        RowBox[{"0.4620694805455479`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673678`"}], "+", 
        RowBox[{"0.3197620019224837`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526315`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813805`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673686`"}], "+", 
        RowBox[{"0.319762001922484`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284304`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636862`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530519`"}], "+", 
        RowBox[{"0.14230747862306453`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558953`"}], "-", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526322`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813743`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.459497163055893`"}], "+", 
        RowBox[{"0.5761912177406205`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526297`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813716`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305074`"}], "-", 
        RowBox[{"0.14230747862306398`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978797`"}], "-", 
        RowBox[{"0.46206948054554664`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673654`"}], "-", 
        RowBox[{"0.3197620019224827`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589305`"}], "+", 
        RowBox[{"0.5761912177406189`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673661`"}], "-", 
        RowBox[{"0.31976200192248294`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284226`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636831`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526298`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181362`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028422`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224821`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020992`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.576191217740623`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673829`"}], "-", 
        RowBox[{"0.3197620019224835`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526302`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181393`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694896`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181385`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028422`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248216`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694887`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813843`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558924`"}], "+", 
        RowBox[{"0.5761912177406234`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020984`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406229`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028407`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224816`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526292`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813904`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694846`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181378`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545020934`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.576191217740621`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.2044954757469483`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181378`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558908`"}], "-", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673818`"}], "+", 
        RowBox[{"0.3197620019224825`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028405`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248144`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020936`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.576191217740621`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395631278`"}], "+", 
        RowBox[{"0.9749279121818261`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9009688679024218`"}], "-", 
        RowBox[{"0.4338837391175569`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.6234898018587351`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824680298`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024184`"}], "+", 
        RowBox[{"0.43388373911755523`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.6234898018587339`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7818314824680282`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.22252093395631187`"}], "-", 
        RowBox[{"0.9749279121818221`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028423`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224824`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061046`"}], ",", 
       RowBox[{"0.204495475746948`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813927`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021236`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406224`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694932`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181385`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995797`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3279852776056822`", ",", 
       RowBox[{"0.6639926388028412`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248494`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020986`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406229`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028404`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248166`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021197`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406202`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568147`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5910090485061026`"}], ",", 
       RowBox[{"0.20449547574694843`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813743`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028392`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248383`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694726`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181385`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995766`"}], ",", 
       RowBox[{"0.13151188545020948`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406211`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028417`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224825`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978886`"}], "+", 
        RowBox[{"0.4620694805455477`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530518`"}], "+", 
        RowBox[{"0.14230747862306414`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978897`"}], "+", 
        RowBox[{"0.46206948054554825`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694904`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813855`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284273`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.718498696363686`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305196`"}], "+", 
        RowBox[{"0.1423074786230645`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.163992638802843`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636861`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020967`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406233`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028408`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248194`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978786`"}], "-", 
        RowBox[{"0.46206948054554664`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530509`"}], "-", 
        RowBox[{"0.14230747862306403`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497883`"}], "-", 
        RowBox[{"0.4620694805455469`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694843`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813766`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028423`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636831`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530514`"}], "-", 
        RowBox[{"0.1423074786230639`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284204`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636834`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020903`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406209`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673777`"}], "-", 
        RowBox[{"0.3197620019224833`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028418`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636855`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021159`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.576191217740622`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028414`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248483`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526307`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181398`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.295504524253052`"}], "+", 
        RowBox[{"0.14230747862306428`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978875`"}], "+", 
        RowBox[{"0.4620694805455485`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694796`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181395`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589206`"}], "+", 
        RowBox[{"0.5761912177406239`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673773`"}], "+", 
        RowBox[{"0.31976200192248283`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028392`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248366`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978736`"}], "-", 
        RowBox[{"0.46206948054554675`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284146`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636842`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526287`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813893`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694718`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813855`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021145`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406212`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305107`"}], "-", 
        RowBox[{"0.14230747862306378`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589033`"}], "-", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558926`"}], "+", 
        RowBox[{"0.5761912177406227`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021145`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406219`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.295504524253052`"}], "+", 
        RowBox[{"0.14230747862306406`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978886`"}], "+", 
        RowBox[{"0.4620694805455472`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673818`"}], "-", 
        RowBox[{"0.31976200192248294`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028411`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248394`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.2044954757469482`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813904`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284173`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636858`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526299`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813943`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558917`"}], "-", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497885`"}], "-", 
        RowBox[{"0.4620694805455466`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694743`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813866`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021122`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406209`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.0729835902967374`"}], "+", 
        RowBox[{"0.31976200192248266`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284176`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636846`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305135`"}], "-", 
        RowBox[{"0.14230747862306392`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028402`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224838`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526291`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181384`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1315118854502099`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406235`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673872`"}], "-", 
        RowBox[{"0.31976200192248355`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028435`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248166`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694937`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181382`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028425`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224825`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526303`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181401`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589206`"}], "+", 
        RowBox[{"0.5761912177406238`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020967`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.576191217740623`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.2044954757469496`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813893`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1315118854502088`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406209`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694826`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813755`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558904`"}], "-", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673816`"}], "+", 
        RowBox[{"0.3197620019224819`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028407`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224814`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1315118854502094`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406208`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.66399263880284`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224802`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526285`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813916`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694907`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813716`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497903`"}], "-", 
        RowBox[{"0.46206948054554653`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673675`"}], "+", 
        RowBox[{"0.3197620019224838`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.663992638802843`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248194`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694907`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181383`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028396`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636862`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526317`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813766`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558942`"}], "-", 
        RowBox[{"0.5761912177406212`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1315118854502099`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.576191217740623`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530526`"}], "-", 
        RowBox[{"0.14230747862306314`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497899`"}], "+", 
        RowBox[{"0.4620694805455454`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694854`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813805`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558931`"}], "+", 
        RowBox[{"0.5761912177406201`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673662`"}], "-", 
        RowBox[{"0.31976200192248283`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880283915`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636844`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020948`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406211`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028403`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224809`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526297`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813666`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530515`"}], "+", 
        RowBox[{"0.14230747862306223`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694812`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181391`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589233`"}], "+", 
        RowBox[{"0.576191217740623`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.368488114549789`"}], "+", 
        RowBox[{"0.4620694805455478`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1639926388028429`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636861`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021247`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406225`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673826`"}], "-", 
        RowBox[{"0.3197620019224836`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526303`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813977`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305185`"}], "+", 
        RowBox[{"0.14230747862306425`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028411`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224848`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.2044954757469476`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181384`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284215`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636832`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.532480753352629`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181392`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558911`"}], "-", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021203`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406203`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305124`"}], "-", 
        RowBox[{"0.14230747862306392`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978797`"}], "-", 
        RowBox[{"0.46206948054554664`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.072983590296738`"}], "+", 
        RowBox[{"0.31976200192248244`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028394`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224839`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028428`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248205`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497913`"}], "-", 
        RowBox[{"0.46206948054554664`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.0729835902967365`"}], "+", 
        RowBox[{"0.3197620019224841`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526309`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181379`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694898`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181384`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880283949`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636865`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305257`"}], "-", 
        RowBox[{"0.14230747862306317`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589494`"}], "-", 
        RowBox[{"0.5761912177406215`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020975`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406233`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028405`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248094`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.53248075335263`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181375`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305146`"}], "+", 
        RowBox[{"0.14230747862306276`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978975`"}], "+", 
        RowBox[{"0.4620694805455447`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694857`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181377`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589294`"}], "+", 
        RowBox[{"0.5761912177406193`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673619`"}], "-", 
        RowBox[{"0.31976200192248255`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880283904`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636844`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020906`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406209`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.2044954757469481`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813916`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558943`"}], "-", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021206`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406223`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028409`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224839`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021153`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406219`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673704`"}], "+", 
        RowBox[{"0.3197620019224835`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526309`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813816`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694812`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181391`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028412`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224846`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694754`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181383`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028403`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224836`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526299`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181376`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589283`"}], "+", 
        RowBox[{"0.57619121774062`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021136`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406212`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694765`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181385`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021175`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406207`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673684`"}], "-", 
        RowBox[{"0.319762001922483`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028395`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248366`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526309`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813793`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694896`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181385`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028396`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636861`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530522`"}], "-", 
        RowBox[{"0.14230747862306328`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558944`"}], "-", 
        RowBox[{"0.5761912177406215`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021014`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406225`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028419`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224825`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454979047`"}], "-", 
        RowBox[{"0.46206948054554686`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.0729835902967368`"}], "+", 
        RowBox[{"0.3197620019224837`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.53248075335263`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181375`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305185`"}], "+", 
        RowBox[{"0.14230747862306298`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028405`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.319762001922482`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.2044954757469485`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181377`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558929`"}], "+", 
        RowBox[{"0.57619121774062`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978947`"}], "+", 
        RowBox[{"0.4620694805455453`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880283937`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636846`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020956`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406212`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673686`"}], "-", 
        RowBox[{"0.3197620019224829`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995787`"}], ",", 
       RowBox[{"0.5324807533526302`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813927`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673694`"}], "+", 
        RowBox[{"0.3197620019224836`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526309`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813805`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.3279852776056822`", ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589217`"}], "+", 
        RowBox[{"0.576191217740623`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673787`"}], "-", 
        RowBox[{"0.3197620019224834`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589433`"}], "-", 
        RowBox[{"0.5761912177406215`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061045`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694885`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813843`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995793`"}], ",", 
       RowBox[{"0.13151188545021242`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406224`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028412`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248505`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1315118854502099`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406232`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.3279852776056825`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5910090485061045`"}], ",", 
       RowBox[{"0.20449547574694799`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181395`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028431`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224817`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694843`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181378`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.663992638802839`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248394`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061029`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995768`"}], ",", 
       RowBox[{"0.13151188545020925`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406209`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694737`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181386`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1315118854502121`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406203`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568114`", ",", 
       RowBox[{"0.6639926388028404`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224805`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545020975`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406228`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.295504524253052`"}], "+", 
        RowBox[{"0.14230747862306403`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284237`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636859`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305196`"}], "+", 
        RowBox[{"0.14230747862306403`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028424`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248244`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497886`"}], "+", 
        RowBox[{"0.462069480545548`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1639926388028424`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636857`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978847`"}], "+", 
        RowBox[{"0.46206948054554786`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694849`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181386`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545020948`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.576191217740621`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305124`"}], "-", 
        RowBox[{"0.1423074786230636`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284215`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.718498696363684`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305124`"}], "-", 
        RowBox[{"0.14230747862306353`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028408`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224814`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978786`"}], "-", 
        RowBox[{"0.4620694805455467`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284207`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636839`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497879`"}], "-", 
        RowBox[{"0.4620694805455467`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.2044954757469483`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813805`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673684`"}], "+", 
        RowBox[{"0.3197620019224838`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880283962`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636864`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020995`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406227`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028433`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248183`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526319`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813755`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305274`"}], "-", 
        RowBox[{"0.14230747862306295`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454979086`"}], "-", 
        RowBox[{"0.46206948054554664`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.2044954757469493`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813843`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589494`"}], "-", 
        RowBox[{"0.5761912177406212`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673662`"}], "-", 
        RowBox[{"0.31976200192248283`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028404`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224806`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978964`"}], "+", 
        RowBox[{"0.46206948054554475`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1639926388028393`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636845`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526297`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181364`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694857`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181376`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545020948`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406212`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305157`"}], "+", 
        RowBox[{"0.1423074786230623`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558933`"}], "+", 
        RowBox[{"0.5761912177406195`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.32798527760568186`", ",", 
       RowBox[{"-", "0.7369762290995784`"}], ",", 
       RowBox[{"-", "0.5910090485061038`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995789`"}], ",", 
       RowBox[{"-", "0.5910090485061043`"}], ",", "0.3279852776056821`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5910090485061044`"}], ",", "0.3279852776056822`", ",", 
       
       RowBox[{"-", "0.736976229099579`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995796`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497915`"}], "-", 
        RowBox[{"0.4620694805455467`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530521`"}], "+", 
        RowBox[{"0.14230747862306498`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978864`"}], "+", 
        RowBox[{"0.4620694805455485`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568236`", ",", 
       RowBox[{"0.16399263880283915`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636871`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530528`"}], "-", 
        RowBox[{"0.14230747862306287`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284318`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636861`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061051`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558939`"}], "-", 
        RowBox[{"0.5761912177406213`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526301`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181397`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568214`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5910090485061044`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673684`"}], "+", 
        RowBox[{"0.3197620019224838`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589233`"}], "+", 
        RowBox[{"0.5761912177406235`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673827`"}], "-", 
        RowBox[{"0.3197620019224835`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995794`"}], ",", 
       RowBox[{"0.5324807533526318`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181375`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558932`"}], "+", 
        RowBox[{"0.5761912177406203`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061028`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673814`"}], "+", 
        RowBox[{"0.31976200192248244`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526292`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813916`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673661`"}], "-", 
        RowBox[{"0.31976200192248283`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995769`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3279852776056813`", ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558906`"}], "-", 
        RowBox[{"0.5761912177406215`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526297`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813655`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.3279852776056823`", ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589466`"}], "-", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526302`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181398`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558924`"}], "+", 
        RowBox[{"0.5761912177406227`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061043`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673707`"}], "+", 
        RowBox[{"0.3197620019224836`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526312`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813793`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.0729835902967382`"}], "-", 
        RowBox[{"0.31976200192248333`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995794`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673808`"}], "-", 
        RowBox[{"0.31976200192248355`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589455`"}], "-", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061047`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995793`"}], ",", 
       RowBox[{"0.5324807533526305`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581814027`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673672`"}], "+", 
        RowBox[{"0.31976200192248394`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526312`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181379`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568225`", ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589194`"}], "+", 
        RowBox[{"0.5761912177406237`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673765`"}], "+", 
        RowBox[{"0.3197620019224826`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995769`"}], ",", 
       RowBox[{"0.5324807533526301`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813716`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558929`"}], "+", 
        RowBox[{"0.5761912177406197`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526286`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181395`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.3279852776056813`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5910090485061025`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673634`"}], "-", 
        RowBox[{"0.3197620019224827`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589056`"}], "-", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284135`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636851`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061039`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305207`"}], "-", 
        RowBox[{"0.1423074786230633`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978975`"}], "-", 
        RowBox[{"0.46206948054554675`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305185`"}], "+", 
        RowBox[{"0.14230747862306387`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995788`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.32798527760568197`", ",", 
       RowBox[{"0.16399263880284032`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636859`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.368488114549789`"}], "+", 
        RowBox[{"0.46206948054554753`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284118`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636848`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978936`"}], "+", 
        RowBox[{"0.46206948054554614`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.3279852776056816`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5910090485061033`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305135`"}], "-", 
        RowBox[{"0.14230747862306364`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028401`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636846`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305185`"}], "+", 
        RowBox[{"0.14230747862306317`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995775`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978825`"}], "-", 
        RowBox[{"0.46206948054554664`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305224`"}], "-", 
        RowBox[{"0.1423074786230632`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028419`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248244`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526308`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813805`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558952`"}], "-", 
        RowBox[{"0.5761912177406218`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454979125`"}], "-", 
        RowBox[{"0.4620694805455469`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.2044954757469494`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813855`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545020925`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406239`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.0729835902967364`"}], "+", 
        RowBox[{"0.31976200192248433`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880283876`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636878`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305174`"}], "+", 
        RowBox[{"0.142307478623063`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589294`"}], "+", 
        RowBox[{"0.576191217740619`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1315118854502084`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406204`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028408`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.319762001922482`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978947`"}], "+", 
        RowBox[{"0.4620694805455446`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673591`"}], "-", 
        RowBox[{"0.3197620019224825`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526299`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181375`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694849`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181374`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028379`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636836`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978914`"}], "+", 
        RowBox[{"0.4620694805455471`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673772`"}], "-", 
        RowBox[{"0.31976200192248333`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.663992638802841`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224845`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694815`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181387`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284168`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636856`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526303`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181395`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589244`"}], "+", 
        RowBox[{"0.5761912177406221`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021153`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406221`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305185`"}], "+", 
        RowBox[{"0.1423074786230641`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497887`"}], "-", 
        RowBox[{"0.46206948054554675`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694807`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813843`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558921`"}], "-", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673769`"}], "+", 
        RowBox[{"0.31976200192248283`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284132`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636844`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1315118854502114`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406211`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028397`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224837`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526292`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813904`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530513`"}], "-", 
        RowBox[{"0.14230747862306384`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589317`"}], "-", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021056`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406221`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.295504524253052`"}], "-", 
        RowBox[{"0.1423074786230634`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497895`"}], "-", 
        RowBox[{"0.4620694805455467`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673711`"}], "+", 
        RowBox[{"0.31976200192248333`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028414`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224827`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694854`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181384`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028404`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636854`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526306`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813827`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589283`"}], "+", 
        RowBox[{"0.5761912177406211`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497894`"}], "+", 
        RowBox[{"0.4620694805455463`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.2044954757469484`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181383`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021048`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673708`"}], "-", 
        RowBox[{"0.3197620019224831`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028403`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.718498696363685`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305174`"}], "+", 
        RowBox[{"0.14230747862306306`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028407`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248244`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526301`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.256429215818138`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694887`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813855`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028412`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224846`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061043`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995795`"}], ",", 
       RowBox[{"0.13151188545020975`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406227`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.2044954757469482`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813893`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1315118854502127`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406221`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568197`", ",", 
       RowBox[{"0.6639926388028428`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224823`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694835`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.256429215818138`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995773`"}], ",", 
       RowBox[{"0.13151188545021197`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406202`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028394`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224842`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020978`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.576191217740621`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568136`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5910090485061026`"}], ",", 
       RowBox[{"0.2044954757469476`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181385`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028408`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248094`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284018`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636858`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021036`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406222`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.072983590296737`"}], "+", 
        RowBox[{"0.31976200192248344`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526312`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813805`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305246`"}], "-", 
        RowBox[{"0.14230747862306325`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028423`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248244`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.2044954757469491`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813843`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589433`"}], "-", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497906`"}], "-", 
        RowBox[{"0.4620694805455466`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880283987`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636847`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526297`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813727`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694846`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181378`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1315118854502102`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530516`"}], "+", 
        RowBox[{"0.14230747862306278`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589317`"}], "+", 
        RowBox[{"0.57619121774062`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673683`"}], "-", 
        RowBox[{"0.31976200192248283`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028404`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248155`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497897`"}], "+", 
        RowBox[{"0.4620694805455453`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526313`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181378`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673668`"}], "+", 
        RowBox[{"0.3197620019224838`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284315`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636859`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530516`"}], "+", 
        RowBox[{"0.14230747862306398`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589405`"}], "-", 
        RowBox[{"0.5761912177406215`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526313`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181378`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589405`"}], "-", 
        RowBox[{"0.5761912177406215`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.368488114549789`"}], "+", 
        RowBox[{"0.4620694805455481`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673666`"}], "+", 
        RowBox[{"0.3197620019224838`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526299`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813705`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530514`"}], "-", 
        RowBox[{"0.14230747862306392`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558929`"}], "+", 
        RowBox[{"0.5761912177406203`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.0729835902967365`"}], "-", 
        RowBox[{"0.31976200192248294`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589283`"}], "+", 
        RowBox[{"0.5761912177406201`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497877`"}], "-", 
        RowBox[{"0.4620694805455466`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284254`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636832`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526299`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813705`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673643`"}], "-", 
        RowBox[{"0.31976200192248294`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880283932`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636872`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061046`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530522`"}], "+", 
        RowBox[{"0.1423074786230645`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978864`"}], "+", 
        RowBox[{"0.462069480545549`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305296`"}], "-", 
        RowBox[{"0.14230747862306314`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995799`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3279852776056821`", ",", 
       RowBox[{"0.16399263880284304`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636861`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497911`"}], "-", 
        RowBox[{"0.46206948054554664`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880283857`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636841`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497866`"}], "-", 
        RowBox[{"0.4620694805455468`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568086`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.591009048506102`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305157`"}], "+", 
        RowBox[{"0.14230747862306217`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284248`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636835`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305085`"}], "-", 
        RowBox[{"0.14230747862306417`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995762`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978975`"}], "+", 
        RowBox[{"0.46206948054554464`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558951`"}], "-", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021275`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406228`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.2044954757469479`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181399`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021228`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406223`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.0729835902967367`"}], "+", 
        RowBox[{"0.3197620019224839`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028411`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224855`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.2044954757469481`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813927`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028414`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224853`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526319`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181377`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.459497163055893`"}], "+", 
        RowBox[{"0.5761912177406191`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.131511885450212`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406207`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694732`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813843`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021228`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406199`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673644`"}], "-", 
        RowBox[{"0.31976200192248283`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028388`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224839`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694688`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181385`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028387`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248433`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526297`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181365`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028409`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248416`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497889`"}], "+", 
        RowBox[{"0.46206948054554764`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673798`"}], "-", 
        RowBox[{"0.3197620019224832`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526305`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813977`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.204495475746948`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813927`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284262`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636859`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305185`"}], "+", 
        RowBox[{"0.14230747862306437`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589217`"}], "+", 
        RowBox[{"0.5761912177406238`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021253`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406225`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.66399263880284`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224837`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.532480753352629`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813904`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530509`"}], "-", 
        RowBox[{"0.1423074786230639`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978814`"}], "-", 
        RowBox[{"0.46206948054554675`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694743`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813855`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558904`"}], "-", 
        RowBox[{"0.5761912177406213`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673789`"}], "+", 
        RowBox[{"0.3197620019224829`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.163992638802842`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636835`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1315118854502121`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406203`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021036`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406223`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673684`"}], "+", 
        RowBox[{"0.3197620019224836`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880283965`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636865`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530521`"}], "-", 
        RowBox[{"0.14230747862306314`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028424`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248244`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526315`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181379`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589355`"}], "-", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454979036`"}], "-", 
        RowBox[{"0.46206948054554686`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694904`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181383`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021003`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406213`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305174`"}], "+", 
        RowBox[{"0.142307478623063`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589305`"}], "+", 
        RowBox[{"0.5761912177406208`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673665`"}], "-", 
        RowBox[{"0.3197620019224829`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028403`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248155`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978936`"}], "+", 
        RowBox[{"0.4620694805455454`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880283924`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636842`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526297`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181369`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694854`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813777`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284318`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636864`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526316`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181376`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673666`"}], "+", 
        RowBox[{"0.31976200192248405`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526309`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181379`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530515`"}], "+", 
        RowBox[{"0.14230747862306434`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558943`"}], "-", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673672`"}], "+", 
        RowBox[{"0.31976200192248405`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558948`"}], "-", 
        RowBox[{"0.5761912177406218`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497885`"}], "+", 
        RowBox[{"0.4620694805455481`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284232`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636832`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526297`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813716`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673632`"}], "-", 
        RowBox[{"0.31976200192248266`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526295`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181365`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.295504524253051`"}], "-", 
        RowBox[{"0.1423074786230638`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589317`"}], "+", 
        RowBox[{"0.5761912177406198`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673618`"}], "-", 
        RowBox[{"0.3197620019224827`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589333`"}], "+", 
        RowBox[{"0.5761912177406204`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978736`"}], "-", 
        RowBox[{"0.4620694805455465`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305207`"}], "-", 
        RowBox[{"0.14230747862306328`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028411`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224847`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497906`"}], "-", 
        RowBox[{"0.46206948054554664`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1639926388028399`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636864`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497907`"}], "-", 
        RowBox[{"0.4620694805455469`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.204495475746948`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813943`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1315118854502122`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406223`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530526`"}], "-", 
        RowBox[{"0.14230747862306306`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880283915`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.718498696363687`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530518`"}], "+", 
        RowBox[{"0.14230747862306298`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880283949`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636841`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021184`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406207`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028395`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248383`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978947`"}], "+", 
        RowBox[{"0.4620694805455451`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305157`"}], "+", 
        RowBox[{"0.1423074786230626`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978964`"}], "+", 
        RowBox[{"0.4620694805455453`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694732`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181385`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028386`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.718498696363684`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978914`"}], "+", 
        RowBox[{"0.46206948054554703`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530519`"}], "-", 
        RowBox[{"0.14230747862306337`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995785`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.32798527760568186`", ",", 
       RowBox[{"0.16399263880284135`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636851`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978975`"}], "-", 
        RowBox[{"0.46206948054554675`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284048`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636857`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061039`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305185`"}], "+", 
        RowBox[{"0.14230747862306384`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497888`"}], "-", 
        RowBox[{"0.46206948054554675`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568164`", ",", 
       RowBox[{"0.16399263880284032`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636847`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530519`"}], "+", 
        RowBox[{"0.14230747862306342`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028412`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636846`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061033`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995778`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978936`"}], "+", 
        RowBox[{"0.4620694805455463`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530514`"}], "-", 
        RowBox[{"0.14230747862306367`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.32798527760568214`", ",", 
       RowBox[{"0.663992638802842`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224823`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021175`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.576191217740622`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028411`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248455`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061043`"}], ",", 
       RowBox[{"0.20449547574694882`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181384`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1315118854502098`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406225`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694826`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181393`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995792`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995794`"}], ",", 
       RowBox[{"-", "0.5910090485061046`"}], ",", "0.32798527760568236`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5910090485061046`"}], ",", "0.3279852776056822`", ",", 
       
       RowBox[{"-", "0.7369762290995794`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.32798527760568197`", ",", 
       RowBox[{"-", "0.7369762290995788`"}], ",", 
       RowBox[{"-", "0.5910090485061043`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305224`"}], "-", 
        RowBox[{"0.14230747862306323`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589394`"}], "-", 
        RowBox[{"0.5761912177406215`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021003`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406225`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028421`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248255`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497905`"}], "-", 
        RowBox[{"0.4620694805455469`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673682`"}], "+", 
        RowBox[{"0.31976200192248383`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526315`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813793`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694915`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181385`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880283943`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636867`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530518`"}], "+", 
        RowBox[{"0.14230747862306298`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028404`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224818`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526298`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181371`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558929`"}], "+", 
        RowBox[{"0.5761912177406202`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497893`"}], "+", 
        RowBox[{"0.46206948054554536`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694837`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813755`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1315118854502097`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406213`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673661`"}], "-", 
        RowBox[{"0.3197620019224829`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880283887`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636841`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1315118854502124`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406225`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673826`"}], "-", 
        RowBox[{"0.31976200192248355`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284282`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636861`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530518`"}], "+", 
        RowBox[{"0.14230747862306461`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028412`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224856`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526305`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581814043`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589217`"}], "+", 
        RowBox[{"0.5761912177406229`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978886`"}], "+", 
        RowBox[{"0.4620694805455477`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694793`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813904`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1315118854502119`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406204`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305074`"}], "-", 
        RowBox[{"0.14230747862306414`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558912`"}], "-", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673801`"}], "+", 
        RowBox[{"0.3197620019224825`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028388`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248433`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497881`"}], "-", 
        RowBox[{"0.46206948054554686`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284207`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636834`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526282`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181395`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.2044954757469477`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181387`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028421`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248255`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1315118854502117`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.576191217740622`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.3279852776056821`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5910090485061043`"}], ",", 
       RowBox[{"0.20449547574694857`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813855`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028411`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224844`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.2044954757469481`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181392`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995789`"}], ",", 
       RowBox[{"0.1315118854502101`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406227`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028407`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224819`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061028`"}], ",", 
       RowBox[{"0.20449547574694754`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813827`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021142`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.576191217740621`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.2044954757469484`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813816`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995773`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3279852776056815`", ",", 
       RowBox[{"0.6639926388028398`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224836`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020961`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406211`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995794`"}], ",", 
       RowBox[{"0.5324807533526316`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181378`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673833`"}], "-", 
        RowBox[{"0.31976200192248355`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526301`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181392`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568214`", ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558943`"}], "-", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.0729835902967369`"}], "+", 
        RowBox[{"0.3197620019224837`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558923`"}], "+", 
        RowBox[{"0.5761912177406233`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061046`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028412`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224851`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1315118854502123`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406221`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673669`"}], "+", 
        RowBox[{"0.319762001922484`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526308`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.256429215818138`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694782`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813927`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028414`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224848`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694815`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181394`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589444`"}], "-", 
        RowBox[{"0.576191217740622`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021233`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406221`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028395`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224842`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526296`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181374`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694726`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181385`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1315118854502119`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406203`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694749`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181382`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589317`"}], "+", 
        RowBox[{"0.5761912177406199`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673623`"}], "-", 
        RowBox[{"0.3197620019224827`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028395`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248394`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021164`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406201`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673701`"}], "+", 
        RowBox[{"0.3197620019224835`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589444`"}], "-", 
        RowBox[{"0.5761912177406215`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497888`"}], "+", 
        RowBox[{"0.46206948054554803`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1639926388028421`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636856`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526316`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813793`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.0729835902967368`"}], "+", 
        RowBox[{"0.31976200192248383`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526311`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813805`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305207`"}], "+", 
        RowBox[{"0.14230747862306448`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589483`"}], "-", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673687`"}], "-", 
        RowBox[{"0.31976200192248316`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284165`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636841`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526297`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181372`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589294`"}], "+", 
        RowBox[{"0.5761912177406199`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526297`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813694`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530509`"}], "-", 
        RowBox[{"0.14230747862306387`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497878`"}], "-", 
        RowBox[{"0.46206948054554686`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673651`"}], "-", 
        RowBox[{"0.3197620019224827`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589294`"}], "+", 
        RowBox[{"0.5761912177406194`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284307`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.718498696363686`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021267`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406224`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673834`"}], "-", 
        RowBox[{"0.3197620019224836`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526307`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581814015`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305196`"}], "+", 
        RowBox[{"0.14230747862306445`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028413`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224853`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694812`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813954`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589206`"}], "+", 
        RowBox[{"0.5761912177406238`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978886`"}], "+", 
        RowBox[{"0.46206948054554847`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284237`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636831`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526285`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813916`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694726`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181384`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1315118854502123`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406203`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305085`"}], "-", 
        RowBox[{"0.14230747862306387`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558904`"}], "-", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673814`"}], "+", 
        RowBox[{"0.3197620019224823`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028388`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248394`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978736`"}], "-", 
        RowBox[{"0.46206948054554675`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.53248075335263`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581814`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673702`"}], "+", 
        RowBox[{"0.3197620019224839`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995795`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3279852776056827`", ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589206`"}], "+", 
        RowBox[{"0.5761912177406238`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526317`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181378`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558953`"}], "-", 
        RowBox[{"0.5761912177406218`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061048`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673855`"}], "-", 
        RowBox[{"0.31976200192248344`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526286`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.256429215818139`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.327985277605681`", ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558934`"}], "+", 
        RowBox[{"0.5761912177406192`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673657`"}], "-", 
        RowBox[{"0.31976200192248283`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558905`"}], "-", 
        RowBox[{"0.5761912177406213`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061023`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995773`"}], ",", 
       RowBox[{"0.5324807533526296`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181366`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673775`"}], "+", 
        RowBox[{"0.31976200192248194`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673816`"}], "-", 
        RowBox[{"0.3197620019224835`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028419`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248266`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020992`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406222`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028423`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248255`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526302`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813966`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694912`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181386`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406227`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694898`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181381`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558924`"}], "+", 
        RowBox[{"0.5761912177406233`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673801`"}], "+", 
        RowBox[{"0.31976200192248294`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028404`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224815`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1315118854502097`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406211`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.663992638802841`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.319762001922482`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.532480753352629`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181388`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694826`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813755`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021003`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.576191217740621`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694873`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181375`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558909`"}], "-", 
        RowBox[{"0.5761912177406219`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454979047`"}], "-", 
        RowBox[{"0.46206948054554664`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305257`"}], "-", 
        RowBox[{"0.14230747862306312`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028413`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248516`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694807`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.256429215818139`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880283999`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636861`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497904`"}], "-", 
        RowBox[{"0.4620694805455468`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1639926388028402`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.718498696363686`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021184`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406223`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530524`"}], "-", 
        RowBox[{"0.14230747862306323`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497895`"}], "+", 
        RowBox[{"0.46206948054554536`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694765`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813855`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880283993`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636846`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530516`"}], "+", 
        RowBox[{"0.14230747862306267`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028396`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636844`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1315118854502115`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406208`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028389`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224839`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497894`"}], "+", 
        RowBox[{"0.46206948054554553`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305146`"}], "+", 
        RowBox[{"0.14230747862306276`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530522`"}], "-", 
        RowBox[{"0.14230747862306317`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995793`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497888`"}], "+", 
        RowBox[{"0.4620694805455485`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284196`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636851`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454979075`"}], "-", 
        RowBox[{"0.4620694805455467`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.3279852776056824`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5910090485061041`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305207`"}], "+", 
        RowBox[{"0.1423074786230644`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880283924`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.718498696363687`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530517`"}], "+", 
        RowBox[{"0.1423074786230632`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284182`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636845`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061031`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995768`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497897`"}], "+", 
        RowBox[{"0.46206948054554536`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305096`"}], "-", 
        RowBox[{"0.14230747862306403`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497873`"}], "-", 
        RowBox[{"0.4620694805455468`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568114`", ",", 
       RowBox[{"0.16399263880283868`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636838`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305185`"}], "+", 
        RowBox[{"0.14230747862306398`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.736976229099579`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454979036`"}], "-", 
        RowBox[{"0.46206948054554675`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284035`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636857`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.368488114549789`"}], "+", 
        RowBox[{"0.4620694805455475`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.3279852776056821`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5910090485061043`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530523`"}], "-", 
        RowBox[{"0.14230747862306328`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284226`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636858`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530513`"}], "-", 
        RowBox[{"0.14230747862306367`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028402`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636847`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.591009048506103`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995773`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497883`"}], "-", 
        RowBox[{"0.4620694805455467`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530516`"}], "+", 
        RowBox[{"0.14230747862306287`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978936`"}], "+", 
        RowBox[{"0.46206948054554553`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.3279852776056814`", ",", 
       RowBox[{"0.16399263880284168`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636837`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526308`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581814004`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.2044954757469487`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813816`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028428`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.319762001922482`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694918`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813843`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558923`"}], "+", 
        RowBox[{"0.5761912177406239`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020964`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406231`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.663992638802843`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248194`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021003`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406228`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673804`"}], "-", 
        RowBox[{"0.31976200192248394`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526285`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813966`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694832`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181375`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028401`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248094`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694812`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181377`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558906`"}], "-", 
        RowBox[{"0.5761912177406218`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020925`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406209`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028403`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248116`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020887`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406207`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673818`"}], "+", 
        RowBox[{"0.31976200192248283`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.591009048506105`"}], ",", "0.3279852776056825`", ",", 
       RowBox[{"-", "0.7369762290995799`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.327985277605682`", ",", 
       RowBox[{"-", "0.7369762290995787`"}], ",", 
       RowBox[{"-", "0.5910090485061041`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995797`"}], ",", 
       RowBox[{"-", "0.5910090485061049`"}], ",", "0.3279852776056826`"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497888`"}], "+", 
        RowBox[{"0.46206948054554864`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673653`"}], "+", 
        RowBox[{"0.31976200192248394`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589566`"}], "-", 
        RowBox[{"0.5761912177406215`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673632`"}], "+", 
        RowBox[{"0.3197620019224842`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.163992638802844`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636865`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526326`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813727`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558943`"}], "-", 
        RowBox[{"0.5761912177406213`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526313`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181377`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305174`"}], "+", 
        RowBox[{"0.1423074786230644`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.368488114549787`"}], "-", 
        RowBox[{"0.4620694805455467`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.0729835902967361`"}], "-", 
        RowBox[{"0.31976200192248266`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589317`"}], "+", 
        RowBox[{"0.5761912177406201`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673615`"}], "-", 
        RowBox[{"0.3197620019224827`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284298`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636825`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526299`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.256429215818137`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558932`"}], "+", 
        RowBox[{"0.5761912177406188`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526295`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181357`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.295504524253051`"}], "-", 
        RowBox[{"0.1423074786230642`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526303`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813966`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.072983590296738`"}], "-", 
        RowBox[{"0.3197620019224835`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880283987`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636865`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530522`"}], "-", 
        RowBox[{"0.14230747862306325`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558923`"}], "+", 
        RowBox[{"0.5761912177406228`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526303`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813954`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589244`"}], "+", 
        RowBox[{"0.5761912177406225`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454979`"}], "-", 
        RowBox[{"0.46206948054554686`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673786`"}], "-", 
        RowBox[{"0.3197620019224834`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.532480753352629`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813893`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305185`"}], "+", 
        RowBox[{"0.14230747862306298`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558916`"}], "-", 
        RowBox[{"0.5761912177406215`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673779`"}], "+", 
        RowBox[{"0.31976200192248266`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558914`"}], "-", 
        RowBox[{"0.5761912177406215`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497893`"}], "+", 
        RowBox[{"0.46206948054554586`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880283935`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636842`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.532480753352629`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813893`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.0729835902967377`"}], "+", 
        RowBox[{"0.31976200192248283`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530516`"}], "+", 
        RowBox[{"0.14230747862306434`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589433`"}], "-", 
        RowBox[{"0.5761912177406218`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526315`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181378`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589455`"}], "-", 
        RowBox[{"0.5761912177406215`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497886`"}], "+", 
        RowBox[{"0.46206948054554814`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673693`"}], "+", 
        RowBox[{"0.31976200192248394`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526308`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813805`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673716`"}], "+", 
        RowBox[{"0.3197620019224838`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284215`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636855`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530509`"}], "-", 
        RowBox[{"0.14230747862306353`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558933`"}], "+", 
        RowBox[{"0.5761912177406198`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526301`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813755`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589305`"}], "+", 
        RowBox[{"0.5761912177406199`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497876`"}], "-", 
        RowBox[{"0.4620694805455464`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673686`"}], "-", 
        RowBox[{"0.3197620019224831`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526298`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813705`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673643`"}], "-", 
        RowBox[{"0.3197620019224829`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028417`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636841`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.32798527760568236`", ",", 
       RowBox[{"0.16399263880284323`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636862`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454979136`"}], "-", 
        RowBox[{"0.4620694805455467`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880283899`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636872`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061051`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305207`"}], "+", 
        RowBox[{"0.14230747862306498`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978864`"}], "+", 
        RowBox[{"0.46206948054554836`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305285`"}], "-", 
        RowBox[{"0.14230747862306306`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995797`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.736976229099579`"}], ",", 
       RowBox[{"0.13151188545021017`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406228`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694807`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813927`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021222`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406223`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568225`", ",", 
       RowBox[{"0.6639926388028426`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248216`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694885`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813843`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.663992638802841`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224846`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061043`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5910090485061045`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530529`"}], "-", 
        RowBox[{"0.14230747862306303`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284373`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636864`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530519`"}], "+", 
        RowBox[{"0.1423074786230644`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.73697622909958`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454979197`"}], "-", 
        RowBox[{"0.4620694805455467`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880283985`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636861`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497888`"}], "+", 
        RowBox[{"0.46206948054554847`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568247`"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284135`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636852`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021064`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406221`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305185`"}], "+", 
        RowBox[{"0.14230747862306398`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497891`"}], "+", 
        RowBox[{"0.4620694805455472`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305185`"}], "+", 
        RowBox[{"0.14230747862306387`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028417`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224826`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694857`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181384`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028417`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636857`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.368488114549789`"}], "+", 
        RowBox[{"0.4620694805455476`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284123`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636847`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497887`"}], "-", 
        RowBox[{"0.46206948054554675`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694837`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813805`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021042`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305146`"}], "-", 
        RowBox[{"0.1423074786230637`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284132`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636844`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530515`"}], "-", 
        RowBox[{"0.14230747862306375`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028407`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248216`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497882`"}], "-", 
        RowBox[{"0.4620694805455467`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673702`"}], "+", 
        RowBox[{"0.31976200192248344`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558924`"}], "+", 
        RowBox[{"0.576191217740623`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.591009048506104`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995786`"}], ",", 
       RowBox[{"0.5324807533526311`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813805`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.0729835902967381`"}], "-", 
        RowBox[{"0.31976200192248344`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526302`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181394`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.3279852776056823`", ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558945`"}], "-", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673707`"}], "-", 
        RowBox[{"0.3197620019224831`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995778`"}], ",", 
       RowBox[{"0.5324807533526291`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813893`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589133`"}], "-", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526297`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181374`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568097`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.591009048506103`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673791`"}], "+", 
        RowBox[{"0.3197620019224827`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589317`"}], "+", 
        RowBox[{"0.5761912177406199`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995793`"}], ",", 
       RowBox[{"0.1315118854502124`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406222`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694937`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181385`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545020998`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406227`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.3279852776056824`", ",", 
       RowBox[{"0.6639926388028415`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224858`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694812`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813954`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028432`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224822`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061047`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284218`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636855`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497888`"}], "+", 
        RowBox[{"0.4620694805455476`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.2044954757469487`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813855`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021014`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406224`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530519`"}], "+", 
        RowBox[{"0.14230747862306392`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284215`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636857`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305196`"}], "+", 
        RowBox[{"0.14230747862306428`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028422`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224824`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978886`"}], "+", 
        RowBox[{"0.4620694805455481`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284182`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636841`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1315118854502098`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305124`"}], "-", 
        RowBox[{"0.1423074786230637`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978836`"}], "-", 
        RowBox[{"0.46206948054554686`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305135`"}], "-", 
        RowBox[{"0.14230747862306367`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028405`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224816`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694832`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181379`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284168`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.718498696363684`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497877`"}], "-", 
        RowBox[{"0.4620694805455467`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.32798527760568214`", ",", 
       RowBox[{"0.663992638802841`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224846`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021003`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406227`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.663992638802842`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224824`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061044`"}], ",", 
       RowBox[{"0.20449547574694807`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181392`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021208`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.576191217740622`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.204495475746949`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181384`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995793`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1315118854502102`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406227`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568214`", ",", 
       RowBox[{"0.6639926388028412`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224844`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694787`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181392`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028423`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248244`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061044`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995789`"}], ",", 
       RowBox[{"0.13151188545021125`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406219`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.2044954757469487`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181385`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545020975`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406211`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.2044954757469473`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181385`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995775`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.32798527760568147`", ",", 
       RowBox[{"0.6639926388028407`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224817`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021125`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.576191217740621`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028398`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224835`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061028`"}], ",", 
       RowBox[{"0.20449547574694832`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813816`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.2044954757469481`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813916`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028413`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224848`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526316`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181379`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589483`"}], "-", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021256`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406227`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694793`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813966`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1315118854502122`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406223`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673676`"}], "+", 
        RowBox[{"0.3197620019224839`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028412`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224854`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694754`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813855`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589294`"}], "+", 
        RowBox[{"0.5761912177406193`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021184`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406207`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028391`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248366`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021203`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406201`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673654`"}], "-", 
        RowBox[{"0.3197620019224829`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526297`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813694`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.2044954757469471`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813855`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028389`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248416`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021206`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406222`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568225`", ",", 
       RowBox[{"0.6639926388028424`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.319762001922482`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694893`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181385`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028413`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.319762001922485`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061047`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995793`"}], ",", 
       RowBox[{"0.13151188545020984`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.576191217740623`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694785`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813954`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1315118854502116`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406208`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694843`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813766`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.736976229099577`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3279852776056813`", ",", 
       RowBox[{"0.663992638802839`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248383`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1315118854502093`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.576191217740621`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028405`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.319762001922481`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061025`"}], ",", 
       RowBox[{"0.20449547574694726`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813866`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.591009048506104`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305196`"}], "+", 
        RowBox[{"0.14230747862306398`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284007`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636861`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305207`"}], "-", 
        RowBox[{"0.1423074786230633`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995787`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978897`"}], "+", 
        RowBox[{"0.46206948054554753`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1639926388028416`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636852`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978997`"}], "-", 
        RowBox[{"0.46206948054554675`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.3279852776056821`"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497886`"}], "+", 
        RowBox[{"0.462069480545548`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305185`"}], "+", 
        RowBox[{"0.1423074786230644`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028426`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248194`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694882`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181384`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284234`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636856`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497887`"}], "+", 
        RowBox[{"0.4620694805455482`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284218`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636855`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020984`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406228`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.295504524253052`"}], "+", 
        RowBox[{"0.14230747862306437`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497879`"}], "-", 
        RowBox[{"0.46206948054554703`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694843`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.256429215818138`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284196`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636841`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.295504524253051`"}], "-", 
        RowBox[{"0.14230747862306395`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028421`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636839`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1315118854502097`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406212`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028405`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248083`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978775`"}], "-", 
        RowBox[{"0.46206948054554686`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.295504524253051`"}], "-", 
        RowBox[{"0.14230747862306392`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995796`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497888`"}], "+", 
        RowBox[{"0.46206948054554825`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.295504524253053`"}], "-", 
        RowBox[{"0.14230747862306303`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497906`"}], "-", 
        RowBox[{"0.4620694805455467`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568197`", ",", 
       RowBox[{"0.16399263880284298`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636864`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305207`"}], "+", 
        RowBox[{"0.1423074786230644`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880283968`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636868`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061048`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5910090485061047`"}], ",", 
       RowBox[{"0.204495475746948`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813954`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028432`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248194`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694904`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181384`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995796`"}], ",", 
       RowBox[{"0.1315118854502128`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406225`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028411`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224846`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021006`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406229`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568247`"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305196`"}], "+", 
        RowBox[{"0.14230747862306417`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028422`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224825`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497889`"}], "+", 
        RowBox[{"0.46206948054554786`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1639926388028425`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.718498696363686`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978886`"}], "+", 
        RowBox[{"0.46206948054554786`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694915`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181385`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545020986`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406228`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.295504524253052`"}], "+", 
        RowBox[{"0.1423074786230641`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284265`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636859`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305107`"}], "-", 
        RowBox[{"0.1423074786230637`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284204`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636836`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020953`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.576191217740621`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028405`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248194`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497878`"}], "-", 
        RowBox[{"0.46206948054554664`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.295504524253051`"}], "-", 
        RowBox[{"0.1423074786230639`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978764`"}], "-", 
        RowBox[{"0.46206948054554664`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694826`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181378`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028421`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636837`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.3279852776056822`", ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558924`"}], "+", 
        RowBox[{"0.5761912177406225`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526312`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181381`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589416`"}], "-", 
        RowBox[{"0.5761912177406215`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061041`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673802`"}], "-", 
        RowBox[{"0.31976200192248344`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526305`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813977`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673702`"}], "+", 
        RowBox[{"0.31976200192248355`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995794`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526311`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181381`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673775`"}], "-", 
        RowBox[{"0.31976200192248333`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995792`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3279852776056824`", ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558943`"}], "-", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526306`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581814015`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589194`"}], "+", 
        RowBox[{"0.5761912177406235`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061044`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673675`"}], "+", 
        RowBox[{"0.319762001922484`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.53248075335263`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181372`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568125`", ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558906`"}], "-", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.0729835902967377`"}], "+", 
        RowBox[{"0.3197620019224827`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589294`"}], "+", 
        RowBox[{"0.5761912177406201`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061029`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.736976229099577`"}], ",", 
       RowBox[{"0.5324807533526283`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813943`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673643`"}], "-", 
        RowBox[{"0.3197620019224828`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5910090485061043`"}], ",", 
       RowBox[{"0.20449547574694876`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181385`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028412`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224844`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694815`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181387`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995785`"}], ",", 
       RowBox[{"0.13151188545021059`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406221`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028417`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224828`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021159`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406221`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.3279852776056821`"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1315118854502124`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406223`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.0729835902967367`"}], "+", 
        RowBox[{"0.31976200192248405`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028412`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224857`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694804`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813916`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028413`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248516`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526318`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813766`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589516`"}], "-", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021283`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406228`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694785`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813977`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021203`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406204`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694743`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181386`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558932`"}], "+", 
        RowBox[{"0.5761912177406193`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673655`"}], "-", 
        RowBox[{"0.3197620019224827`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028389`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224839`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1315118854502123`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406197`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028384`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248433`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526297`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181366`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694676`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813843`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.2044954757469495`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813877`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284318`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636859`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497887`"}], "+", 
        RowBox[{"0.4620694805455485`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284265`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636861`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021011`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406227`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530515`"}], "+", 
        RowBox[{"0.14230747862306437`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497885`"}], "+", 
        RowBox[{"0.46206948054554836`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530524`"}], "+", 
        RowBox[{"0.1423074786230645`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028432`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248233`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694865`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813743`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284215`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636837`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.368488114549787`"}], "-", 
        RowBox[{"0.46206948054554636`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284226`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636832`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020953`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406211`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530509`"}], "-", 
        RowBox[{"0.14230747862306414`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.368488114549787`"}], "-", 
        RowBox[{"0.4620694805455469`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305057`"}], "-", 
        RowBox[{"0.14230747862306337`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028404`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248094`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589217`"}], "+", 
        RowBox[{"0.5761912177406224`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978986`"}], "-", 
        RowBox[{"0.46206948054554664`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673789`"}], "-", 
        RowBox[{"0.31976200192248333`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526303`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181394`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673779`"}], "-", 
        RowBox[{"0.3197620019224834`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284004`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636864`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530522`"}], "-", 
        RowBox[{"0.14230747862306317`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558921`"}], "+", 
        RowBox[{"0.5761912177406231`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526301`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813977`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589183`"}], "-", 
        RowBox[{"0.5761912177406218`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526291`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181389`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305185`"}], "+", 
        RowBox[{"0.14230747862306292`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978947`"}], "+", 
        RowBox[{"0.46206948054554586`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673762`"}], "+", 
        RowBox[{"0.31976200192248266`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558913`"}], "-", 
        RowBox[{"0.5761912177406218`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673779`"}], "+", 
        RowBox[{"0.319762001922483`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880283962`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636844`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526288`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813927`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5910090485061041`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673696`"}], "+", 
        RowBox[{"0.31976200192248344`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558921`"}], "+", 
        RowBox[{"0.5761912177406227`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.0729835902967379`"}], "-", 
        RowBox[{"0.3197620019224833`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995792`"}], ",", 
       RowBox[{"0.5324807533526311`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813805`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589416`"}], "-", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526303`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181399`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568214`"}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.52620667712547*^9, 3.5262067358546867`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1.`", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1.`", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1.`"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.32798527760568197`", ",", 
       RowBox[{"0.16399263880284023`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636859`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978864`"}], "+", 
        RowBox[{"0.46206948054554764`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.163992638802842`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636859`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061041`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305207`"}], "-", 
        RowBox[{"0.1423074786230634`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497906`"}], "-", 
        RowBox[{"0.4620694805455465`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530519`"}], "+", 
        RowBox[{"0.14230747862306387`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995795`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.532480753352631`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181378`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305257`"}], "-", 
        RowBox[{"0.14230747862306348`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028424`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224825`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694893`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181387`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558939`"}], "-", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497903`"}], "-", 
        RowBox[{"0.46206948054554675`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1639926388028401`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636864`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1315118854502103`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406225`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673661`"}], "+", 
        RowBox[{"0.3197620019224835`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526295`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813727`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694843`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181378`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028396`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636846`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530518`"}], "+", 
        RowBox[{"0.14230747862306284`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558927`"}], "+", 
        RowBox[{"0.5761912177406203`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1315118854502099`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406212`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028407`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248155`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978964`"}], "+", 
        RowBox[{"0.46206948054554553`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673687`"}], "-", 
        RowBox[{"0.3197620019224824`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9009688679024193`"}], "+", 
        RowBox[{"0.4338837391175599`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.6234898018587329`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.781831482468033`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.2225209339563179`"}], "-", 
        RowBox[{"0.9749279121818252`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9009688679024177`"}], "-", 
        RowBox[{"0.4338837391175591`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.6234898018587303`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824680297`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395631686`"}], "+", 
        RowBox[{"0.9749279121818207`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5910090485061039`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673793`"}], "-", 
        RowBox[{"0.3197620019224834`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589405`"}], "-", 
        RowBox[{"0.5761912177406212`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673707`"}], "+", 
        RowBox[{"0.3197620019224835`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995792`"}], ",", 
       RowBox[{"0.5324807533526303`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181398`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558922`"}], "+", 
        RowBox[{"0.5761912177406228`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526311`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813793`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568225`"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.6234898018587351`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824680299`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.2225209339563134`"}], "+", 
        RowBox[{"0.9749279121818247`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9009688679024204`"}], "-", 
        RowBox[{"0.4338837391175575`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024188`"}], "+", 
        RowBox[{"0.4338837391175568`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6234898018587338`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7818314824680282`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.222520933956313`"}], "-", 
        RowBox[{"0.9749279121818231`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497888`"}], "+", 
        RowBox[{"0.46206948054554786`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568214`", ",", 
       RowBox[{"0.16399263880283974`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636864`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305246`"}], "-", 
        RowBox[{"0.1423074786230631`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028424`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636857`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061045`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995795`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454979097`"}], "-", 
        RowBox[{"0.46206948054554686`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.295504524253052`"}], "+", 
        RowBox[{"0.14230747862306445`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497879`"}], "-", 
        RowBox[{"0.46206948054554686`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305185`"}], "+", 
        RowBox[{"0.14230747862306276`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995768`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3279852776056816`", ",", 
       RowBox[{"0.16399263880284182`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636836`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497895`"}], "+", 
        RowBox[{"0.46206948054554514`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1639926388028393`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636842`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061027`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530508`"}], "-", 
        RowBox[{"0.14230747862306395`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558924`"}], "+", 
        RowBox[{"0.5761912177406229`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526307`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813816`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568214`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5910090485061048`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673814`"}], "-", 
        RowBox[{"0.3197620019224838`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558947`"}], "-", 
        RowBox[{"0.5761912177406218`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673633`"}], "+", 
        RowBox[{"0.3197620019224841`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.73697622909958`"}], ",", 
       RowBox[{"0.5324807533526306`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181407`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589133`"}], "-", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061024`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673612`"}], "-", 
        RowBox[{"0.3197620019224825`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526297`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813777`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673801`"}], "+", 
        RowBox[{"0.3197620019224825`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995765`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3279852776056815`", ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589294`"}], "+", 
        RowBox[{"0.5761912177406195`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.532480753352628`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181396`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6234898018587334`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.781831482468031`", " ", "\[ImaginaryI]"}]}], ",", "0", ",",
        "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395631517`"}], "-", 
        RowBox[{"0.974927912181824`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024195`"}], "+", 
        RowBox[{"0.4338837391175594`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6234898018587323`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824680297`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395631495`"}], "+", 
        RowBox[{"0.974927912181823`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024179`"}], "-", 
        RowBox[{"0.4338837391175586`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395631306`"}], "+", 
        RowBox[{"0.9749279121818255`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024217`"}], "-", 
        RowBox[{"0.4338837391175567`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.623489801858735`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824680295`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.6234898018587341`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7818314824680284`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.22252093395631237`"}], "-", 
        RowBox[{"0.9749279121818225`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024187`"}], "+", 
        RowBox[{"0.43388373911755523`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673782`"}], "-", 
        RowBox[{"0.3197620019224833`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589233`"}], "+", 
        RowBox[{"0.5761912177406227`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454979`"}], "-", 
        RowBox[{"0.46206948054554675`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1639926388028402`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636859`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526303`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813943`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673777`"}], "-", 
        RowBox[{"0.31976200192248344`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526302`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181395`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305235`"}], "-", 
        RowBox[{"0.14230747862306314`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558923`"}], "+", 
        RowBox[{"0.576191217740623`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673776`"}], "+", 
        RowBox[{"0.31976200192248283`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028399`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636846`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526292`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813904`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558915`"}], "-", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526292`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181389`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530517`"}], "+", 
        RowBox[{"0.14230747862306287`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978936`"}], "+", 
        RowBox[{"0.4620694805455459`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673768`"}], "+", 
        RowBox[{"0.31976200192248266`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558912`"}], "-", 
        RowBox[{"0.5761912177406215`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.900968867902421`"}], "-", 
        RowBox[{"0.43388373911755745`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.6234898018587359`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824680298`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.22252093395631362`"}], "+", 
        RowBox[{"0.9749279121818246`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395631325`"}], "-", 
        RowBox[{"0.9749279121818231`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9009688679024185`"}], "+", 
        RowBox[{"0.43388373911755623`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.623489801858734`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7818314824680275`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.22252093395631362`"}], "+", 
        RowBox[{"0.9749279121818244`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.900968867902421`"}], "-", 
        RowBox[{"0.4338837391175573`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.6234898018587363`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824680298`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.22252093395631334`"}], "-", 
        RowBox[{"0.9749279121818233`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024186`"}], "+", 
        RowBox[{"0.4338837391175561`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.6234898018587341`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7818314824680271`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.2044954757469485`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813843`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558932`"}], "-", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978964`"}], "-", 
        RowBox[{"0.46206948054554664`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284018`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.718498696363686`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1315118854502104`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406225`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673704`"}], "+", 
        RowBox[{"0.3197620019224836`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526311`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813793`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530524`"}], "-", 
        RowBox[{"0.14230747862306312`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028423`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224823`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694843`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181384`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880283987`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636845`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526298`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181372`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558929`"}], "+", 
        RowBox[{"0.576191217740621`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020998`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406212`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305157`"}], "+", 
        RowBox[{"0.14230747862306276`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497894`"}], "+", 
        RowBox[{"0.46206948054554625`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673679`"}], "-", 
        RowBox[{"0.3197620019224827`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028404`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248155`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "1.0000000000000013`", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1.0000000000000016`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.0000000000000007`", ",", "0", ",", "0"}], "}"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0.9999999999999993`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999999987`", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0.9999999999999984`", ",", "0"}], "}"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.623489801858733`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7818314824680325`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395631756`"}], "-", 
        RowBox[{"0.9749279121818253`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9009688679024195`"}], "+", 
        RowBox[{"0.43388373911756023`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024173`"}], "-", 
        RowBox[{"0.4338837391175592`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6234898018587308`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824680297`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395631653`"}], "+", 
        RowBox[{"0.9749279121818207`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.6234898018587381`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824680295`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.22252093395631212`"}], "+", 
        RowBox[{"0.9749279121818261`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024235`"}], "-", 
        RowBox[{"0.43388373911755596`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395631128`"}], "-", 
        RowBox[{"0.9749279121818224`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024181`"}], "+", 
        RowBox[{"0.43388373911755335`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6234898018587349`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7818314824680254`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558937`"}], "-", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978897`"}], "+", 
        RowBox[{"0.4620694805455479`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673678`"}], "+", 
        RowBox[{"0.3197620019224837`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526315`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813805`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673686`"}], "+", 
        RowBox[{"0.319762001922484`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284304`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636862`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530519`"}], "+", 
        RowBox[{"0.14230747862306453`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558953`"}], "-", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526322`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813743`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.459497163055893`"}], "+", 
        RowBox[{"0.5761912177406205`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526297`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813716`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305074`"}], "-", 
        RowBox[{"0.14230747862306398`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978797`"}], "-", 
        RowBox[{"0.46206948054554664`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673654`"}], "-", 
        RowBox[{"0.3197620019224827`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589305`"}], "+", 
        RowBox[{"0.5761912177406189`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673661`"}], "-", 
        RowBox[{"0.31976200192248294`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284226`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636831`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526298`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181362`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028422`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224821`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020992`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.576191217740623`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673829`"}], "-", 
        RowBox[{"0.3197620019224835`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526302`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181393`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694896`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181385`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028422`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248216`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694887`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813843`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558924`"}], "+", 
        RowBox[{"0.5761912177406234`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020984`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406229`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028407`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224816`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526292`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813904`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694846`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181378`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545020934`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.576191217740621`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.2044954757469483`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181378`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558908`"}], "-", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673818`"}], "+", 
        RowBox[{"0.3197620019224825`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028405`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248144`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020936`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.576191217740621`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395631278`"}], "+", 
        RowBox[{"0.9749279121818261`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9009688679024218`"}], "-", 
        RowBox[{"0.4338837391175569`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.6234898018587351`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824680298`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024184`"}], "+", 
        RowBox[{"0.43388373911755523`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.6234898018587339`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7818314824680282`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.22252093395631187`"}], "-", 
        RowBox[{"0.9749279121818221`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028423`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224824`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061046`"}], ",", 
       RowBox[{"0.204495475746948`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813927`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021236`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406224`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694932`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181385`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995797`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3279852776056822`", ",", 
       RowBox[{"0.6639926388028412`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248494`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020986`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406229`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028404`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248166`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021197`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406202`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568147`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5910090485061026`"}], ",", 
       RowBox[{"0.20449547574694843`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813743`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028392`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248383`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694726`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181385`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995766`"}], ",", 
       RowBox[{"0.13151188545020948`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406211`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028417`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224825`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978886`"}], "+", 
        RowBox[{"0.4620694805455477`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530518`"}], "+", 
        RowBox[{"0.14230747862306414`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978897`"}], "+", 
        RowBox[{"0.46206948054554825`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694904`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813855`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284273`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.718498696363686`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305196`"}], "+", 
        RowBox[{"0.1423074786230645`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.163992638802843`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636861`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020967`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406233`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028408`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248194`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978786`"}], "-", 
        RowBox[{"0.46206948054554664`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530509`"}], "-", 
        RowBox[{"0.14230747862306403`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497883`"}], "-", 
        RowBox[{"0.4620694805455469`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694843`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813766`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028423`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636831`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530514`"}], "-", 
        RowBox[{"0.1423074786230639`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284204`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636834`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020903`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406209`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673777`"}], "-", 
        RowBox[{"0.3197620019224833`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028418`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636855`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021159`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.576191217740622`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028414`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248483`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526307`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181398`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.295504524253052`"}], "+", 
        RowBox[{"0.14230747862306428`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978875`"}], "+", 
        RowBox[{"0.4620694805455485`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694796`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181395`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589206`"}], "+", 
        RowBox[{"0.5761912177406239`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673773`"}], "+", 
        RowBox[{"0.31976200192248283`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028392`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248366`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978736`"}], "-", 
        RowBox[{"0.46206948054554675`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284146`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636842`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526287`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813893`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694718`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813855`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021145`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406212`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305107`"}], "-", 
        RowBox[{"0.14230747862306378`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589033`"}], "-", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558926`"}], "+", 
        RowBox[{"0.5761912177406227`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021145`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406219`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.295504524253052`"}], "+", 
        RowBox[{"0.14230747862306406`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978886`"}], "+", 
        RowBox[{"0.4620694805455472`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673818`"}], "-", 
        RowBox[{"0.31976200192248294`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028411`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248394`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.2044954757469482`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813904`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284173`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636858`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526299`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813943`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558917`"}], "-", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497885`"}], "-", 
        RowBox[{"0.4620694805455466`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694743`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813866`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021122`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406209`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.0729835902967374`"}], "+", 
        RowBox[{"0.31976200192248266`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284176`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636846`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305135`"}], "-", 
        RowBox[{"0.14230747862306392`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028402`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224838`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526291`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181384`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1315118854502099`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406235`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673872`"}], "-", 
        RowBox[{"0.31976200192248355`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028435`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248166`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694937`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181382`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028425`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224825`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526303`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181401`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589206`"}], "+", 
        RowBox[{"0.5761912177406238`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020967`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.576191217740623`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.2044954757469496`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813893`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1315118854502088`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406209`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694826`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813755`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558904`"}], "-", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673816`"}], "+", 
        RowBox[{"0.3197620019224819`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028407`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224814`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1315118854502094`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406208`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.66399263880284`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224802`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526285`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813916`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694907`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813716`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497903`"}], "-", 
        RowBox[{"0.46206948054554653`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673675`"}], "+", 
        RowBox[{"0.3197620019224838`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.663992638802843`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248194`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694907`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181383`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028396`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636862`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526317`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813766`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558942`"}], "-", 
        RowBox[{"0.5761912177406212`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1315118854502099`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.576191217740623`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530526`"}], "-", 
        RowBox[{"0.14230747862306314`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497899`"}], "+", 
        RowBox[{"0.4620694805455454`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694854`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813805`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558931`"}], "+", 
        RowBox[{"0.5761912177406201`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673662`"}], "-", 
        RowBox[{"0.31976200192248283`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880283915`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636844`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020948`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406211`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028403`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224809`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526297`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813666`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530515`"}], "+", 
        RowBox[{"0.14230747862306223`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694812`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181391`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589233`"}], "+", 
        RowBox[{"0.576191217740623`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.368488114549789`"}], "+", 
        RowBox[{"0.4620694805455478`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1639926388028429`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636861`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021247`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406225`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673826`"}], "-", 
        RowBox[{"0.3197620019224836`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526303`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813977`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305185`"}], "+", 
        RowBox[{"0.14230747862306425`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028411`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224848`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.2044954757469476`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181384`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284215`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636832`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.532480753352629`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181392`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558911`"}], "-", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021203`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406203`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305124`"}], "-", 
        RowBox[{"0.14230747862306392`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978797`"}], "-", 
        RowBox[{"0.46206948054554664`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.072983590296738`"}], "+", 
        RowBox[{"0.31976200192248244`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028394`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224839`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028428`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248205`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497913`"}], "-", 
        RowBox[{"0.46206948054554664`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.0729835902967365`"}], "+", 
        RowBox[{"0.3197620019224841`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526309`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181379`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694898`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181384`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880283949`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636865`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305257`"}], "-", 
        RowBox[{"0.14230747862306317`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589494`"}], "-", 
        RowBox[{"0.5761912177406215`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020975`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406233`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028405`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248094`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.53248075335263`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181375`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305146`"}], "+", 
        RowBox[{"0.14230747862306276`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978975`"}], "+", 
        RowBox[{"0.4620694805455447`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694857`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181377`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589294`"}], "+", 
        RowBox[{"0.5761912177406193`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673619`"}], "-", 
        RowBox[{"0.31976200192248255`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880283904`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636844`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020906`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406209`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.2044954757469481`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813916`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558943`"}], "-", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021206`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406223`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028409`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224839`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021153`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406219`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673704`"}], "+", 
        RowBox[{"0.3197620019224835`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526309`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813816`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694812`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181391`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028412`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224846`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694754`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181383`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028403`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224836`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526299`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181376`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589283`"}], "+", 
        RowBox[{"0.57619121774062`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021136`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406212`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694765`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181385`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021175`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406207`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673684`"}], "-", 
        RowBox[{"0.319762001922483`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028395`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248366`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526309`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813793`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694896`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181385`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028396`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636861`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530522`"}], "-", 
        RowBox[{"0.14230747862306328`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558944`"}], "-", 
        RowBox[{"0.5761912177406215`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021014`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406225`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028419`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224825`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454979047`"}], "-", 
        RowBox[{"0.46206948054554686`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.0729835902967368`"}], "+", 
        RowBox[{"0.3197620019224837`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.53248075335263`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181375`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305185`"}], "+", 
        RowBox[{"0.14230747862306298`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028405`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.319762001922482`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.2044954757469485`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181377`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558929`"}], "+", 
        RowBox[{"0.57619121774062`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978947`"}], "+", 
        RowBox[{"0.4620694805455453`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880283937`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636846`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020956`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406212`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673686`"}], "-", 
        RowBox[{"0.3197620019224829`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995787`"}], ",", 
       RowBox[{"0.5324807533526302`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813927`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673694`"}], "+", 
        RowBox[{"0.3197620019224836`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526309`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813805`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.3279852776056822`", ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589217`"}], "+", 
        RowBox[{"0.576191217740623`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673787`"}], "-", 
        RowBox[{"0.3197620019224834`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589433`"}], "-", 
        RowBox[{"0.5761912177406215`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061045`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694885`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813843`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995793`"}], ",", 
       RowBox[{"0.13151188545021242`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406224`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028412`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248505`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1315118854502099`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406232`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.3279852776056825`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5910090485061045`"}], ",", 
       RowBox[{"0.20449547574694799`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181395`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028431`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224817`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694843`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181378`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.663992638802839`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248394`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061029`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995768`"}], ",", 
       RowBox[{"0.13151188545020925`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406209`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694737`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181386`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1315118854502121`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406203`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568114`", ",", 
       RowBox[{"0.6639926388028404`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224805`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545020975`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406228`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.295504524253052`"}], "+", 
        RowBox[{"0.14230747862306403`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284237`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636859`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305196`"}], "+", 
        RowBox[{"0.14230747862306403`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028424`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248244`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497886`"}], "+", 
        RowBox[{"0.462069480545548`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1639926388028424`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636857`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978847`"}], "+", 
        RowBox[{"0.46206948054554786`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694849`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181386`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545020948`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.576191217740621`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305124`"}], "-", 
        RowBox[{"0.1423074786230636`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284215`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.718498696363684`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305124`"}], "-", 
        RowBox[{"0.14230747862306353`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028408`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224814`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978786`"}], "-", 
        RowBox[{"0.4620694805455467`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284207`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636839`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497879`"}], "-", 
        RowBox[{"0.4620694805455467`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.2044954757469483`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813805`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673684`"}], "+", 
        RowBox[{"0.3197620019224838`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880283962`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636864`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020995`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406227`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028433`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248183`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526319`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813755`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305274`"}], "-", 
        RowBox[{"0.14230747862306295`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454979086`"}], "-", 
        RowBox[{"0.46206948054554664`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.2044954757469493`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813843`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589494`"}], "-", 
        RowBox[{"0.5761912177406212`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673662`"}], "-", 
        RowBox[{"0.31976200192248283`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028404`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224806`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978964`"}], "+", 
        RowBox[{"0.46206948054554475`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1639926388028393`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636845`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526297`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181364`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694857`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181376`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545020948`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406212`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305157`"}], "+", 
        RowBox[{"0.1423074786230623`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558933`"}], "+", 
        RowBox[{"0.5761912177406195`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.32798527760568186`", ",", 
       RowBox[{"-", "0.7369762290995784`"}], ",", 
       RowBox[{"-", "0.5910090485061038`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995789`"}], ",", 
       RowBox[{"-", "0.5910090485061043`"}], ",", "0.3279852776056821`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5910090485061044`"}], ",", "0.3279852776056822`", ",", 
       
       RowBox[{"-", "0.736976229099579`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995796`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497915`"}], "-", 
        RowBox[{"0.4620694805455467`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530521`"}], "+", 
        RowBox[{"0.14230747862306498`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978864`"}], "+", 
        RowBox[{"0.4620694805455485`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568236`", ",", 
       RowBox[{"0.16399263880283915`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636871`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530528`"}], "-", 
        RowBox[{"0.14230747862306287`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284318`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636861`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061051`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558939`"}], "-", 
        RowBox[{"0.5761912177406213`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526301`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181397`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568214`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5910090485061044`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673684`"}], "+", 
        RowBox[{"0.3197620019224838`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589233`"}], "+", 
        RowBox[{"0.5761912177406235`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673827`"}], "-", 
        RowBox[{"0.3197620019224835`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995794`"}], ",", 
       RowBox[{"0.5324807533526318`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181375`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558932`"}], "+", 
        RowBox[{"0.5761912177406203`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061028`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673814`"}], "+", 
        RowBox[{"0.31976200192248244`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526292`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813916`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673661`"}], "-", 
        RowBox[{"0.31976200192248283`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995769`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3279852776056813`", ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558906`"}], "-", 
        RowBox[{"0.5761912177406215`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526297`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813655`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.3279852776056823`", ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589466`"}], "-", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526302`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181398`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558924`"}], "+", 
        RowBox[{"0.5761912177406227`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061043`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673707`"}], "+", 
        RowBox[{"0.3197620019224836`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526312`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813793`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.0729835902967382`"}], "-", 
        RowBox[{"0.31976200192248333`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995794`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673808`"}], "-", 
        RowBox[{"0.31976200192248355`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589455`"}], "-", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061047`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995793`"}], ",", 
       RowBox[{"0.5324807533526305`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581814027`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673672`"}], "+", 
        RowBox[{"0.31976200192248394`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526312`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181379`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568225`", ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589194`"}], "+", 
        RowBox[{"0.5761912177406237`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673765`"}], "+", 
        RowBox[{"0.3197620019224826`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995769`"}], ",", 
       RowBox[{"0.5324807533526301`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813716`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558929`"}], "+", 
        RowBox[{"0.5761912177406197`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526286`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181395`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.3279852776056813`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5910090485061025`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673634`"}], "-", 
        RowBox[{"0.3197620019224827`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589056`"}], "-", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284135`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636851`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061039`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305207`"}], "-", 
        RowBox[{"0.1423074786230633`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978975`"}], "-", 
        RowBox[{"0.46206948054554675`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305185`"}], "+", 
        RowBox[{"0.14230747862306387`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995788`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.32798527760568197`", ",", 
       RowBox[{"0.16399263880284032`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636859`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.368488114549789`"}], "+", 
        RowBox[{"0.46206948054554753`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284118`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636848`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978936`"}], "+", 
        RowBox[{"0.46206948054554614`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.3279852776056816`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5910090485061033`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305135`"}], "-", 
        RowBox[{"0.14230747862306364`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028401`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636846`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305185`"}], "+", 
        RowBox[{"0.14230747862306317`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995775`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978825`"}], "-", 
        RowBox[{"0.46206948054554664`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305224`"}], "-", 
        RowBox[{"0.1423074786230632`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028419`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248244`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526308`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813805`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558952`"}], "-", 
        RowBox[{"0.5761912177406218`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454979125`"}], "-", 
        RowBox[{"0.4620694805455469`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.2044954757469494`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813855`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545020925`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406239`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.0729835902967364`"}], "+", 
        RowBox[{"0.31976200192248433`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880283876`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636878`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305174`"}], "+", 
        RowBox[{"0.142307478623063`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589294`"}], "+", 
        RowBox[{"0.576191217740619`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1315118854502084`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406204`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028408`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.319762001922482`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978947`"}], "+", 
        RowBox[{"0.4620694805455446`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673591`"}], "-", 
        RowBox[{"0.3197620019224825`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526299`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181375`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694849`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181374`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028379`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636836`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978914`"}], "+", 
        RowBox[{"0.4620694805455471`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673772`"}], "-", 
        RowBox[{"0.31976200192248333`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.663992638802841`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224845`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694815`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181387`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284168`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636856`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526303`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181395`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589244`"}], "+", 
        RowBox[{"0.5761912177406221`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021153`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406221`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305185`"}], "+", 
        RowBox[{"0.1423074786230641`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497887`"}], "-", 
        RowBox[{"0.46206948054554675`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694807`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813843`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558921`"}], "-", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673769`"}], "+", 
        RowBox[{"0.31976200192248283`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284132`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636844`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1315118854502114`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406211`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028397`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224837`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526292`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813904`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530513`"}], "-", 
        RowBox[{"0.14230747862306384`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589317`"}], "-", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021056`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406221`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.295504524253052`"}], "-", 
        RowBox[{"0.1423074786230634`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497895`"}], "-", 
        RowBox[{"0.4620694805455467`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673711`"}], "+", 
        RowBox[{"0.31976200192248333`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028414`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224827`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694854`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181384`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028404`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636854`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526306`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813827`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589283`"}], "+", 
        RowBox[{"0.5761912177406211`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497894`"}], "+", 
        RowBox[{"0.4620694805455463`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.2044954757469484`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181383`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021048`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673708`"}], "-", 
        RowBox[{"0.3197620019224831`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028403`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.718498696363685`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305174`"}], "+", 
        RowBox[{"0.14230747862306306`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028407`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248244`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526301`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.256429215818138`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694887`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813855`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028412`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224846`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061043`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995795`"}], ",", 
       RowBox[{"0.13151188545020975`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406227`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.2044954757469482`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813893`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1315118854502127`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406221`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568197`", ",", 
       RowBox[{"0.6639926388028428`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224823`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694835`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.256429215818138`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995773`"}], ",", 
       RowBox[{"0.13151188545021197`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406202`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028394`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224842`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020978`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.576191217740621`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568136`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5910090485061026`"}], ",", 
       RowBox[{"0.2044954757469476`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181385`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028408`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248094`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284018`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636858`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021036`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406222`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.072983590296737`"}], "+", 
        RowBox[{"0.31976200192248344`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526312`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813805`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305246`"}], "-", 
        RowBox[{"0.14230747862306325`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028423`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248244`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.2044954757469491`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813843`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589433`"}], "-", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497906`"}], "-", 
        RowBox[{"0.4620694805455466`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880283987`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636847`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526297`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813727`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694846`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181378`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1315118854502102`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530516`"}], "+", 
        RowBox[{"0.14230747862306278`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589317`"}], "+", 
        RowBox[{"0.57619121774062`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673683`"}], "-", 
        RowBox[{"0.31976200192248283`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028404`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248155`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497897`"}], "+", 
        RowBox[{"0.4620694805455453`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526313`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181378`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673668`"}], "+", 
        RowBox[{"0.3197620019224838`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284315`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636859`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530516`"}], "+", 
        RowBox[{"0.14230747862306398`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589405`"}], "-", 
        RowBox[{"0.5761912177406215`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526313`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181378`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589405`"}], "-", 
        RowBox[{"0.5761912177406215`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.368488114549789`"}], "+", 
        RowBox[{"0.4620694805455481`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673666`"}], "+", 
        RowBox[{"0.3197620019224838`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526299`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813705`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530514`"}], "-", 
        RowBox[{"0.14230747862306392`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558929`"}], "+", 
        RowBox[{"0.5761912177406203`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.0729835902967365`"}], "-", 
        RowBox[{"0.31976200192248294`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589283`"}], "+", 
        RowBox[{"0.5761912177406201`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497877`"}], "-", 
        RowBox[{"0.4620694805455466`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284254`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636832`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526299`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813705`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673643`"}], "-", 
        RowBox[{"0.31976200192248294`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880283932`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636872`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061046`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530522`"}], "+", 
        RowBox[{"0.1423074786230645`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978864`"}], "+", 
        RowBox[{"0.462069480545549`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305296`"}], "-", 
        RowBox[{"0.14230747862306314`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995799`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3279852776056821`", ",", 
       RowBox[{"0.16399263880284304`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636861`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497911`"}], "-", 
        RowBox[{"0.46206948054554664`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880283857`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636841`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497866`"}], "-", 
        RowBox[{"0.4620694805455468`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568086`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.591009048506102`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305157`"}], "+", 
        RowBox[{"0.14230747862306217`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284248`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636835`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305085`"}], "-", 
        RowBox[{"0.14230747862306417`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995762`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978975`"}], "+", 
        RowBox[{"0.46206948054554464`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558951`"}], "-", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021275`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406228`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.2044954757469479`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181399`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021228`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406223`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.0729835902967367`"}], "+", 
        RowBox[{"0.3197620019224839`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028411`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224855`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.2044954757469481`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813927`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028414`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224853`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526319`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181377`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.459497163055893`"}], "+", 
        RowBox[{"0.5761912177406191`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.131511885450212`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406207`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694732`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813843`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021228`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406199`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673644`"}], "-", 
        RowBox[{"0.31976200192248283`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028388`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224839`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694688`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181385`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028387`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248433`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526297`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181365`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028409`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248416`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497889`"}], "+", 
        RowBox[{"0.46206948054554764`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673798`"}], "-", 
        RowBox[{"0.3197620019224832`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526305`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813977`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.204495475746948`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813927`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284262`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636859`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305185`"}], "+", 
        RowBox[{"0.14230747862306437`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589217`"}], "+", 
        RowBox[{"0.5761912177406238`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021253`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406225`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.66399263880284`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224837`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.532480753352629`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813904`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530509`"}], "-", 
        RowBox[{"0.1423074786230639`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978814`"}], "-", 
        RowBox[{"0.46206948054554675`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694743`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813855`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558904`"}], "-", 
        RowBox[{"0.5761912177406213`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673789`"}], "+", 
        RowBox[{"0.3197620019224829`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.163992638802842`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636835`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1315118854502121`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406203`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021036`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406223`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673684`"}], "+", 
        RowBox[{"0.3197620019224836`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880283965`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636865`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530521`"}], "-", 
        RowBox[{"0.14230747862306314`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028424`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248244`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526315`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181379`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589355`"}], "-", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454979036`"}], "-", 
        RowBox[{"0.46206948054554686`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694904`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181383`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021003`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406213`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305174`"}], "+", 
        RowBox[{"0.142307478623063`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589305`"}], "+", 
        RowBox[{"0.5761912177406208`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673665`"}], "-", 
        RowBox[{"0.3197620019224829`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028403`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248155`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978936`"}], "+", 
        RowBox[{"0.4620694805455454`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880283924`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636842`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526297`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181369`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694854`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813777`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284318`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636864`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526316`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181376`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673666`"}], "+", 
        RowBox[{"0.31976200192248405`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526309`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181379`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530515`"}], "+", 
        RowBox[{"0.14230747862306434`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558943`"}], "-", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673672`"}], "+", 
        RowBox[{"0.31976200192248405`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558948`"}], "-", 
        RowBox[{"0.5761912177406218`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497885`"}], "+", 
        RowBox[{"0.4620694805455481`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284232`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636832`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526297`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813716`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673632`"}], "-", 
        RowBox[{"0.31976200192248266`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526295`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181365`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.295504524253051`"}], "-", 
        RowBox[{"0.1423074786230638`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589317`"}], "+", 
        RowBox[{"0.5761912177406198`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673618`"}], "-", 
        RowBox[{"0.3197620019224827`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589333`"}], "+", 
        RowBox[{"0.5761912177406204`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978736`"}], "-", 
        RowBox[{"0.4620694805455465`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305207`"}], "-", 
        RowBox[{"0.14230747862306328`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028411`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224847`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497906`"}], "-", 
        RowBox[{"0.46206948054554664`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1639926388028399`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636864`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497907`"}], "-", 
        RowBox[{"0.4620694805455469`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.204495475746948`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813943`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1315118854502122`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406223`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530526`"}], "-", 
        RowBox[{"0.14230747862306306`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880283915`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.718498696363687`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530518`"}], "+", 
        RowBox[{"0.14230747862306298`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880283949`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636841`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021184`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406207`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028395`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248383`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978947`"}], "+", 
        RowBox[{"0.4620694805455451`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305157`"}], "+", 
        RowBox[{"0.1423074786230626`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978964`"}], "+", 
        RowBox[{"0.4620694805455453`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694732`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181385`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028386`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.718498696363684`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978914`"}], "+", 
        RowBox[{"0.46206948054554703`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530519`"}], "-", 
        RowBox[{"0.14230747862306337`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995785`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.32798527760568186`", ",", 
       RowBox[{"0.16399263880284135`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636851`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978975`"}], "-", 
        RowBox[{"0.46206948054554675`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284048`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636857`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061039`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305185`"}], "+", 
        RowBox[{"0.14230747862306384`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497888`"}], "-", 
        RowBox[{"0.46206948054554675`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568164`", ",", 
       RowBox[{"0.16399263880284032`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636847`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530519`"}], "+", 
        RowBox[{"0.14230747862306342`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028412`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636846`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061033`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995778`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978936`"}], "+", 
        RowBox[{"0.4620694805455463`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530514`"}], "-", 
        RowBox[{"0.14230747862306367`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.32798527760568214`", ",", 
       RowBox[{"0.663992638802842`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224823`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021175`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.576191217740622`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028411`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248455`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061043`"}], ",", 
       RowBox[{"0.20449547574694882`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181384`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1315118854502098`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406225`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694826`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181393`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995792`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995794`"}], ",", 
       RowBox[{"-", "0.5910090485061046`"}], ",", "0.32798527760568236`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5910090485061046`"}], ",", "0.3279852776056822`", ",", 
       
       RowBox[{"-", "0.7369762290995794`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.32798527760568197`", ",", 
       RowBox[{"-", "0.7369762290995788`"}], ",", 
       RowBox[{"-", "0.5910090485061043`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305224`"}], "-", 
        RowBox[{"0.14230747862306323`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589394`"}], "-", 
        RowBox[{"0.5761912177406215`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021003`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406225`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028421`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248255`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497905`"}], "-", 
        RowBox[{"0.4620694805455469`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673682`"}], "+", 
        RowBox[{"0.31976200192248383`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526315`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813793`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694915`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181385`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880283943`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636867`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530518`"}], "+", 
        RowBox[{"0.14230747862306298`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028404`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224818`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526298`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181371`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558929`"}], "+", 
        RowBox[{"0.5761912177406202`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497893`"}], "+", 
        RowBox[{"0.46206948054554536`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694837`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813755`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1315118854502097`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406213`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673661`"}], "-", 
        RowBox[{"0.3197620019224829`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880283887`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636841`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1315118854502124`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406225`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673826`"}], "-", 
        RowBox[{"0.31976200192248355`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284282`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636861`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530518`"}], "+", 
        RowBox[{"0.14230747862306461`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028412`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224856`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526305`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581814043`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589217`"}], "+", 
        RowBox[{"0.5761912177406229`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978886`"}], "+", 
        RowBox[{"0.4620694805455477`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694793`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813904`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1315118854502119`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406204`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305074`"}], "-", 
        RowBox[{"0.14230747862306414`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558912`"}], "-", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673801`"}], "+", 
        RowBox[{"0.3197620019224825`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028388`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248433`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497881`"}], "-", 
        RowBox[{"0.46206948054554686`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284207`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636834`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526282`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181395`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.2044954757469477`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181387`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028421`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248255`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1315118854502117`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.576191217740622`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.3279852776056821`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5910090485061043`"}], ",", 
       RowBox[{"0.20449547574694857`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813855`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028411`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224844`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.2044954757469481`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181392`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995789`"}], ",", 
       RowBox[{"0.1315118854502101`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406227`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028407`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224819`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061028`"}], ",", 
       RowBox[{"0.20449547574694754`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813827`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021142`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.576191217740621`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.2044954757469484`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813816`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995773`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3279852776056815`", ",", 
       RowBox[{"0.6639926388028398`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224836`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020961`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406211`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995794`"}], ",", 
       RowBox[{"0.5324807533526316`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181378`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673833`"}], "-", 
        RowBox[{"0.31976200192248355`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526301`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181392`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568214`", ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558943`"}], "-", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.0729835902967369`"}], "+", 
        RowBox[{"0.3197620019224837`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558923`"}], "+", 
        RowBox[{"0.5761912177406233`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061046`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028412`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224851`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1315118854502123`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406221`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673669`"}], "+", 
        RowBox[{"0.319762001922484`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526308`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.256429215818138`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694782`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813927`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028414`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224848`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694815`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181394`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589444`"}], "-", 
        RowBox[{"0.576191217740622`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021233`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406221`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028395`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224842`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526296`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181374`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694726`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181385`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1315118854502119`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406203`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694749`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181382`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589317`"}], "+", 
        RowBox[{"0.5761912177406199`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673623`"}], "-", 
        RowBox[{"0.3197620019224827`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028395`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248394`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021164`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406201`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673701`"}], "+", 
        RowBox[{"0.3197620019224835`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589444`"}], "-", 
        RowBox[{"0.5761912177406215`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497888`"}], "+", 
        RowBox[{"0.46206948054554803`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1639926388028421`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636856`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526316`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813793`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.0729835902967368`"}], "+", 
        RowBox[{"0.31976200192248383`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526311`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813805`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305207`"}], "+", 
        RowBox[{"0.14230747862306448`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589483`"}], "-", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673687`"}], "-", 
        RowBox[{"0.31976200192248316`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284165`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636841`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526297`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181372`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589294`"}], "+", 
        RowBox[{"0.5761912177406199`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526297`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813694`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530509`"}], "-", 
        RowBox[{"0.14230747862306387`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497878`"}], "-", 
        RowBox[{"0.46206948054554686`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673651`"}], "-", 
        RowBox[{"0.3197620019224827`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589294`"}], "+", 
        RowBox[{"0.5761912177406194`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284307`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.718498696363686`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021267`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406224`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673834`"}], "-", 
        RowBox[{"0.3197620019224836`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526307`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581814015`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305196`"}], "+", 
        RowBox[{"0.14230747862306445`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028413`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224853`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694812`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813954`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589206`"}], "+", 
        RowBox[{"0.5761912177406238`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978886`"}], "+", 
        RowBox[{"0.46206948054554847`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284237`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636831`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526285`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813916`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694726`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181384`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1315118854502123`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406203`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305085`"}], "-", 
        RowBox[{"0.14230747862306387`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558904`"}], "-", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673814`"}], "+", 
        RowBox[{"0.3197620019224823`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028388`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248394`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978736`"}], "-", 
        RowBox[{"0.46206948054554675`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.53248075335263`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581814`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673702`"}], "+", 
        RowBox[{"0.3197620019224839`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995795`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3279852776056827`", ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589206`"}], "+", 
        RowBox[{"0.5761912177406238`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526317`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181378`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558953`"}], "-", 
        RowBox[{"0.5761912177406218`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061048`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673855`"}], "-", 
        RowBox[{"0.31976200192248344`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526286`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.256429215818139`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.327985277605681`", ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558934`"}], "+", 
        RowBox[{"0.5761912177406192`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673657`"}], "-", 
        RowBox[{"0.31976200192248283`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558905`"}], "-", 
        RowBox[{"0.5761912177406213`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061023`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995773`"}], ",", 
       RowBox[{"0.5324807533526296`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181366`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673775`"}], "+", 
        RowBox[{"0.31976200192248194`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673816`"}], "-", 
        RowBox[{"0.3197620019224835`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028419`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248266`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020992`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406222`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028423`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248255`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526302`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813966`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694912`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181386`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406227`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694898`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181381`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558924`"}], "+", 
        RowBox[{"0.5761912177406233`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673801`"}], "+", 
        RowBox[{"0.31976200192248294`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028404`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224815`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1315118854502097`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406211`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.663992638802841`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.319762001922482`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.532480753352629`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181388`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694826`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813755`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021003`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.576191217740621`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694873`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181375`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558909`"}], "-", 
        RowBox[{"0.5761912177406219`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454979047`"}], "-", 
        RowBox[{"0.46206948054554664`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305257`"}], "-", 
        RowBox[{"0.14230747862306312`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028413`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248516`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694807`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.256429215818139`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880283999`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636861`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497904`"}], "-", 
        RowBox[{"0.4620694805455468`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1639926388028402`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.718498696363686`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021184`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406223`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530524`"}], "-", 
        RowBox[{"0.14230747862306323`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497895`"}], "+", 
        RowBox[{"0.46206948054554536`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694765`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813855`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880283993`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636846`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530516`"}], "+", 
        RowBox[{"0.14230747862306267`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028396`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636844`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1315118854502115`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406208`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028389`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224839`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497894`"}], "+", 
        RowBox[{"0.46206948054554553`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305146`"}], "+", 
        RowBox[{"0.14230747862306276`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530522`"}], "-", 
        RowBox[{"0.14230747862306317`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995793`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497888`"}], "+", 
        RowBox[{"0.4620694805455485`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284196`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636851`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454979075`"}], "-", 
        RowBox[{"0.4620694805455467`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.3279852776056824`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5910090485061041`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305207`"}], "+", 
        RowBox[{"0.1423074786230644`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880283924`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.718498696363687`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530517`"}], "+", 
        RowBox[{"0.1423074786230632`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284182`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636845`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061031`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995768`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497897`"}], "+", 
        RowBox[{"0.46206948054554536`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305096`"}], "-", 
        RowBox[{"0.14230747862306403`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497873`"}], "-", 
        RowBox[{"0.4620694805455468`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568114`", ",", 
       RowBox[{"0.16399263880283868`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636838`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305185`"}], "+", 
        RowBox[{"0.14230747862306398`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.736976229099579`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454979036`"}], "-", 
        RowBox[{"0.46206948054554675`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284035`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636857`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.368488114549789`"}], "+", 
        RowBox[{"0.4620694805455475`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.3279852776056821`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5910090485061043`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530523`"}], "-", 
        RowBox[{"0.14230747862306328`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284226`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636858`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530513`"}], "-", 
        RowBox[{"0.14230747862306367`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028402`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636847`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.591009048506103`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995773`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497883`"}], "-", 
        RowBox[{"0.4620694805455467`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530516`"}], "+", 
        RowBox[{"0.14230747862306287`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978936`"}], "+", 
        RowBox[{"0.46206948054554553`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.3279852776056814`", ",", 
       RowBox[{"0.16399263880284168`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636837`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526308`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581814004`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.2044954757469487`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813816`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028428`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.319762001922482`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694918`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813843`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558923`"}], "+", 
        RowBox[{"0.5761912177406239`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020964`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406231`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.663992638802843`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248194`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021003`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406228`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673804`"}], "-", 
        RowBox[{"0.31976200192248394`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526285`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813966`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694832`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181375`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028401`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248094`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694812`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181377`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558906`"}], "-", 
        RowBox[{"0.5761912177406218`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020925`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406209`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028403`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248116`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020887`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406207`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673818`"}], "+", 
        RowBox[{"0.31976200192248283`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.591009048506105`"}], ",", "0.3279852776056825`", ",", 
       RowBox[{"-", "0.7369762290995799`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.327985277605682`", ",", 
       RowBox[{"-", "0.7369762290995787`"}], ",", 
       RowBox[{"-", "0.5910090485061041`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995797`"}], ",", 
       RowBox[{"-", "0.5910090485061049`"}], ",", "0.3279852776056826`"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497888`"}], "+", 
        RowBox[{"0.46206948054554864`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673653`"}], "+", 
        RowBox[{"0.31976200192248394`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589566`"}], "-", 
        RowBox[{"0.5761912177406215`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673632`"}], "+", 
        RowBox[{"0.3197620019224842`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.163992638802844`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636865`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526326`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813727`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558943`"}], "-", 
        RowBox[{"0.5761912177406213`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526313`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181377`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305174`"}], "+", 
        RowBox[{"0.1423074786230644`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.368488114549787`"}], "-", 
        RowBox[{"0.4620694805455467`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.0729835902967361`"}], "-", 
        RowBox[{"0.31976200192248266`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589317`"}], "+", 
        RowBox[{"0.5761912177406201`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673615`"}], "-", 
        RowBox[{"0.3197620019224827`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284298`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636825`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526299`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.256429215818137`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558932`"}], "+", 
        RowBox[{"0.5761912177406188`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526295`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181357`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.295504524253051`"}], "-", 
        RowBox[{"0.1423074786230642`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526303`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813966`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.072983590296738`"}], "-", 
        RowBox[{"0.3197620019224835`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880283987`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636865`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530522`"}], "-", 
        RowBox[{"0.14230747862306325`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558923`"}], "+", 
        RowBox[{"0.5761912177406228`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526303`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813954`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589244`"}], "+", 
        RowBox[{"0.5761912177406225`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454979`"}], "-", 
        RowBox[{"0.46206948054554686`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673786`"}], "-", 
        RowBox[{"0.3197620019224834`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.532480753352629`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813893`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305185`"}], "+", 
        RowBox[{"0.14230747862306298`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558916`"}], "-", 
        RowBox[{"0.5761912177406215`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673779`"}], "+", 
        RowBox[{"0.31976200192248266`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558914`"}], "-", 
        RowBox[{"0.5761912177406215`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497893`"}], "+", 
        RowBox[{"0.46206948054554586`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880283935`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636842`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.532480753352629`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813893`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.0729835902967377`"}], "+", 
        RowBox[{"0.31976200192248283`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530516`"}], "+", 
        RowBox[{"0.14230747862306434`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589433`"}], "-", 
        RowBox[{"0.5761912177406218`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526315`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181378`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589455`"}], "-", 
        RowBox[{"0.5761912177406215`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497886`"}], "+", 
        RowBox[{"0.46206948054554814`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673693`"}], "+", 
        RowBox[{"0.31976200192248394`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526308`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813805`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673716`"}], "+", 
        RowBox[{"0.3197620019224838`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284215`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636855`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530509`"}], "-", 
        RowBox[{"0.14230747862306353`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558933`"}], "+", 
        RowBox[{"0.5761912177406198`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526301`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813755`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589305`"}], "+", 
        RowBox[{"0.5761912177406199`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497876`"}], "-", 
        RowBox[{"0.4620694805455464`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673686`"}], "-", 
        RowBox[{"0.3197620019224831`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526298`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813705`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673643`"}], "-", 
        RowBox[{"0.3197620019224829`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028417`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636841`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.32798527760568236`", ",", 
       RowBox[{"0.16399263880284323`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636862`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454979136`"}], "-", 
        RowBox[{"0.4620694805455467`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880283899`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636872`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061051`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305207`"}], "+", 
        RowBox[{"0.14230747862306498`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978864`"}], "+", 
        RowBox[{"0.46206948054554836`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305285`"}], "-", 
        RowBox[{"0.14230747862306306`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995797`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.736976229099579`"}], ",", 
       RowBox[{"0.13151188545021017`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406228`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694807`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813927`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021222`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406223`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568225`", ",", 
       RowBox[{"0.6639926388028426`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248216`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694885`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813843`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.663992638802841`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224846`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061043`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5910090485061045`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530529`"}], "-", 
        RowBox[{"0.14230747862306303`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284373`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636864`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530519`"}], "+", 
        RowBox[{"0.1423074786230644`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.73697622909958`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454979197`"}], "-", 
        RowBox[{"0.4620694805455467`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880283985`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636861`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497888`"}], "+", 
        RowBox[{"0.46206948054554847`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568247`"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284135`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636852`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021064`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406221`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305185`"}], "+", 
        RowBox[{"0.14230747862306398`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497891`"}], "+", 
        RowBox[{"0.4620694805455472`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305185`"}], "+", 
        RowBox[{"0.14230747862306387`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028417`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224826`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694857`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181384`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028417`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636857`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.368488114549789`"}], "+", 
        RowBox[{"0.4620694805455476`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284123`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636847`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497887`"}], "-", 
        RowBox[{"0.46206948054554675`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694837`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813805`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021042`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305146`"}], "-", 
        RowBox[{"0.1423074786230637`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284132`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636844`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530515`"}], "-", 
        RowBox[{"0.14230747862306375`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028407`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248216`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497882`"}], "-", 
        RowBox[{"0.4620694805455467`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673702`"}], "+", 
        RowBox[{"0.31976200192248344`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558924`"}], "+", 
        RowBox[{"0.576191217740623`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.591009048506104`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995786`"}], ",", 
       RowBox[{"0.5324807533526311`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813805`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.0729835902967381`"}], "-", 
        RowBox[{"0.31976200192248344`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526302`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181394`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.3279852776056823`", ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558945`"}], "-", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673707`"}], "-", 
        RowBox[{"0.3197620019224831`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995778`"}], ",", 
       RowBox[{"0.5324807533526291`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813893`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589133`"}], "-", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526297`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181374`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568097`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.591009048506103`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673791`"}], "+", 
        RowBox[{"0.3197620019224827`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589317`"}], "+", 
        RowBox[{"0.5761912177406199`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995793`"}], ",", 
       RowBox[{"0.1315118854502124`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406222`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694937`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181385`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545020998`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406227`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.3279852776056824`", ",", 
       RowBox[{"0.6639926388028415`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224858`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694812`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813954`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028432`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224822`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061047`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284218`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636855`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497888`"}], "+", 
        RowBox[{"0.4620694805455476`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.2044954757469487`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813855`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021014`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406224`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530519`"}], "+", 
        RowBox[{"0.14230747862306392`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284215`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636857`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305196`"}], "+", 
        RowBox[{"0.14230747862306428`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028422`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224824`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978886`"}], "+", 
        RowBox[{"0.4620694805455481`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284182`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636841`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1315118854502098`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305124`"}], "-", 
        RowBox[{"0.1423074786230637`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978836`"}], "-", 
        RowBox[{"0.46206948054554686`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305135`"}], "-", 
        RowBox[{"0.14230747862306367`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028405`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224816`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694832`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181379`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284168`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.718498696363684`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497877`"}], "-", 
        RowBox[{"0.4620694805455467`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.32798527760568214`", ",", 
       RowBox[{"0.663992638802841`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224846`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021003`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406227`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.663992638802842`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224824`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061044`"}], ",", 
       RowBox[{"0.20449547574694807`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181392`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021208`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.576191217740622`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.204495475746949`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181384`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995793`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1315118854502102`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406227`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568214`", ",", 
       RowBox[{"0.6639926388028412`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224844`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694787`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181392`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028423`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248244`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061044`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995789`"}], ",", 
       RowBox[{"0.13151188545021125`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406219`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.2044954757469487`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181385`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545020975`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406211`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.2044954757469473`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181385`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995775`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.32798527760568147`", ",", 
       RowBox[{"0.6639926388028407`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224817`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021125`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.576191217740621`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028398`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224835`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061028`"}], ",", 
       RowBox[{"0.20449547574694832`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813816`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.2044954757469481`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813916`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028413`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224848`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526316`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181379`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589483`"}], "-", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021256`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406227`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694793`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813966`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1315118854502122`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406223`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673676`"}], "+", 
        RowBox[{"0.3197620019224839`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028412`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224854`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694754`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813855`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589294`"}], "+", 
        RowBox[{"0.5761912177406193`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021184`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406207`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028391`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248366`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021203`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406201`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673654`"}], "-", 
        RowBox[{"0.3197620019224829`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526297`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813694`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.2044954757469471`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813855`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028389`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248416`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021206`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406222`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568225`", ",", 
       RowBox[{"0.6639926388028424`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.319762001922482`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694893`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181385`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028413`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.319762001922485`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061047`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995793`"}], ",", 
       RowBox[{"0.13151188545020984`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.576191217740623`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694785`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813954`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1315118854502116`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406208`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694843`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813766`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.736976229099577`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3279852776056813`", ",", 
       RowBox[{"0.663992638802839`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248383`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1315118854502093`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.576191217740621`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028405`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.319762001922481`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061025`"}], ",", 
       RowBox[{"0.20449547574694726`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813866`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.591009048506104`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305196`"}], "+", 
        RowBox[{"0.14230747862306398`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284007`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636861`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305207`"}], "-", 
        RowBox[{"0.1423074786230633`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995787`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978897`"}], "+", 
        RowBox[{"0.46206948054554753`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1639926388028416`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636852`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978997`"}], "-", 
        RowBox[{"0.46206948054554675`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.3279852776056821`"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497886`"}], "+", 
        RowBox[{"0.462069480545548`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305185`"}], "+", 
        RowBox[{"0.1423074786230644`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028426`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248194`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694882`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181384`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284234`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636856`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497887`"}], "+", 
        RowBox[{"0.4620694805455482`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284218`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636855`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020984`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406228`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.295504524253052`"}], "+", 
        RowBox[{"0.14230747862306437`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497879`"}], "-", 
        RowBox[{"0.46206948054554703`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694843`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.256429215818138`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284196`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636841`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.295504524253051`"}], "-", 
        RowBox[{"0.14230747862306395`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028421`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636839`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1315118854502097`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406212`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028405`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248083`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978775`"}], "-", 
        RowBox[{"0.46206948054554686`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.295504524253051`"}], "-", 
        RowBox[{"0.14230747862306392`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995796`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497888`"}], "+", 
        RowBox[{"0.46206948054554825`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.295504524253053`"}], "-", 
        RowBox[{"0.14230747862306303`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497906`"}], "-", 
        RowBox[{"0.4620694805455467`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568197`", ",", 
       RowBox[{"0.16399263880284298`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636864`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305207`"}], "+", 
        RowBox[{"0.1423074786230644`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880283968`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636868`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061048`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5910090485061047`"}], ",", 
       RowBox[{"0.204495475746948`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813954`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028432`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248194`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694904`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181384`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995796`"}], ",", 
       RowBox[{"0.1315118854502128`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406225`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028411`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224846`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021006`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406229`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568247`"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305196`"}], "+", 
        RowBox[{"0.14230747862306417`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028422`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224825`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497889`"}], "+", 
        RowBox[{"0.46206948054554786`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1639926388028425`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.718498696363686`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978886`"}], "+", 
        RowBox[{"0.46206948054554786`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694915`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181385`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545020986`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406228`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.295504524253052`"}], "+", 
        RowBox[{"0.1423074786230641`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284265`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636859`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305107`"}], "-", 
        RowBox[{"0.1423074786230637`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284204`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636836`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020953`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.576191217740621`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028405`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248194`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497878`"}], "-", 
        RowBox[{"0.46206948054554664`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.295504524253051`"}], "-", 
        RowBox[{"0.1423074786230639`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978764`"}], "-", 
        RowBox[{"0.46206948054554664`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694826`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181378`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028421`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636837`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.3279852776056822`", ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558924`"}], "+", 
        RowBox[{"0.5761912177406225`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526312`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181381`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589416`"}], "-", 
        RowBox[{"0.5761912177406215`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061041`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673802`"}], "-", 
        RowBox[{"0.31976200192248344`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526305`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813977`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673702`"}], "+", 
        RowBox[{"0.31976200192248355`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995794`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526311`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181381`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673775`"}], "-", 
        RowBox[{"0.31976200192248333`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995792`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3279852776056824`", ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558943`"}], "-", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526306`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581814015`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589194`"}], "+", 
        RowBox[{"0.5761912177406235`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061044`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673675`"}], "+", 
        RowBox[{"0.319762001922484`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.53248075335263`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181372`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568125`", ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558906`"}], "-", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.0729835902967377`"}], "+", 
        RowBox[{"0.3197620019224827`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589294`"}], "+", 
        RowBox[{"0.5761912177406201`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061029`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.736976229099577`"}], ",", 
       RowBox[{"0.5324807533526283`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813943`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673643`"}], "-", 
        RowBox[{"0.3197620019224828`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5910090485061043`"}], ",", 
       RowBox[{"0.20449547574694876`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181385`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028412`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224844`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694815`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181387`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995785`"}], ",", 
       RowBox[{"0.13151188545021059`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406221`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028417`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224828`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021159`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406221`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.3279852776056821`"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1315118854502124`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406223`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.0729835902967367`"}], "+", 
        RowBox[{"0.31976200192248405`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028412`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224857`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694804`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813916`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028413`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248516`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526318`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813766`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589516`"}], "-", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021283`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406228`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694785`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813977`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021203`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406204`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694743`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181386`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558932`"}], "+", 
        RowBox[{"0.5761912177406193`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673655`"}], "-", 
        RowBox[{"0.3197620019224827`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028389`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224839`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1315118854502123`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406197`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028384`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248433`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526297`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181366`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694676`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813843`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.2044954757469495`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813877`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284318`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636859`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497887`"}], "+", 
        RowBox[{"0.4620694805455485`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284265`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636861`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021011`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406227`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530515`"}], "+", 
        RowBox[{"0.14230747862306437`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497885`"}], "+", 
        RowBox[{"0.46206948054554836`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530524`"}], "+", 
        RowBox[{"0.1423074786230645`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028432`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248233`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694865`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813743`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284215`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636837`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.368488114549787`"}], "-", 
        RowBox[{"0.46206948054554636`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284226`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636832`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020953`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406211`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530509`"}], "-", 
        RowBox[{"0.14230747862306414`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.368488114549787`"}], "-", 
        RowBox[{"0.4620694805455469`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305057`"}], "-", 
        RowBox[{"0.14230747862306337`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028404`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248094`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589217`"}], "+", 
        RowBox[{"0.5761912177406224`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978986`"}], "-", 
        RowBox[{"0.46206948054554664`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673789`"}], "-", 
        RowBox[{"0.31976200192248333`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526303`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181394`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673779`"}], "-", 
        RowBox[{"0.3197620019224834`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284004`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636864`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530522`"}], "-", 
        RowBox[{"0.14230747862306317`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558921`"}], "+", 
        RowBox[{"0.5761912177406231`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526301`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813977`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589183`"}], "-", 
        RowBox[{"0.5761912177406218`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526291`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181389`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305185`"}], "+", 
        RowBox[{"0.14230747862306292`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978947`"}], "+", 
        RowBox[{"0.46206948054554586`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673762`"}], "+", 
        RowBox[{"0.31976200192248266`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558913`"}], "-", 
        RowBox[{"0.5761912177406218`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673779`"}], "+", 
        RowBox[{"0.319762001922483`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880283962`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636844`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526288`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813927`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5910090485061041`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673696`"}], "+", 
        RowBox[{"0.31976200192248344`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558921`"}], "+", 
        RowBox[{"0.5761912177406227`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.0729835902967379`"}], "-", 
        RowBox[{"0.3197620019224833`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995792`"}], ",", 
       RowBox[{"0.5324807533526311`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813805`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589416`"}], "-", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526303`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181399`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568214`"}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.52620667712547*^9, 3.52620673604237*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1.`", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1.`", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1.`"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.32798527760568197`", ",", 
       RowBox[{"0.16399263880284023`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636859`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978864`"}], "+", 
        RowBox[{"0.46206948054554764`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.163992638802842`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636859`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061041`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305207`"}], "-", 
        RowBox[{"0.1423074786230634`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497906`"}], "-", 
        RowBox[{"0.4620694805455465`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530519`"}], "+", 
        RowBox[{"0.14230747862306387`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995795`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.532480753352631`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181378`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305257`"}], "-", 
        RowBox[{"0.14230747862306348`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028424`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224825`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694893`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181387`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558939`"}], "-", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497903`"}], "-", 
        RowBox[{"0.46206948054554675`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1639926388028401`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636864`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1315118854502103`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406225`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673661`"}], "+", 
        RowBox[{"0.3197620019224835`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526295`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813727`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694843`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181378`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028396`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636846`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530518`"}], "+", 
        RowBox[{"0.14230747862306284`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558927`"}], "+", 
        RowBox[{"0.5761912177406203`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1315118854502099`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406212`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028407`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248155`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978964`"}], "+", 
        RowBox[{"0.46206948054554553`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673687`"}], "-", 
        RowBox[{"0.3197620019224824`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9009688679024193`"}], "+", 
        RowBox[{"0.4338837391175599`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.6234898018587329`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.781831482468033`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.2225209339563179`"}], "-", 
        RowBox[{"0.9749279121818252`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9009688679024177`"}], "-", 
        RowBox[{"0.4338837391175591`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.6234898018587303`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824680297`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395631686`"}], "+", 
        RowBox[{"0.9749279121818207`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5910090485061039`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673793`"}], "-", 
        RowBox[{"0.3197620019224834`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589405`"}], "-", 
        RowBox[{"0.5761912177406212`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673707`"}], "+", 
        RowBox[{"0.3197620019224835`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995792`"}], ",", 
       RowBox[{"0.5324807533526303`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181398`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558922`"}], "+", 
        RowBox[{"0.5761912177406228`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526311`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813793`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568225`"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.6234898018587351`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824680299`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.2225209339563134`"}], "+", 
        RowBox[{"0.9749279121818247`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9009688679024204`"}], "-", 
        RowBox[{"0.4338837391175575`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024188`"}], "+", 
        RowBox[{"0.4338837391175568`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6234898018587338`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7818314824680282`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.222520933956313`"}], "-", 
        RowBox[{"0.9749279121818231`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497888`"}], "+", 
        RowBox[{"0.46206948054554786`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568214`", ",", 
       RowBox[{"0.16399263880283974`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636864`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305246`"}], "-", 
        RowBox[{"0.1423074786230631`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028424`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636857`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061045`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995795`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454979097`"}], "-", 
        RowBox[{"0.46206948054554686`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.295504524253052`"}], "+", 
        RowBox[{"0.14230747862306445`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497879`"}], "-", 
        RowBox[{"0.46206948054554686`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305185`"}], "+", 
        RowBox[{"0.14230747862306276`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995768`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3279852776056816`", ",", 
       RowBox[{"0.16399263880284182`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636836`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497895`"}], "+", 
        RowBox[{"0.46206948054554514`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1639926388028393`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636842`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061027`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530508`"}], "-", 
        RowBox[{"0.14230747862306395`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558924`"}], "+", 
        RowBox[{"0.5761912177406229`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526307`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813816`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568214`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5910090485061048`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673814`"}], "-", 
        RowBox[{"0.3197620019224838`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558947`"}], "-", 
        RowBox[{"0.5761912177406218`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673633`"}], "+", 
        RowBox[{"0.3197620019224841`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.73697622909958`"}], ",", 
       RowBox[{"0.5324807533526306`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181407`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589133`"}], "-", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061024`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673612`"}], "-", 
        RowBox[{"0.3197620019224825`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526297`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813777`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673801`"}], "+", 
        RowBox[{"0.3197620019224825`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995765`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3279852776056815`", ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589294`"}], "+", 
        RowBox[{"0.5761912177406195`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.532480753352628`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181396`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6234898018587334`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.781831482468031`", " ", "\[ImaginaryI]"}]}], ",", "0", ",",
        "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395631517`"}], "-", 
        RowBox[{"0.974927912181824`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024195`"}], "+", 
        RowBox[{"0.4338837391175594`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6234898018587323`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824680297`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395631495`"}], "+", 
        RowBox[{"0.974927912181823`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024179`"}], "-", 
        RowBox[{"0.4338837391175586`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395631306`"}], "+", 
        RowBox[{"0.9749279121818255`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024217`"}], "-", 
        RowBox[{"0.4338837391175567`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.623489801858735`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824680295`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.6234898018587341`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7818314824680284`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.22252093395631237`"}], "-", 
        RowBox[{"0.9749279121818225`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024187`"}], "+", 
        RowBox[{"0.43388373911755523`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673782`"}], "-", 
        RowBox[{"0.3197620019224833`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589233`"}], "+", 
        RowBox[{"0.5761912177406227`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454979`"}], "-", 
        RowBox[{"0.46206948054554675`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1639926388028402`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636859`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526303`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813943`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673777`"}], "-", 
        RowBox[{"0.31976200192248344`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526302`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181395`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305235`"}], "-", 
        RowBox[{"0.14230747862306314`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558923`"}], "+", 
        RowBox[{"0.576191217740623`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673776`"}], "+", 
        RowBox[{"0.31976200192248283`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028399`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636846`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526292`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813904`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558915`"}], "-", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526292`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181389`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530517`"}], "+", 
        RowBox[{"0.14230747862306287`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978936`"}], "+", 
        RowBox[{"0.4620694805455459`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673768`"}], "+", 
        RowBox[{"0.31976200192248266`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558912`"}], "-", 
        RowBox[{"0.5761912177406215`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.900968867902421`"}], "-", 
        RowBox[{"0.43388373911755745`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.6234898018587359`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824680298`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.22252093395631362`"}], "+", 
        RowBox[{"0.9749279121818246`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395631325`"}], "-", 
        RowBox[{"0.9749279121818231`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9009688679024185`"}], "+", 
        RowBox[{"0.43388373911755623`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.623489801858734`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7818314824680275`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.22252093395631362`"}], "+", 
        RowBox[{"0.9749279121818244`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.900968867902421`"}], "-", 
        RowBox[{"0.4338837391175573`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.6234898018587363`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824680298`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.22252093395631334`"}], "-", 
        RowBox[{"0.9749279121818233`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024186`"}], "+", 
        RowBox[{"0.4338837391175561`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.6234898018587341`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7818314824680271`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.2044954757469485`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813843`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558932`"}], "-", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978964`"}], "-", 
        RowBox[{"0.46206948054554664`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284018`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.718498696363686`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1315118854502104`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406225`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673704`"}], "+", 
        RowBox[{"0.3197620019224836`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526311`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813793`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530524`"}], "-", 
        RowBox[{"0.14230747862306312`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028423`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224823`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694843`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181384`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880283987`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636845`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526298`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181372`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558929`"}], "+", 
        RowBox[{"0.576191217740621`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020998`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406212`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305157`"}], "+", 
        RowBox[{"0.14230747862306276`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497894`"}], "+", 
        RowBox[{"0.46206948054554625`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673679`"}], "-", 
        RowBox[{"0.3197620019224827`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028404`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248155`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "1.0000000000000013`", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1.0000000000000016`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.0000000000000007`", ",", "0", ",", "0"}], "}"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0.9999999999999993`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999999987`", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0.9999999999999984`", ",", "0"}], "}"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.623489801858733`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7818314824680325`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395631756`"}], "-", 
        RowBox[{"0.9749279121818253`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9009688679024195`"}], "+", 
        RowBox[{"0.43388373911756023`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024173`"}], "-", 
        RowBox[{"0.4338837391175592`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6234898018587308`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824680297`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395631653`"}], "+", 
        RowBox[{"0.9749279121818207`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.6234898018587381`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824680295`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.22252093395631212`"}], "+", 
        RowBox[{"0.9749279121818261`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024235`"}], "-", 
        RowBox[{"0.43388373911755596`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395631128`"}], "-", 
        RowBox[{"0.9749279121818224`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024181`"}], "+", 
        RowBox[{"0.43388373911755335`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6234898018587349`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7818314824680254`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558937`"}], "-", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978897`"}], "+", 
        RowBox[{"0.4620694805455479`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673678`"}], "+", 
        RowBox[{"0.3197620019224837`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526315`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813805`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673686`"}], "+", 
        RowBox[{"0.319762001922484`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284304`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636862`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530519`"}], "+", 
        RowBox[{"0.14230747862306453`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558953`"}], "-", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526322`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813743`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.459497163055893`"}], "+", 
        RowBox[{"0.5761912177406205`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526297`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813716`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305074`"}], "-", 
        RowBox[{"0.14230747862306398`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978797`"}], "-", 
        RowBox[{"0.46206948054554664`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673654`"}], "-", 
        RowBox[{"0.3197620019224827`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589305`"}], "+", 
        RowBox[{"0.5761912177406189`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673661`"}], "-", 
        RowBox[{"0.31976200192248294`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284226`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636831`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526298`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181362`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028422`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224821`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020992`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.576191217740623`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673829`"}], "-", 
        RowBox[{"0.3197620019224835`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526302`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181393`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694896`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181385`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028422`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248216`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694887`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813843`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558924`"}], "+", 
        RowBox[{"0.5761912177406234`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020984`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406229`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028407`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224816`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526292`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813904`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694846`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181378`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545020934`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.576191217740621`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.2044954757469483`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181378`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558908`"}], "-", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673818`"}], "+", 
        RowBox[{"0.3197620019224825`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028405`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248144`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020936`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.576191217740621`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395631278`"}], "+", 
        RowBox[{"0.9749279121818261`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9009688679024218`"}], "-", 
        RowBox[{"0.4338837391175569`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.6234898018587351`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824680298`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024184`"}], "+", 
        RowBox[{"0.43388373911755523`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.6234898018587339`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7818314824680282`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.22252093395631187`"}], "-", 
        RowBox[{"0.9749279121818221`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028423`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224824`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061046`"}], ",", 
       RowBox[{"0.204495475746948`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813927`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021236`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406224`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694932`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181385`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995797`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3279852776056822`", ",", 
       RowBox[{"0.6639926388028412`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248494`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020986`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406229`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028404`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248166`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021197`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406202`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568147`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5910090485061026`"}], ",", 
       RowBox[{"0.20449547574694843`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813743`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028392`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248383`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694726`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181385`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995766`"}], ",", 
       RowBox[{"0.13151188545020948`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406211`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028417`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224825`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978886`"}], "+", 
        RowBox[{"0.4620694805455477`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530518`"}], "+", 
        RowBox[{"0.14230747862306414`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978897`"}], "+", 
        RowBox[{"0.46206948054554825`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694904`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813855`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284273`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.718498696363686`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305196`"}], "+", 
        RowBox[{"0.1423074786230645`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.163992638802843`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636861`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020967`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406233`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028408`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248194`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978786`"}], "-", 
        RowBox[{"0.46206948054554664`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530509`"}], "-", 
        RowBox[{"0.14230747862306403`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497883`"}], "-", 
        RowBox[{"0.4620694805455469`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694843`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813766`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028423`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636831`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530514`"}], "-", 
        RowBox[{"0.1423074786230639`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284204`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636834`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020903`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406209`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673777`"}], "-", 
        RowBox[{"0.3197620019224833`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028418`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636855`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021159`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.576191217740622`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028414`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248483`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526307`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181398`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.295504524253052`"}], "+", 
        RowBox[{"0.14230747862306428`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978875`"}], "+", 
        RowBox[{"0.4620694805455485`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694796`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181395`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589206`"}], "+", 
        RowBox[{"0.5761912177406239`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673773`"}], "+", 
        RowBox[{"0.31976200192248283`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028392`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248366`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978736`"}], "-", 
        RowBox[{"0.46206948054554675`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284146`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636842`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526287`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813893`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694718`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813855`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021145`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406212`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305107`"}], "-", 
        RowBox[{"0.14230747862306378`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589033`"}], "-", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558926`"}], "+", 
        RowBox[{"0.5761912177406227`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021145`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406219`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.295504524253052`"}], "+", 
        RowBox[{"0.14230747862306406`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978886`"}], "+", 
        RowBox[{"0.4620694805455472`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673818`"}], "-", 
        RowBox[{"0.31976200192248294`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028411`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248394`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.2044954757469482`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813904`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284173`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636858`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526299`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813943`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558917`"}], "-", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497885`"}], "-", 
        RowBox[{"0.4620694805455466`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694743`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813866`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021122`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406209`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.0729835902967374`"}], "+", 
        RowBox[{"0.31976200192248266`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284176`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636846`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305135`"}], "-", 
        RowBox[{"0.14230747862306392`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028402`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224838`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526291`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181384`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1315118854502099`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406235`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673872`"}], "-", 
        RowBox[{"0.31976200192248355`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028435`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248166`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694937`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181382`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028425`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224825`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526303`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181401`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589206`"}], "+", 
        RowBox[{"0.5761912177406238`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020967`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.576191217740623`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.2044954757469496`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813893`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1315118854502088`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406209`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694826`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813755`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558904`"}], "-", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673816`"}], "+", 
        RowBox[{"0.3197620019224819`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028407`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224814`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1315118854502094`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406208`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.66399263880284`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224802`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526285`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813916`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694907`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813716`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497903`"}], "-", 
        RowBox[{"0.46206948054554653`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673675`"}], "+", 
        RowBox[{"0.3197620019224838`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.663992638802843`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248194`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694907`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181383`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028396`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636862`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526317`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813766`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558942`"}], "-", 
        RowBox[{"0.5761912177406212`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1315118854502099`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.576191217740623`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530526`"}], "-", 
        RowBox[{"0.14230747862306314`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497899`"}], "+", 
        RowBox[{"0.4620694805455454`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694854`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813805`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558931`"}], "+", 
        RowBox[{"0.5761912177406201`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673662`"}], "-", 
        RowBox[{"0.31976200192248283`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880283915`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636844`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020948`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406211`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028403`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224809`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526297`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813666`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530515`"}], "+", 
        RowBox[{"0.14230747862306223`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694812`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181391`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589233`"}], "+", 
        RowBox[{"0.576191217740623`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.368488114549789`"}], "+", 
        RowBox[{"0.4620694805455478`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1639926388028429`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636861`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021247`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406225`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673826`"}], "-", 
        RowBox[{"0.3197620019224836`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526303`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813977`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305185`"}], "+", 
        RowBox[{"0.14230747862306425`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028411`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224848`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.2044954757469476`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181384`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284215`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636832`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.532480753352629`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181392`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558911`"}], "-", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021203`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406203`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305124`"}], "-", 
        RowBox[{"0.14230747862306392`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978797`"}], "-", 
        RowBox[{"0.46206948054554664`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.072983590296738`"}], "+", 
        RowBox[{"0.31976200192248244`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028394`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224839`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028428`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248205`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497913`"}], "-", 
        RowBox[{"0.46206948054554664`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.0729835902967365`"}], "+", 
        RowBox[{"0.3197620019224841`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526309`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181379`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694898`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181384`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880283949`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636865`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305257`"}], "-", 
        RowBox[{"0.14230747862306317`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589494`"}], "-", 
        RowBox[{"0.5761912177406215`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020975`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406233`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028405`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248094`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.53248075335263`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181375`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305146`"}], "+", 
        RowBox[{"0.14230747862306276`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978975`"}], "+", 
        RowBox[{"0.4620694805455447`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694857`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181377`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589294`"}], "+", 
        RowBox[{"0.5761912177406193`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673619`"}], "-", 
        RowBox[{"0.31976200192248255`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880283904`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636844`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020906`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406209`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.2044954757469481`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813916`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558943`"}], "-", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021206`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406223`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028409`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224839`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021153`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406219`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673704`"}], "+", 
        RowBox[{"0.3197620019224835`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526309`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813816`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694812`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181391`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028412`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224846`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694754`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181383`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028403`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224836`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526299`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181376`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589283`"}], "+", 
        RowBox[{"0.57619121774062`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021136`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406212`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694765`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181385`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021175`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406207`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673684`"}], "-", 
        RowBox[{"0.319762001922483`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028395`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248366`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526309`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813793`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694896`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181385`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028396`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636861`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530522`"}], "-", 
        RowBox[{"0.14230747862306328`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558944`"}], "-", 
        RowBox[{"0.5761912177406215`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021014`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406225`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028419`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224825`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454979047`"}], "-", 
        RowBox[{"0.46206948054554686`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.0729835902967368`"}], "+", 
        RowBox[{"0.3197620019224837`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.53248075335263`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181375`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305185`"}], "+", 
        RowBox[{"0.14230747862306298`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028405`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.319762001922482`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.2044954757469485`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181377`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558929`"}], "+", 
        RowBox[{"0.57619121774062`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978947`"}], "+", 
        RowBox[{"0.4620694805455453`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880283937`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636846`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020956`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406212`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673686`"}], "-", 
        RowBox[{"0.3197620019224829`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995787`"}], ",", 
       RowBox[{"0.5324807533526302`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813927`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673694`"}], "+", 
        RowBox[{"0.3197620019224836`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526309`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813805`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.3279852776056822`", ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589217`"}], "+", 
        RowBox[{"0.576191217740623`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673787`"}], "-", 
        RowBox[{"0.3197620019224834`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589433`"}], "-", 
        RowBox[{"0.5761912177406215`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061045`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694885`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813843`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995793`"}], ",", 
       RowBox[{"0.13151188545021242`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406224`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028412`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248505`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1315118854502099`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406232`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.3279852776056825`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5910090485061045`"}], ",", 
       RowBox[{"0.20449547574694799`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181395`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028431`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224817`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694843`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181378`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.663992638802839`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248394`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061029`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995768`"}], ",", 
       RowBox[{"0.13151188545020925`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406209`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694737`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181386`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1315118854502121`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406203`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568114`", ",", 
       RowBox[{"0.6639926388028404`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224805`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545020975`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406228`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.295504524253052`"}], "+", 
        RowBox[{"0.14230747862306403`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284237`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636859`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305196`"}], "+", 
        RowBox[{"0.14230747862306403`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028424`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248244`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497886`"}], "+", 
        RowBox[{"0.462069480545548`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1639926388028424`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636857`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978847`"}], "+", 
        RowBox[{"0.46206948054554786`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694849`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181386`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545020948`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.576191217740621`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305124`"}], "-", 
        RowBox[{"0.1423074786230636`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284215`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.718498696363684`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305124`"}], "-", 
        RowBox[{"0.14230747862306353`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028408`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224814`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978786`"}], "-", 
        RowBox[{"0.4620694805455467`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284207`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636839`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497879`"}], "-", 
        RowBox[{"0.4620694805455467`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.2044954757469483`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813805`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673684`"}], "+", 
        RowBox[{"0.3197620019224838`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880283962`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636864`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020995`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406227`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028433`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248183`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526319`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813755`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305274`"}], "-", 
        RowBox[{"0.14230747862306295`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454979086`"}], "-", 
        RowBox[{"0.46206948054554664`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.2044954757469493`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813843`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589494`"}], "-", 
        RowBox[{"0.5761912177406212`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673662`"}], "-", 
        RowBox[{"0.31976200192248283`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028404`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224806`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978964`"}], "+", 
        RowBox[{"0.46206948054554475`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1639926388028393`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636845`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526297`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181364`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694857`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181376`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545020948`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406212`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305157`"}], "+", 
        RowBox[{"0.1423074786230623`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558933`"}], "+", 
        RowBox[{"0.5761912177406195`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.32798527760568186`", ",", 
       RowBox[{"-", "0.7369762290995784`"}], ",", 
       RowBox[{"-", "0.5910090485061038`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995789`"}], ",", 
       RowBox[{"-", "0.5910090485061043`"}], ",", "0.3279852776056821`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5910090485061044`"}], ",", "0.3279852776056822`", ",", 
       
       RowBox[{"-", "0.736976229099579`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995796`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497915`"}], "-", 
        RowBox[{"0.4620694805455467`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530521`"}], "+", 
        RowBox[{"0.14230747862306498`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978864`"}], "+", 
        RowBox[{"0.4620694805455485`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568236`", ",", 
       RowBox[{"0.16399263880283915`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636871`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530528`"}], "-", 
        RowBox[{"0.14230747862306287`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284318`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636861`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061051`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558939`"}], "-", 
        RowBox[{"0.5761912177406213`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526301`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181397`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568214`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5910090485061044`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673684`"}], "+", 
        RowBox[{"0.3197620019224838`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589233`"}], "+", 
        RowBox[{"0.5761912177406235`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673827`"}], "-", 
        RowBox[{"0.3197620019224835`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995794`"}], ",", 
       RowBox[{"0.5324807533526318`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181375`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558932`"}], "+", 
        RowBox[{"0.5761912177406203`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061028`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673814`"}], "+", 
        RowBox[{"0.31976200192248244`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526292`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813916`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673661`"}], "-", 
        RowBox[{"0.31976200192248283`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995769`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3279852776056813`", ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558906`"}], "-", 
        RowBox[{"0.5761912177406215`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526297`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813655`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.3279852776056823`", ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589466`"}], "-", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526302`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181398`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558924`"}], "+", 
        RowBox[{"0.5761912177406227`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061043`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673707`"}], "+", 
        RowBox[{"0.3197620019224836`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526312`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813793`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.0729835902967382`"}], "-", 
        RowBox[{"0.31976200192248333`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995794`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673808`"}], "-", 
        RowBox[{"0.31976200192248355`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589455`"}], "-", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061047`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995793`"}], ",", 
       RowBox[{"0.5324807533526305`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581814027`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673672`"}], "+", 
        RowBox[{"0.31976200192248394`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526312`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181379`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568225`", ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589194`"}], "+", 
        RowBox[{"0.5761912177406237`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673765`"}], "+", 
        RowBox[{"0.3197620019224826`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995769`"}], ",", 
       RowBox[{"0.5324807533526301`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813716`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558929`"}], "+", 
        RowBox[{"0.5761912177406197`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526286`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181395`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.3279852776056813`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5910090485061025`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673634`"}], "-", 
        RowBox[{"0.3197620019224827`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589056`"}], "-", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284135`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636851`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061039`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305207`"}], "-", 
        RowBox[{"0.1423074786230633`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978975`"}], "-", 
        RowBox[{"0.46206948054554675`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305185`"}], "+", 
        RowBox[{"0.14230747862306387`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995788`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.32798527760568197`", ",", 
       RowBox[{"0.16399263880284032`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636859`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.368488114549789`"}], "+", 
        RowBox[{"0.46206948054554753`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284118`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636848`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978936`"}], "+", 
        RowBox[{"0.46206948054554614`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.3279852776056816`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5910090485061033`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305135`"}], "-", 
        RowBox[{"0.14230747862306364`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028401`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636846`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305185`"}], "+", 
        RowBox[{"0.14230747862306317`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995775`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978825`"}], "-", 
        RowBox[{"0.46206948054554664`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305224`"}], "-", 
        RowBox[{"0.1423074786230632`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028419`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248244`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526308`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813805`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558952`"}], "-", 
        RowBox[{"0.5761912177406218`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454979125`"}], "-", 
        RowBox[{"0.4620694805455469`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.2044954757469494`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813855`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545020925`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406239`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.0729835902967364`"}], "+", 
        RowBox[{"0.31976200192248433`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880283876`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636878`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305174`"}], "+", 
        RowBox[{"0.142307478623063`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589294`"}], "+", 
        RowBox[{"0.576191217740619`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1315118854502084`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406204`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028408`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.319762001922482`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978947`"}], "+", 
        RowBox[{"0.4620694805455446`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673591`"}], "-", 
        RowBox[{"0.3197620019224825`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526299`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181375`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694849`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181374`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028379`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636836`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978914`"}], "+", 
        RowBox[{"0.4620694805455471`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673772`"}], "-", 
        RowBox[{"0.31976200192248333`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.663992638802841`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224845`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694815`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181387`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284168`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636856`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526303`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181395`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589244`"}], "+", 
        RowBox[{"0.5761912177406221`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021153`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406221`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305185`"}], "+", 
        RowBox[{"0.1423074786230641`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497887`"}], "-", 
        RowBox[{"0.46206948054554675`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694807`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813843`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558921`"}], "-", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673769`"}], "+", 
        RowBox[{"0.31976200192248283`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284132`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636844`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1315118854502114`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406211`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028397`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224837`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526292`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813904`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530513`"}], "-", 
        RowBox[{"0.14230747862306384`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589317`"}], "-", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021056`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406221`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.295504524253052`"}], "-", 
        RowBox[{"0.1423074786230634`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497895`"}], "-", 
        RowBox[{"0.4620694805455467`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673711`"}], "+", 
        RowBox[{"0.31976200192248333`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028414`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224827`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694854`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181384`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028404`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636854`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526306`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813827`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589283`"}], "+", 
        RowBox[{"0.5761912177406211`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497894`"}], "+", 
        RowBox[{"0.4620694805455463`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.2044954757469484`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181383`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021048`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673708`"}], "-", 
        RowBox[{"0.3197620019224831`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028403`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.718498696363685`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305174`"}], "+", 
        RowBox[{"0.14230747862306306`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028407`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248244`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526301`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.256429215818138`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694887`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813855`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028412`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224846`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061043`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995795`"}], ",", 
       RowBox[{"0.13151188545020975`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406227`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.2044954757469482`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813893`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1315118854502127`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406221`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568197`", ",", 
       RowBox[{"0.6639926388028428`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224823`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694835`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.256429215818138`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995773`"}], ",", 
       RowBox[{"0.13151188545021197`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406202`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028394`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224842`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020978`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.576191217740621`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568136`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5910090485061026`"}], ",", 
       RowBox[{"0.2044954757469476`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181385`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028408`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248094`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284018`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636858`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021036`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406222`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.072983590296737`"}], "+", 
        RowBox[{"0.31976200192248344`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526312`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813805`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305246`"}], "-", 
        RowBox[{"0.14230747862306325`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028423`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248244`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.2044954757469491`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813843`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589433`"}], "-", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497906`"}], "-", 
        RowBox[{"0.4620694805455466`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880283987`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636847`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526297`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813727`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694846`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181378`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1315118854502102`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530516`"}], "+", 
        RowBox[{"0.14230747862306278`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589317`"}], "+", 
        RowBox[{"0.57619121774062`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673683`"}], "-", 
        RowBox[{"0.31976200192248283`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028404`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248155`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497897`"}], "+", 
        RowBox[{"0.4620694805455453`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526313`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181378`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673668`"}], "+", 
        RowBox[{"0.3197620019224838`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284315`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636859`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530516`"}], "+", 
        RowBox[{"0.14230747862306398`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589405`"}], "-", 
        RowBox[{"0.5761912177406215`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526313`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181378`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589405`"}], "-", 
        RowBox[{"0.5761912177406215`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.368488114549789`"}], "+", 
        RowBox[{"0.4620694805455481`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673666`"}], "+", 
        RowBox[{"0.3197620019224838`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526299`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813705`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530514`"}], "-", 
        RowBox[{"0.14230747862306392`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558929`"}], "+", 
        RowBox[{"0.5761912177406203`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.0729835902967365`"}], "-", 
        RowBox[{"0.31976200192248294`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589283`"}], "+", 
        RowBox[{"0.5761912177406201`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497877`"}], "-", 
        RowBox[{"0.4620694805455466`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284254`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636832`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526299`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813705`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673643`"}], "-", 
        RowBox[{"0.31976200192248294`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880283932`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636872`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061046`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530522`"}], "+", 
        RowBox[{"0.1423074786230645`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978864`"}], "+", 
        RowBox[{"0.462069480545549`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305296`"}], "-", 
        RowBox[{"0.14230747862306314`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995799`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3279852776056821`", ",", 
       RowBox[{"0.16399263880284304`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636861`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497911`"}], "-", 
        RowBox[{"0.46206948054554664`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880283857`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636841`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497866`"}], "-", 
        RowBox[{"0.4620694805455468`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568086`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.591009048506102`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305157`"}], "+", 
        RowBox[{"0.14230747862306217`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284248`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636835`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305085`"}], "-", 
        RowBox[{"0.14230747862306417`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995762`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978975`"}], "+", 
        RowBox[{"0.46206948054554464`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558951`"}], "-", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021275`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406228`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.2044954757469479`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181399`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021228`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406223`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.0729835902967367`"}], "+", 
        RowBox[{"0.3197620019224839`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028411`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224855`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.2044954757469481`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813927`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028414`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224853`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526319`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181377`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.459497163055893`"}], "+", 
        RowBox[{"0.5761912177406191`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.131511885450212`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406207`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694732`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813843`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021228`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406199`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673644`"}], "-", 
        RowBox[{"0.31976200192248283`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028388`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224839`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694688`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181385`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028387`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248433`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526297`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181365`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028409`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248416`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497889`"}], "+", 
        RowBox[{"0.46206948054554764`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673798`"}], "-", 
        RowBox[{"0.3197620019224832`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526305`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813977`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.204495475746948`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813927`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284262`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636859`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305185`"}], "+", 
        RowBox[{"0.14230747862306437`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589217`"}], "+", 
        RowBox[{"0.5761912177406238`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021253`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406225`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.66399263880284`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224837`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.532480753352629`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813904`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530509`"}], "-", 
        RowBox[{"0.1423074786230639`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978814`"}], "-", 
        RowBox[{"0.46206948054554675`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694743`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813855`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558904`"}], "-", 
        RowBox[{"0.5761912177406213`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673789`"}], "+", 
        RowBox[{"0.3197620019224829`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.163992638802842`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636835`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1315118854502121`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406203`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021036`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406223`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673684`"}], "+", 
        RowBox[{"0.3197620019224836`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880283965`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636865`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530521`"}], "-", 
        RowBox[{"0.14230747862306314`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028424`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248244`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526315`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181379`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589355`"}], "-", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454979036`"}], "-", 
        RowBox[{"0.46206948054554686`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694904`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181383`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021003`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406213`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305174`"}], "+", 
        RowBox[{"0.142307478623063`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589305`"}], "+", 
        RowBox[{"0.5761912177406208`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673665`"}], "-", 
        RowBox[{"0.3197620019224829`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028403`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248155`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978936`"}], "+", 
        RowBox[{"0.4620694805455454`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880283924`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636842`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526297`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181369`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694854`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813777`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284318`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636864`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526316`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181376`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673666`"}], "+", 
        RowBox[{"0.31976200192248405`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526309`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181379`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530515`"}], "+", 
        RowBox[{"0.14230747862306434`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558943`"}], "-", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673672`"}], "+", 
        RowBox[{"0.31976200192248405`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558948`"}], "-", 
        RowBox[{"0.5761912177406218`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497885`"}], "+", 
        RowBox[{"0.4620694805455481`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284232`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636832`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526297`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813716`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673632`"}], "-", 
        RowBox[{"0.31976200192248266`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526295`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181365`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.295504524253051`"}], "-", 
        RowBox[{"0.1423074786230638`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589317`"}], "+", 
        RowBox[{"0.5761912177406198`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673618`"}], "-", 
        RowBox[{"0.3197620019224827`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589333`"}], "+", 
        RowBox[{"0.5761912177406204`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978736`"}], "-", 
        RowBox[{"0.4620694805455465`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305207`"}], "-", 
        RowBox[{"0.14230747862306328`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028411`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224847`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497906`"}], "-", 
        RowBox[{"0.46206948054554664`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1639926388028399`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636864`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497907`"}], "-", 
        RowBox[{"0.4620694805455469`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.204495475746948`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813943`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1315118854502122`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406223`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530526`"}], "-", 
        RowBox[{"0.14230747862306306`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880283915`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.718498696363687`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530518`"}], "+", 
        RowBox[{"0.14230747862306298`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880283949`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636841`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021184`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406207`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028395`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248383`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978947`"}], "+", 
        RowBox[{"0.4620694805455451`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305157`"}], "+", 
        RowBox[{"0.1423074786230626`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978964`"}], "+", 
        RowBox[{"0.4620694805455453`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694732`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181385`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028386`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.718498696363684`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978914`"}], "+", 
        RowBox[{"0.46206948054554703`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530519`"}], "-", 
        RowBox[{"0.14230747862306337`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995785`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.32798527760568186`", ",", 
       RowBox[{"0.16399263880284135`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636851`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978975`"}], "-", 
        RowBox[{"0.46206948054554675`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284048`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636857`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061039`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305185`"}], "+", 
        RowBox[{"0.14230747862306384`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497888`"}], "-", 
        RowBox[{"0.46206948054554675`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568164`", ",", 
       RowBox[{"0.16399263880284032`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636847`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530519`"}], "+", 
        RowBox[{"0.14230747862306342`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028412`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636846`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061033`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995778`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978936`"}], "+", 
        RowBox[{"0.4620694805455463`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530514`"}], "-", 
        RowBox[{"0.14230747862306367`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.32798527760568214`", ",", 
       RowBox[{"0.663992638802842`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224823`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021175`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.576191217740622`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028411`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248455`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061043`"}], ",", 
       RowBox[{"0.20449547574694882`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181384`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1315118854502098`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406225`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694826`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181393`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995792`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995794`"}], ",", 
       RowBox[{"-", "0.5910090485061046`"}], ",", "0.32798527760568236`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5910090485061046`"}], ",", "0.3279852776056822`", ",", 
       
       RowBox[{"-", "0.7369762290995794`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.32798527760568197`", ",", 
       RowBox[{"-", "0.7369762290995788`"}], ",", 
       RowBox[{"-", "0.5910090485061043`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305224`"}], "-", 
        RowBox[{"0.14230747862306323`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589394`"}], "-", 
        RowBox[{"0.5761912177406215`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021003`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406225`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028421`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248255`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497905`"}], "-", 
        RowBox[{"0.4620694805455469`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673682`"}], "+", 
        RowBox[{"0.31976200192248383`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526315`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813793`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694915`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181385`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880283943`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636867`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530518`"}], "+", 
        RowBox[{"0.14230747862306298`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028404`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224818`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526298`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181371`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558929`"}], "+", 
        RowBox[{"0.5761912177406202`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497893`"}], "+", 
        RowBox[{"0.46206948054554536`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694837`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813755`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1315118854502097`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406213`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673661`"}], "-", 
        RowBox[{"0.3197620019224829`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880283887`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636841`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1315118854502124`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406225`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673826`"}], "-", 
        RowBox[{"0.31976200192248355`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284282`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636861`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530518`"}], "+", 
        RowBox[{"0.14230747862306461`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028412`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224856`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526305`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581814043`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589217`"}], "+", 
        RowBox[{"0.5761912177406229`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978886`"}], "+", 
        RowBox[{"0.4620694805455477`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694793`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813904`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1315118854502119`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406204`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305074`"}], "-", 
        RowBox[{"0.14230747862306414`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558912`"}], "-", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673801`"}], "+", 
        RowBox[{"0.3197620019224825`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028388`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248433`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497881`"}], "-", 
        RowBox[{"0.46206948054554686`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284207`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636834`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526282`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181395`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.2044954757469477`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181387`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028421`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248255`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1315118854502117`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.576191217740622`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.3279852776056821`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5910090485061043`"}], ",", 
       RowBox[{"0.20449547574694857`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813855`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028411`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224844`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.2044954757469481`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181392`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995789`"}], ",", 
       RowBox[{"0.1315118854502101`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406227`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028407`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224819`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061028`"}], ",", 
       RowBox[{"0.20449547574694754`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813827`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021142`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.576191217740621`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.2044954757469484`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813816`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995773`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3279852776056815`", ",", 
       RowBox[{"0.6639926388028398`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224836`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020961`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406211`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995794`"}], ",", 
       RowBox[{"0.5324807533526316`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181378`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673833`"}], "-", 
        RowBox[{"0.31976200192248355`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526301`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181392`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568214`", ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558943`"}], "-", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.0729835902967369`"}], "+", 
        RowBox[{"0.3197620019224837`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558923`"}], "+", 
        RowBox[{"0.5761912177406233`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061046`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028412`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224851`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1315118854502123`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406221`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673669`"}], "+", 
        RowBox[{"0.319762001922484`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526308`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.256429215818138`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694782`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813927`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028414`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224848`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694815`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181394`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589444`"}], "-", 
        RowBox[{"0.576191217740622`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021233`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406221`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028395`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224842`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526296`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181374`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694726`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181385`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1315118854502119`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406203`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694749`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181382`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589317`"}], "+", 
        RowBox[{"0.5761912177406199`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673623`"}], "-", 
        RowBox[{"0.3197620019224827`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028395`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248394`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021164`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406201`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673701`"}], "+", 
        RowBox[{"0.3197620019224835`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589444`"}], "-", 
        RowBox[{"0.5761912177406215`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497888`"}], "+", 
        RowBox[{"0.46206948054554803`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1639926388028421`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636856`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526316`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813793`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.0729835902967368`"}], "+", 
        RowBox[{"0.31976200192248383`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526311`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813805`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305207`"}], "+", 
        RowBox[{"0.14230747862306448`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589483`"}], "-", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673687`"}], "-", 
        RowBox[{"0.31976200192248316`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284165`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636841`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526297`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181372`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589294`"}], "+", 
        RowBox[{"0.5761912177406199`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526297`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813694`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530509`"}], "-", 
        RowBox[{"0.14230747862306387`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497878`"}], "-", 
        RowBox[{"0.46206948054554686`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673651`"}], "-", 
        RowBox[{"0.3197620019224827`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589294`"}], "+", 
        RowBox[{"0.5761912177406194`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284307`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.718498696363686`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021267`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406224`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673834`"}], "-", 
        RowBox[{"0.3197620019224836`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526307`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581814015`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305196`"}], "+", 
        RowBox[{"0.14230747862306445`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028413`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224853`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694812`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813954`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589206`"}], "+", 
        RowBox[{"0.5761912177406238`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978886`"}], "+", 
        RowBox[{"0.46206948054554847`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284237`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636831`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526285`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813916`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694726`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181384`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1315118854502123`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406203`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305085`"}], "-", 
        RowBox[{"0.14230747862306387`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558904`"}], "-", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673814`"}], "+", 
        RowBox[{"0.3197620019224823`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028388`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248394`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978736`"}], "-", 
        RowBox[{"0.46206948054554675`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.53248075335263`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581814`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673702`"}], "+", 
        RowBox[{"0.3197620019224839`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995795`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3279852776056827`", ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589206`"}], "+", 
        RowBox[{"0.5761912177406238`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526317`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181378`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558953`"}], "-", 
        RowBox[{"0.5761912177406218`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061048`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673855`"}], "-", 
        RowBox[{"0.31976200192248344`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526286`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.256429215818139`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.327985277605681`", ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558934`"}], "+", 
        RowBox[{"0.5761912177406192`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673657`"}], "-", 
        RowBox[{"0.31976200192248283`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558905`"}], "-", 
        RowBox[{"0.5761912177406213`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061023`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995773`"}], ",", 
       RowBox[{"0.5324807533526296`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181366`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673775`"}], "+", 
        RowBox[{"0.31976200192248194`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673816`"}], "-", 
        RowBox[{"0.3197620019224835`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028419`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248266`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020992`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406222`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028423`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248255`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526302`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813966`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694912`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181386`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406227`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694898`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181381`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558924`"}], "+", 
        RowBox[{"0.5761912177406233`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673801`"}], "+", 
        RowBox[{"0.31976200192248294`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028404`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224815`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1315118854502097`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406211`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.663992638802841`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.319762001922482`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.532480753352629`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181388`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694826`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813755`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021003`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.576191217740621`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694873`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181375`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558909`"}], "-", 
        RowBox[{"0.5761912177406219`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454979047`"}], "-", 
        RowBox[{"0.46206948054554664`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305257`"}], "-", 
        RowBox[{"0.14230747862306312`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028413`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248516`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694807`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.256429215818139`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880283999`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636861`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497904`"}], "-", 
        RowBox[{"0.4620694805455468`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1639926388028402`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.718498696363686`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021184`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406223`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530524`"}], "-", 
        RowBox[{"0.14230747862306323`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497895`"}], "+", 
        RowBox[{"0.46206948054554536`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694765`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813855`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880283993`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636846`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530516`"}], "+", 
        RowBox[{"0.14230747862306267`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028396`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636844`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1315118854502115`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406208`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028389`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224839`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497894`"}], "+", 
        RowBox[{"0.46206948054554553`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305146`"}], "+", 
        RowBox[{"0.14230747862306276`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530522`"}], "-", 
        RowBox[{"0.14230747862306317`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995793`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497888`"}], "+", 
        RowBox[{"0.4620694805455485`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284196`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636851`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454979075`"}], "-", 
        RowBox[{"0.4620694805455467`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.3279852776056824`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5910090485061041`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305207`"}], "+", 
        RowBox[{"0.1423074786230644`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880283924`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.718498696363687`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530517`"}], "+", 
        RowBox[{"0.1423074786230632`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284182`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636845`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061031`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995768`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497897`"}], "+", 
        RowBox[{"0.46206948054554536`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305096`"}], "-", 
        RowBox[{"0.14230747862306403`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497873`"}], "-", 
        RowBox[{"0.4620694805455468`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568114`", ",", 
       RowBox[{"0.16399263880283868`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636838`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305185`"}], "+", 
        RowBox[{"0.14230747862306398`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.736976229099579`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454979036`"}], "-", 
        RowBox[{"0.46206948054554675`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284035`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636857`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.368488114549789`"}], "+", 
        RowBox[{"0.4620694805455475`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.3279852776056821`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5910090485061043`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530523`"}], "-", 
        RowBox[{"0.14230747862306328`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284226`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636858`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530513`"}], "-", 
        RowBox[{"0.14230747862306367`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028402`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636847`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.591009048506103`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995773`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497883`"}], "-", 
        RowBox[{"0.4620694805455467`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530516`"}], "+", 
        RowBox[{"0.14230747862306287`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978936`"}], "+", 
        RowBox[{"0.46206948054554553`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.3279852776056814`", ",", 
       RowBox[{"0.16399263880284168`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636837`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526308`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581814004`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.2044954757469487`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813816`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028428`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.319762001922482`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694918`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813843`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558923`"}], "+", 
        RowBox[{"0.5761912177406239`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020964`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406231`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.663992638802843`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248194`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021003`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406228`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673804`"}], "-", 
        RowBox[{"0.31976200192248394`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526285`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813966`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694832`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181375`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028401`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248094`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694812`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181377`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558906`"}], "-", 
        RowBox[{"0.5761912177406218`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020925`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406209`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028403`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248116`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020887`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406207`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673818`"}], "+", 
        RowBox[{"0.31976200192248283`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.591009048506105`"}], ",", "0.3279852776056825`", ",", 
       RowBox[{"-", "0.7369762290995799`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.327985277605682`", ",", 
       RowBox[{"-", "0.7369762290995787`"}], ",", 
       RowBox[{"-", "0.5910090485061041`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995797`"}], ",", 
       RowBox[{"-", "0.5910090485061049`"}], ",", "0.3279852776056826`"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497888`"}], "+", 
        RowBox[{"0.46206948054554864`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673653`"}], "+", 
        RowBox[{"0.31976200192248394`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589566`"}], "-", 
        RowBox[{"0.5761912177406215`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673632`"}], "+", 
        RowBox[{"0.3197620019224842`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.163992638802844`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636865`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526326`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813727`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558943`"}], "-", 
        RowBox[{"0.5761912177406213`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526313`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181377`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305174`"}], "+", 
        RowBox[{"0.1423074786230644`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.368488114549787`"}], "-", 
        RowBox[{"0.4620694805455467`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.0729835902967361`"}], "-", 
        RowBox[{"0.31976200192248266`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589317`"}], "+", 
        RowBox[{"0.5761912177406201`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673615`"}], "-", 
        RowBox[{"0.3197620019224827`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284298`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636825`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526299`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.256429215818137`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558932`"}], "+", 
        RowBox[{"0.5761912177406188`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526295`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181357`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.295504524253051`"}], "-", 
        RowBox[{"0.1423074786230642`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526303`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813966`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.072983590296738`"}], "-", 
        RowBox[{"0.3197620019224835`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880283987`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636865`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530522`"}], "-", 
        RowBox[{"0.14230747862306325`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558923`"}], "+", 
        RowBox[{"0.5761912177406228`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526303`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813954`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589244`"}], "+", 
        RowBox[{"0.5761912177406225`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454979`"}], "-", 
        RowBox[{"0.46206948054554686`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673786`"}], "-", 
        RowBox[{"0.3197620019224834`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.532480753352629`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813893`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305185`"}], "+", 
        RowBox[{"0.14230747862306298`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558916`"}], "-", 
        RowBox[{"0.5761912177406215`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673779`"}], "+", 
        RowBox[{"0.31976200192248266`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558914`"}], "-", 
        RowBox[{"0.5761912177406215`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497893`"}], "+", 
        RowBox[{"0.46206948054554586`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880283935`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636842`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.532480753352629`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813893`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.0729835902967377`"}], "+", 
        RowBox[{"0.31976200192248283`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530516`"}], "+", 
        RowBox[{"0.14230747862306434`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589433`"}], "-", 
        RowBox[{"0.5761912177406218`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526315`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181378`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589455`"}], "-", 
        RowBox[{"0.5761912177406215`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497886`"}], "+", 
        RowBox[{"0.46206948054554814`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673693`"}], "+", 
        RowBox[{"0.31976200192248394`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526308`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813805`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673716`"}], "+", 
        RowBox[{"0.3197620019224838`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284215`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636855`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530509`"}], "-", 
        RowBox[{"0.14230747862306353`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558933`"}], "+", 
        RowBox[{"0.5761912177406198`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526301`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813755`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589305`"}], "+", 
        RowBox[{"0.5761912177406199`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497876`"}], "-", 
        RowBox[{"0.4620694805455464`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673686`"}], "-", 
        RowBox[{"0.3197620019224831`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526298`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813705`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673643`"}], "-", 
        RowBox[{"0.3197620019224829`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028417`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636841`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.32798527760568236`", ",", 
       RowBox[{"0.16399263880284323`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636862`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454979136`"}], "-", 
        RowBox[{"0.4620694805455467`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880283899`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636872`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061051`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305207`"}], "+", 
        RowBox[{"0.14230747862306498`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978864`"}], "+", 
        RowBox[{"0.46206948054554836`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305285`"}], "-", 
        RowBox[{"0.14230747862306306`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995797`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.736976229099579`"}], ",", 
       RowBox[{"0.13151188545021017`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406228`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694807`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813927`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021222`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406223`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568225`", ",", 
       RowBox[{"0.6639926388028426`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248216`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694885`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813843`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.663992638802841`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224846`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061043`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5910090485061045`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530529`"}], "-", 
        RowBox[{"0.14230747862306303`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284373`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636864`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530519`"}], "+", 
        RowBox[{"0.1423074786230644`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.73697622909958`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454979197`"}], "-", 
        RowBox[{"0.4620694805455467`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880283985`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636861`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497888`"}], "+", 
        RowBox[{"0.46206948054554847`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568247`"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284135`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636852`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021064`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406221`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305185`"}], "+", 
        RowBox[{"0.14230747862306398`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497891`"}], "+", 
        RowBox[{"0.4620694805455472`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305185`"}], "+", 
        RowBox[{"0.14230747862306387`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028417`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224826`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694857`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181384`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028417`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636857`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.368488114549789`"}], "+", 
        RowBox[{"0.4620694805455476`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284123`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636847`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497887`"}], "-", 
        RowBox[{"0.46206948054554675`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694837`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813805`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021042`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305146`"}], "-", 
        RowBox[{"0.1423074786230637`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284132`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636844`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530515`"}], "-", 
        RowBox[{"0.14230747862306375`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028407`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248216`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497882`"}], "-", 
        RowBox[{"0.4620694805455467`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673702`"}], "+", 
        RowBox[{"0.31976200192248344`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558924`"}], "+", 
        RowBox[{"0.576191217740623`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.591009048506104`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995786`"}], ",", 
       RowBox[{"0.5324807533526311`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813805`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.0729835902967381`"}], "-", 
        RowBox[{"0.31976200192248344`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526302`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181394`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.3279852776056823`", ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558945`"}], "-", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673707`"}], "-", 
        RowBox[{"0.3197620019224831`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995778`"}], ",", 
       RowBox[{"0.5324807533526291`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813893`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589133`"}], "-", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526297`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181374`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568097`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.591009048506103`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673791`"}], "+", 
        RowBox[{"0.3197620019224827`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589317`"}], "+", 
        RowBox[{"0.5761912177406199`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995793`"}], ",", 
       RowBox[{"0.1315118854502124`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406222`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694937`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181385`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545020998`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406227`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.3279852776056824`", ",", 
       RowBox[{"0.6639926388028415`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224858`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694812`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813954`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028432`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224822`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061047`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284218`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636855`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497888`"}], "+", 
        RowBox[{"0.4620694805455476`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.2044954757469487`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813855`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021014`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406224`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530519`"}], "+", 
        RowBox[{"0.14230747862306392`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284215`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636857`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305196`"}], "+", 
        RowBox[{"0.14230747862306428`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028422`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224824`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978886`"}], "+", 
        RowBox[{"0.4620694805455481`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284182`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636841`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1315118854502098`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305124`"}], "-", 
        RowBox[{"0.1423074786230637`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978836`"}], "-", 
        RowBox[{"0.46206948054554686`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305135`"}], "-", 
        RowBox[{"0.14230747862306367`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028405`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224816`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694832`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181379`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284168`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.718498696363684`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497877`"}], "-", 
        RowBox[{"0.4620694805455467`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.32798527760568214`", ",", 
       RowBox[{"0.663992638802841`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224846`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021003`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406227`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.663992638802842`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224824`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061044`"}], ",", 
       RowBox[{"0.20449547574694807`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181392`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021208`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.576191217740622`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.204495475746949`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181384`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995793`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1315118854502102`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406227`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568214`", ",", 
       RowBox[{"0.6639926388028412`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224844`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694787`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181392`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028423`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248244`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061044`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995789`"}], ",", 
       RowBox[{"0.13151188545021125`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406219`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.2044954757469487`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181385`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545020975`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406211`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.2044954757469473`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181385`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995775`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.32798527760568147`", ",", 
       RowBox[{"0.6639926388028407`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224817`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021125`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.576191217740621`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028398`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224835`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061028`"}], ",", 
       RowBox[{"0.20449547574694832`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813816`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.2044954757469481`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813916`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028413`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224848`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526316`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181379`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589483`"}], "-", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021256`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406227`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694793`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813966`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1315118854502122`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406223`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673676`"}], "+", 
        RowBox[{"0.3197620019224839`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028412`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224854`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694754`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813855`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589294`"}], "+", 
        RowBox[{"0.5761912177406193`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021184`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406207`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028391`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248366`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021203`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406201`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673654`"}], "-", 
        RowBox[{"0.3197620019224829`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526297`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813694`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.2044954757469471`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813855`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028389`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248416`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021206`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406222`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568225`", ",", 
       RowBox[{"0.6639926388028424`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.319762001922482`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694893`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181385`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028413`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.319762001922485`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061047`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995793`"}], ",", 
       RowBox[{"0.13151188545020984`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.576191217740623`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694785`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813954`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1315118854502116`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406208`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694843`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813766`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.736976229099577`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3279852776056813`", ",", 
       RowBox[{"0.663992638802839`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248383`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1315118854502093`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.576191217740621`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028405`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.319762001922481`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061025`"}], ",", 
       RowBox[{"0.20449547574694726`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813866`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.591009048506104`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305196`"}], "+", 
        RowBox[{"0.14230747862306398`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284007`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636861`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305207`"}], "-", 
        RowBox[{"0.1423074786230633`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995787`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978897`"}], "+", 
        RowBox[{"0.46206948054554753`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1639926388028416`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636852`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978997`"}], "-", 
        RowBox[{"0.46206948054554675`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.3279852776056821`"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497886`"}], "+", 
        RowBox[{"0.462069480545548`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305185`"}], "+", 
        RowBox[{"0.1423074786230644`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028426`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248194`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694882`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181384`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284234`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636856`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497887`"}], "+", 
        RowBox[{"0.4620694805455482`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284218`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636855`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020984`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406228`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.295504524253052`"}], "+", 
        RowBox[{"0.14230747862306437`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497879`"}], "-", 
        RowBox[{"0.46206948054554703`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694843`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.256429215818138`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284196`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636841`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.295504524253051`"}], "-", 
        RowBox[{"0.14230747862306395`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028421`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636839`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1315118854502097`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406212`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028405`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248083`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978775`"}], "-", 
        RowBox[{"0.46206948054554686`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.295504524253051`"}], "-", 
        RowBox[{"0.14230747862306392`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995796`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497888`"}], "+", 
        RowBox[{"0.46206948054554825`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.295504524253053`"}], "-", 
        RowBox[{"0.14230747862306303`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497906`"}], "-", 
        RowBox[{"0.4620694805455467`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568197`", ",", 
       RowBox[{"0.16399263880284298`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636864`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305207`"}], "+", 
        RowBox[{"0.1423074786230644`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880283968`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636868`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061048`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5910090485061047`"}], ",", 
       RowBox[{"0.204495475746948`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813954`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028432`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248194`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694904`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181384`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995796`"}], ",", 
       RowBox[{"0.1315118854502128`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406225`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028411`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224846`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021006`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406229`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568247`"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305196`"}], "+", 
        RowBox[{"0.14230747862306417`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028422`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224825`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497889`"}], "+", 
        RowBox[{"0.46206948054554786`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1639926388028425`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.718498696363686`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978886`"}], "+", 
        RowBox[{"0.46206948054554786`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694915`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181385`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545020986`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406228`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.295504524253052`"}], "+", 
        RowBox[{"0.1423074786230641`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284265`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636859`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305107`"}], "-", 
        RowBox[{"0.1423074786230637`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284204`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636836`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020953`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.576191217740621`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028405`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248194`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497878`"}], "-", 
        RowBox[{"0.46206948054554664`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.295504524253051`"}], "-", 
        RowBox[{"0.1423074786230639`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978764`"}], "-", 
        RowBox[{"0.46206948054554664`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694826`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181378`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028421`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636837`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.3279852776056822`", ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558924`"}], "+", 
        RowBox[{"0.5761912177406225`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526312`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181381`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589416`"}], "-", 
        RowBox[{"0.5761912177406215`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061041`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673802`"}], "-", 
        RowBox[{"0.31976200192248344`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526305`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813977`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673702`"}], "+", 
        RowBox[{"0.31976200192248355`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995794`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526311`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181381`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673775`"}], "-", 
        RowBox[{"0.31976200192248333`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995792`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3279852776056824`", ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558943`"}], "-", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526306`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581814015`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589194`"}], "+", 
        RowBox[{"0.5761912177406235`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061044`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673675`"}], "+", 
        RowBox[{"0.319762001922484`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.53248075335263`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181372`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568125`", ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558906`"}], "-", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.0729835902967377`"}], "+", 
        RowBox[{"0.3197620019224827`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589294`"}], "+", 
        RowBox[{"0.5761912177406201`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061029`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.736976229099577`"}], ",", 
       RowBox[{"0.5324807533526283`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813943`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673643`"}], "-", 
        RowBox[{"0.3197620019224828`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5910090485061043`"}], ",", 
       RowBox[{"0.20449547574694876`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181385`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028412`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224844`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694815`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181387`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995785`"}], ",", 
       RowBox[{"0.13151188545021059`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406221`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028417`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224828`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021159`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406221`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.3279852776056821`"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1315118854502124`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406223`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.0729835902967367`"}], "+", 
        RowBox[{"0.31976200192248405`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028412`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224857`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694804`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813916`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028413`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248516`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526318`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813766`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589516`"}], "-", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021283`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406228`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694785`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813977`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021203`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406204`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694743`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181386`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558932`"}], "+", 
        RowBox[{"0.5761912177406193`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673655`"}], "-", 
        RowBox[{"0.3197620019224827`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028389`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224839`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1315118854502123`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406197`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028384`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248433`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526297`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181366`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694676`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813843`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.2044954757469495`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813877`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284318`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636859`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497887`"}], "+", 
        RowBox[{"0.4620694805455485`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284265`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636861`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021011`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406227`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530515`"}], "+", 
        RowBox[{"0.14230747862306437`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497885`"}], "+", 
        RowBox[{"0.46206948054554836`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530524`"}], "+", 
        RowBox[{"0.1423074786230645`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028432`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248233`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694865`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813743`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284215`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636837`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.368488114549787`"}], "-", 
        RowBox[{"0.46206948054554636`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284226`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636832`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020953`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406211`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530509`"}], "-", 
        RowBox[{"0.14230747862306414`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.368488114549787`"}], "-", 
        RowBox[{"0.4620694805455469`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305057`"}], "-", 
        RowBox[{"0.14230747862306337`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028404`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248094`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589217`"}], "+", 
        RowBox[{"0.5761912177406224`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978986`"}], "-", 
        RowBox[{"0.46206948054554664`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673789`"}], "-", 
        RowBox[{"0.31976200192248333`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526303`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181394`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673779`"}], "-", 
        RowBox[{"0.3197620019224834`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284004`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636864`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530522`"}], "-", 
        RowBox[{"0.14230747862306317`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558921`"}], "+", 
        RowBox[{"0.5761912177406231`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526301`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813977`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589183`"}], "-", 
        RowBox[{"0.5761912177406218`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526291`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181389`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305185`"}], "+", 
        RowBox[{"0.14230747862306292`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978947`"}], "+", 
        RowBox[{"0.46206948054554586`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673762`"}], "+", 
        RowBox[{"0.31976200192248266`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558913`"}], "-", 
        RowBox[{"0.5761912177406218`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673779`"}], "+", 
        RowBox[{"0.319762001922483`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880283962`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636844`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526288`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813927`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5910090485061041`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673696`"}], "+", 
        RowBox[{"0.31976200192248344`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558921`"}], "+", 
        RowBox[{"0.5761912177406227`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.0729835902967379`"}], "-", 
        RowBox[{"0.3197620019224833`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995792`"}], ",", 
       RowBox[{"0.5324807533526311`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813805`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589416`"}], "-", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526303`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181399`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568214`"}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.52620667712547*^9, 3.5262067362777233`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1.`", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1.`", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1.`"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.32798527760568197`", ",", 
       RowBox[{"0.16399263880284023`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636859`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978864`"}], "+", 
        RowBox[{"0.46206948054554764`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.163992638802842`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636859`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061041`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305207`"}], "-", 
        RowBox[{"0.1423074786230634`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497906`"}], "-", 
        RowBox[{"0.4620694805455465`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530519`"}], "+", 
        RowBox[{"0.14230747862306387`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995795`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.532480753352631`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181378`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305257`"}], "-", 
        RowBox[{"0.14230747862306348`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028424`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224825`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694893`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181387`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558939`"}], "-", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497903`"}], "-", 
        RowBox[{"0.46206948054554675`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1639926388028401`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636864`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1315118854502103`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406225`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673661`"}], "+", 
        RowBox[{"0.3197620019224835`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526295`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813727`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694843`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181378`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028396`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636846`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530518`"}], "+", 
        RowBox[{"0.14230747862306284`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558927`"}], "+", 
        RowBox[{"0.5761912177406203`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1315118854502099`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406212`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028407`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248155`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978964`"}], "+", 
        RowBox[{"0.46206948054554553`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673687`"}], "-", 
        RowBox[{"0.3197620019224824`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9009688679024193`"}], "+", 
        RowBox[{"0.4338837391175599`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.6234898018587329`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.781831482468033`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.2225209339563179`"}], "-", 
        RowBox[{"0.9749279121818252`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9009688679024177`"}], "-", 
        RowBox[{"0.4338837391175591`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.6234898018587303`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824680297`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395631686`"}], "+", 
        RowBox[{"0.9749279121818207`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5910090485061039`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673793`"}], "-", 
        RowBox[{"0.3197620019224834`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589405`"}], "-", 
        RowBox[{"0.5761912177406212`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673707`"}], "+", 
        RowBox[{"0.3197620019224835`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995792`"}], ",", 
       RowBox[{"0.5324807533526303`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181398`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558922`"}], "+", 
        RowBox[{"0.5761912177406228`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526311`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813793`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568225`"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.6234898018587351`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824680299`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.2225209339563134`"}], "+", 
        RowBox[{"0.9749279121818247`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9009688679024204`"}], "-", 
        RowBox[{"0.4338837391175575`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024188`"}], "+", 
        RowBox[{"0.4338837391175568`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6234898018587338`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7818314824680282`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.222520933956313`"}], "-", 
        RowBox[{"0.9749279121818231`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497888`"}], "+", 
        RowBox[{"0.46206948054554786`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568214`", ",", 
       RowBox[{"0.16399263880283974`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636864`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305246`"}], "-", 
        RowBox[{"0.1423074786230631`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028424`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636857`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061045`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995795`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454979097`"}], "-", 
        RowBox[{"0.46206948054554686`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.295504524253052`"}], "+", 
        RowBox[{"0.14230747862306445`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497879`"}], "-", 
        RowBox[{"0.46206948054554686`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305185`"}], "+", 
        RowBox[{"0.14230747862306276`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995768`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3279852776056816`", ",", 
       RowBox[{"0.16399263880284182`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636836`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497895`"}], "+", 
        RowBox[{"0.46206948054554514`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1639926388028393`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636842`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061027`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530508`"}], "-", 
        RowBox[{"0.14230747862306395`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558924`"}], "+", 
        RowBox[{"0.5761912177406229`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526307`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813816`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568214`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5910090485061048`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673814`"}], "-", 
        RowBox[{"0.3197620019224838`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558947`"}], "-", 
        RowBox[{"0.5761912177406218`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673633`"}], "+", 
        RowBox[{"0.3197620019224841`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.73697622909958`"}], ",", 
       RowBox[{"0.5324807533526306`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181407`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589133`"}], "-", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061024`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673612`"}], "-", 
        RowBox[{"0.3197620019224825`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526297`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813777`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673801`"}], "+", 
        RowBox[{"0.3197620019224825`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995765`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3279852776056815`", ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589294`"}], "+", 
        RowBox[{"0.5761912177406195`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.532480753352628`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181396`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6234898018587334`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.781831482468031`", " ", "\[ImaginaryI]"}]}], ",", "0", ",",
        "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395631517`"}], "-", 
        RowBox[{"0.974927912181824`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024195`"}], "+", 
        RowBox[{"0.4338837391175594`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6234898018587323`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824680297`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395631495`"}], "+", 
        RowBox[{"0.974927912181823`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024179`"}], "-", 
        RowBox[{"0.4338837391175586`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395631306`"}], "+", 
        RowBox[{"0.9749279121818255`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024217`"}], "-", 
        RowBox[{"0.4338837391175567`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.623489801858735`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824680295`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.6234898018587341`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7818314824680284`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.22252093395631237`"}], "-", 
        RowBox[{"0.9749279121818225`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024187`"}], "+", 
        RowBox[{"0.43388373911755523`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673782`"}], "-", 
        RowBox[{"0.3197620019224833`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589233`"}], "+", 
        RowBox[{"0.5761912177406227`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454979`"}], "-", 
        RowBox[{"0.46206948054554675`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1639926388028402`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636859`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526303`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813943`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673777`"}], "-", 
        RowBox[{"0.31976200192248344`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526302`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181395`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305235`"}], "-", 
        RowBox[{"0.14230747862306314`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558923`"}], "+", 
        RowBox[{"0.576191217740623`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673776`"}], "+", 
        RowBox[{"0.31976200192248283`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028399`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636846`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526292`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813904`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558915`"}], "-", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526292`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181389`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530517`"}], "+", 
        RowBox[{"0.14230747862306287`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978936`"}], "+", 
        RowBox[{"0.4620694805455459`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673768`"}], "+", 
        RowBox[{"0.31976200192248266`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558912`"}], "-", 
        RowBox[{"0.5761912177406215`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.900968867902421`"}], "-", 
        RowBox[{"0.43388373911755745`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.6234898018587359`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824680298`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.22252093395631362`"}], "+", 
        RowBox[{"0.9749279121818246`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395631325`"}], "-", 
        RowBox[{"0.9749279121818231`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9009688679024185`"}], "+", 
        RowBox[{"0.43388373911755623`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.623489801858734`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7818314824680275`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.22252093395631362`"}], "+", 
        RowBox[{"0.9749279121818244`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.900968867902421`"}], "-", 
        RowBox[{"0.4338837391175573`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.6234898018587363`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824680298`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.22252093395631334`"}], "-", 
        RowBox[{"0.9749279121818233`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024186`"}], "+", 
        RowBox[{"0.4338837391175561`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.6234898018587341`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7818314824680271`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.2044954757469485`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813843`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558932`"}], "-", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978964`"}], "-", 
        RowBox[{"0.46206948054554664`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284018`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.718498696363686`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1315118854502104`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406225`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673704`"}], "+", 
        RowBox[{"0.3197620019224836`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526311`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813793`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530524`"}], "-", 
        RowBox[{"0.14230747862306312`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028423`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224823`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694843`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181384`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880283987`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636845`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526298`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181372`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558929`"}], "+", 
        RowBox[{"0.576191217740621`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020998`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406212`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305157`"}], "+", 
        RowBox[{"0.14230747862306276`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497894`"}], "+", 
        RowBox[{"0.46206948054554625`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673679`"}], "-", 
        RowBox[{"0.3197620019224827`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028404`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248155`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "1.0000000000000013`", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1.0000000000000016`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.0000000000000007`", ",", "0", ",", "0"}], "}"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0.9999999999999993`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999999987`", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0.9999999999999984`", ",", "0"}], "}"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.623489801858733`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7818314824680325`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395631756`"}], "-", 
        RowBox[{"0.9749279121818253`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9009688679024195`"}], "+", 
        RowBox[{"0.43388373911756023`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024173`"}], "-", 
        RowBox[{"0.4338837391175592`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6234898018587308`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824680297`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395631653`"}], "+", 
        RowBox[{"0.9749279121818207`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.6234898018587381`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824680295`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.22252093395631212`"}], "+", 
        RowBox[{"0.9749279121818261`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024235`"}], "-", 
        RowBox[{"0.43388373911755596`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395631128`"}], "-", 
        RowBox[{"0.9749279121818224`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024181`"}], "+", 
        RowBox[{"0.43388373911755335`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6234898018587349`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7818314824680254`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558937`"}], "-", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978897`"}], "+", 
        RowBox[{"0.4620694805455479`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673678`"}], "+", 
        RowBox[{"0.3197620019224837`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526315`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813805`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673686`"}], "+", 
        RowBox[{"0.319762001922484`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284304`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636862`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530519`"}], "+", 
        RowBox[{"0.14230747862306453`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558953`"}], "-", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526322`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813743`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.459497163055893`"}], "+", 
        RowBox[{"0.5761912177406205`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526297`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813716`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305074`"}], "-", 
        RowBox[{"0.14230747862306398`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978797`"}], "-", 
        RowBox[{"0.46206948054554664`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673654`"}], "-", 
        RowBox[{"0.3197620019224827`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589305`"}], "+", 
        RowBox[{"0.5761912177406189`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673661`"}], "-", 
        RowBox[{"0.31976200192248294`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284226`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636831`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526298`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181362`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028422`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224821`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020992`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.576191217740623`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673829`"}], "-", 
        RowBox[{"0.3197620019224835`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526302`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181393`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694896`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181385`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028422`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248216`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694887`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813843`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558924`"}], "+", 
        RowBox[{"0.5761912177406234`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020984`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406229`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028407`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224816`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526292`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813904`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694846`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181378`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545020934`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.576191217740621`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.2044954757469483`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181378`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558908`"}], "-", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673818`"}], "+", 
        RowBox[{"0.3197620019224825`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028405`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248144`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020936`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.576191217740621`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395631278`"}], "+", 
        RowBox[{"0.9749279121818261`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9009688679024218`"}], "-", 
        RowBox[{"0.4338837391175569`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.6234898018587351`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824680298`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024184`"}], "+", 
        RowBox[{"0.43388373911755523`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.6234898018587339`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7818314824680282`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.22252093395631187`"}], "-", 
        RowBox[{"0.9749279121818221`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028423`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224824`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061046`"}], ",", 
       RowBox[{"0.204495475746948`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813927`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021236`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406224`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694932`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181385`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995797`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3279852776056822`", ",", 
       RowBox[{"0.6639926388028412`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248494`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020986`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406229`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028404`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248166`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021197`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406202`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568147`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5910090485061026`"}], ",", 
       RowBox[{"0.20449547574694843`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813743`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028392`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248383`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694726`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181385`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995766`"}], ",", 
       RowBox[{"0.13151188545020948`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406211`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028417`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224825`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978886`"}], "+", 
        RowBox[{"0.4620694805455477`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530518`"}], "+", 
        RowBox[{"0.14230747862306414`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978897`"}], "+", 
        RowBox[{"0.46206948054554825`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694904`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813855`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284273`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.718498696363686`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305196`"}], "+", 
        RowBox[{"0.1423074786230645`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.163992638802843`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636861`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020967`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406233`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028408`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248194`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978786`"}], "-", 
        RowBox[{"0.46206948054554664`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530509`"}], "-", 
        RowBox[{"0.14230747862306403`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497883`"}], "-", 
        RowBox[{"0.4620694805455469`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694843`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813766`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028423`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636831`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530514`"}], "-", 
        RowBox[{"0.1423074786230639`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284204`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636834`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020903`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406209`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673777`"}], "-", 
        RowBox[{"0.3197620019224833`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028418`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636855`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021159`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.576191217740622`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028414`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248483`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526307`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181398`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.295504524253052`"}], "+", 
        RowBox[{"0.14230747862306428`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978875`"}], "+", 
        RowBox[{"0.4620694805455485`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694796`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181395`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589206`"}], "+", 
        RowBox[{"0.5761912177406239`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673773`"}], "+", 
        RowBox[{"0.31976200192248283`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028392`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248366`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978736`"}], "-", 
        RowBox[{"0.46206948054554675`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284146`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636842`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526287`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813893`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694718`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813855`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021145`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406212`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305107`"}], "-", 
        RowBox[{"0.14230747862306378`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589033`"}], "-", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558926`"}], "+", 
        RowBox[{"0.5761912177406227`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021145`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406219`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.295504524253052`"}], "+", 
        RowBox[{"0.14230747862306406`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978886`"}], "+", 
        RowBox[{"0.4620694805455472`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673818`"}], "-", 
        RowBox[{"0.31976200192248294`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028411`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248394`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.2044954757469482`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813904`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284173`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636858`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526299`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813943`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558917`"}], "-", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497885`"}], "-", 
        RowBox[{"0.4620694805455466`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694743`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813866`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021122`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406209`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.0729835902967374`"}], "+", 
        RowBox[{"0.31976200192248266`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284176`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636846`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305135`"}], "-", 
        RowBox[{"0.14230747862306392`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028402`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224838`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526291`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181384`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1315118854502099`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406235`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673872`"}], "-", 
        RowBox[{"0.31976200192248355`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028435`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248166`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694937`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181382`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028425`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224825`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526303`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181401`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589206`"}], "+", 
        RowBox[{"0.5761912177406238`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020967`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.576191217740623`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.2044954757469496`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813893`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1315118854502088`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406209`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694826`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813755`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558904`"}], "-", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673816`"}], "+", 
        RowBox[{"0.3197620019224819`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028407`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224814`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1315118854502094`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406208`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.66399263880284`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224802`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526285`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813916`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694907`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813716`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497903`"}], "-", 
        RowBox[{"0.46206948054554653`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673675`"}], "+", 
        RowBox[{"0.3197620019224838`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.663992638802843`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248194`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694907`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181383`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028396`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636862`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526317`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813766`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558942`"}], "-", 
        RowBox[{"0.5761912177406212`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1315118854502099`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.576191217740623`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530526`"}], "-", 
        RowBox[{"0.14230747862306314`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497899`"}], "+", 
        RowBox[{"0.4620694805455454`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694854`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813805`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558931`"}], "+", 
        RowBox[{"0.5761912177406201`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673662`"}], "-", 
        RowBox[{"0.31976200192248283`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880283915`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636844`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020948`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406211`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028403`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224809`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526297`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813666`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530515`"}], "+", 
        RowBox[{"0.14230747862306223`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694812`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181391`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589233`"}], "+", 
        RowBox[{"0.576191217740623`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.368488114549789`"}], "+", 
        RowBox[{"0.4620694805455478`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1639926388028429`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636861`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021247`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406225`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673826`"}], "-", 
        RowBox[{"0.3197620019224836`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526303`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813977`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305185`"}], "+", 
        RowBox[{"0.14230747862306425`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028411`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224848`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.2044954757469476`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181384`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284215`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636832`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.532480753352629`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181392`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558911`"}], "-", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021203`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406203`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305124`"}], "-", 
        RowBox[{"0.14230747862306392`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978797`"}], "-", 
        RowBox[{"0.46206948054554664`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.072983590296738`"}], "+", 
        RowBox[{"0.31976200192248244`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028394`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224839`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028428`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248205`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497913`"}], "-", 
        RowBox[{"0.46206948054554664`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.0729835902967365`"}], "+", 
        RowBox[{"0.3197620019224841`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526309`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181379`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694898`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181384`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880283949`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636865`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305257`"}], "-", 
        RowBox[{"0.14230747862306317`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589494`"}], "-", 
        RowBox[{"0.5761912177406215`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020975`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406233`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028405`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248094`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.53248075335263`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181375`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305146`"}], "+", 
        RowBox[{"0.14230747862306276`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978975`"}], "+", 
        RowBox[{"0.4620694805455447`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694857`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181377`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589294`"}], "+", 
        RowBox[{"0.5761912177406193`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673619`"}], "-", 
        RowBox[{"0.31976200192248255`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880283904`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636844`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020906`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406209`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.2044954757469481`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813916`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558943`"}], "-", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021206`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406223`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028409`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224839`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021153`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406219`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673704`"}], "+", 
        RowBox[{"0.3197620019224835`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526309`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813816`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694812`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181391`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028412`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224846`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694754`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181383`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028403`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224836`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526299`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181376`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589283`"}], "+", 
        RowBox[{"0.57619121774062`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021136`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406212`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694765`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181385`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021175`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406207`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673684`"}], "-", 
        RowBox[{"0.319762001922483`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028395`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248366`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526309`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813793`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694896`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181385`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028396`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636861`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530522`"}], "-", 
        RowBox[{"0.14230747862306328`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558944`"}], "-", 
        RowBox[{"0.5761912177406215`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021014`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406225`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028419`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224825`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454979047`"}], "-", 
        RowBox[{"0.46206948054554686`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.0729835902967368`"}], "+", 
        RowBox[{"0.3197620019224837`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.53248075335263`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181375`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305185`"}], "+", 
        RowBox[{"0.14230747862306298`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028405`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.319762001922482`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.2044954757469485`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181377`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558929`"}], "+", 
        RowBox[{"0.57619121774062`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978947`"}], "+", 
        RowBox[{"0.4620694805455453`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880283937`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636846`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020956`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406212`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673686`"}], "-", 
        RowBox[{"0.3197620019224829`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995787`"}], ",", 
       RowBox[{"0.5324807533526302`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813927`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673694`"}], "+", 
        RowBox[{"0.3197620019224836`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526309`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813805`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.3279852776056822`", ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589217`"}], "+", 
        RowBox[{"0.576191217740623`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673787`"}], "-", 
        RowBox[{"0.3197620019224834`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589433`"}], "-", 
        RowBox[{"0.5761912177406215`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061045`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694885`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813843`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995793`"}], ",", 
       RowBox[{"0.13151188545021242`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406224`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028412`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248505`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1315118854502099`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406232`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.3279852776056825`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5910090485061045`"}], ",", 
       RowBox[{"0.20449547574694799`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181395`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028431`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224817`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694843`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181378`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.663992638802839`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248394`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061029`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995768`"}], ",", 
       RowBox[{"0.13151188545020925`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406209`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694737`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181386`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1315118854502121`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406203`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568114`", ",", 
       RowBox[{"0.6639926388028404`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224805`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545020975`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406228`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.295504524253052`"}], "+", 
        RowBox[{"0.14230747862306403`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284237`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636859`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305196`"}], "+", 
        RowBox[{"0.14230747862306403`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028424`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248244`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497886`"}], "+", 
        RowBox[{"0.462069480545548`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1639926388028424`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636857`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978847`"}], "+", 
        RowBox[{"0.46206948054554786`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694849`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181386`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545020948`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.576191217740621`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305124`"}], "-", 
        RowBox[{"0.1423074786230636`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284215`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.718498696363684`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305124`"}], "-", 
        RowBox[{"0.14230747862306353`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028408`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224814`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978786`"}], "-", 
        RowBox[{"0.4620694805455467`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284207`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636839`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497879`"}], "-", 
        RowBox[{"0.4620694805455467`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.2044954757469483`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813805`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673684`"}], "+", 
        RowBox[{"0.3197620019224838`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880283962`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636864`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020995`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406227`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028433`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248183`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526319`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813755`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305274`"}], "-", 
        RowBox[{"0.14230747862306295`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454979086`"}], "-", 
        RowBox[{"0.46206948054554664`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.2044954757469493`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813843`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589494`"}], "-", 
        RowBox[{"0.5761912177406212`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673662`"}], "-", 
        RowBox[{"0.31976200192248283`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028404`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224806`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978964`"}], "+", 
        RowBox[{"0.46206948054554475`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1639926388028393`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636845`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526297`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181364`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694857`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181376`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545020948`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406212`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305157`"}], "+", 
        RowBox[{"0.1423074786230623`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558933`"}], "+", 
        RowBox[{"0.5761912177406195`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.32798527760568186`", ",", 
       RowBox[{"-", "0.7369762290995784`"}], ",", 
       RowBox[{"-", "0.5910090485061038`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995789`"}], ",", 
       RowBox[{"-", "0.5910090485061043`"}], ",", "0.3279852776056821`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5910090485061044`"}], ",", "0.3279852776056822`", ",", 
       
       RowBox[{"-", "0.736976229099579`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995796`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497915`"}], "-", 
        RowBox[{"0.4620694805455467`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530521`"}], "+", 
        RowBox[{"0.14230747862306498`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978864`"}], "+", 
        RowBox[{"0.4620694805455485`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568236`", ",", 
       RowBox[{"0.16399263880283915`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636871`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530528`"}], "-", 
        RowBox[{"0.14230747862306287`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284318`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636861`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061051`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558939`"}], "-", 
        RowBox[{"0.5761912177406213`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526301`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181397`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568214`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5910090485061044`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673684`"}], "+", 
        RowBox[{"0.3197620019224838`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589233`"}], "+", 
        RowBox[{"0.5761912177406235`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673827`"}], "-", 
        RowBox[{"0.3197620019224835`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995794`"}], ",", 
       RowBox[{"0.5324807533526318`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181375`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558932`"}], "+", 
        RowBox[{"0.5761912177406203`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061028`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673814`"}], "+", 
        RowBox[{"0.31976200192248244`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526292`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813916`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673661`"}], "-", 
        RowBox[{"0.31976200192248283`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995769`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3279852776056813`", ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558906`"}], "-", 
        RowBox[{"0.5761912177406215`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526297`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813655`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.3279852776056823`", ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589466`"}], "-", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526302`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181398`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558924`"}], "+", 
        RowBox[{"0.5761912177406227`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061043`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673707`"}], "+", 
        RowBox[{"0.3197620019224836`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526312`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813793`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.0729835902967382`"}], "-", 
        RowBox[{"0.31976200192248333`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995794`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673808`"}], "-", 
        RowBox[{"0.31976200192248355`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589455`"}], "-", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061047`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995793`"}], ",", 
       RowBox[{"0.5324807533526305`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581814027`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673672`"}], "+", 
        RowBox[{"0.31976200192248394`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526312`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181379`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568225`", ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589194`"}], "+", 
        RowBox[{"0.5761912177406237`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673765`"}], "+", 
        RowBox[{"0.3197620019224826`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995769`"}], ",", 
       RowBox[{"0.5324807533526301`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813716`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558929`"}], "+", 
        RowBox[{"0.5761912177406197`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526286`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181395`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.3279852776056813`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5910090485061025`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673634`"}], "-", 
        RowBox[{"0.3197620019224827`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589056`"}], "-", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284135`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636851`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061039`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305207`"}], "-", 
        RowBox[{"0.1423074786230633`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978975`"}], "-", 
        RowBox[{"0.46206948054554675`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305185`"}], "+", 
        RowBox[{"0.14230747862306387`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995788`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.32798527760568197`", ",", 
       RowBox[{"0.16399263880284032`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636859`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.368488114549789`"}], "+", 
        RowBox[{"0.46206948054554753`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284118`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636848`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978936`"}], "+", 
        RowBox[{"0.46206948054554614`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.3279852776056816`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5910090485061033`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305135`"}], "-", 
        RowBox[{"0.14230747862306364`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028401`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636846`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305185`"}], "+", 
        RowBox[{"0.14230747862306317`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995775`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978825`"}], "-", 
        RowBox[{"0.46206948054554664`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305224`"}], "-", 
        RowBox[{"0.1423074786230632`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028419`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248244`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526308`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813805`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558952`"}], "-", 
        RowBox[{"0.5761912177406218`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454979125`"}], "-", 
        RowBox[{"0.4620694805455469`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.2044954757469494`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813855`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545020925`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406239`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.0729835902967364`"}], "+", 
        RowBox[{"0.31976200192248433`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880283876`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636878`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305174`"}], "+", 
        RowBox[{"0.142307478623063`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589294`"}], "+", 
        RowBox[{"0.576191217740619`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1315118854502084`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406204`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028408`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.319762001922482`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978947`"}], "+", 
        RowBox[{"0.4620694805455446`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673591`"}], "-", 
        RowBox[{"0.3197620019224825`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526299`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181375`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694849`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181374`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028379`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636836`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978914`"}], "+", 
        RowBox[{"0.4620694805455471`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673772`"}], "-", 
        RowBox[{"0.31976200192248333`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.663992638802841`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224845`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694815`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181387`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284168`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636856`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526303`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181395`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589244`"}], "+", 
        RowBox[{"0.5761912177406221`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021153`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406221`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305185`"}], "+", 
        RowBox[{"0.1423074786230641`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497887`"}], "-", 
        RowBox[{"0.46206948054554675`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694807`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813843`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558921`"}], "-", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673769`"}], "+", 
        RowBox[{"0.31976200192248283`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284132`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636844`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1315118854502114`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406211`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028397`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224837`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526292`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813904`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530513`"}], "-", 
        RowBox[{"0.14230747862306384`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589317`"}], "-", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021056`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406221`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.295504524253052`"}], "-", 
        RowBox[{"0.1423074786230634`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497895`"}], "-", 
        RowBox[{"0.4620694805455467`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673711`"}], "+", 
        RowBox[{"0.31976200192248333`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028414`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224827`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694854`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181384`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028404`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636854`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526306`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813827`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589283`"}], "+", 
        RowBox[{"0.5761912177406211`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497894`"}], "+", 
        RowBox[{"0.4620694805455463`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.2044954757469484`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181383`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021048`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673708`"}], "-", 
        RowBox[{"0.3197620019224831`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028403`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.718498696363685`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305174`"}], "+", 
        RowBox[{"0.14230747862306306`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028407`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248244`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526301`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.256429215818138`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694887`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813855`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028412`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224846`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061043`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995795`"}], ",", 
       RowBox[{"0.13151188545020975`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406227`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.2044954757469482`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813893`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1315118854502127`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406221`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568197`", ",", 
       RowBox[{"0.6639926388028428`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224823`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694835`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.256429215818138`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995773`"}], ",", 
       RowBox[{"0.13151188545021197`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406202`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028394`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224842`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020978`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.576191217740621`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568136`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5910090485061026`"}], ",", 
       RowBox[{"0.2044954757469476`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181385`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028408`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248094`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284018`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636858`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021036`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406222`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.072983590296737`"}], "+", 
        RowBox[{"0.31976200192248344`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526312`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813805`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305246`"}], "-", 
        RowBox[{"0.14230747862306325`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028423`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248244`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.2044954757469491`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813843`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589433`"}], "-", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497906`"}], "-", 
        RowBox[{"0.4620694805455466`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880283987`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636847`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526297`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813727`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694846`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181378`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1315118854502102`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530516`"}], "+", 
        RowBox[{"0.14230747862306278`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589317`"}], "+", 
        RowBox[{"0.57619121774062`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673683`"}], "-", 
        RowBox[{"0.31976200192248283`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028404`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248155`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497897`"}], "+", 
        RowBox[{"0.4620694805455453`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526313`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181378`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673668`"}], "+", 
        RowBox[{"0.3197620019224838`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284315`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636859`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530516`"}], "+", 
        RowBox[{"0.14230747862306398`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589405`"}], "-", 
        RowBox[{"0.5761912177406215`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526313`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181378`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589405`"}], "-", 
        RowBox[{"0.5761912177406215`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.368488114549789`"}], "+", 
        RowBox[{"0.4620694805455481`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673666`"}], "+", 
        RowBox[{"0.3197620019224838`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526299`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813705`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530514`"}], "-", 
        RowBox[{"0.14230747862306392`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558929`"}], "+", 
        RowBox[{"0.5761912177406203`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.0729835902967365`"}], "-", 
        RowBox[{"0.31976200192248294`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589283`"}], "+", 
        RowBox[{"0.5761912177406201`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497877`"}], "-", 
        RowBox[{"0.4620694805455466`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284254`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636832`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526299`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813705`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673643`"}], "-", 
        RowBox[{"0.31976200192248294`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880283932`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636872`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061046`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530522`"}], "+", 
        RowBox[{"0.1423074786230645`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978864`"}], "+", 
        RowBox[{"0.462069480545549`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305296`"}], "-", 
        RowBox[{"0.14230747862306314`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995799`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3279852776056821`", ",", 
       RowBox[{"0.16399263880284304`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636861`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497911`"}], "-", 
        RowBox[{"0.46206948054554664`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880283857`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636841`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497866`"}], "-", 
        RowBox[{"0.4620694805455468`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568086`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.591009048506102`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305157`"}], "+", 
        RowBox[{"0.14230747862306217`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284248`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636835`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305085`"}], "-", 
        RowBox[{"0.14230747862306417`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995762`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978975`"}], "+", 
        RowBox[{"0.46206948054554464`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558951`"}], "-", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021275`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406228`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.2044954757469479`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181399`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021228`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406223`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.0729835902967367`"}], "+", 
        RowBox[{"0.3197620019224839`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028411`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224855`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.2044954757469481`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813927`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028414`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224853`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526319`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181377`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.459497163055893`"}], "+", 
        RowBox[{"0.5761912177406191`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.131511885450212`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406207`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694732`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813843`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021228`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406199`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673644`"}], "-", 
        RowBox[{"0.31976200192248283`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028388`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224839`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694688`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181385`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028387`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248433`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526297`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181365`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028409`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248416`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497889`"}], "+", 
        RowBox[{"0.46206948054554764`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673798`"}], "-", 
        RowBox[{"0.3197620019224832`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526305`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813977`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.204495475746948`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813927`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284262`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636859`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305185`"}], "+", 
        RowBox[{"0.14230747862306437`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589217`"}], "+", 
        RowBox[{"0.5761912177406238`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021253`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406225`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.66399263880284`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224837`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.532480753352629`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813904`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530509`"}], "-", 
        RowBox[{"0.1423074786230639`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978814`"}], "-", 
        RowBox[{"0.46206948054554675`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694743`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813855`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558904`"}], "-", 
        RowBox[{"0.5761912177406213`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673789`"}], "+", 
        RowBox[{"0.3197620019224829`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.163992638802842`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636835`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1315118854502121`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406203`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021036`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406223`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673684`"}], "+", 
        RowBox[{"0.3197620019224836`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880283965`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636865`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530521`"}], "-", 
        RowBox[{"0.14230747862306314`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028424`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248244`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526315`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181379`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589355`"}], "-", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454979036`"}], "-", 
        RowBox[{"0.46206948054554686`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694904`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181383`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021003`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406213`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305174`"}], "+", 
        RowBox[{"0.142307478623063`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589305`"}], "+", 
        RowBox[{"0.5761912177406208`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673665`"}], "-", 
        RowBox[{"0.3197620019224829`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028403`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248155`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978936`"}], "+", 
        RowBox[{"0.4620694805455454`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880283924`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636842`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526297`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181369`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694854`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813777`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284318`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636864`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526316`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181376`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673666`"}], "+", 
        RowBox[{"0.31976200192248405`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526309`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181379`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530515`"}], "+", 
        RowBox[{"0.14230747862306434`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558943`"}], "-", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673672`"}], "+", 
        RowBox[{"0.31976200192248405`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558948`"}], "-", 
        RowBox[{"0.5761912177406218`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497885`"}], "+", 
        RowBox[{"0.4620694805455481`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284232`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636832`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526297`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813716`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673632`"}], "-", 
        RowBox[{"0.31976200192248266`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526295`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181365`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.295504524253051`"}], "-", 
        RowBox[{"0.1423074786230638`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589317`"}], "+", 
        RowBox[{"0.5761912177406198`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673618`"}], "-", 
        RowBox[{"0.3197620019224827`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589333`"}], "+", 
        RowBox[{"0.5761912177406204`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978736`"}], "-", 
        RowBox[{"0.4620694805455465`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305207`"}], "-", 
        RowBox[{"0.14230747862306328`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028411`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224847`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497906`"}], "-", 
        RowBox[{"0.46206948054554664`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1639926388028399`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636864`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497907`"}], "-", 
        RowBox[{"0.4620694805455469`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.204495475746948`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813943`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1315118854502122`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406223`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530526`"}], "-", 
        RowBox[{"0.14230747862306306`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880283915`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.718498696363687`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530518`"}], "+", 
        RowBox[{"0.14230747862306298`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880283949`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636841`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021184`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406207`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028395`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248383`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978947`"}], "+", 
        RowBox[{"0.4620694805455451`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305157`"}], "+", 
        RowBox[{"0.1423074786230626`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978964`"}], "+", 
        RowBox[{"0.4620694805455453`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694732`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181385`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028386`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.718498696363684`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978914`"}], "+", 
        RowBox[{"0.46206948054554703`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530519`"}], "-", 
        RowBox[{"0.14230747862306337`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995785`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.32798527760568186`", ",", 
       RowBox[{"0.16399263880284135`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636851`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978975`"}], "-", 
        RowBox[{"0.46206948054554675`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284048`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636857`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061039`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305185`"}], "+", 
        RowBox[{"0.14230747862306384`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497888`"}], "-", 
        RowBox[{"0.46206948054554675`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568164`", ",", 
       RowBox[{"0.16399263880284032`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636847`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530519`"}], "+", 
        RowBox[{"0.14230747862306342`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028412`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636846`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061033`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995778`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978936`"}], "+", 
        RowBox[{"0.4620694805455463`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530514`"}], "-", 
        RowBox[{"0.14230747862306367`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.32798527760568214`", ",", 
       RowBox[{"0.663992638802842`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224823`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021175`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.576191217740622`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028411`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248455`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061043`"}], ",", 
       RowBox[{"0.20449547574694882`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181384`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1315118854502098`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406225`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694826`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181393`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995792`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995794`"}], ",", 
       RowBox[{"-", "0.5910090485061046`"}], ",", "0.32798527760568236`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5910090485061046`"}], ",", "0.3279852776056822`", ",", 
       
       RowBox[{"-", "0.7369762290995794`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.32798527760568197`", ",", 
       RowBox[{"-", "0.7369762290995788`"}], ",", 
       RowBox[{"-", "0.5910090485061043`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305224`"}], "-", 
        RowBox[{"0.14230747862306323`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589394`"}], "-", 
        RowBox[{"0.5761912177406215`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021003`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406225`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028421`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248255`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497905`"}], "-", 
        RowBox[{"0.4620694805455469`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673682`"}], "+", 
        RowBox[{"0.31976200192248383`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526315`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813793`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694915`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181385`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880283943`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636867`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530518`"}], "+", 
        RowBox[{"0.14230747862306298`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028404`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224818`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526298`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181371`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558929`"}], "+", 
        RowBox[{"0.5761912177406202`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497893`"}], "+", 
        RowBox[{"0.46206948054554536`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694837`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813755`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1315118854502097`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406213`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673661`"}], "-", 
        RowBox[{"0.3197620019224829`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880283887`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636841`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1315118854502124`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406225`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673826`"}], "-", 
        RowBox[{"0.31976200192248355`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284282`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636861`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530518`"}], "+", 
        RowBox[{"0.14230747862306461`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028412`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224856`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526305`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581814043`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589217`"}], "+", 
        RowBox[{"0.5761912177406229`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978886`"}], "+", 
        RowBox[{"0.4620694805455477`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694793`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813904`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1315118854502119`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406204`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305074`"}], "-", 
        RowBox[{"0.14230747862306414`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558912`"}], "-", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673801`"}], "+", 
        RowBox[{"0.3197620019224825`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028388`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248433`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497881`"}], "-", 
        RowBox[{"0.46206948054554686`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284207`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636834`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526282`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181395`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.2044954757469477`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181387`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028421`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248255`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1315118854502117`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.576191217740622`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.3279852776056821`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5910090485061043`"}], ",", 
       RowBox[{"0.20449547574694857`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813855`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028411`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224844`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.2044954757469481`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181392`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995789`"}], ",", 
       RowBox[{"0.1315118854502101`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406227`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028407`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224819`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061028`"}], ",", 
       RowBox[{"0.20449547574694754`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813827`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021142`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.576191217740621`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.2044954757469484`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813816`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995773`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3279852776056815`", ",", 
       RowBox[{"0.6639926388028398`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224836`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020961`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406211`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995794`"}], ",", 
       RowBox[{"0.5324807533526316`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181378`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673833`"}], "-", 
        RowBox[{"0.31976200192248355`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526301`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181392`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568214`", ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558943`"}], "-", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.0729835902967369`"}], "+", 
        RowBox[{"0.3197620019224837`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558923`"}], "+", 
        RowBox[{"0.5761912177406233`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061046`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028412`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224851`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1315118854502123`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406221`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673669`"}], "+", 
        RowBox[{"0.319762001922484`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526308`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.256429215818138`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694782`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813927`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028414`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224848`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694815`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181394`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589444`"}], "-", 
        RowBox[{"0.576191217740622`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021233`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406221`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028395`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224842`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526296`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181374`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694726`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181385`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1315118854502119`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406203`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694749`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181382`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589317`"}], "+", 
        RowBox[{"0.5761912177406199`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673623`"}], "-", 
        RowBox[{"0.3197620019224827`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028395`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248394`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021164`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406201`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673701`"}], "+", 
        RowBox[{"0.3197620019224835`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589444`"}], "-", 
        RowBox[{"0.5761912177406215`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497888`"}], "+", 
        RowBox[{"0.46206948054554803`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1639926388028421`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636856`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526316`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813793`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.0729835902967368`"}], "+", 
        RowBox[{"0.31976200192248383`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526311`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813805`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305207`"}], "+", 
        RowBox[{"0.14230747862306448`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589483`"}], "-", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673687`"}], "-", 
        RowBox[{"0.31976200192248316`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284165`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636841`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526297`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181372`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589294`"}], "+", 
        RowBox[{"0.5761912177406199`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526297`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813694`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530509`"}], "-", 
        RowBox[{"0.14230747862306387`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497878`"}], "-", 
        RowBox[{"0.46206948054554686`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673651`"}], "-", 
        RowBox[{"0.3197620019224827`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589294`"}], "+", 
        RowBox[{"0.5761912177406194`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284307`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.718498696363686`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021267`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406224`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673834`"}], "-", 
        RowBox[{"0.3197620019224836`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526307`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581814015`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305196`"}], "+", 
        RowBox[{"0.14230747862306445`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028413`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224853`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694812`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813954`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589206`"}], "+", 
        RowBox[{"0.5761912177406238`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978886`"}], "+", 
        RowBox[{"0.46206948054554847`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284237`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636831`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526285`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813916`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694726`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181384`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1315118854502123`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406203`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305085`"}], "-", 
        RowBox[{"0.14230747862306387`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558904`"}], "-", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673814`"}], "+", 
        RowBox[{"0.3197620019224823`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028388`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248394`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978736`"}], "-", 
        RowBox[{"0.46206948054554675`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.53248075335263`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581814`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673702`"}], "+", 
        RowBox[{"0.3197620019224839`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995795`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3279852776056827`", ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589206`"}], "+", 
        RowBox[{"0.5761912177406238`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526317`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181378`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558953`"}], "-", 
        RowBox[{"0.5761912177406218`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061048`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673855`"}], "-", 
        RowBox[{"0.31976200192248344`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526286`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.256429215818139`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.327985277605681`", ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558934`"}], "+", 
        RowBox[{"0.5761912177406192`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673657`"}], "-", 
        RowBox[{"0.31976200192248283`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558905`"}], "-", 
        RowBox[{"0.5761912177406213`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061023`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995773`"}], ",", 
       RowBox[{"0.5324807533526296`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181366`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673775`"}], "+", 
        RowBox[{"0.31976200192248194`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673816`"}], "-", 
        RowBox[{"0.3197620019224835`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028419`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248266`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020992`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406222`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028423`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248255`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526302`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813966`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694912`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181386`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406227`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694898`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181381`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558924`"}], "+", 
        RowBox[{"0.5761912177406233`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673801`"}], "+", 
        RowBox[{"0.31976200192248294`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028404`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224815`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1315118854502097`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406211`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.663992638802841`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.319762001922482`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.532480753352629`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181388`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694826`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813755`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021003`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.576191217740621`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694873`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181375`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558909`"}], "-", 
        RowBox[{"0.5761912177406219`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454979047`"}], "-", 
        RowBox[{"0.46206948054554664`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305257`"}], "-", 
        RowBox[{"0.14230747862306312`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028413`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248516`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694807`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.256429215818139`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880283999`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636861`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497904`"}], "-", 
        RowBox[{"0.4620694805455468`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1639926388028402`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.718498696363686`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021184`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406223`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530524`"}], "-", 
        RowBox[{"0.14230747862306323`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497895`"}], "+", 
        RowBox[{"0.46206948054554536`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694765`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813855`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880283993`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636846`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530516`"}], "+", 
        RowBox[{"0.14230747862306267`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028396`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636844`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1315118854502115`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406208`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028389`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224839`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497894`"}], "+", 
        RowBox[{"0.46206948054554553`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305146`"}], "+", 
        RowBox[{"0.14230747862306276`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530522`"}], "-", 
        RowBox[{"0.14230747862306317`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995793`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497888`"}], "+", 
        RowBox[{"0.4620694805455485`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284196`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636851`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454979075`"}], "-", 
        RowBox[{"0.4620694805455467`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.3279852776056824`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5910090485061041`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305207`"}], "+", 
        RowBox[{"0.1423074786230644`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880283924`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.718498696363687`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530517`"}], "+", 
        RowBox[{"0.1423074786230632`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284182`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636845`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061031`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995768`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497897`"}], "+", 
        RowBox[{"0.46206948054554536`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305096`"}], "-", 
        RowBox[{"0.14230747862306403`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497873`"}], "-", 
        RowBox[{"0.4620694805455468`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568114`", ",", 
       RowBox[{"0.16399263880283868`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636838`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305185`"}], "+", 
        RowBox[{"0.14230747862306398`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.736976229099579`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454979036`"}], "-", 
        RowBox[{"0.46206948054554675`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284035`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636857`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.368488114549789`"}], "+", 
        RowBox[{"0.4620694805455475`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.3279852776056821`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5910090485061043`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530523`"}], "-", 
        RowBox[{"0.14230747862306328`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284226`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636858`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530513`"}], "-", 
        RowBox[{"0.14230747862306367`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028402`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636847`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.591009048506103`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995773`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497883`"}], "-", 
        RowBox[{"0.4620694805455467`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530516`"}], "+", 
        RowBox[{"0.14230747862306287`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978936`"}], "+", 
        RowBox[{"0.46206948054554553`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.3279852776056814`", ",", 
       RowBox[{"0.16399263880284168`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636837`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526308`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581814004`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.2044954757469487`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813816`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028428`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.319762001922482`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694918`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813843`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558923`"}], "+", 
        RowBox[{"0.5761912177406239`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020964`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406231`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.663992638802843`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248194`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021003`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406228`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673804`"}], "-", 
        RowBox[{"0.31976200192248394`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526285`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813966`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694832`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181375`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028401`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248094`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694812`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181377`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558906`"}], "-", 
        RowBox[{"0.5761912177406218`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020925`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406209`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028403`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248116`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020887`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406207`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673818`"}], "+", 
        RowBox[{"0.31976200192248283`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.591009048506105`"}], ",", "0.3279852776056825`", ",", 
       RowBox[{"-", "0.7369762290995799`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.327985277605682`", ",", 
       RowBox[{"-", "0.7369762290995787`"}], ",", 
       RowBox[{"-", "0.5910090485061041`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995797`"}], ",", 
       RowBox[{"-", "0.5910090485061049`"}], ",", "0.3279852776056826`"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497888`"}], "+", 
        RowBox[{"0.46206948054554864`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673653`"}], "+", 
        RowBox[{"0.31976200192248394`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589566`"}], "-", 
        RowBox[{"0.5761912177406215`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673632`"}], "+", 
        RowBox[{"0.3197620019224842`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.163992638802844`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636865`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526326`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813727`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558943`"}], "-", 
        RowBox[{"0.5761912177406213`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526313`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181377`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305174`"}], "+", 
        RowBox[{"0.1423074786230644`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.368488114549787`"}], "-", 
        RowBox[{"0.4620694805455467`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.0729835902967361`"}], "-", 
        RowBox[{"0.31976200192248266`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589317`"}], "+", 
        RowBox[{"0.5761912177406201`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673615`"}], "-", 
        RowBox[{"0.3197620019224827`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284298`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636825`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526299`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.256429215818137`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4594971630558932`"}], "+", 
        RowBox[{"0.5761912177406188`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526295`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181357`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.295504524253051`"}], "-", 
        RowBox[{"0.1423074786230642`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526303`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813966`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.072983590296738`"}], "-", 
        RowBox[{"0.3197620019224835`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880283987`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636865`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530522`"}], "-", 
        RowBox[{"0.14230747862306325`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558923`"}], "+", 
        RowBox[{"0.5761912177406228`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526303`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813954`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589244`"}], "+", 
        RowBox[{"0.5761912177406225`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454979`"}], "-", 
        RowBox[{"0.46206948054554686`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673786`"}], "-", 
        RowBox[{"0.3197620019224834`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.532480753352629`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813893`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305185`"}], "+", 
        RowBox[{"0.14230747862306298`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558916`"}], "-", 
        RowBox[{"0.5761912177406215`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673779`"}], "+", 
        RowBox[{"0.31976200192248266`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558914`"}], "-", 
        RowBox[{"0.5761912177406215`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497893`"}], "+", 
        RowBox[{"0.46206948054554586`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880283935`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636842`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.532480753352629`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813893`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.0729835902967377`"}], "+", 
        RowBox[{"0.31976200192248283`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530516`"}], "+", 
        RowBox[{"0.14230747862306434`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589433`"}], "-", 
        RowBox[{"0.5761912177406218`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526315`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181378`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589455`"}], "-", 
        RowBox[{"0.5761912177406215`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497886`"}], "+", 
        RowBox[{"0.46206948054554814`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673693`"}], "+", 
        RowBox[{"0.31976200192248394`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526308`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813805`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673716`"}], "+", 
        RowBox[{"0.3197620019224838`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284215`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636855`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530509`"}], "-", 
        RowBox[{"0.14230747862306353`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558933`"}], "+", 
        RowBox[{"0.5761912177406198`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526301`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813755`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589305`"}], "+", 
        RowBox[{"0.5761912177406199`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497876`"}], "-", 
        RowBox[{"0.4620694805455464`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673686`"}], "-", 
        RowBox[{"0.3197620019224831`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526298`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813705`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673643`"}], "-", 
        RowBox[{"0.3197620019224829`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028417`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636841`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.32798527760568236`", ",", 
       RowBox[{"0.16399263880284323`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636862`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454979136`"}], "-", 
        RowBox[{"0.4620694805455467`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880283899`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636872`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061051`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305207`"}], "+", 
        RowBox[{"0.14230747862306498`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978864`"}], "+", 
        RowBox[{"0.46206948054554836`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305285`"}], "-", 
        RowBox[{"0.14230747862306306`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995797`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.736976229099579`"}], ",", 
       RowBox[{"0.13151188545021017`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406228`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694807`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813927`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021222`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406223`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568225`", ",", 
       RowBox[{"0.6639926388028426`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248216`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694885`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813843`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.663992638802841`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224846`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061043`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5910090485061045`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530529`"}], "-", 
        RowBox[{"0.14230747862306303`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284373`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636864`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530519`"}], "+", 
        RowBox[{"0.1423074786230644`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.73697622909958`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454979197`"}], "-", 
        RowBox[{"0.4620694805455467`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880283985`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636861`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497888`"}], "+", 
        RowBox[{"0.46206948054554847`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568247`"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284135`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636852`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021064`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406221`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305185`"}], "+", 
        RowBox[{"0.14230747862306398`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497891`"}], "+", 
        RowBox[{"0.4620694805455472`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305185`"}], "+", 
        RowBox[{"0.14230747862306387`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028417`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224826`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694857`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181384`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028417`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636857`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.368488114549789`"}], "+", 
        RowBox[{"0.4620694805455476`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284123`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636847`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497887`"}], "-", 
        RowBox[{"0.46206948054554675`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694837`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813805`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021042`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305146`"}], "-", 
        RowBox[{"0.1423074786230637`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284132`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636844`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530515`"}], "-", 
        RowBox[{"0.14230747862306375`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028407`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248216`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497882`"}], "-", 
        RowBox[{"0.4620694805455467`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673702`"}], "+", 
        RowBox[{"0.31976200192248344`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558924`"}], "+", 
        RowBox[{"0.576191217740623`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.591009048506104`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995786`"}], ",", 
       RowBox[{"0.5324807533526311`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813805`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.0729835902967381`"}], "-", 
        RowBox[{"0.31976200192248344`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526302`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181394`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.3279852776056823`", ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558945`"}], "-", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673707`"}], "-", 
        RowBox[{"0.3197620019224831`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995778`"}], ",", 
       RowBox[{"0.5324807533526291`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813893`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589133`"}], "-", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526297`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181374`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568097`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.591009048506103`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673791`"}], "+", 
        RowBox[{"0.3197620019224827`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589317`"}], "+", 
        RowBox[{"0.5761912177406199`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995793`"}], ",", 
       RowBox[{"0.1315118854502124`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406222`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694937`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181385`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545020998`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406227`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.3279852776056824`", ",", 
       RowBox[{"0.6639926388028415`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224858`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694812`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813954`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028432`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224822`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061047`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284218`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636855`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497888`"}], "+", 
        RowBox[{"0.4620694805455476`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.2044954757469487`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813855`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021014`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406224`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530519`"}], "+", 
        RowBox[{"0.14230747862306392`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284215`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636857`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305196`"}], "+", 
        RowBox[{"0.14230747862306428`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028422`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224824`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978886`"}], "+", 
        RowBox[{"0.4620694805455481`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284182`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636841`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1315118854502098`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305124`"}], "-", 
        RowBox[{"0.1423074786230637`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978836`"}], "-", 
        RowBox[{"0.46206948054554686`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305135`"}], "-", 
        RowBox[{"0.14230747862306367`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028405`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224816`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694832`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181379`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284168`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.718498696363684`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497877`"}], "-", 
        RowBox[{"0.4620694805455467`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.32798527760568214`", ",", 
       RowBox[{"0.663992638802841`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224846`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021003`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406227`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.663992638802842`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224824`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061044`"}], ",", 
       RowBox[{"0.20449547574694807`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181392`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021208`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.576191217740622`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.204495475746949`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181384`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995793`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1315118854502102`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406227`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568214`", ",", 
       RowBox[{"0.6639926388028412`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224844`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694787`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181392`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028423`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248244`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061044`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995789`"}], ",", 
       RowBox[{"0.13151188545021125`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406219`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.2044954757469487`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181385`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545020975`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406211`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.2044954757469473`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181385`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995775`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.32798527760568147`", ",", 
       RowBox[{"0.6639926388028407`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224817`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021125`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.576191217740621`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028398`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224835`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061028`"}], ",", 
       RowBox[{"0.20449547574694832`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813816`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.2044954757469481`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813916`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028413`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224848`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526316`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181379`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589483`"}], "-", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021256`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406227`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694793`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813966`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1315118854502122`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406223`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673676`"}], "+", 
        RowBox[{"0.3197620019224839`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028412`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224854`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694754`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813855`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589294`"}], "+", 
        RowBox[{"0.5761912177406193`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021184`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406207`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028391`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248366`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021203`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406201`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673654`"}], "-", 
        RowBox[{"0.3197620019224829`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526297`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813694`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.2044954757469471`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813855`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028389`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248416`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021206`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406222`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568225`", ",", 
       RowBox[{"0.6639926388028424`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.319762001922482`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694893`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181385`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028413`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.319762001922485`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061047`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995793`"}], ",", 
       RowBox[{"0.13151188545020984`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.576191217740623`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694785`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813954`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1315118854502116`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406208`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694843`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813766`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.736976229099577`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3279852776056813`", ",", 
       RowBox[{"0.663992638802839`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248383`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1315118854502093`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.576191217740621`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028405`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.319762001922481`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061025`"}], ",", 
       RowBox[{"0.20449547574694726`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813866`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.591009048506104`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305196`"}], "+", 
        RowBox[{"0.14230747862306398`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284007`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636861`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305207`"}], "-", 
        RowBox[{"0.1423074786230633`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995787`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978897`"}], "+", 
        RowBox[{"0.46206948054554753`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1639926388028416`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636852`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978997`"}], "-", 
        RowBox[{"0.46206948054554675`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.3279852776056821`"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497886`"}], "+", 
        RowBox[{"0.462069480545548`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305185`"}], "+", 
        RowBox[{"0.1423074786230644`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028426`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248194`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694882`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181384`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284234`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636856`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497887`"}], "+", 
        RowBox[{"0.4620694805455482`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284218`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636855`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020984`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406228`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.295504524253052`"}], "+", 
        RowBox[{"0.14230747862306437`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497879`"}], "-", 
        RowBox[{"0.46206948054554703`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694843`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.256429215818138`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284196`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636841`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.295504524253051`"}], "-", 
        RowBox[{"0.14230747862306395`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028421`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636839`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1315118854502097`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406212`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028405`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248083`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978775`"}], "-", 
        RowBox[{"0.46206948054554686`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.295504524253051`"}], "-", 
        RowBox[{"0.14230747862306392`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7369762290995796`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497888`"}], "+", 
        RowBox[{"0.46206948054554825`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.295504524253053`"}], "-", 
        RowBox[{"0.14230747862306303`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497906`"}], "-", 
        RowBox[{"0.4620694805455467`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568197`", ",", 
       RowBox[{"0.16399263880284298`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636864`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305207`"}], "+", 
        RowBox[{"0.1423074786230644`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880283968`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636868`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061048`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5910090485061047`"}], ",", 
       RowBox[{"0.204495475746948`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813954`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028432`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248194`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694904`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181384`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995796`"}], ",", 
       RowBox[{"0.1315118854502128`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406225`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028411`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224846`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021006`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406229`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568247`"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305196`"}], "+", 
        RowBox[{"0.14230747862306417`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028422`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224825`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497889`"}], "+", 
        RowBox[{"0.46206948054554786`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1639926388028425`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.718498696363686`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978886`"}], "+", 
        RowBox[{"0.46206948054554786`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694915`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181385`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545020986`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406228`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.295504524253052`"}], "+", 
        RowBox[{"0.1423074786230641`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284265`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636859`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.29550452425305107`"}], "-", 
        RowBox[{"0.1423074786230637`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284204`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636836`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020953`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.576191217740621`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028405`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248194`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497878`"}], "-", 
        RowBox[{"0.46206948054554664`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.295504524253051`"}], "-", 
        RowBox[{"0.1423074786230639`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978764`"}], "-", 
        RowBox[{"0.46206948054554664`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694826`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181378`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1639926388028421`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636837`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.3279852776056822`", ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558924`"}], "+", 
        RowBox[{"0.5761912177406225`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526312`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181381`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589416`"}], "-", 
        RowBox[{"0.5761912177406215`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061041`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673802`"}], "-", 
        RowBox[{"0.31976200192248344`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526305`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813977`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673702`"}], "+", 
        RowBox[{"0.31976200192248355`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995794`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526311`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181381`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673775`"}], "-", 
        RowBox[{"0.31976200192248333`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995792`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3279852776056824`", ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558943`"}], "-", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526306`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581814015`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589194`"}], "+", 
        RowBox[{"0.5761912177406235`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061044`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673675`"}], "+", 
        RowBox[{"0.319762001922484`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.53248075335263`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181372`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568125`", ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558906`"}], "-", 
        RowBox[{"0.5761912177406217`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.0729835902967377`"}], "+", 
        RowBox[{"0.3197620019224827`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.45949716305589294`"}], "+", 
        RowBox[{"0.5761912177406201`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.5910090485061029`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.736976229099577`"}], ",", 
       RowBox[{"0.5324807533526283`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813943`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673643`"}], "-", 
        RowBox[{"0.3197620019224828`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5910090485061043`"}], ",", 
       RowBox[{"0.20449547574694876`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181385`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028412`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224844`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694815`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181387`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995785`"}], ",", 
       RowBox[{"0.13151188545021059`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406221`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028417`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224828`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021159`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406221`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.3279852776056821`"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1315118854502124`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406223`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.0729835902967367`"}], "+", 
        RowBox[{"0.31976200192248405`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028412`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3197620019224857`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694804`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813916`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028413`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248516`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526318`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813766`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589516`"}], "-", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021283`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406228`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694785`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813977`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.13151188545021203`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406204`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694743`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181386`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558932`"}], "+", 
        RowBox[{"0.5761912177406193`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673655`"}], "-", 
        RowBox[{"0.3197620019224827`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028389`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3197620019224839`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.1315118854502123`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406197`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6639926388028384`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248433`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526297`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181366`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.20449547574694676`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813843`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.2044954757469495`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813877`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284318`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636859`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.3684881145497887`"}], "+", 
        RowBox[{"0.4620694805455485`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284265`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636861`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545021011`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5761912177406227`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530515`"}], "+", 
        RowBox[{"0.14230747862306437`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3684881145497885`"}], "+", 
        RowBox[{"0.46206948054554836`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530524`"}], "+", 
        RowBox[{"0.1423074786230645`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028432`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.31976200192248233`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.20449547574694865`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813743`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284215`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636837`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.368488114549787`"}], "-", 
        RowBox[{"0.46206948054554636`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.16399263880284226`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636832`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.13151188545020953`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5761912177406211`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.2955045242530509`"}], "-", 
        RowBox[{"0.14230747862306414`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.368488114549787`"}], "-", 
        RowBox[{"0.4620694805455469`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305057`"}], "-", 
        RowBox[{"0.14230747862306337`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.6639926388028404`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.31976200192248094`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589217`"}], "+", 
        RowBox[{"0.5761912177406224`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.36848811454978986`"}], "-", 
        RowBox[{"0.46206948054554664`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673789`"}], "-", 
        RowBox[{"0.31976200192248333`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5324807533526303`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181394`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673779`"}], "-", 
        RowBox[{"0.3197620019224834`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880284004`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7184986963636864`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2955045242530522`"}], "-", 
        RowBox[{"0.14230747862306317`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558921`"}], "+", 
        RowBox[{"0.5761912177406231`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526301`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.25642921581813977`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589183`"}], "-", 
        RowBox[{"0.5761912177406218`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526291`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2564292158181389`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.29550452425305185`"}], "+", 
        RowBox[{"0.14230747862306292`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.36848811454978947`"}], "+", 
        RowBox[{"0.46206948054554586`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673762`"}], "+", 
        RowBox[{"0.31976200192248266`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558913`"}], "-", 
        RowBox[{"0.5761912177406218`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07298359029673779`"}], "+", 
        RowBox[{"0.319762001922483`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.16399263880283962`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7184986963636844`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526288`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813927`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5910090485061041`"}], ",", 
       RowBox[{
        RowBox[{"-", "0.07298359029673696`"}], "+", 
        RowBox[{"0.31976200192248344`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.4594971630558921`"}], "+", 
        RowBox[{"0.5761912177406227`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.0729835902967379`"}], "-", 
        RowBox[{"0.3197620019224833`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "0.7369762290995792`"}], ",", 
       RowBox[{"0.5324807533526311`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.25642921581813805`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.45949716305589416`"}], "-", 
        RowBox[{"0.5761912177406214`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.5324807533526303`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2564292158181399`", " ", "\[ImaginaryI]"}]}], ",", 
       "0.32798527760568214`"}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.52620667712547*^9, 3.5262067364596*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "example: ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["T", "n"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "vs. ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["T", 
    RowBox[{"n", "[", "a", "]"}]], TraditionalForm]],
  FormatType->"TraditionalForm"]
}], "Subsubsection",
 CellChangeTimes->{{3.526206817221119*^9, 3.526206838506587*^9}, {
  3.5262092430607*^9, 3.526209266593732*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"for", " ", "the", " ", 
      SubscriptBox["T", 
       RowBox[{"n", "[", "a", "]"}]]}], "-", 
     RowBox[{
     "groups", " ", "that", " ", "are", " ", "already", " ", "uniquely", " ", 
      "defined", " ", "by", " ", "the", " ", "value", " ", "of", " ", "n"}]}],
     ",", " ", 
    RowBox[{"this", " ", "information", " ", "is", " ", 
     RowBox[{"enough", ":"}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Group", "[", "\"\<\!\(\*SubscriptBox[\(T\), \(7\)]\)\>\"", "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
   "Group", "[", "\"\<\!\(\*SubscriptBox[\(T\), \(7[2]\)]\)\>\"", 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.526206851077571*^9, 3.526206868811447*^9}, {
  3.526209269076926*^9, 3.526209300716587*^9}, {3.526209334550317*^9, 
  3.526209355851983*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1.`", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1.`", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1.`"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395631367`"}], "+", 
        RowBox[{"0.9749279121818248`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024174`"}], "-", 
        RowBox[{"0.4338837391175589`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6234898018587341`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824680297`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.6234898018587338`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7818314824680292`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2225209339563132`"}], "-", 
        RowBox[{"0.9749279121818228`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024196`"}], "+", 
        RowBox[{"0.43388373911755995`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6234898018587343`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824680299`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395631467`"}], "+", 
        RowBox[{"0.9749279121818233`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024188`"}], "-", 
        RowBox[{"0.43388373911755823`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6234898018587336`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.781831482468029`", " ", "\[ImaginaryI]"}]}], ",", "0", ",",
        "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395631478`"}], "-", 
        RowBox[{"0.9749279121818237`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024193`"}], "+", 
        RowBox[{"0.43388373911755845`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024188`"}], "+", 
        RowBox[{"0.4338837391175573`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6234898018587333`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7818314824680315`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395631395`"}], "-", 
        RowBox[{"0.9749279121818235`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.6234898018587318`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824680297`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395631403`"}], "+", 
        RowBox[{"0.9749279121818238`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9009688679024199`"}], "-", 
        RowBox[{"0.43388373911755784`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0.9999999999999991`", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1.0000000000000002`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.0000000000000009`", ",", "0", ",", "0"}], "}"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0.9999999999999991`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.0000000000000009`", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0.9999999999999998`", ",", "0"}], "}"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024208`"}], "-", 
        RowBox[{"0.4338837391175577`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.6234898018587313`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824680298`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.22252093395631387`"}], "+", 
        RowBox[{"0.9749279121818242`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395631367`"}], "-", 
        RowBox[{"0.9749279121818233`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9009688679024184`"}], "+", 
        RowBox[{"0.4338837391175565`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.623489801858733`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.781831482468032`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9009688679024195`"}], "-", 
        RowBox[{"0.43388373911755795`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.6234898018587343`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824680299`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.222520933956315`"}], "+", 
        RowBox[{"0.9749279121818228`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.900968867902419`"}], "+", 
        RowBox[{"0.43388373911755773`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.6234898018587336`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.781831482468029`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395631528`"}], "-", 
        RowBox[{"0.9749279121818241`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395631428`"}], "+", 
        RowBox[{"0.9749279121818237`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9009688679024195`"}], "-", 
        RowBox[{"0.433883739117558`", " ", "\[ImaginaryI]"}]}], ",", "0", ",",
        "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.623489801858733`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824680298`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.900968867902419`"}], "+", 
        RowBox[{"0.4338837391175578`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.6234898018587334`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7818314824680302`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.22252093395631425`"}], "-", 
        RowBox[{"0.9749279121818235`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.22252093395631534`"}], "-", 
        RowBox[{"0.9749279121818242`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024188`"}], "+", 
        RowBox[{"0.4338837391175568`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.6234898018587334`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7818314824680302`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.222520933956315`"}], "+", 
        RowBox[{"0.9749279121818227`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024204`"}], "-", 
        RowBox[{"0.4338837391175575`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.623489801858733`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824680299`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.6234898018587313`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824680298`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.22252093395631387`"}], "+", 
        RowBox[{"0.9749279121818242`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024208`"}], "-", 
        RowBox[{"0.4338837391175577`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395631367`"}], "-", 
        RowBox[{"0.9749279121818233`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024184`"}], "+", 
        RowBox[{"0.4338837391175565`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.623489801858733`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.781831482468032`", " ", "\[ImaginaryI]"}]}], ",", "0", ",",
        "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.6234898018587334`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7818314824680309`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395631378`"}], "-", 
        RowBox[{"0.9749279121818233`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.900968867902419`"}], "+", 
        RowBox[{"0.43388373911755784`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024194`"}], "-", 
        RowBox[{"0.433883739117558`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6234898018587324`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824680297`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395631398`"}], "+", 
        RowBox[{"0.9749279121818242`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.526206869503542*^9, 3.52620935665807*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1.`", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1.`", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1.`"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395631367`"}], "+", 
        RowBox[{"0.9749279121818248`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024174`"}], "-", 
        RowBox[{"0.4338837391175589`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6234898018587341`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824680297`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.6234898018587338`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7818314824680292`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2225209339563132`"}], "-", 
        RowBox[{"0.9749279121818228`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024196`"}], "+", 
        RowBox[{"0.43388373911755995`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6234898018587343`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824680299`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395631467`"}], "+", 
        RowBox[{"0.9749279121818233`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024188`"}], "-", 
        RowBox[{"0.43388373911755823`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6234898018587336`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.781831482468029`", " ", "\[ImaginaryI]"}]}], ",", "0", ",",
        "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395631478`"}], "-", 
        RowBox[{"0.9749279121818237`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024193`"}], "+", 
        RowBox[{"0.43388373911755845`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024188`"}], "+", 
        RowBox[{"0.4338837391175573`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6234898018587333`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7818314824680315`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395631395`"}], "-", 
        RowBox[{"0.9749279121818235`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.6234898018587318`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824680297`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395631403`"}], "+", 
        RowBox[{"0.9749279121818238`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9009688679024199`"}], "-", 
        RowBox[{"0.43388373911755784`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0.9999999999999991`", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1.0000000000000002`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.0000000000000009`", ",", "0", ",", "0"}], "}"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0.9999999999999991`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.0000000000000009`", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0.9999999999999998`", ",", "0"}], "}"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024208`"}], "-", 
        RowBox[{"0.4338837391175577`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.6234898018587313`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824680298`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.22252093395631387`"}], "+", 
        RowBox[{"0.9749279121818242`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395631367`"}], "-", 
        RowBox[{"0.9749279121818233`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9009688679024184`"}], "+", 
        RowBox[{"0.4338837391175565`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.623489801858733`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.781831482468032`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9009688679024195`"}], "-", 
        RowBox[{"0.43388373911755795`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.6234898018587343`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824680299`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.222520933956315`"}], "+", 
        RowBox[{"0.9749279121818228`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.900968867902419`"}], "+", 
        RowBox[{"0.43388373911755773`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.6234898018587336`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.781831482468029`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395631528`"}], "-", 
        RowBox[{"0.9749279121818241`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395631428`"}], "+", 
        RowBox[{"0.9749279121818237`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9009688679024195`"}], "-", 
        RowBox[{"0.433883739117558`", " ", "\[ImaginaryI]"}]}], ",", "0", ",",
        "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.623489801858733`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824680298`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.900968867902419`"}], "+", 
        RowBox[{"0.4338837391175578`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.6234898018587334`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7818314824680302`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.22252093395631425`"}], "-", 
        RowBox[{"0.9749279121818235`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.22252093395631534`"}], "-", 
        RowBox[{"0.9749279121818242`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024188`"}], "+", 
        RowBox[{"0.4338837391175568`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.6234898018587334`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7818314824680302`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.222520933956315`"}], "+", 
        RowBox[{"0.9749279121818227`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024204`"}], "-", 
        RowBox[{"0.4338837391175575`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.623489801858733`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824680299`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.6234898018587313`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824680298`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.22252093395631387`"}], "+", 
        RowBox[{"0.9749279121818242`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024208`"}], "-", 
        RowBox[{"0.4338837391175577`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395631367`"}], "-", 
        RowBox[{"0.9749279121818233`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024184`"}], "+", 
        RowBox[{"0.4338837391175565`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.623489801858733`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.781831482468032`", " ", "\[ImaginaryI]"}]}], ",", "0", ",",
        "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.6234898018587334`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7818314824680309`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395631378`"}], "-", 
        RowBox[{"0.9749279121818233`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.900968867902419`"}], "+", 
        RowBox[{"0.43388373911755784`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024194`"}], "-", 
        RowBox[{"0.433883739117558`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6234898018587324`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824680297`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395631398`"}], "+", 
        RowBox[{"0.9749279121818242`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.526206869503542*^9, 3.526209356673472*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"for", " ", "some", " ", 
      SubscriptBox["T", 
       RowBox[{"n", "[", "a", "]"}]]}], "-", "groups"}], ",", " ", "however", 
    ",", " ", 
    RowBox[{"one", " ", "needs", " ", "both", " ", "n", " ", "and", " ", 
     RowBox[{"a", ":"}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
   "Group", "[", "\"\<\!\(\*SubscriptBox[\(T\), \(91[16]\)]\)\>\"", "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
   "Group", "[", "\"\<\!\(\*SubscriptBox[\(T\), \(91[9]\)]\)\>\"", 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.5262068802212057`*^9, 3.526206896362769*^9}, {
  3.5262093742625113`*^9, 3.52620944665742*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1.`", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1.`", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1.`"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "1.0000000000000333`", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0.9999999999999294`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.0000000000000135`", ",", "0", ",", "0"}], "}"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0.9999999999999865`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999999667`", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1.0000000000000706`", ",", "0"}], "}"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.44937040096715697`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.8933455337855349`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.3866667429414074`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9222195128618038`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.9976172723012691`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.06899114440433933`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.9976172723012243`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.06899114440433624`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.44937040096718134`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.8933455337855833`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.38666674294141545`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.922219512861823`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9287562401252927`"}], "-", 
        RowBox[{"0.3706910390450554`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.9786235252959727`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.20565990308593063`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9851389890168568`"}], "+", 
        RowBox[{"0.17175905309127512`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9287562401253177`"}], "+", 
        RowBox[{"0.3706910390450654`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.9786235252959417`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2056599030859241`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9851389890168901`"}], "-", 
        RowBox[{"0.17175905309128092`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.7009776598061207`"}], "+", 
        RowBox[{"0.7131832306305839`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.9904804439875717`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.13765351458716818`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.5961324854692218`"}], "-", 
        RowBox[{"0.8028860814388962`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.7009776598061613`"}], "-", 
        RowBox[{"0.7131832306306252`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.990480443987555`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.13765351458716585`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.5961324854692113`"}], "+", 
        RowBox[{"0.8028860814388818`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.7009776598061528`"}], "-", 
        RowBox[{"0.7131832306306027`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.9904804439875639`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.1376535145871718`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.5961324854692115`"}], "+", 
        RowBox[{"0.8028860814388747`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.5961324854692287`"}], "-", 
        RowBox[{"0.802886081438898`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.700977659806143`"}], "+", 
        RowBox[{"0.7131832306305927`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.9904804439875615`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.13765351458717145`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9709418174260265`"}], "+", 
        RowBox[{"0.23931566428756532`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.748510748171124`"}], "+", 
        RowBox[{"0.6631226582408016`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.5680647467311496`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.8229838658936456`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9709418174260711`"}], "-", 
        RowBox[{"0.23931566428757634`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.748510748171092`"}], "-", 
        RowBox[{"0.6631226582407733`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.5680647467311637`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.822983865893666`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.5680647467311548`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.8229838658936872`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9709418174259998`"}], "+", 
        RowBox[{"0.2393156642875656`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.7485107481711072`"}], "+", 
        RowBox[{"0.6631226582408027`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.7485107481710929`"}], "-", 
        RowBox[{"0.6631226582407901`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5680647467311266`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.8229838658936464`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9709418174260946`"}], "-", 
        RowBox[{"0.23931566428758896`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.44937040096716885`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.8933455337855682`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.3866667429414166`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9222195128618058`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.9976172723012371`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.06899114440432963`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.9976172723012573`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.06899114440433103`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.4493704009671617`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.893345533785554`", " ", "\[ImaginaryI]"}]}], ",", "0", ",",
        "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.3866667429414205`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.922219512861815`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.2892521195365713`"}], "-", 
        RowBox[{"0.9572529505535678`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.017260640905387425`"}], "+", 
        RowBox[{"0.9998510240408574`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.9621030198436167`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.272686228489516`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.01726064090538715`"}], "-", 
        RowBox[{"0.9998510240408415`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.9621030198435752`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.27268622848950425`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.28925211953659724`"}], "+", 
        RowBox[{"0.9572529505536537`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.9621030198436114`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2726862284894942`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.28925211953658136`"}], "+", 
        RowBox[{"0.9572529505536211`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.017260640905403087`"}], "-", 
        RowBox[{"0.9998510240408123`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.01726064090540436`"}], "+", 
        RowBox[{"0.999851024040886`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.9621030198435911`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2726862284894885`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.2892521195365761`"}], "-", 
        RowBox[{"0.9572529505536037`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.885456025653198`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.46472317204376284`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.12053668025533398`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9927088740980231`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.35460488704253434`"}], "-", 
        RowBox[{"0.9350162426854385`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.12053668025534106`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9927088740980814`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.35460488704251897`"}], "+", 
        RowBox[{"0.935016242685398`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.8854560256532213`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.46472317204377506`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.12053668025531306`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9927088740980612`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.3546048870425381`"}], "-", 
        RowBox[{"0.9350162426853659`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.8854560256532235`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.4647231720437808`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.8854560256531921`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.46472317204376434`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.12053668025531163`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9927088740980494`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.3546048870425699`"}], "+", 
        RowBox[{"0.9350162426854498`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.8512844415843328`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5247044877989886`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.8326664226871925`"}], "+", 
        RowBox[{"0.5537748897605337`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9994041405510905`"}], "-", 
        RowBox[{"0.034516138969721555`", " ", "\[ImaginaryI]"}]}], ",", "0"}],
       "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.8326664226872111`"}], "-", 
        RowBox[{"0.5537748897605461`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9994041405510495`"}], "+", 
        RowBox[{"0.03451613896972014`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.8512844415843768`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5247044877990157`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.9904804439875032`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.1376535145871836`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.596132485469233`"}], "-", 
        RowBox[{"0.8028860814388903`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.7009776598061855`"}], "+", 
        RowBox[{"0.7131832306306015`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.5961324854692202`"}], "+", 
        RowBox[{"0.8028860814388729`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.7009776598061448`"}], "-", 
        RowBox[{"0.7131832306305601`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.9904804439876166`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.13765351458719938`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.985138989016844`"}], "+", 
        RowBox[{"0.17175905309128361`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9287562401253124`"}], "-", 
        RowBox[{"0.3706910390450771`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.9786235252959566`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.20565990308593052`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9287562401252883`"}], "+", 
        RowBox[{"0.3706910390450675`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.9786235252959564`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.20565990308593046`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9851389890168992`"}], "-", 
        RowBox[{"0.17175905309129325`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.7709531747949887`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.6368918293348993`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.05176135288418533`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9986594826804898`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.6759436441446899`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7369533159843059`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.7709531747949679`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.6368918293348822`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.05176135288418199`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9986594826804253`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.6759436441447795`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7369533159844036`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9709418174260865`"}], "+", 
        RowBox[{"0.23931566428754641`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.7485107481710608`"}], "+", 
        RowBox[{"0.663122658240777`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5680647467311581`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.8229838658936445`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.5680647467311678`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.8229838658936585`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9709418174260267`"}], "-", 
        RowBox[{"0.23931566428753168`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.7485107481711241`"}], "-", 
        RowBox[{"0.663122658240833`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.7485107481711053`"}], "-", 
        RowBox[{"0.663122658240811`", " ", "\[ImaginaryI]"}]}], ",", "0", ",",
        "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.5680647467311377`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.822983865893643`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9709418174260516`"}], "-", 
        RowBox[{"0.23931566428755421`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.748510748171085`"}], "+", 
        RowBox[{"0.663122658240793`", " ", "\[ImaginaryI]"}]}], ",", "0", ",",
        "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.5680647467311619`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.822983865893678`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9709418174260541`"}], "+", 
        RowBox[{"0.23931566428755482`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.08620037988060594`"}], "-", 
        RowBox[{"0.996277819942046`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.18873759545289104`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9820275556533898`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9946415246952025`"}], "+", 
        RowBox[{"0.10338393178837171`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9946415246951827`"}], "-", 
        RowBox[{"0.10338393178836966`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.08620037988060279`"}], "+", 
        RowBox[{"0.9962778199420095`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.18873759545290786`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9820275556534774`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.8688879687249921`"}], "-", 
        RowBox[{"0.4950087855835597`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.41826780077558273`"}], "+", 
        RowBox[{"0.908323756616768`", " ", "\[ImaginaryI]"}]}], ",", "0", ",",
        "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.8130560994785206`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5821853477207638`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.4182678007755659`"}], "-", 
        RowBox[{"0.9083237566167315`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.8130560994785428`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5821853477207797`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.8688879687250326`"}], "+", 
        RowBox[{"0.4950087855835828`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.05176135288419176`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9986594826804837`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.6759436441447139`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7369533159843143`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.7709531747949732`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.6368918293348926`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.05176135288418901`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9986594826804307`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.6759436441447731`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7369533159843791`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.7709531747949775`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.6368918293348962`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.9154080085254019`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.402527238739959`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.9409976553623207`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.33841307983366986`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.7251763071433801`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.688563231343274`", " ", "\[ImaginaryI]"}]}], ",", "0", ",",
        "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.7251763071433793`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.6885632313432732`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.9154080085253485`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.4025272387399355`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.9409976553624197`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3384130798337055`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.47993747795977815`"}], "-", 
        RowBox[{"0.8773026941993771`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.15472933479028508`"}], "-", 
        RowBox[{"0.9879568983287578`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.7924768419511`"}], "-", 
        RowBox[{"0.609902004400108`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.15472933479028145`"}], "+", 
        RowBox[{"0.9879568983287345`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.792476841951054`"}], "+", 
        RowBox[{"0.6099020044000726`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.47993747795983654`"}], "+", 
        RowBox[{"0.8773026941994838`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395625838`"}], "+", 
        RowBox[{"0.9749279121817451`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9009688679024361`"}], "-", 
        RowBox[{"0.43388373911756306`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.6234898018587365`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824680881`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024047`"}], "+", 
        RowBox[{"0.4338837391175479`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.6234898018586774`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7818314824680139`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.222520933956298`"}], "-", 
        RowBox[{"0.9749279121819187`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.12053668025530369`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9927088740980197`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.3546048870425424`"}], "+", 
        RowBox[{"0.9350162426854252`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.885456025653223`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.4647231720437619`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.12053668025531246`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9927088740980919`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.35460488704253385`"}], "-", 
        RowBox[{"0.9350162426854026`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.8854560256532079`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.46472317204375396`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.2225209339563114`"}], "-", 
        RowBox[{"0.9749279121818313`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.900968867902408`"}], "+", 
        RowBox[{"0.43388373911755707`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6234898018587317`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.78183148246803`", " ", "\[ImaginaryI]"}]}], ",", "0", ",", 
       "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.6234898018587329`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824680316`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.22252093395630837`"}], "+", 
        RowBox[{"0.974927912181818`", " ", "\[ImaginaryI]"}]}], ",", "0", ",",
        "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024268`"}], "-", 
        RowBox[{"0.4338837391175661`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.3221204417984461`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9466986959827538`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5099326043901408`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.8602143564135114`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.6501040936687836`"}], "+", 
        RowBox[{"0.7598451601445866`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.5099326043901288`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.8602143564134912`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.6501040936687427`"}], "-", 
        RowBox[{"0.7598451601445387`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.32212044179848714`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9466986959828744`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.9621030198436151`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2726862284895008`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.2892521195365582`"}], "-", 
        RowBox[{"0.9572529505536319`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.01726064090536722`"}], "+", 
        RowBox[{"0.9998510240408011`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.017260640905368902`"}], "-", 
        RowBox[{"0.9998510240408984`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.9621030198435844`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2726862284894921`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.2892521195365509`"}], "+", 
        RowBox[{"0.9572529505536076`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.12053668025530562`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9927088740980297`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.35460488704255294`"}], "+", 
        RowBox[{"0.935016242685432`", " ", "\[ImaginaryI]"}]}], ",", "0", ",",
        "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.8854560256532003`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.4647231720437631`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.3546048870425372`"}], "-", 
        RowBox[{"0.9350162426853904`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.8854560256532198`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.4647231720437734`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.12053668025531195`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9927088740980818`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4799374779597899`"}], "+", 
        RowBox[{"0.8773026941994512`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.154729334790302`"}], "+", 
        RowBox[{"0.987956898328766`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.7924768419510431`"}], "+", 
        RowBox[{"0.6099020044000592`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.47993747795978053`"}], "-", 
        RowBox[{"0.877302694199434`", " ", "\[ImaginaryI]"}]}], ",", "0", ",",
        "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.15472933479029502`"}], "-", 
        RowBox[{"0.9879568983287215`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.7924768419511158`"}], "-", 
        RowBox[{"0.6099020044001151`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5680647467311571`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.8229838658936506`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9709418174260713`"}], "+", 
        RowBox[{"0.23931566428755152`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.7485107481710783`"}], "+", 
        RowBox[{"0.6631226582407855`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5680647467311617`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.8229838658936572`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9709418174260378`"}], "-", 
        RowBox[{"0.23931566428754328`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.7485107481711134`"}], "-", 
        RowBox[{"0.6631226582408166`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.7251763071433457`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.6885632313432107`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.915408008525378`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.40252723873997476`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.9409976553624163`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3384130798336576`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.9154080085253532`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.4025272387399639`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.9409976553623539`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.33841307983363517`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.7251763071434443`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.6885632313433044`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.4182678007755576`"}], "+", 
        RowBox[{"0.9083237566167484`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.8130560994785367`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5821853477207791`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.8688879687250007`"}], "-", 
        RowBox[{"0.4950087855835761`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.8130560994785231`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5821853477207694`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.8688879687250141`"}], "+", 
        RowBox[{"0.4950087855835837`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4182678007755645`"}], "-", 
        RowBox[{"0.9083237566167635`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.9976172723012866`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.06899114440429882`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.4493704009670988`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.8933455337855066`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.386666742941427`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9222195128618234`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.3866667429414153`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9222195128617954`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.9976172723012126`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.0689911444042937`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.4493704009671694`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.893345533785647`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.509932604390128`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.8602143564134992`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.6501040936687665`"}], "+", 
        RowBox[{"0.7598451601445848`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.3221204417984729`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9466986959827821`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5099326043901334`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.8602143564135083`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.6501040936687418`"}], "-", 
        RowBox[{"0.7598451601445558`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.3221204417984911`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9466986959828356`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.7924768419511085`"}], "+", 
        RowBox[{"0.609902004400075`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.47993747795978114`"}], "+", 
        RowBox[{"0.8773026941994305`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.154729334790269`"}], "+", 
        RowBox[{"0.9879568983287281`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.1547293347902752`"}], "-", 
        RowBox[{"0.9879568983287677`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.7924768419510837`"}], "-", 
        RowBox[{"0.6099020044000559`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.4799374779597932`"}], "-", 
        RowBox[{"0.8773026941994525`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.38666674294142583`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9222195128618225`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.9976172723012875`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.06899114440429821`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.4493704009671001`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.8933455337855101`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.38666674294141506`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9222195128617968`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.9976172723012118`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.06899114440429298`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.4493704009671674`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.8933455337856439`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.25603909005753656`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9666664286932302`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.5393200344991521`"}], "+", 
        RowBox[{"0.8421008849227809`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9521176659107358`"}], "+", 
        RowBox[{"0.3057318273597523`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.5393200344992075`"}], "-", 
        RowBox[{"0.8421008849228674`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9521176659106969`"}], "-", 
        RowBox[{"0.3057318273597398`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.25603909005753267`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9666664286932155`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.4799374779597873`"}], "-", 
        RowBox[{"0.8773026941994533`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.15472933479027928`"}], "-", 
        RowBox[{"0.9879568983287432`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.7924768419510835`"}], "-", 
        RowBox[{"0.6099020044000575`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.792476841951107`"}], "+", 
        RowBox[{"0.6099020044000756`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4799374779597773`"}], "+", 
        RowBox[{"0.8773026941994351`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.15472933479028037`"}], "+", 
        RowBox[{"0.9879568983287501`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.2560390900575423`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9666664286932438`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.5393200344991883`"}], "+", 
        RowBox[{"0.8421008849227999`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9521176659106908`"}], "+", 
        RowBox[{"0.3057318273597583`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.95211766591073`"}], "-", 
        RowBox[{"0.3057318273597709`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.2560390900575309`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9666664286932009`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.5393200344992054`"}], "-", 
        RowBox[{"0.8421008849228265`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.6501040936687381`"}], "-", 
        RowBox[{"0.7598451601445663`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.3221204417984928`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9466986959827991`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.509932604390136`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.8602143564135124`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.5099326043901257`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.860214356413495`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.6501040936687557`"}], "+", 
        RowBox[{"0.7598451601445868`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.3221204417984965`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.94669869598281`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9009688679024185`"}], "-", 
        RowBox[{"0.43388373911756484`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.6234898018587244`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824679962`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.2225209339563214`"}], "+", 
        RowBox[{"0.9749279121818365`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9009688679024143`"}], "+", 
        RowBox[{"0.43388373911756284`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.6234898018587643`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7818314824680462`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395631511`"}], "-", 
        RowBox[{"0.974927912181809`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.25603909005756126`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9666664286932306`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.5393200344991926`"}], "-", 
        RowBox[{"0.8421008849227847`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9521176659107151`"}], "-", 
        RowBox[{"0.30573182735975085`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9521176659107146`"}], "+", 
        RowBox[{"0.3057318273597507`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.25603909005755393`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9666664286932029`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.5393200344992211`"}], "+", 
        RowBox[{"0.842100884922829`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.354604887042542`"}], "+", 
        RowBox[{"0.9350162426854193`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.8854560256532029`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.4647231720437664`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.1205366802553193`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9927088740980495`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.12053668025532048`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9927088740980592`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.35460488704253745`"}], "-", 
        RowBox[{"0.9350162426854073`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.8854560256532157`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.46472317204377306`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.940997655362339`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3384130798336429`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.7251763071433559`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.6885632313432763`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.9154080085253903`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.40252723874000146`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.7251763071433782`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.6885632313432976`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.9154080085253251`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.4025272387399728`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.9409976553624229`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.338413079833673`", " ", "\[ImaginaryI]"}]}], ",", "0", ",",
        "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.35460488704250426`"}], "+", 
        RowBox[{"0.9350162426853869`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.8854560256532346`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.4647231720437713`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.12053668025532799`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9927088740980506`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.8854560256531936`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.4647231720437498`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.12053668025532864`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9927088740980561`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3546048870425307`"}], "-", 
        RowBox[{"0.9350162426854566`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.9786235252959653`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.20565990308593873`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9851389890168925`"}], "+", 
        RowBox[{"0.17175905309126516`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.92875624012527`"}], "-", 
        RowBox[{"0.3706910390450364`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9287562401253472`"}], "+", 
        RowBox[{"0.3706910390450672`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.9786235252959452`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.20565990308593451`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9851389890168599`"}], "-", 
        RowBox[{"0.1717590530912595`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.7009776598061757`"}], "+", 
        RowBox[{"0.7131832306305997`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.9904804439875186`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.1376535145871785`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.596132485469231`"}], "-", 
        RowBox[{"0.8028860814388874`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.5961324854692223`"}], "+", 
        RowBox[{"0.8028860814388756`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.7009776598061463`"}], "-", 
        RowBox[{"0.71318323063057`", " ", "\[ImaginaryI]"}]}], ",", "0", ",", 
       "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.9904804439876033`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.13765351458719027`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.99048044398756`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.13765351458716524`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.5961324854692189`"}], "-", 
        RowBox[{"0.8028860814388684`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.7009776598061449`"}], "+", 
        RowBox[{"0.7131832306305916`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.9904804439875671`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.13765351458716624`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.5961324854692369`"}], "+", 
        RowBox[{"0.8028860814388927`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.700977659806154`"}], "-", 
        RowBox[{"0.7131832306306009`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.25603909005754266`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9666664286932158`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.5393200344991989`"}], "-", 
        RowBox[{"0.84210088492282`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9521176659107071`"}], "-", 
        RowBox[{"0.3057318273597488`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.25603909005754505`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9666664286932249`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.5393200344991915`"}], "+", 
        RowBox[{"0.8421008849228085`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9521176659107222`"}], "+", 
        RowBox[{"0.3057318273597536`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.18873759545291627`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9820275556534371`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9946415246951972`"}], "-", 
        RowBox[{"0.10338393178837607`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.08620037988060947`"}], "+", 
        RowBox[{"0.9962778199420084`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.18873759545291377`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9820275556534241`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9946415246951871`"}], "+", 
        RowBox[{"0.10338393178837503`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.08620037988061273`"}], "-", 
        RowBox[{"0.996277819942046`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.9621030198435668`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2726862284894976`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.28925211953656993`"}], "+", 
        RowBox[{"0.9572529505536235`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.01726064090537826`"}], "-", 
        RowBox[{"0.999851024040862`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.9621030198436272`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2726862284895147`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.28925211953656527`"}], "-", 
        RowBox[{"0.9572529505536082`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.01726064090537783`"}], "+", 
        RowBox[{"0.9998510240408371`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.44937040096716185`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.8933455337855484`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.3866667429414301`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9222195128618162`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.9976172723012283`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.06899114440432047`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.44937040096717346`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.8933455337855715`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.3866667429414225`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9222195128617982`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.9976172723012673`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.06899114440432316`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.15472933479027393`"}], "+", 
        RowBox[{"0.9879568983287339`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.7924768419510924`"}], "+", 
        RowBox[{"0.6099020044000747`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.47993747795979425`"}], "+", 
        RowBox[{"0.8773026941994451`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.7924768419510881`"}], "-", 
        RowBox[{"0.6099020044000715`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.47993747795978803`"}], "-", 
        RowBox[{"0.8773026941994336`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.15472933479027812`"}], "-", 
        RowBox[{"0.9879568983287607`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.9786235252959743`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.20565990308596008`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9851389890168267`"}], "-", 
        RowBox[{"0.17175905309124775`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9287562401253107`"}], "+", 
        RowBox[{"0.37069103904507233`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.928756240125293`"}], "-", 
        RowBox[{"0.3706910390450653`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.9786235252959283`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.20565990308595042`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9851389890169276`"}], "+", 
        RowBox[{"0.17175905309126535`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9287562401253082`"}], "-", 
        RowBox[{"0.3706910390450697`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.9786235252959739`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.205659903085926`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9851389890168366`"}], "+", 
        RowBox[{"0.1717590530912837`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9851389890169062`"}], "-", 
        RowBox[{"0.17175905309129583`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9287562401252966`"}], "+", 
        RowBox[{"0.37069103904506506`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.9786235252959425`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.20565990308591942`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.832666422687205`"}], "+", 
        RowBox[{"0.5537748897605287`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9994041405510499`"}], "-", 
        RowBox[{"0.0345161389696974`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.8512844415843592`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5247044877990196`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9994041405510917`"}], "+", 
        RowBox[{"0.034516138969698844`", " ", "\[ImaginaryI]"}]}], ",", "0"}],
       "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.8512844415843372`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.524704487799006`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.8326664226872109`"}], "-", 
        RowBox[{"0.5537748897605326`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.08620037988065632`"}], "+", 
        RowBox[{"0.9962778199420651`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.18873759545293406`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9820275556533354`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9946415246952093`"}], "-", 
        RowBox[{"0.10338393178836948`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9946415246951766`"}], "+", 
        RowBox[{"0.10338393178836608`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.08620037988064913`"}], "-", 
        RowBox[{"0.9962778199419821`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.18873759545296798`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.982027555653512`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.017260640905386093`"}], "+", 
        RowBox[{"0.9998510240408528`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.9621030198436133`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2726862284895098`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.2892521195365699`"}], "-", 
        RowBox[{"0.957252950553583`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.01726064090538598`"}], "-", 
        RowBox[{"0.9998510240408461`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.9621030198435812`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2726862284895007`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.2892521195365877`"}], "+", 
        RowBox[{"0.9572529505536419`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2225209339563161`"}], "-", 
        RowBox[{"0.9749279121818282`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024349`"}], "+", 
        RowBox[{"0.4338837391175552`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.6234898018587101`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7818314824680168`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.22252093395631398`"}], "+", 
        RowBox[{"0.9749279121818187`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024116`"}], "-", 
        RowBox[{"0.43388373911754397`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.6234898018587409`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824680556`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679023828`"}], "+", 
        RowBox[{"0.43388373911755507`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6234898018587348`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7818314824680346`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.2225209339563059`"}], "-", 
        RowBox[{"0.9749279121818437`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.6234898018587292`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824680275`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395629802`"}], "+", 
        RowBox[{"0.9749279121818092`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9009688679024441`"}], "-", 
        RowBox[{"0.4338837391175846`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.748510748171114`"}], "-", 
        RowBox[{"0.6631226582408186`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.5680647467311595`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.8229838658936502`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9709418174260135`"}], "-", 
        RowBox[{"0.23931566428752632`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9709418174261008`"}], "+", 
        RowBox[{"0.23931566428754783`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.7485107481710763`"}], "+", 
        RowBox[{"0.6631226582407853`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.5680647467311628`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.8229838658936551`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.9154080085253801`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.4025272387399694`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.9409976553623829`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.33841307983366486`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.7251763071433631`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.6885632313432452`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.9154080085253558`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.40252723873995866`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.940997655362375`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.33841307983366203`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.7251763071434091`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.6885632313432888`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.7709531747949732`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.6368918293348897`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.05176135288420056`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9986594826804722`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.6759436441447356`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7369533159843256`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.05176135288419895`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9986594826804411`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.6759436441447639`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7369533159843564`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.7709531747949803`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.6368918293348956`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.8512844415843167`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5247044877990058`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.8326664226872202`"}], "-", 
        RowBox[{"0.5537748897605543`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9994041405510615`"}], "+", 
        RowBox[{"0.03451613896970625`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.8326664226871814`"}], "+", 
        RowBox[{"0.5537748897605285`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9994041405510795`"}], "-", 
        RowBox[{"0.034516138969706865`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.8512844415843687`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5247044877990378`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.7485107481710863`"}], "+", 
        RowBox[{"0.6631226582407921`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5680647467311573`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.8229838658936712`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9709418174260376`"}], "+", 
        RowBox[{"0.2393156642875553`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.5680647467311425`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.8229838658936498`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.970941817426066`"}], "-", 
        RowBox[{"0.2393156642875623`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.748510748171106`"}], "-", 
        RowBox[{"0.6631226582408095`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.28925211953655783`"}], "+", 
        RowBox[{"0.9572529505536107`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.017260640905371383`"}], "-", 
        RowBox[{"0.999851024040876`", " ", "\[ImaginaryI]"}]}], ",", "0", ",",
        "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.9621030198435616`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2726862284894956`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.017260640905370474`"}], "+", 
        RowBox[{"0.9998510240408234`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.9621030198436327`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.27268622848951574`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.28925211953656227`"}], "-", 
        RowBox[{"0.9572529505536255`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.7009776598061511`"}], "+", 
        RowBox[{"0.7131832306305956`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.9904804439875564`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.13765351458716735`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.5961324854692222`"}], "-", 
        RowBox[{"0.8028860814388679`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.99048044398757`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.13765351458716923`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.5961324854692385`"}], "+", 
        RowBox[{"0.8028860814388897`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.7009776598061501`"}], "-", 
        RowBox[{"0.7131832306305945`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.675943644144742`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7369533159843003`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.770953174794986`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.6368918293348943`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.051761352884223455`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9986594826804732`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.7709531747949734`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.6368918293348839`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.051761352884221616`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9986594826804378`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6759436441447897`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7369533159843522`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.5393200344992068`"}], "-", 
        RowBox[{"0.8421008849228209`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9521176659107341`"}], "-", 
        RowBox[{"0.30573182735978277`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.2560390900575105`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9666664286931703`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.5393200344991941`"}], "+", 
        RowBox[{"0.842100884922801`", " ", "\[ImaginaryI]"}]}], ",", "0", ",",
        "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9521176659106805`"}], "+", 
        RowBox[{"0.30573182735976556`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.25603909005753966`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9666664286932805`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.97094181742602`"}], "-", 
        RowBox[{"0.23931566428754203`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.7485107481710922`"}], "-", 
        RowBox[{"0.6631226582407667`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5680647467311879`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.8229838658936727`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.5680647467311519`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.8229838658936206`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9709418174260876`"}], "+", 
        RowBox[{"0.2393156642875587`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.7485107481711305`"}], "+", 
        RowBox[{"0.6631226582408006`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9521176659107238`"}], "-", 
        RowBox[{"0.3057318273597547`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.2560390900575739`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.966666428693239`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.5393200344991878`"}], "-", 
        RowBox[{"0.8421008849227538`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9521176659107052`"}], "+", 
        RowBox[{"0.30573182735974874`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.25603909005756076`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9666664286931893`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.539320034499247`"}], "+", 
        RowBox[{"0.8421008849228463`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.8688879687250045`"}], "+", 
        RowBox[{"0.49500878558358286`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.41826780077556347`"}], "-", 
        RowBox[{"0.9083237566167649`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.8130560994785172`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5821853477207661`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.8688879687250063`"}], "-", 
        RowBox[{"0.4950087855835839`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.41826780077555575`"}], "+", 
        RowBox[{"0.9083237566167481`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.8130560994785417`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5821853477207837`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9946415246952208`"}], "+", 
        RowBox[{"0.10338393178835657`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.08620037988062601`"}], "-", 
        RowBox[{"0.9962778199419935`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.18873759545290475`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9820275556534193`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.1887375954529097`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.982027555653445`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.994641524695168`"}], "-", 
        RowBox[{"0.10338393178835108`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.08620037988063158`"}], "+", 
        RowBox[{"0.9962778199420578`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.41826780077556425`"}], "-", 
        RowBox[{"0.9083237566167319`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.8130560994785382`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5821853477207726`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.8688879687250142`"}], "+", 
        RowBox[{"0.4950087855835779`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.8130560994785289`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5821853477207659`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.8688879687250056`"}], "-", 
        RowBox[{"0.49500878558357303`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.41826780077558134`"}], "+", 
        RowBox[{"0.908323756616769`", " ", "\[ImaginaryI]"}]}], ",", "0", ",",
        "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.8688879687250116`"}], "+", 
        RowBox[{"0.495008785583572`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4182678007755643`"}], "-", 
        RowBox[{"0.9083237566166982`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.8130560994785577`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5821853477207781`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.418267800775607`"}], "+", 
        RowBox[{"0.9083237566167909`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.8130560994785173`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5821853477207491`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.8688879687250121`"}], "-", 
        RowBox[{"0.4950087855835722`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.9154080085253584`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.4025272387399683`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.9409976553623827`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.33841307983366975`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.7251763071433739`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.6885632313432746`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.9409976553623721`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3384130798336659`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.7251763071433791`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.6885632313432796`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.9154080085253711`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.4025272387399739`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9994041405510636`"}], "-", 
        RowBox[{"0.03451613896971095`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.8512844415843354`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5247044877989808`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.8326664226872266`"}], "+", 
        RowBox[{"0.5537748897605369`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.8512844415843827`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5247044877990099`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.832666422687195`"}], "-", 
        RowBox[{"0.5537748897605159`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9994041405510771`"}], "+", 
        RowBox[{"0.03451613896971142`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.3221204417984975`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9466986959827619`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5099326043901393`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.8602143564135282`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.6501040936687341`"}], "-", 
        RowBox[{"0.7598451601445733`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.5099326043901135`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.8602143564134844`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.6501040936687481`"}], "+", 
        RowBox[{"0.7598451601445897`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.32212044179852295`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9466986959828366`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.7009776598061205`"}], "-", 
        RowBox[{"0.7131832306305258`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.9904804439875776`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.13765351458716785`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.5961324854692674`"}], "+", 
        RowBox[{"0.8028860814388952`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.9904804439875494`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.13765351458716393`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.5961324854692254`"}], "-", 
        RowBox[{"0.8028860814388386`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.7009776598062194`"}], "+", 
        RowBox[{"0.7131832306306264`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.5961324854692249`"}], "-", 
        RowBox[{"0.8028860814389039`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.7009776598061156`"}], "+", 
        RowBox[{"0.7131832306305814`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.9904804439875696`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.13765351458717023`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.9904804439875564`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.1376535145871684`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.5961324854692047`"}], "+", 
        RowBox[{"0.8028860814388766`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.7009776598061637`"}], "-", 
        RowBox[{"0.7131832306306304`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.596132485469225`"}], "-", 
        RowBox[{"0.8028860814388902`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.7009776598061381`"}], "+", 
        RowBox[{"0.713183230630591`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.9904804439875645`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.137653514587169`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.5961324854692179`"}], "+", 
        RowBox[{"0.8028860814388805`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.7009776598061546`"}], "-", 
        RowBox[{"0.7131832306306076`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.9904804439875616`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.13765351458716862`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9709418174260452`"}], "-", 
        RowBox[{"0.23931566428754825`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.748510748171108`"}], "-", 
        RowBox[{"0.6631226582408178`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.5680647467311326`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.8229838658936376`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.7485107481710778`"}], "+", 
        RowBox[{"0.6631226582407911`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.5680647467311651`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.8229838658936848`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9709418174260624`"}], "+", 
        RowBox[{"0.2393156642875525`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.9976172723012539`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.06899114440432685`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.44937040096715847`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.8933455337855688`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.3866667429414044`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9222195128617958`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.38666674294141906`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9222195128618308`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.9976172723012411`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.06899114440432598`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.449370400967155`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.893345533785562`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.8854560256531985`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.46472317204374736`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.12053668025531322`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9927088740980792`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.3546048870425313`"}], "-", 
        RowBox[{"0.9350162426853911`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.8854560256532338`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.4647231720437659`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.12053668025530748`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9927088740980319`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.3546048870425481`"}], "+", 
        RowBox[{"0.9350162426854355`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3546048870425412`"}], "-", 
        RowBox[{"0.9350162426854247`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.8854560256532249`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.4647231720438021`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.12053668025533953`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9927088740979912`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.35460488704253323`"}], "+", 
        RowBox[{"0.9350162426854037`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.8854560256531737`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.4647231720437753`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.12053668025535408`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9927088740981109`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9851389890169109`"}], "+", 
        RowBox[{"0.17175905309125583`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9287562401252483`"}], "-", 
        RowBox[{"0.37069103904501655`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.9786235252959684`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2056599030859414`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.9786235252959413`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2056599030859357`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9851389890168457`"}], "-", 
        RowBox[{"0.17175905309124448`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9287562401253766`"}], "+", 
        RowBox[{"0.3706910390450678`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.1887375954529047`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9820275556534549`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9946415246951499`"}], "-", 
        RowBox[{"0.1033839317883476`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.08620037988061868`"}], "+", 
        RowBox[{"0.9962778199420353`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.08620037988061717`"}], "-", 
        RowBox[{"0.9962778199420178`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.18873759545289642`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9820275556534119`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9946415246952393`"}], "+", 
        RowBox[{"0.10338393178835688`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.8688879687250176`"}], "-", 
        RowBox[{"0.4950087855835993`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.4182678007755578`"}], "+", 
        RowBox[{"0.9083237566167407`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.8130560994785224`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5821853477207499`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.8130560994785554`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5821853477207736`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.8688879687249855`"}], "+", 
        RowBox[{"0.49500878558358097`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.41826780077557046`"}], "-", 
        RowBox[{"0.9083237566167682`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.9621030198435714`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2726862284894751`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2892521195365723`"}], "-", 
        RowBox[{"0.9572529505536066`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.017260640905405744`"}], "+", 
        RowBox[{"0.9998510240408707`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.28925211953657665`"}], "+", 
        RowBox[{"0.9572529505536208`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.017260640905405`"}], "-", 
        RowBox[{"0.9998510240408276`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.9621030198436351`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2726862284894932`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.7251763071433845`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.6885632313432818`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.9154080085253689`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.40252723873998014`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.9409976553623527`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.338413079833649`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.7251763071433713`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.6885632313432692`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.9154080085253553`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.4025272387399742`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.9409976553624084`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.33841307983366903`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.47993747795981123`"}], "+", 
        RowBox[{"0.8773026941994583`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.15472933479027307`"}], "+", 
        RowBox[{"0.9879568983287246`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.7924768419510648`"}], "+", 
        RowBox[{"0.6099020044000707`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.792476841951099`"}], "-", 
        RowBox[{"0.609902004400097`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.47993747795978603`"}], "-", 
        RowBox[{"0.8773026941994122`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.15472933479028014`"}], "-", 
        RowBox[{"0.9879568983287698`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.7924768419510968`"}], "+", 
        RowBox[{"0.6099020044000792`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.4799374779598139`"}], "+", 
        RowBox[{"0.8773026941994536`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.15472933479025508`"}], "+", 
        RowBox[{"0.9879568983287019`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.7924768419510826`"}], "-", 
        RowBox[{"0.6099020044000683`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.4799374779597914`"}], "-", 
        RowBox[{"0.8773026941994125`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.15472933479026996`"}], "-", 
        RowBox[{"0.9879568983287969`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4182678007755669`"}], "-", 
        RowBox[{"0.9083237566167497`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.8130560994785476`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5821853477207712`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.8688879687249839`"}], "+", 
        RowBox[{"0.4950087855835778`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4182678007755696`"}], "+", 
        RowBox[{"0.9083237566167555`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.8130560994785271`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5821853477207566`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.8688879687250212`"}], "-", 
        RowBox[{"0.49500878558359906`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.8326664226871795`"}], "+", 
        RowBox[{"0.5537748897605314`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9994041405510905`"}], "-", 
        RowBox[{"0.03451613896971828`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.8512844415843424`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5247044877990023`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.8326664226872184`"}], "-", 
        RowBox[{"0.5537748897605572`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9994041405510498`"}], "+", 
        RowBox[{"0.03451613896971687`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.8512844415843603`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5247044877990134`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.7251763071433998`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.6885632313432793`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.9154080085253391`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.4025272387399395`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.9409976553623834`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3384130798336718`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.9409976553623702`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.33841307983366703`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.725176307143373`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.6885632313432539`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.9154080085254054`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.40252723873996865`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.8130560994785146`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5821853477207409`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.8688879687250121`"}], "-", 
        RowBox[{"0.4950087855835831`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.41826780077558434`"}], "+", 
        RowBox[{"0.908323756616765`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.8688879687250023`"}], "+", 
        RowBox[{"0.4950087855835775`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.41826780077556924`"}], "-", 
        RowBox[{"0.9083237566167323`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.8130560994785664`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.582185347720778`", " ", "\[ImaginaryI]"}]}], ",", "0", ",",
        "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.4493704009671401`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.8933455337855463`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.3866667429414183`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9222195128618238`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.997617272301244`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.06899114440431958`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.38666674294140885`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9222195128618013`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.9976172723012519`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.06899114440432014`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.4493704009671622`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.8933455337855902`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.4799374779597787`"}], "+", 
        RowBox[{"0.8773026941994401`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.15472933479029602`"}], "+", 
        RowBox[{"0.9879568983287633`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.7924768419510626`"}], "+", 
        RowBox[{"0.6099020044000627`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.15472933479029016`"}], "-", 
        RowBox[{"0.9879568983287259`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.7924768419511073`"}], "-", 
        RowBox[{"0.6099020044000971`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4799374779597838`"}], "-", 
        RowBox[{"0.8773026941994494`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.675943644144781`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.73695331598434`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.7709531747949361`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.636891829334875`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.05176135288421077`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.998659482680465`", " ", "\[ImaginaryI]"}]}], ",", "0", ",",
        "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.05176135288420985`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9986594826804472`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6759436441447534`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7369533159843099`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.7709531747950018`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.6368918293349293`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024294`"}], "-", 
        RowBox[{"0.43388373911756956`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.6234898018587276`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824680342`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2225209339562936`"}], "+", 
        RowBox[{"0.9749279121817958`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395630776`"}], "-", 
        RowBox[{"0.9749279121818577`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9009688679024038`"}], "+", 
        RowBox[{"0.43388373911755723`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.6234898018587279`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7818314824680346`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9994041405510696`"}], "+", 
        RowBox[{"0.034516138969711806`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.8512844415843706`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5247044877990072`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.83266642268719`"}], "-", 
        RowBox[{"0.553774889760511`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9994041405510711`"}], "-", 
        RowBox[{"0.034516138969711854`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.8512844415843432`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5247044877989904`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.832666422687233`"}], "+", 
        RowBox[{"0.5537748897605396`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9851389890168687`"}], "-", 
        RowBox[{"0.17175905309126932`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9287562401253222`"}], "+", 
        RowBox[{"0.3706910390450629`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.9786235252959335`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.20565990308592527`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9851389890168809`"}], "+", 
        RowBox[{"0.17175905309127146`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9287562401252911`"}], "-", 
        RowBox[{"0.37069103904505046`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.9786235252959796`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.20565990308593496`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.4493704009671612`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.8933455337855565`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.3866667429414293`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9222195128618144`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.9976172723012311`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.06899114440431953`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.3866667429414233`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9222195128618`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.9976172723012646`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.06899114440432184`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.44937040096716657`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.8933455337855671`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9521176659107269`"}], "+", 
        RowBox[{"0.30573182735974386`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.25603909005755277`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9666664286931754`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.5393200344992098`"}], "+", 
        RowBox[{"0.8421008849228216`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.5393200344991946`"}], "-", 
        RowBox[{"0.8421008849227979`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.952117665910709`"}], "-", 
        RowBox[{"0.30573182735973814`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.25603909005757386`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.966666428693255`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.8326664226871743`"}], "-", 
        RowBox[{"0.5537748897604879`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9994041405510798`"}], "+", 
        RowBox[{"0.0345161389697089`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.8512844415843825`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5247044877990018`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9994041405510611`"}], "-", 
        RowBox[{"0.034516138969708246`", " ", "\[ImaginaryI]"}]}], ",", "0"}],
       "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.8512844415843427`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5247044877989773`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.8326664226872604`"}], "+", 
        RowBox[{"0.5537748897605452`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.6501040936687587`"}], "-", 
        RowBox[{"0.7598451601445907`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.322120441798473`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9466986959828616`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.509932604390121`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.8602143564134015`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.6501040936687348`"}], "+", 
        RowBox[{"0.7598451601445627`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.3221204417984427`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9466986959827726`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.5099326043902157`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.8602143564135614`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679023905`"}], "-", 
        RowBox[{"0.4338837391175268`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6234898018587395`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824680355`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395633343`"}], "+", 
        RowBox[{"0.9749279121818397`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.6234898018587294`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7818314824680227`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395632455`"}], "-", 
        RowBox[{"0.9749279121818009`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9009688679024614`"}], "+", 
        RowBox[{"0.43388373911756095`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.940997655362382`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.33841307983367186`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.7251763071433993`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.6885632313432782`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.9154080085253391`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.40252723873993995`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.9409976553623712`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.338413079833668`", " ", "\[ImaginaryI]"}]}], ",", "0", ",",
        "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.7251763071433741`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.6885632313432544`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.915408008525405`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.402527238739969`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.770953174794985`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.6368918293349123`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.05176135288419614`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9986594826804236`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6759436441447558`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7369533159843327`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.6759436441447586`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7369533159843357`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.770953174794956`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.6368918293348882`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.051761352884199585`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.99865948268049`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.3221204417985009`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9466986959828046`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.5099326043900927`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.8602143564134689`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.6501040936687642`"}], "+", 
        RowBox[{"0.7598451601445892`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.650104093668737`"}], "-", 
        RowBox[{"0.7598451601445575`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.3221204417984996`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9466986959828007`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.5099326043901431`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.8602143564135538`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9946415246952158`"}], "+", 
        RowBox[{"0.10338393178836175`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.08620037988061963`"}], "-", 
        RowBox[{"0.9962778199420093`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.18873759545289853`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9820275556534087`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9946415246951718`"}], "-", 
        RowBox[{"0.10338393178835717`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.08620037988062258`"}], "+", 
        RowBox[{"0.9962778199420433`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.18873759545290783`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9820275556534571`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.9976172723012706`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.06899114440431547`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.4493704009671592`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.8933455337855525`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.38666674294142134`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9222195128617746`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.9976172723012261`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.0689911444043124`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.44937040096716857`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.8933455337855711`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.38666674294144604`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9222195128618336`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6234898018587385`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824680347`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395633382`"}], "+", 
        RowBox[{"0.9749279121818388`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679023906`"}], "-", 
        RowBox[{"0.43388373911752703`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6234898018587298`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7818314824680239`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.2225209339563253`"}], "-", 
        RowBox[{"0.9749279121818014`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024612`"}], "+", 
        RowBox[{"0.433883739117561`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.9154080085253625`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.4025272387399601`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.9409976553623899`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.33841307983369046`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.7251763071433482`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.6885632313432636`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.9409976553623534`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3384130798336773`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.7251763071433914`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.6885632313433045`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.9154080085253744`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.4025272387399653`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6759436441447608`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.73695331598434`", " ", "\[ImaginaryI]"}]}], ",", "0", ",", 
       "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.7709531747949869`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.6368918293349244`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.05176135288418513`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9986594826804015`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6759436441447517`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.73695331598433`", " ", "\[ImaginaryI]"}]}], ",", "0", ",", 
       "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.7709531747949436`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.6368918293348886`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.05176135288419091`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9986594826805131`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.8130560994785441`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5821853477207772`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.8688879687250227`"}], "-", 
        RowBox[{"0.49500878558362477`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.41826780077550857`"}], "+", 
        RowBox[{"0.9083237566167011`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.8130560994785225`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5821853477207618`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.868887968724961`"}], "+", 
        RowBox[{"0.4950087855835896`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.4182678007755686`"}], "-", 
        RowBox[{"0.9083237566168314`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.6501040936687509`"}], "+", 
        RowBox[{"0.7598451601445737`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.32212044179846444`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9466986959827774`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5099326043901484`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.8602143564135116`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.5099326043901323`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.8602143564134844`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.6501040936687503`"}], "-", 
        RowBox[{"0.759845160144573`", " ", "\[ImaginaryI]"}]}], ",", "0", ",",
        "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.32212044179848726`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9466986959828445`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.051761352884197476`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9986594826804753`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.6759436441447262`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7369533159843216`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.7709531747949755`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.6368918293348915`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.770953174794978`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.6368918293348936`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.05176135288419556`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9986594826804384`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.675943644144767`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7369533159843661`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.3546048870425363`"}], "-", 
        RowBox[{"0.9350162426853799`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.8854560256532162`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.4647231720437708`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.12053668025531333`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9927088740980706`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.8854560256532045`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.4647231720437646`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.12053668025530964`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9927088740980402`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3546048870425593`"}], "+", 
        RowBox[{"0.9350162426854406`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2892521195365698`"}], "-", 
        RowBox[{"0.9572529505536205`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.01726064090539825`"}], "+", 
        RowBox[{"0.9998510240408609`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.9621030198435792`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2726862284894776`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2892521195365669`"}], "+", 
        RowBox[{"0.9572529505536107`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.017260640905397848`"}], "-", 
        RowBox[{"0.9998510240408376`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.9621030198436272`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2726862284894912`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.8512844415843581`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5247044877990107`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.8326664226872303`"}], "+", 
        RowBox[{"0.5537748897605321`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9994041405510334`"}], "-", 
        RowBox[{"0.0345161389696913`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.8512844415843457`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.524704487799003`", " ", "\[ImaginaryI]"}]}], ",", "0", ",",
        "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.832666422687198`"}], "-", 
        RowBox[{"0.5537748897605106`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9994041405511086`"}], "+", 
        RowBox[{"0.034516138969693896`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9521176659107218`"}], "-", 
        RowBox[{"0.3057318273597651`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.25603909005753267`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9666664286931999`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.5393200344992013`"}], "-", 
        RowBox[{"0.8421008849228147`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.5393200344991974`"}], "+", 
        RowBox[{"0.8421008849228085`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9521176659107008`"}], "+", 
        RowBox[{"0.3057318273597584`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.2560390900575443`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9666664286932438`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.9621030198435843`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2726862284894983`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2892521195365833`"}], "+", 
        RowBox[{"0.9572529505536292`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.017260640905391977`"}], "-", 
        RowBox[{"0.9998510240408272`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.2892521195365732`"}], "-", 
        RowBox[{"0.9572529505535959`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.017260640905392744`"}], "+", 
        RowBox[{"0.9998510240408716`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.962103019843612`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2726862284895062`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.08620037988062179`"}], "+", 
        RowBox[{"0.996277819942034`", " ", "\[ImaginaryI]"}]}], ",", "0", ",",
        "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.18873759545291097`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9820275556534355`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9946415246951665`"}], "-", 
        RowBox[{"0.10338393178835631`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.08620037988062046`"}], "-", 
        RowBox[{"0.9962778199420186`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.18873759545290947`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9820275556534276`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9946415246952212`"}], "+", 
        RowBox[{"0.10338393178836199`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.978623525295903`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.20565990308594698`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9851389890168856`"}], "+", 
        RowBox[{"0.1717590530912767`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9287562401253134`"}], "-", 
        RowBox[{"0.3706910390450914`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.9786235252959989`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.20565990308596713`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9851389890168625`"}], "-", 
        RowBox[{"0.17175905309127268`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9287562401252778`"}], "+", 
        RowBox[{"0.37069103904507716`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.18873759545290186`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9820275556534088`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9946415246952031`"}], "+", 
        RowBox[{"0.10338393178836758`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.08620037988061345`"}], "-", 
        RowBox[{"0.996277819942029`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9946415246951831`"}], "-", 
        RowBox[{"0.1033839317883655`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.0862003798806131`"}], "+", 
        RowBox[{"0.996277819942025`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.18873759545291088`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9820275556534558`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.2560390900575409`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9666664286932113`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.5393200344991967`"}], "-", 
        RowBox[{"0.8421008849228149`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9521176659107021`"}], "-", 
        RowBox[{"0.3057318273597466`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.5393200344991953`"}], "+", 
        RowBox[{"0.8421008849228127`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9521176659107276`"}], "+", 
        RowBox[{"0.30573182735975474`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.25603909005754577`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9666664286932298`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.985138989016878`"}], "-", 
        RowBox[{"0.17175905309128126`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9287562401252865`"}], "+", 
        RowBox[{"0.37069103904506817`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.9786235252959596`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.20565990308593832`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.9786235252959505`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2056599030859364`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9851389890168681`"}], "+", 
        RowBox[{"0.17175905309127953`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9287562401253133`"}], "-", 
        RowBox[{"0.37069103904507894`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.15472933479028222`"}], "-", 
        RowBox[{"0.987956898328751`", " ", "\[ImaginaryI]"}]}], ",", "0", ",",
        "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.7924768419510931`"}], "-", 
        RowBox[{"0.609902004400088`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.47993747795978275`"}], "-", 
        RowBox[{"0.8773026941994151`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.15472933479028078`"}], "+", 
        RowBox[{"0.9879568983287418`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.792476841951075`"}], "+", 
        RowBox[{"0.6099020044000741`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.47993747795980707`"}], "+", 
        RowBox[{"0.8773026941994595`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.3221204417984803`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9466986959828118`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.5099326043901293`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.8602143564134511`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.65010409366875`"}], "-", 
        RowBox[{"0.7598451601445982`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.6501040936687259`"}], "+", 
        RowBox[{"0.7598451601445702`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.32212044179847893`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9466986959828076`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.5099326043901762`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.8602143564135302`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.32212044179849403`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.946698695982813`", " ", "\[ImaginaryI]"}]}], ",", "0", ",",
        "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.509932604390132`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.8602143564135261`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.6501040936687298`"}], "-", 
        RowBox[{"0.7598451601445368`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.32212044179848903`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9466986959827983`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.5099326043901118`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.8602143564134919`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.6501040936687834`"}], "+", 
        RowBox[{"0.7598451601445996`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.8512844415843573`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5247044877990129`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.8326664226872192`"}], "+", 
        RowBox[{"0.5537748897605315`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.999404140551045`"}], "-", 
        RowBox[{"0.03451613896969544`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9994041405510967`"}], "+", 
        RowBox[{"0.03451613896969723`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.851284441584344`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5247044877990047`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.8326664226872029`"}], "-", 
        RowBox[{"0.5537748897605206`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.6234898018587198`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7818314824680219`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.22252093395631223`"}], "-", 
        RowBox[{"0.9749279121818257`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024159`"}], "+", 
        RowBox[{"0.4338837391175546`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395631153`"}], "+", 
        RowBox[{"0.9749279121818226`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024238`"}], "-", 
        RowBox[{"0.43388373911755845`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6234898018587381`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824680449`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.08620037988060311`"}], "+", 
        RowBox[{"0.9962778199419808`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.18873759545292434`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9820275556534158`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9946415246952198`"}], "-", 
        RowBox[{"0.10338393178839456`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.18873759545292917`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9820275556534409`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9946415246951611`"}], "+", 
        RowBox[{"0.10338393178838845`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.08620037988061119`"}], "-", 
        RowBox[{"0.9962778199420742`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.05176135288421968`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9986594826804254`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.675943644144758`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7369533159843419`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.7709531747949985`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.6368918293348896`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.6759436441447496`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7369533159843327`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.7709531747949756`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.6368918293348708`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.05176135288422281`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9986594826804858`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.526206896998942*^9, {3.526209422918448*^9, 3.526209447072093*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1.`", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1.`", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1.`"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.18873759545291552`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9820275556534331`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.9904804439875712`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.13765351458716207`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.3221204417984907`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9466986959828048`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.18873759545291455`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9820275556534281`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.9904804439875572`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.13765351458716013`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.3221204417984914`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9466986959828069`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.8854560256531852`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.46472317204377056`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.35460488704253756`"}], "+", 
        RowBox[{"0.9350162426854239`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.12053668025534675`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9927088740980685`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.354604887042531`"}], "-", 
        RowBox[{"0.9350162426854067`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.12053668025534259`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9927088740980342`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.8854560256532223`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.46472317204379004`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.999404140551053`"}], "+", 
        RowBox[{"0.034516138969717336`", " ", "\[ImaginaryI]"}]}], ",", "0"}],
       "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9521176659107199`"}], "+", 
        RowBox[{"0.30573182735975596`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.9409976553623857`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.33841307983369473`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.9409976553623539`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3384130798336833`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9994041405510873`"}], "-", 
        RowBox[{"0.03451613896971852`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9521176659107077`"}], "-", 
        RowBox[{"0.305731827359752`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.5961324854692256`"}], "-", 
        RowBox[{"0.8028860814388923`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5099326043901428`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.8602143564135003`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9946415246951891`"}], "-", 
        RowBox[{"0.1033839317883683`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.5099326043901395`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.8602143564134949`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9946415246951966`"}], "+", 
        RowBox[{"0.10338393178836909`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.596132485469216`"}], "+", 
        RowBox[{"0.8028860814388794`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.5680647467311544`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.8229838658936305`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.7485107481711073`"}], "+", 
        RowBox[{"0.6631226582408032`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9709418174260749`"}], "+", 
        RowBox[{"0.23931566428753967`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.7485107481710924`"}], "-", 
        RowBox[{"0.66312265824079`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9709418174260402`"}], "-", 
        RowBox[{"0.23931566428753112`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5680647467311796`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.8229838658936669`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.35460488704256915`"}], "+", 
        RowBox[{"0.9350162426854257`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.12053668025530412`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9927088740980311`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.885456025653218`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.4647231720437759`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.8854560256531993`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.464723172043766`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3546048870425535`"}], "-", 
        RowBox[{"0.9350162426853844`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.12053668025531014`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9927088740980807`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.900968867902408`"}], "-", 
        RowBox[{"0.4338837391175407`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6234898018587393`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824680354`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.222520933956335`"}], "+", 
        RowBox[{"0.9749279121818344`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.6234898018587294`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.781831482468023`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395632827`"}], "-", 
        RowBox[{"0.974927912181805`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9009688679024397`"}], "+", 
        RowBox[{"0.4338837391175559`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9946415246951938`"}], "+", 
        RowBox[{"0.10338393178836658`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.5961324854692178`"}], "+", 
        RowBox[{"0.8028860814388818`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.5099326043901355`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.8602143564135114`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.5961324854692238`"}], "-", 
        RowBox[{"0.8028860814388898`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.5099326043901263`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.8602143564134959`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9946415246951923`"}], "-", 
        RowBox[{"0.10338393178836643`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.7009776598061465`"}], "-", 
        RowBox[{"0.7131832306305762`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.6501040936687492`"}], "-", 
        RowBox[{"0.7598451601445896`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.08620037988060436`"}], "-", 
        RowBox[{"0.9962778199420392`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.6501040936687343`"}], "+", 
        RowBox[{"0.7598451601445723`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.08620037988060239`"}], "+", 
        RowBox[{"0.9962778199420165`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.7009776598061694`"}], "+", 
        RowBox[{"0.7131832306305995`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.9904804439875643`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.13765351458717456`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.3221204417984939`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.946698695982798`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.18873759545292584`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9820275556534382`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.18873759545292226`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9820275556534196`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.9904804439875604`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.137653514587174`", " ", "\[ImaginaryI]"}]}], ",", "0", ",",
        "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.3221204417984981`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9466986959828102`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.051761352884208384`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9986594826804691`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.4493704009671972`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.8933455337855701`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.8688879687249742`"}], "+", 
        RowBox[{"0.4950087855835824`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.05176135288420705`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9986594826804435`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.44937040096717706`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.89334553378553`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.8688879687250222`"}], "-", 
        RowBox[{"0.4950087855836097`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.915408008525341`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.4025272387399719`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.8326664226872134`"}], "+", 
        RowBox[{"0.5537748897605392`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.5393200344991911`"}], "-", 
        RowBox[{"0.8421008849228397`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.832666422687198`"}], "-", 
        RowBox[{"0.553774889760529`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.5393200344991703`"}], "+", 
        RowBox[{"0.8421008849228073`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.9154080085253803`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.4025272387399892`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.7924768419511299`"}], "+", 
        RowBox[{"0.6099020044000629`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9287562401252807`"}], "-", 
        RowBox[{"0.3706910390450401`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.962103019843613`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.27268622848949386`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.9621030198435898`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2726862284894873`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.7924768419510899`"}], "-", 
        RowBox[{"0.6099020044000322`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9287562401253369`"}], "+", 
        RowBox[{"0.3706910390450625`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.28925211953656366`"}], "-", 
        RowBox[{"0.9572529505536271`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.4799374779597902`"}], "+", 
        RowBox[{"0.8773026941994397`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.9786235252959486`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.20565990308594137`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.9786235252959594`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.20565990308594362`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.28925211953655805`"}], "+", 
        RowBox[{"0.9572529505536085`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.4799374779597903`"}], "-", 
        RowBox[{"0.87730269419944`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.01726064090538898`"}], "+", 
        RowBox[{"0.9998510240408442`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.15472933479027567`"}], "+", 
        RowBox[{"0.987956898328745`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.985138989016887`"}], "+", 
        RowBox[{"0.1717590530912675`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9851389890168643`"}], "-", 
        RowBox[{"0.17175905309126352`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.017260640905389157`"}], "-", 
        RowBox[{"0.9998510240408546`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.1547293347902764`"}], "-", 
        RowBox[{"0.9879568983287496`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9709418174260147`"}], "+", 
        RowBox[{"0.23931566428756895`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.568064746731165`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.8229838658936671`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.7485107481711457`"}], "+", 
        RowBox[{"0.6631226582407874`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.568064746731149`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.8229838658936439`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.7485107481711034`"}], "-", 
        RowBox[{"0.66312265824075`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9709418174260799`"}], "-", 
        RowBox[{"0.23931566428758502`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9994041405510707`"}], "+", 
        RowBox[{"0.034516138969710786`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9521176659107236`"}], "+", 
        RowBox[{"0.3057318273597479`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.9409976553623722`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.33841307983366736`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9521176659107093`"}], "-", 
        RowBox[{"0.30573182735974336`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.9409976553623817`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.33841307983367075`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.99940414055107`"}], "-", 
        RowBox[{"0.03451613896971076`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.9976172723012634`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.06899114440434773`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.8130560994785236`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5821853477207474`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.7709531747949889`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.6368918293348946`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.8130560994785574`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5821853477207716`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.7709531747949725`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.6368918293348811`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.9976172723012288`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.06899114440434534`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.700977659806149`"}], "+", 
        RowBox[{"0.713183230630595`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.650104093668742`"}], "+", 
        RowBox[{"0.7598451601445791`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.08620037988062351`"}], "+", 
        RowBox[{"0.9962778199420304`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.6501040936687436`"}], "-", 
        RowBox[{"0.7598451601445809`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.08620037988062278`"}], "-", 
        RowBox[{"0.9962778199420219`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.7009776598061507`"}], "-", 
        RowBox[{"0.7131832306305967`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.962103019843572`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2726862284894601`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.7924768419511017`"}], "+", 
        RowBox[{"0.6099020044000851`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9287562401253185`"}], "-", 
        RowBox[{"0.3706910390451146`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.7924768419510756`"}], "-", 
        RowBox[{"0.609902004400065`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9287562401252581`"}], "+", 
        RowBox[{"0.3706910390450905`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.9621030198436424`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.27268622848948004`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.12053668025531972`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9927088740980561`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.8854560256532114`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.4647231720437748`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.354604887042534`"}], "-", 
        RowBox[{"0.9350162426854163`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.12053668025531931`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9927088740980528`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.8854560256532039`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.4647231720437709`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.35460488704253346`"}], "+", 
        RowBox[{"0.9350162426854148`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.8688879687250102`"}], "-", 
        RowBox[{"0.4950087855835704`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.051761352884183875`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9986594826804862`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.4493704009671554`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.893345533785548`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.8688879687250142`"}], "+", 
        RowBox[{"0.4950087855835727`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.051761352884180906`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9986594826804289`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.4493704009671699`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.8933455337855768`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.5393200344992048`"}], "+", 
        RowBox[{"0.8421008849228127`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.9154080085253641`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.40252723873996543`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.8326664226872076`"}], "-", 
        RowBox[{"0.553774889760533`", " ", "\[ImaginaryI]"}]}], ",", "0", ",",
        "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.8326664226872059`"}], "+", 
        RowBox[{"0.5537748897605319`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.5393200344992007`"}], "-", 
        RowBox[{"0.8421008849228062`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.9154080085253694`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.40252723873996776`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.47993747795977615`"}], "-", 
        RowBox[{"0.8773026941994726`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.9786235252959373`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2056599030859197`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2892521195365674`"}], "+", 
        RowBox[{"0.9572529505536229`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.2892521195365635`"}], "-", 
        RowBox[{"0.95725295055361`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.47993747795975505`"}], "+", 
        RowBox[{"0.8773026941994341`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.9786235252959785`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.20565990308592833`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.4182678007755613`"}], "-", 
        RowBox[{"0.9083237566167646`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.6759436441447517`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7369533159843322`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.38666674294142134`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9222195128618088`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.38666674294142167`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9222195128618096`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4182678007755546`"}], "+", 
        RowBox[{"0.90832375661675`", " ", "\[ImaginaryI]"}]}], ",", "0", ",", 
       "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.6759436441447586`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7369533159843398`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.15472933479028506`"}], "-", 
        RowBox[{"0.9879568983287431`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9851389890168812`"}], "-", 
        RowBox[{"0.17175905309128447`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.017260640905386898`"}], "-", 
        RowBox[{"0.9998510240408472`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.1547293347902859`"}], "+", 
        RowBox[{"0.9879568983287484`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9851389890168639`"}], "+", 
        RowBox[{"0.17175905309128145`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.017260640905386974`"}], "+", 
        RowBox[{"0.9998510240408516`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9851389890168911`"}], "-", 
        RowBox[{"0.17175905309129413`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.01726064090537993`"}], "-", 
        RowBox[{"0.9998510240408487`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.15472933479029033`"}], "-", 
        RowBox[{"0.9879568983287343`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.1547293347902936`"}], "+", 
        RowBox[{"0.9879568983287552`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9851389890168514`"}], "+", 
        RowBox[{"0.1717590530912872`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.017260640905379963`"}], "+", 
        RowBox[{"0.9998510240408505`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.8130560994785594`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5821853477207644`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.7709531747949723`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.6368918293348687`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.9976172723012543`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.06899114440432796`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.8130560994785299`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5821853477207432`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.7709531747950011`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.6368918293348925`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.9976172723012405`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.068991144404327`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.12053668025532191`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9927088740980579`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.8854560256532301`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.46472317204376123`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.35460488704252424`"}], "+", 
        RowBox[{"0.935016242685405`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.8854560256532045`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.46472317204374775`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.3546048870425336`"}], "-", 
        RowBox[{"0.9350162426854297`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.12053668025532102`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9927088740980505`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.017260640905393282`"}], "-", 
        RowBox[{"0.9998510240408486`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.15472933479026785`"}], "-", 
        RowBox[{"0.987956898328766`", " ", "\[ImaginaryI]"}]}], ",", "0", ",",
        "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9851389890168651`"}], "-", 
        RowBox[{"0.1717590530912712`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.15472933479026252`"}], "+", 
        RowBox[{"0.9879568983287319`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9851389890168836`"}], "+", 
        RowBox[{"0.17175905309127443`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.017260640905393306`"}], "+", 
        RowBox[{"0.9998510240408501`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.05176135288420319`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9986594826804569`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.44937040096716413`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.8933455337855519`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.8688879687250145`"}], "-", 
        RowBox[{"0.4950087855835973`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.44937040096717196`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.8933455337855675`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.8688879687249889`"}], "+", 
        RowBox[{"0.49500878558358263`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.05176135288420315`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9986594826804561`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.7924768419510967`"}], "+", 
        RowBox[{"0.6099020044000788`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9287562401253113`"}], "-", 
        RowBox[{"0.3706910390450958`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.9621030198435834`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.27268622848947544`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.792476841951083`"}], "-", 
        RowBox[{"0.6099020044000683`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9287562401252764`"}], "+", 
        RowBox[{"0.3706910390450818`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.9621030198436248`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.27268622848948715`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9287562401253155`"}], "+", 
        RowBox[{"0.3706910390450596`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.9621030198435865`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2726862284894982`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.7924768419510955`"}], "-", 
        RowBox[{"0.6099020044000776`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.9621030198436101`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2726862284895049`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.7924768419510846`"}], "+", 
        RowBox[{"0.6099020044000691`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9287562401252981`"}], "-", 
        RowBox[{"0.3706910390450527`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.2892521195365729`"}], "+", 
        RowBox[{"0.9572529505536146`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.47993747795978964`"}], "-", 
        RowBox[{"0.8773026941994331`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.9786235252959657`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.20565990308594723`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.9786235252959413`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2056599030859421`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2892521195365727`"}], "-", 
        RowBox[{"0.9572529505536138`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.47993747795979563`"}], "+", 
        RowBox[{"0.877302694199444`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0.9999999999999943`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.0000000000000173`", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0.9999999999999958`", ",", "0"}], "}"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0.9999999999999827`", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1.0000000000000042`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.0000000000000058`", ",", "0", ",", "0"}], "}"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.5680647467311518`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.8229838658936882`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.7485107481710942`"}], "+", 
        RowBox[{"0.6631226582407868`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9709418174260449`"}], "+", 
        RowBox[{"0.23931566428756693`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9709418174260541`"}], "-", 
        RowBox[{"0.23931566428756917`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5680647467311246`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.8229838658936488`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.7485107481711103`"}], "-", 
        RowBox[{"0.6631226582408011`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.15472933479026907`"}], "-", 
        RowBox[{"0.9879568983287601`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.985138989016862`"}], "-", 
        RowBox[{"0.17175905309126405`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.017260640905388147`"}], "-", 
        RowBox[{"0.9998510240408567`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9851389890168889`"}], "+", 
        RowBox[{"0.17175905309126874`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.017260640905387897`"}], "+", 
        RowBox[{"0.9998510240408421`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.1547293347902655`"}], "+", 
        RowBox[{"0.9879568983287372`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.8512844415843498`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5247044877990029`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.2560390900575544`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9666664286932117`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.7251763071433982`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.6885632313432781`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.25603909005755726`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9666664286932227`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.7251763071433743`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.6885632313432555`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.8512844415843563`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.524704487799007`", " ", "\[ImaginaryI]"}]}], ",", "0", ",",
        "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.7924768419510863`"}], "-", 
        RowBox[{"0.6099020044000562`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9287562401253148`"}], "+", 
        RowBox[{"0.3706910390450666`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.9621030198436131`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2726862284894831`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9287562401252939`"}], "-", 
        RowBox[{"0.3706910390450583`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.9621030198435954`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2726862284894781`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.7924768419511076`"}], "+", 
        RowBox[{"0.6099020044000726`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.35460488704253434`"}], "-", 
        RowBox[{"0.9350162426854083`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.12053668025532699`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9927088740980533`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.8854560256532154`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.4647231720437846`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.12053668025532704`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9927088740980538`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.8854560256531936`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.46472317204377317`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.354604887042539`"}], "+", 
        RowBox[{"0.9350162426854206`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9521176659107136`"}], "+", 
        RowBox[{"0.30573182735975357`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.9409976553623774`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.33841307983367275`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9994041405510695`"}], "+", 
        RowBox[{"0.03451613896970812`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9521176659107142`"}], "-", 
        RowBox[{"0.3057318273597538`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.9409976553623742`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3384130798336716`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9994041405510714`"}], "-", 
        RowBox[{"0.034516138969708184`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.051761352884191036`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9986594826804759`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.44937040096715913`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.8933455337855498`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.8688879687250097`"}], "-", 
        RowBox[{"0.49500878558357664`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.868887968725009`"}], "+", 
        RowBox[{"0.49500878558357625`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.0517613528841891`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9986594826804385`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.4493704009671707`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.8933455337855728`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.8512844415843609`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5247044877990436`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.2560390900575417`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.966666428693208`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.7251763071433808`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.6885632313432675`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.7251763071433859`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.6885632313432722`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.851284441584315`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5247044877990154`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.25603909005754816`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9666664286932323`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395631722`"}], "+", 
        RowBox[{"0.974927912181833`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024243`"}], "-", 
        RowBox[{"0.43388373911758027`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6234898018587324`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824680084`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.6234898018587541`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7818314824680357`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2225209339563129`"}], "-", 
        RowBox[{"0.974927912181814`", " ", "\[ImaginaryI]"}]}], ",", "0", ",",
        "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679023986`"}], "+", 
        RowBox[{"0.43388373911756795`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.9976172723012394`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.06899114440433038`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.813056099478541`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5821853477207721`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.7709531747949778`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.6368918293348975`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.8130560994785284`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5821853477207631`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.7709531747949717`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.6368918293348925`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.997617272301255`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.06899114440433145`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.9621030198436062`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.27268622848949464`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.7924768419511125`"}], "+", 
        RowBox[{"0.6099020044000687`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9287562401252913`"}], "-", 
        RowBox[{"0.37069103904505285`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.9621030198435953`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.27268622848949153`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.7924768419510888`"}], "-", 
        RowBox[{"0.6099020044000505`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9287562401253204`"}], "+", 
        RowBox[{"0.37069103904506445`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.25603909005753306`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9666664286932125`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.7251763071433794`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.6885632313432992`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.8512844415843472`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5247044877990164`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.7251763071433542`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.6885632313432752`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.8512844415843456`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5247044877990154`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.2560390900575384`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9666664286932326`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2892521195365866`"}], "+", 
        RowBox[{"0.9572529505536297`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.4799374779597787`"}], "-", 
        RowBox[{"0.8773026941994433`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.9786235252959484`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2056599030859239`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2892521195365757`"}], "-", 
        RowBox[{"0.9572529505535937`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.4799374779597811`"}], "+", 
        RowBox[{"0.8773026941994477`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.9786235252959666`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.20565990308592774`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.868887968725003`"}], "-", 
        RowBox[{"0.49500878558358175`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.051761352884216155`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9986594826804516`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.4493704009671564`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.8933455337855818`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.05176135288421659`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.99865948268046`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.44937040096714337`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.8933455337855559`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.8688879687250081`"}], "+", 
        RowBox[{"0.49500878558358463`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.5393200344992123`"}], "+", 
        RowBox[{"0.8421008849228122`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.9154080085253593`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.4025272387399569`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.8326664226872114`"}], "-", 
        RowBox[{"0.5537748897605372`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.915408008525379`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.40252723873996554`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.8326664226872006`"}], "+", 
        RowBox[{"0.5537748897605301`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.5393200344992042`"}], "-", 
        RowBox[{"0.8421008849227997`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.8130560994785279`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5821853477207688`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.7709531747949722`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.6368918293348919`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.9976172723012622`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.06899114440433812`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.7709531747949784`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.636891829334897`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.9976172723012313`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.06899114440433599`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.8130560994785357`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5821853477207745`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.386666742941414`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9222195128618103`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.4182678007755819`"}], "+", 
        RowBox[{"0.9083237566167625`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6759436441447515`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.736953315984333`", " ", "\[ImaginaryI]"}]}], ",", "0", ",",
        "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.6759436441447578`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7369533159843399`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.3866667429414155`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9222195128618138`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.41826780077556963`"}], "-", 
        RowBox[{"0.9083237566167358`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.32212044179849003`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9466986959828112`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.18873759545290236`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9820275556534501`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.990480443987547`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.13765351458717506`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.18873759545289603`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9820275556534173`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.9904804439875768`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.13765351458717923`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.3221204417984869`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9466986959828021`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.5961324854692339`"}], "+", 
        RowBox[{"0.8028860814388865`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.5099326043901315`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.8602143564135069`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9946415246951845`"}], "+", 
        RowBox[{"0.10338393178837524`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9946415246951996`"}], "-", 
        RowBox[{"0.1033839317883768`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.5961324854692239`"}], "-", 
        RowBox[{"0.8028860814388731`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.5099326043901283`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.8602143564135015`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.9904804439875706`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.13765351458716835`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.32212044179847943`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9466986959828242`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.18873759545290403`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9820275556534166`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.990480443987556`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.13765351458716632`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.3221204417984706`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9466986959827983`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.18873759545291002`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9820275556534478`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9287562401253024`"}], "+", 
        RowBox[{"0.3706910390450626`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.962103019843592`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2726862284894996`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.7924768419510958`"}], "-", 
        RowBox[{"0.6099020044000916`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.7924768419510709`"}], "+", 
        RowBox[{"0.6099020044000725`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9287562401253056`"}], "-", 
        RowBox[{"0.3706910390450639`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.9621030198436047`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2726862284895032`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.7709531747949867`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.6368918293349095`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.9976172723012499`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.06899114440431461`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.813056099478516`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5821853477207728`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.7709531747949583`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.6368918293348861`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.9976172723012467`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.0689911444043144`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.8130560994785359`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.582185347720787`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.22252093395631964`"}], "+", 
        RowBox[{"0.9749279121818328`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024226`"}], "-", 
        RowBox[{"0.4338837391175768`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.6234898018587333`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.781831482468011`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.22252093395631511`"}], "-", 
        RowBox[{"0.9749279121818131`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024024`"}], "+", 
        RowBox[{"0.43388373911756706`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.6234898018587518`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7818314824680342`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.41826780077557585`"}], "-", 
        RowBox[{"0.9083237566167697`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.6759436441447453`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7369533159843923`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.38666674294142644`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9222195128617601`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4182678007755602`"}], "+", 
        RowBox[{"0.9083237566167357`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.6759436441446982`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.736953315984341`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.38666674294146003`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9222195128618401`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.885456025653224`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.46472317204377345`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.35460488704251264`"}], "-", 
        RowBox[{"0.9350162426854515`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.12053668025533923`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9927088740980184`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.8854560256531978`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.46472317204375974`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.3546048870424941`"}], "+", 
        RowBox[{"0.9350162426854026`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.12053668025534726`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9927088740980846`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9521176659107207`"}], "+", 
        RowBox[{"0.30573182735974963`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.9409976553623753`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.33841307983367136`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9994041405510704`"}], "+", 
        RowBox[{"0.034516138969709315`", " ", "\[ImaginaryI]"}]}], ",", "0"}],
       "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.9409976553623767`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.33841307983367186`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9994041405510704`"}], "-", 
        RowBox[{"0.034516138969709315`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9521176659107107`"}], "-", 
        RowBox[{"0.3057318273597464`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.8854560256532442`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.46472317204375324`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.35460488704250914`"}], "+", 
        RowBox[{"0.9350162426853945`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.12053668025532244`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9927088740980669`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.12053668025531938`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9927088740980416`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.885456025653203`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.4647231720437316`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.3546048870425293`"}], "-", 
        RowBox[{"0.9350162426854476`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.41826780077555253`"}], "+", 
        RowBox[{"0.9083237566167452`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6759436441447582`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7369533159843417`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.38666674294143627`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9222195128618154`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.6759436441447498`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7369533159843326`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.38666674294142744`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9222195128617944`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4182678007755636`"}], "-", 
        RowBox[{"0.9083237566167692`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.4493704009671668`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.893345533785554`", " ", "\[ImaginaryI]"}]}], ",", "0", ",",
        "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.8688879687250156`"}], "-", 
        RowBox[{"0.4950087855836034`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.05176135288420669`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.998659482680452`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.44937040096717185`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.8933455337855641`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.868887968724983`"}], "+", 
        RowBox[{"0.4950087855835848`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.051761352884207135`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9986594826804606`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.8512844415843293`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5247044877990107`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.25603909005754444`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9666664286932369`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.7251763071433954`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.6885632313432716`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.8512844415843587`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5247044877990288`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.25603909005753617`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9666664286932057`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.725176307143381`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.6885632313432579`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.770953174794985`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.6368918293348871`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.9976172723012441`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.06899114440432205`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.8130560994785345`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5821853477207746`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.8130560994785282`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.58218534772077`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.7709531747949806`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.6368918293348834`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.9976172723012514`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.06899114440432257`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.32212044179849264`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9466986959828183`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.18873759545289337`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9820275556534597`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.9904804439875331`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.1376535145871826`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.3221204417984847`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9466986959827949`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.18873759545288415`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9820275556534117`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.9904804439875882`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.13765351458719027`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.9976172723012517`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.06899114440433629`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.8130560994785285`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5821853477207559`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.7709531747949928`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.6368918293348922`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.7709531747949742`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.6368918293348768`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.9976172723012419`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.06899114440433561`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.8130560994785477`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5821853477207697`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.9154080085253878`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.4025272387399587`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.8326664226871913`"}], "+", 
        RowBox[{"0.5537748897605315`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.5393200344992042`"}], "-", 
        RowBox[{"0.8421008849228125`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.9154080085253583`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.4025272387399457`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.8326664226872137`"}], "-", 
        RowBox[{"0.5537748897605463`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.5393200344992005`"}], "+", 
        RowBox[{"0.8421008849228069`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.9786235252959518`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.20565990308593346`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.2892521195365725`"}], "+", 
        RowBox[{"0.9572529505536203`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.4799374779597825`"}], "-", 
        RowBox[{"0.8773026941994504`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.9786235252959598`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.20565990308593513`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.2892521195365692`"}], "-", 
        RowBox[{"0.9572529505536094`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.47993747795977715`"}], "+", 
        RowBox[{"0.8773026941994407`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6234898018587329`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824680376`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395631367`"}], "+", 
        RowBox[{"0.9749279121818215`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.900968867902419`"}], "-", 
        RowBox[{"0.4338837391175561`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6234898018587258`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7818314824680287`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395631464`"}], "-", 
        RowBox[{"0.9749279121818258`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024207`"}], "+", 
        RowBox[{"0.43388373911755695`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.8688879687250055`"}], "+", 
        RowBox[{"0.49500878558357714`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.051761352884201806`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.998659482680451`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.4493704009671792`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.893345533785572`", " ", "\[ImaginaryI]"}]}], ",", "0", ",",
        "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.4493704009671648`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.8933455337855435`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.8688879687250107`"}], "-", 
        RowBox[{"0.49500878558358014`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.05176135288420238`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9986594826804621`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.9154080085253721`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.40252723873996954`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.8326664226872087`"}], "-", 
        RowBox[{"0.5537748897605506`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.5393200344991846`"}], "+", 
        RowBox[{"0.8421008849228053`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.539320034499199`"}], "-", 
        RowBox[{"0.8421008849228276`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.915408008525361`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.40252723873996465`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.8326664226871894`"}], "+", 
        RowBox[{"0.5537748897605377`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.5099326043901292`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.8602143564135185`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.99464152469518`"}], "+", 
        RowBox[{"0.1033839317883753`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.5961324854692258`"}], "+", 
        RowBox[{"0.8028860814388873`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9946415246952041`"}], "-", 
        RowBox[{"0.1033839317883778`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.5961324854692209`"}], "-", 
        RowBox[{"0.8028860814388806`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.509932604390117`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.860214356413498`", " ", "\[ImaginaryI]"}]}], ",", "0", ",",
        "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395632117`"}], "-", 
        RowBox[{"0.9749279121818135`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9009688679024377`"}], "+", 
        RowBox[{"0.43388373911755396`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.6234898018587398`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7818314824680259`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024108`"}], "-", 
        RowBox[{"0.433883739117541`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.6234898018587387`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824680246`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.22252093395632488`"}], "+", 
        RowBox[{"0.9749279121818297`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.38666674294142234`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9222195128618162`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.41826780077555437`"}], "-", 
        RowBox[{"0.9083237566167772`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.6759436441447502`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7369533159843158`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.38666674294141706`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9222195128618037`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.4182678007755405`"}], "+", 
        RowBox[{"0.9083237566167471`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.6759436441447749`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7369533159843428`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.9786235252959575`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2056599030859408`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.28925211953656554`"}], "+", 
        RowBox[{"0.9572529505536135`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.47993747795978736`"}], "-", 
        RowBox[{"0.8773026941994423`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.47993747795978664`"}], "+", 
        RowBox[{"0.877302694199441`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.9786235252959514`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.2056599030859395`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.28925211953656715`"}], "-", 
        RowBox[{"0.9572529505536188`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9287562401252989`"}], "-", 
        RowBox[{"0.37069103904506406`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.9621030198436051`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.27268622848949786`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.7924768419511016`"}], "+", 
        RowBox[{"0.6099020044000687`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.9621030198435945`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.27268622848949486`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.7924768419510916`"}], "-", 
        RowBox[{"0.609902004400061`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9287562401253072`"}], "+", 
        RowBox[{"0.3706910390450674`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.9976172723012595`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.06899114440430808`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.8130560994785111`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5821853477207716`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.7709531747949864`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.6368918293349048`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.770953174794963`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.6368918293348855`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.9976172723012381`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.06899114440430659`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.8130560994785385`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5821853477207912`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.9976172723012335`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.06899114440431292`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.8130560994785403`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5821853477207886`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.770953174794993`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.6368918293348834`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.9976172723012632`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.06899114440431497`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.8130560994785131`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.582185347720769`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.7709531747949827`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.6368918293348749`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.051761352884192036`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9986594826804351`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.4493704009671721`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.8933455337855751`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.8688879687250306`"}], "+", 
        RowBox[{"0.49500878558357053`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.4493704009671581`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.8933455337855473`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.8688879687250036`"}], "-", 
        RowBox[{"0.49500878558355516`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.051761352884194305`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9986594826804789`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.7485107481710978`"}], "-", 
        RowBox[{"0.6631226582407765`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.970941817426063`"}], "-", 
        RowBox[{"0.23931566428756806`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.5680647467311729`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.8229838658936551`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.7485107481711201`"}], "+", 
        RowBox[{"0.6631226582407963`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9709418174260375`"}], "+", 
        RowBox[{"0.2393156642875618`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.568064746731163`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.8229838658936408`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.6501040936687484`"}], "-", 
        RowBox[{"0.7598451601445684`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.0862003798806038`"}], "-", 
        RowBox[{"0.9962778199420474`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.7009776598061441`"}], "-", 
        RowBox[{"0.7131832306305936`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.08620037988060043`"}], "+", 
        RowBox[{"0.9962778199420085`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.7009776598061519`"}], "+", 
        RowBox[{"0.7131832306306016`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.6501040936687552`"}], "+", 
        RowBox[{"0.7598451601445763`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.3221204417984792`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9466986959828246`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.18873759545290436`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9820275556534168`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.9904804439875691`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.13765351458716849`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.9904804439875574`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.13765351458716688`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.32212044179847016`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9466986959827981`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.18873759545291025`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9820275556534475`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.47993747795977915`"}], "+", 
        RowBox[{"0.8773026941994357`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.9786235252959563`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.20565990308593995`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.2892521195365577`"}], "-", 
        RowBox[{"0.9572529505536325`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.28925211953655017`"}], "+", 
        RowBox[{"0.9572529505536074`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4799374779597877`"}], "-", 
        RowBox[{"0.8773026941994514`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.978623525295953`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.20565990308593923`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9946415246951983`"}], "+", 
        RowBox[{"0.10338393178836906`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.596132485469236`"}], "+", 
        RowBox[{"0.8028860814388824`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5099326043901351`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.8602143564134954`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.5099326043901401`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.8602143564135039`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9946415246951874`"}], "-", 
        RowBox[{"0.10338393178836794`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.5961324854692285`"}], "-", 
        RowBox[{"0.8028860814388723`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9851389890168832`"}], "-", 
        RowBox[{"0.17175905309127687`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.01726064090536443`"}], "-", 
        RowBox[{"0.9998510240408708`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.15472933479029144`"}], "-", 
        RowBox[{"0.9879568983287217`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9851389890168647`"}], "+", 
        RowBox[{"0.17175905309127362`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.01726064090536371`"}], "+", 
        RowBox[{"0.9998510240408289`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.15472933479029852`"}], "+", 
        RowBox[{"0.9879568983287669`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.9409976553623745`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3384130798336716`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9994041405510696`"}], "+", 
        RowBox[{"0.03451613896970818`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.952117665910724`"}], "+", 
        RowBox[{"0.30573182735974824`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9994041405510713`"}], "-", 
        RowBox[{"0.03451613896970823`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9521176659107088`"}], "-", 
        RowBox[{"0.30573182735974336`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.9409976553623772`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3384130798336726`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3546048870425375`"}], "+", 
        RowBox[{"0.9350162426854238`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.12053668025534653`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9927088740980683`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.8854560256531852`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.4647231720437704`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.35460488704253107`"}], "-", 
        RowBox[{"0.9350162426854068`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.12053668025534242`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9927088740980345`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.8854560256532225`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.46472317204378993`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.418267800775568`"}], "-", 
        RowBox[{"0.908323756616728`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6759436441447626`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.736953315984343`", " ", "\[ImaginaryI]"}]}], ",", "0", ",",
        "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.38666674294140413`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9222195128618368`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.6759436441447488`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.736953315984328`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.38666674294138964`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9222195128618023`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.41826780077558673`"}], "+", 
        RowBox[{"0.9083237566167687`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9009688679024108`"}], "+", 
        RowBox[{"0.4338837391175633`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.6234898018587602`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.781831482468035`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.2225209339563108`"}], "-", 
        RowBox[{"0.9749279121818175`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9009688679024203`"}], "-", 
        RowBox[{"0.43388373911756783`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.6234898018587344`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824680026`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.2225209339563138`"}], "+", 
        RowBox[{"0.9749279121818306`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.725176307143383`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.6885632313432801`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.8512844415843547`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5247044877990336`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.25603909005753267`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9666664286932043`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.8512844415843268`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5247044877990164`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.2560390900575421`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9666664286932399`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.7251763071433731`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.6885632313432707`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.7485107481711198`"}], "+", 
        RowBox[{"0.6631226582407956`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9709418174260479`"}], "+", 
        RowBox[{"0.23931566428755507`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5680647467311588`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.8229838658936506`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.5680647467311623`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.8229838658936557`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.7485107481710984`"}], "-", 
        RowBox[{"0.6631226582407767`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9709418174260569`"}], "-", 
        RowBox[{"0.2393156642875573`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.5961324854692072`"}], "+", 
        RowBox[{"0.8028860814388755`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5099326043901399`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.8602143564135061`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9946415246952092`"}], "+", 
        RowBox[{"0.10338393178835448`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.5099326043901331`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.8602143564134945`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9946415246951799`"}], "-", 
        RowBox[{"0.10338393178835142`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.5961324854692267`"}], "-", 
        RowBox[{"0.8028860814389019`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9709418174260578`"}], "-", 
        RowBox[{"0.2393156642875692`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.5680647467311455`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.8229838658936521`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.7485107481711044`"}], "-", 
        RowBox[{"0.6631226582407975`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.7485107481710984`"}], "+", 
        RowBox[{"0.6631226582407922`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9709418174260416`"}], "+", 
        RowBox[{"0.2393156642875652`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.5680647467311561`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.8229838658936676`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.9154080085253673`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.40252723873996643`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.8326664226872078`"}], "-", 
        RowBox[{"0.5537748897605417`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.5393200344991954`"}], "+", 
        RowBox[{"0.8421008849228089`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.8326664226871979`"}], "+", 
        RowBox[{"0.5537748897605351`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.5393200344992002`"}], "-", 
        RowBox[{"0.8421008849228163`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.9154080085253665`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.4025272387399661`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9851389890168781`"}], "+", 
        RowBox[{"0.17175905309126532`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.01726064090537427`"}], "+", 
        RowBox[{"0.9998510240408365`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.1547293347902975`"}], "+", 
        RowBox[{"0.987956898328764`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.017260640905374724`"}], "-", 
        RowBox[{"0.9998510240408628`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.15472933479029136`"}], "-", 
        RowBox[{"0.9879568983287248`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9851389890168734`"}], "-", 
        RowBox[{"0.1717590530912645`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.7009776598061961`"}], "+", 
        RowBox[{"0.7131832306305933`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.6501040936687046`"}], "+", 
        RowBox[{"0.7598451601445668`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.08620037988061868`"}], "+", 
        RowBox[{"0.996277819942042`", " ", "\[ImaginaryI]"}]}], ",", "0", ",",
        "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.08620037988061602`"}], "-", 
        RowBox[{"0.9962778199420113`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.7009776598061532`"}], "-", 
        RowBox[{"0.7131832306305497`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.65010409366875`"}], "-", 
        RowBox[{"0.7598451601446199`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.479937477959808`"}], "+", 
        RowBox[{"0.8773026941994514`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.9786235252959514`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.20565990308593252`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.2892521195365733`"}], "-", 
        RowBox[{"0.9572529505536074`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4799374779597901`"}], "-", 
        RowBox[{"0.8773026941994186`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.9786235252959604`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2056599030859344`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.28925211953657703`"}], "+", 
        RowBox[{"0.9572529505536197`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.18873759545289237`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9820275556534588`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.9904804439875329`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.13765351458718242`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.32212044179849264`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9466986959828186`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.3221204417984845`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9466986959827947`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.18873759545288354`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9820275556534129`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.9904804439875885`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.13765351458719013`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.017260640905379265`"}], "+", 
        RowBox[{"0.9998510240408395`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.15472933479029155`"}], "+", 
        RowBox[{"0.9879568983287595`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9851389890168788`"}], "+", 
        RowBox[{"0.1717590530912672`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.15472933479028705`"}], "-", 
        RowBox[{"0.9879568983287308`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9851389890168721`"}], "-", 
        RowBox[{"0.17175905309126605`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.017260640905379612`"}], "-", 
        RowBox[{"0.9998510240408597`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9287562401253064`"}], "-", 
        RowBox[{"0.3706910390450685`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.9621030198436049`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2726862284895045`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.7924768419510801`"}], "+", 
        RowBox[{"0.6099020044000717`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9287562401252987`"}], "+", 
        RowBox[{"0.3706910390450654`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.9621030198435911`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.27268622848950064`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.7924768419510941`"}], "-", 
        RowBox[{"0.6099020044000825`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024254`"}], "+", 
        RowBox[{"0.43388373911755257`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6234898018587216`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7818314824680278`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.2225209339563106`"}], "-", 
        RowBox[{"0.9749279121818359`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.6234898018587328`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824680419`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395630562`"}], "+", 
        RowBox[{"0.9749279121818142`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9009688679024196`"}], "-", 
        RowBox[{"0.4338837391175498`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.256039090057547`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9666664286932233`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.7251763071433764`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.6885632313432922`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.8512844415843465`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5247044877989996`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.25603909005754516`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9666664286932163`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.7251763071433613`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.6885632313432779`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.8512844415843609`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5247044877990085`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.0862003798806229`"}], "-", 
        RowBox[{"0.996277819942029`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.7009776598061481`"}], "-", 
        RowBox[{"0.7131832306306167`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.6501040936687406`"}], "-", 
        RowBox[{"0.7598451601445656`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.6501040936687568`"}], "+", 
        RowBox[{"0.7598451601445845`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.08620037988062242`"}], "+", 
        RowBox[{"0.9962778199420234`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.7009776598061289`"}], "+", 
        RowBox[{"0.7131832306305972`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.44937040096713937`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.8933455337855494`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.8688879687250133`"}], "+", 
        RowBox[{"0.49500878558358663`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.05176135288423375`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9986594826804744`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.8688879687249986`"}], "-", 
        RowBox[{"0.49500878558357825`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.05176135288423173`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9986594826804355`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.44937040096715924`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.8933455337855889`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9709418174260582`"}], "-", 
        RowBox[{"0.2393156642875577`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.5680647467311765`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.8229838658936579`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.7485107481710958`"}], "-", 
        RowBox[{"0.6631226582407782`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9709418174260466`"}], "+", 
        RowBox[{"0.23931566428755482`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.5680647467311617`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.8229838658936366`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.7485107481711186`"}], "+", 
        RowBox[{"0.6631226582407984`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.7251763071433617`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.6885632313432771`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.8512844415843718`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5247044877990072`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.25603909005753894`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9666664286932223`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.7251763071433772`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.6885632313432919`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.8512844415843427`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5247044877989893`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.25603909005753867`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9666664286932212`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.7009776598061491`"}], "-", 
        RowBox[{"0.7131832306305887`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.6501040936687458`"}], "-", 
        RowBox[{"0.7598451601445859`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.0862003798806143`"}], "-", 
        RowBox[{"0.9962778199420288`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.7009776598061569`"}], "+", 
        RowBox[{"0.7131832306305966`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.6501040936687374`"}], "+", 
        RowBox[{"0.7598451601445761`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.08620037988061398`"}], "+", 
        RowBox[{"0.996277819942025`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.08620037988060186`"}], "+", 
        RowBox[{"0.9962778199420094`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.700977659806173`"}], "+", 
        RowBox[{"0.7131832306306031`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.650104093668762`"}], "+", 
        RowBox[{"0.7598451601445737`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.700977659806143`"}], "-", 
        RowBox[{"0.7131832306305725`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.650104093668752`"}], "-", 
        RowBox[{"0.759845160144562`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.08620037988060505`"}], "-", 
        RowBox[{"0.9962778199420463`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.08620037988060136`"}], "-", 
        RowBox[{"0.9962778199420468`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.7009776598061435`"}], "-", 
        RowBox[{"0.7131832306305883`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.6501040936687491`"}], "-", 
        RowBox[{"0.7598451601445733`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.08620037988059814`"}], "+", 
        RowBox[{"0.9962778199420096`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.7009776598061572`"}], "+", 
        RowBox[{"0.7131832306306024`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.6501040936687504`"}], "+", 
        RowBox[{"0.7598451601445748`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9709418174260751`"}], "+", 
        RowBox[{"0.23931566428754109`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.5680647467311558`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.8229838658936306`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.7485107481711112`"}], "+", 
        RowBox[{"0.6631226582408013`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.7485107481710939`"}], "-", 
        RowBox[{"0.663122658240786`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9709418174260394`"}], "-", 
        RowBox[{"0.23931566428753226`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.5680647467311799`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.8229838658936656`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.5393200344991964`"}], "-", 
        RowBox[{"0.8421008849228409`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.9154080085253639`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.4025272387399602`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.8326664226871938`"}], "+", 
        RowBox[{"0.5537748897605363`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.8326664226872083`"}], "-", 
        RowBox[{"0.5537748897605459`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.5393200344991715`"}], "+", 
        RowBox[{"0.8421008849228021`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.9154080085253734`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.40252723873996443`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.994641524695185`"}], "-", 
        RowBox[{"0.10338393178836158`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.596132485469226`"}], "-", 
        RowBox[{"0.8028860814388967`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.5099326043901447`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.8602143564134985`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9946415246952021`"}], "+", 
        RowBox[{"0.10338393178836336`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.5961324854692119`"}], "+", 
        RowBox[{"0.8028860814388777`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.509932604390142`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.860214356413494`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.5961324854692337`"}], "+", 
        RowBox[{"0.8028860814388882`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.5099326043901292`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.8602143564135132`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9946415246951801`"}], "+", 
        RowBox[{"0.10338393178837779`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.5961324854692223`"}], "-", 
        RowBox[{"0.8028860814388729`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.5099326043901217`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.8602143564135005`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9946415246952035`"}], "-", 
        RowBox[{"0.10338393178838022`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.7251763071433712`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.6885632313432962`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.8512844415843428`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5247044877989868`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.25603909005755754`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.966666428693233`", " ", "\[ImaginaryI]"}]}], ",", "0", ",",
        "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.2560390900575495`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9666664286932026`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.7251763071433577`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.6885632313432833`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.8512844415843739`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.524704487799006`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.9904804439875472`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.13765351458715513`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.3221204417984929`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9466986959828123`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.18873759545293906`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9820275556534429`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.32212044179848853`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9466986959827994`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.18873759545293278`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9820275556534103`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.9904804439875821`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.13765351458716`", " ", "\[ImaginaryI]"}]}], ",", "0", ",", 
       "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9994041405510833`"}], "-", 
        RowBox[{"0.03451613896971878`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9521176659107099`"}], "-", 
        RowBox[{"0.30573182735975335`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.9409976553623705`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3384130798336736`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.999404140551057`"}], "+", 
        RowBox[{"0.03451613896971787`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9521176659107173`"}], "+", 
        RowBox[{"0.30573182735975574`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.9409976553623791`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3384130798336767`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.12053668025531983`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9927088740980582`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.8854560256532086`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.46472317204376834`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3546048870425368`"}], "-", 
        RowBox[{"0.9350162426854136`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.3546048870425373`"}], "+", 
        RowBox[{"0.9350162426854149`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.12053668025531891`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9927088740980506`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.8854560256532108`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.4647231720437695`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.9409976553623643`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3384130798336771`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9994041405510892`"}], "-", 
        RowBox[{"0.03451613896972361`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9521176659107095`"}], "-", 
        RowBox[{"0.30573182735975857`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.9409976553623816`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.33841307983368324`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9994041405510508`"}], "+", 
        RowBox[{"0.03451613896972228`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9521176659107147`"}], "+", 
        RowBox[{"0.30573182735976023`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5099326043901408`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.8602143564135076`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9946415246952096`"}], "+", 
        RowBox[{"0.10338393178835326`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.5961324854692065`"}], "+", 
        RowBox[{"0.8028860814388745`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5099326043901321`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.8602143564134931`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9946415246951796`"}], "-", 
        RowBox[{"0.10338393178835013`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.5961324854692275`"}], "-", 
        RowBox[{"0.8028860814389028`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.5393200344992027`"}], "-", 
        RowBox[{"0.8421008849228042`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.9154080085253848`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.4025272387399626`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.8326664226872036`"}], "+", 
        RowBox[{"0.5537748897605292`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.5393200344992075`"}], "+", 
        RowBox[{"0.8421008849228117`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.9154080085253575`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.40252723873995055`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.832666422687211`"}], "-", 
        RowBox[{"0.5537748897605341`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.8512844415843556`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5247044877990263`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.25603909005754466`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9666664286932131`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.725176307143379`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.6885632313432755`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.25603909005754816`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9666664286932264`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.725176307143378`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.6885632313432745`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.8512844415843329`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5247044877990124`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.38666674294141534`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9222195128618151`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.41826780077556713`"}], "-", 
        RowBox[{"0.9083237566167469`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.6759436441447562`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7369533159843427`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.4182678007755718`"}], "+", 
        RowBox[{"0.9083237566167571`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.6759436441447486`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7369533159843344`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.38666674294141296`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9222195128618095`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5680647467311561`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.822983865893648`", " ", "\[ImaginaryI]"}]}], ",", "0", ",",
        "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.7485107481711077`"}], "+", 
        RowBox[{"0.6631226582407975`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9709418174260567`"}], "+", 
        RowBox[{"0.23931566428755258`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5680647467311637`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.822983865893659`", " ", "\[ImaginaryI]"}]}], ",", "0", ",",
        "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.748510748171098`"}], "-", 
        RowBox[{"0.6631226582407889`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9709418174260503`"}], "-", 
        RowBox[{"0.23931566428755102`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.6501040936687437`"}], "-", 
        RowBox[{"0.7598451601445978`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.08620037988061979`"}], "-", 
        RowBox[{"0.9962778199420205`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.700977659806151`"}], "-", 
        RowBox[{"0.7131832306305915`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.6501040936687253`"}], "+", 
        RowBox[{"0.7598451601445765`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.08620037988062082`"}], "+", 
        RowBox[{"0.9962778199420323`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.7009776598061542`"}], "+", 
        RowBox[{"0.7131832306305947`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.9786235252959737`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.20565990308592463`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.2892521195365688`"}], "-", 
        RowBox[{"0.9572529505536038`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.4799374779597847`"}], "+", 
        RowBox[{"0.8773026941994442`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.4799374779597836`"}], "-", 
        RowBox[{"0.8773026941994422`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.9786235252959431`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.2056599030859182`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.28925211953657526`"}], "+", 
        RowBox[{"0.9572529505536251`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9994041405510558`"}], "-", 
        RowBox[{"0.03451613896969502`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9521176659107251`"}], "-", 
        RowBox[{"0.30573182735976123`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.9409976553623911`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3384130798336598`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9521176659107004`"}], "+", 
        RowBox[{"0.3057318273597533`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.9409976553623719`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.33841307983365293`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9994041405510861`"}], "+", 
        RowBox[{"0.03451613896969607`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.8326664226872045`"}], "+", 
        RowBox[{"0.5537748897605372`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.5393200344991949`"}], "-", 
        RowBox[{"0.8421008849228323`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.915408008525356`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.40252723873996693`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.8326664226872033`"}], "-", 
        RowBox[{"0.5537748897605365`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.5393200344991786`"}], "+", 
        RowBox[{"0.8421008849228071`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.9154080085253739`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.40252723873997476`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9521176659107036`"}], "-", 
        RowBox[{"0.30573182735973947`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.9409976553623818`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.3384130798336735`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9994041405510828`"}], "-", 
        RowBox[{"0.0345161389697235`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.9409976553623703`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.3384130798336694`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9994041405510571`"}], "+", 
        RowBox[{"0.03451613896972261`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9521176659107305`"}], "+", 
        RowBox[{"0.30573182735974813`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.01726064090538243`"}], "-", 
        RowBox[{"0.9998510240408662`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.1547293347902639`"}], "-", 
        RowBox[{"0.9879568983287602`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9851389890168567`"}], "-", 
        RowBox[{"0.17175905309125772`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.017260640905381854`"}], "+", 
        RowBox[{"0.9998510240408328`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.15472933479026052`"}], "+", 
        RowBox[{"0.9879568983287387`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.9851389890168961`"}], "+", 
        RowBox[{"0.1717590530912646`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.6234898018587332`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824680106`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.22252093395632158`"}], "+", 
        RowBox[{"0.9749279121818349`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.90096886790242`"}], "-", 
        RowBox[{"0.4338837391175754`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395631595`"}], "-", 
        RowBox[{"0.9749279121818103`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.900968867902405`"}], "+", 
        RowBox[{"0.43388373911756817`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6234898018587521`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7818314824680345`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.18873759545293542`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9820275556534349`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.990480443987547`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.13765351458714953`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.32212044179848626`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9466986959828299`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.9904804439875838`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.13765351458715466`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.3221204417984726`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.9466986959827897`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.18873759545293237`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.982027555653419`", " ", "\[ImaginaryI]"}]}], ",", "0", ",",
        "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6759436441447696`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7369533159843396`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.38666674294142095`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.922219512861807`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.41826780077555886`"}], "+", 
        RowBox[{"0.9083237566167519`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6759436441447528`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7369533159843213`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.38666674294142267`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.9222195128618111`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.41826780077556264`"}], "-", 
        RowBox[{"0.9083237566167601`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.9009688679024355`"}], "+", 
        RowBox[{"0.4338837391175599`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.6234898018587594`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7818314824680273`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.22252093395632475`"}], "-", 
        RowBox[{"0.9749279121817989`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.22252093395633446`"}], "+", 
        RowBox[{"0.9749279121818414`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.9009688679024076`"}], "-", 
        RowBox[{"0.43388373911754646`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.6234898018587418`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7818314824680052`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.3866667429414087`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.922219512861821`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "0.41826780077556946`"}], "-", 
        RowBox[{"0.9083237566167341`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.6759436441447596`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.7369533159843564`", " ", "\[ImaginaryI]"}]}], ",", "0", 
       ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"0.6759436441447352`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.7369533159843298`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.3866667429414041`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.92221951286181`", " ", "\[ImaginaryI]"}]}], ",", "0", ",", 
       "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "0.418267800775583`"}], "+", 
        RowBox[{"0.9083237566167636`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.526206896998942*^9, {3.526209422918448*^9, 3.526209447399989*^9}}]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["recover information on the group:", "Subsection",
 CellChangeTimes->{{3.526206778086073*^9, 3.526206784843713*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "GroupName"}]], "Input",
 CellChangeTimes->{{3.5262067907096233`*^9, 3.526206792333157*^9}}],

Cell[BoxData[
 StyleBox["\<\"GroupName[n] or GroupName[g,j] return a the name of the group \
with\\ngroup number n or the group labeled by the GAP numbers [g,j].\"\>", 
  "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.5271437229263573`*^9},
 CellTags->"Info3527150922-5989200"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "FinGroupOrder"}]], "Input",
 CellChangeTimes->{{3.526206800576791*^9, 3.5262068041565723`*^9}, {
  3.531573449067685*^9, 3.531573449330122*^9}}],

Cell[BoxData[
 StyleBox["\<\"FinGroupOrder['name'] or FinGroupOrder[n] return the order of \
the group \\n'name' or the group with group number n.\"\>", "MSG"]], "Print", \
"PrintUsage",
 CellChangeTimes->{3.531573450351829*^9},
 CellTags->"Info3531577050-5498891"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "jNumber"}]], "Input",
 CellChangeTimes->{{3.526206808038231*^9, 3.526206809452479*^9}}],

Cell[BoxData[
 StyleBox["\<\"jNumber['name'] or jNumber[n] return the j-number of the group \
'name' or\\nthe group with group number n.\"\>", "MSG"]], "Print", \
"PrintUsage",
 CellChangeTimes->{3.527143723688644*^9},
 CellTags->"Info3527150923-6293931"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
example: recover the group name(s) given the group number or the GAP numbers\
\>", "Subsubsection",
 CellChangeTimes->{{3.526206817221119*^9, 3.526206838506587*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"GroupName", "[", "14", "]"}], "\[IndentingNewLine]", 
 RowBox[{"GroupName", "[", 
  RowBox[{"96", ",", "64"}], "]"}]}], "Input",
 CellChangeTimes->{{3.526206851077571*^9, 3.526206868811447*^9}}],

Cell[BoxData[
 RowBox[{"{", \
"\<\"\[CapitalDelta](96)=\[CapitalDelta](6\[CenterDot]\\!\\(\\*SuperscriptBox[\
\\(4\\), \\(2\\)]\\))\"\>", "}"}]], "Output",
 CellChangeTimes->{3.526206869503542*^9}],

Cell[BoxData[
 RowBox[{"{", \
"\<\"\[CapitalDelta](96)=\[CapitalDelta](6\[CenterDot]\\!\\(\\*SuperscriptBox[\
\\(4\\), \\(2\\)]\\))\"\>", "}"}]], "Output",
 CellChangeTimes->{3.526206869533311*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"GroupName", "[", "47", "]"}], "\[IndentingNewLine]", 
 RowBox[{"GroupName", "[", 
  RowBox[{"381", ",", "1"}], "]"}]}], "Input",
 CellChangeTimes->{{3.5262068802212057`*^9, 3.526206896362769*^9}}],

Cell[BoxData[
 RowBox[{"{", "\<\"C(127,1,19); \\!\\(\\*SubscriptBox[\\(T\\), \\(127\\)]\\); \
\\!\\(\\*SubscriptBox[\\(T\\), \\(127[19]\\)]\\)\"\>", "}"}]], "Output",
 CellChangeTimes->{3.526206896998942*^9, 3.526209469105309*^9}],

Cell[BoxData[
 RowBox[{"{", "\<\"C(127,1,19); \\!\\(\\*SubscriptBox[\\(T\\), \\(127\\)]\\); \
\\!\\(\\*SubscriptBox[\\(T\\), \\(127[19]\\)]\\)\"\>", "}"}]], "Output",
 CellChangeTimes->{3.526206896998942*^9, 3.526209469112047*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["example: recover the order of a certain group", "Subsubsection",
 CellChangeTimes->{{3.5262094967979307`*^9, 3.526209511788406*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"FinGroupOrder", "[", 
  "\"\<\!\(\*SubscriptBox[\(T\), \(91[16]\)]\)\>\"", 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"FinGroupOrder", "[", "35", "]"}]}], "Input",
 CellChangeTimes->{{3.5262095187279863`*^9, 3.526209550829596*^9}, {
  3.526209598878512*^9, 3.526209598964005*^9}, {3.531573461346051*^9, 
  3.531573463288849*^9}}],

Cell[BoxData["273"], "Output",
 CellChangeTimes->{{3.526209527757504*^9, 3.5262095517388697`*^9}, 
   3.5262095995657682`*^9, 3.531573464058901*^9}],

Cell[BoxData["273"], "Output",
 CellChangeTimes->{{3.526209527757504*^9, 3.5262095517388697`*^9}, 
   3.5262095995657682`*^9, 3.5315734640642242`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["example: recover the j-number of a certain group", "Subsubsection",
 CellChangeTimes->{{3.5262095649561872`*^9, 3.526209573802864*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"jNumber", "[", "\"\<\!\(\*SubscriptBox[\(T\), \(91[16]\)]\)\>\"", 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"jNumber", "[", "35", "]"}]}], "Input",
 CellChangeTimes->{{3.526209585455584*^9, 3.526209596084456*^9}}],

Cell[BoxData["3"], "Output",
 CellChangeTimes->{{3.526209587095661*^9, 3.526209596944018*^9}}],

Cell[BoxData["3"], "Output",
 CellChangeTimes->{{3.526209587095661*^9, 3.526209596945547*^9}}]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Molien functions:", "Section",
 CellChangeTimes->{{3.5262098476378393`*^9, 3.5262098506356792`*^9}}],

Cell[CellGroupData[{

Cell["display the Molien function of a certain group:", "Subsection",
 CellChangeTimes->{{3.526209857365487*^9, 3.526209865843315*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "Molien"}]], "Input",
 CellChangeTimes->{{3.526209868988865*^9, 3.5262098703406963`*^9}}],

Cell[BoxData[
 StyleBox["\<\"Molien['name'], Molien[n], and Molien[g,j] return the Molien \
function of\\nthe group 'name', the group with group number n, or the group \
labeled by \\nthe GAP numbers [g,j].\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.52714373307852*^9},
 CellTags->"Info3527150932-1637611"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "example: ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["T", "31"], TraditionalForm]],
  FormatType->"TraditionalForm"]
}], "Subsubsection",
 CellChangeTimes->{{3.526209875728454*^9, 3.526209886118503*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Molien", "[", "\"\<\!\(\*SubscriptBox[\(T\), \(31\)]\)\>\"", 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Molien", "[", "\"\<\!\(\*SubscriptBox[\(T\), \(31[5]\)]\)\>\"", 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Molien", "[", "\"\<C(31,1,5)\>\"", "]"}], "\[IndentingNewLine]", 
 RowBox[{"Molien", "[", "13", "]"}], "\[IndentingNewLine]", 
 RowBox[{"Molien", "[", 
  RowBox[{"93", ",", "1"}], "]"}]}], "Input",
 CellChangeTimes->{{3.5262098883882217`*^9, 3.526209938684663*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"1", "+", 
   SuperscriptBox["P", "7"], "+", 
   SuperscriptBox["P", "14"], "+", 
   SuperscriptBox["P", "15"], "+", 
   SuperscriptBox["P", "19"], "+", 
   SuperscriptBox["P", "21"], "+", 
   SuperscriptBox["P", "23"], "+", 
   SuperscriptBox["P", "27"], "+", 
   SuperscriptBox["P", "28"], "+", 
   SuperscriptBox["P", "35"], "+", 
   SuperscriptBox["P", "42"]}], 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "-", 
     SuperscriptBox["P", "3"]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     SuperscriptBox["P", "11"]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     SuperscriptBox["P", "31"]}], ")"}]}]]], "Output",
 CellChangeTimes->{3.526209939302944*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{"1", "+", 
   SuperscriptBox["P", "7"], "+", 
   SuperscriptBox["P", "14"], "+", 
   SuperscriptBox["P", "15"], "+", 
   SuperscriptBox["P", "19"], "+", 
   SuperscriptBox["P", "21"], "+", 
   SuperscriptBox["P", "23"], "+", 
   SuperscriptBox["P", "27"], "+", 
   SuperscriptBox["P", "28"], "+", 
   SuperscriptBox["P", "35"], "+", 
   SuperscriptBox["P", "42"]}], 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "-", 
     SuperscriptBox["P", "3"]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     SuperscriptBox["P", "11"]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     SuperscriptBox["P", "31"]}], ")"}]}]]], "Output",
 CellChangeTimes->{3.52620993933403*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{"1", "+", 
   SuperscriptBox["P", "7"], "+", 
   SuperscriptBox["P", "14"], "+", 
   SuperscriptBox["P", "15"], "+", 
   SuperscriptBox["P", "19"], "+", 
   SuperscriptBox["P", "21"], "+", 
   SuperscriptBox["P", "23"], "+", 
   SuperscriptBox["P", "27"], "+", 
   SuperscriptBox["P", "28"], "+", 
   SuperscriptBox["P", "35"], "+", 
   SuperscriptBox["P", "42"]}], 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "-", 
     SuperscriptBox["P", "3"]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     SuperscriptBox["P", "11"]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     SuperscriptBox["P", "31"]}], ")"}]}]]], "Output",
 CellChangeTimes->{3.526209939368327*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{"1", "+", 
   SuperscriptBox["P", "7"], "+", 
   SuperscriptBox["P", "14"], "+", 
   SuperscriptBox["P", "15"], "+", 
   SuperscriptBox["P", "19"], "+", 
   SuperscriptBox["P", "21"], "+", 
   SuperscriptBox["P", "23"], "+", 
   SuperscriptBox["P", "27"], "+", 
   SuperscriptBox["P", "28"], "+", 
   SuperscriptBox["P", "35"], "+", 
   SuperscriptBox["P", "42"]}], 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "-", 
     SuperscriptBox["P", "3"]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     SuperscriptBox["P", "11"]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     SuperscriptBox["P", "31"]}], ")"}]}]]], "Output",
 CellChangeTimes->{3.526209939401896*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{"1", "+", 
   SuperscriptBox["P", "7"], "+", 
   SuperscriptBox["P", "14"], "+", 
   SuperscriptBox["P", "15"], "+", 
   SuperscriptBox["P", "19"], "+", 
   SuperscriptBox["P", "21"], "+", 
   SuperscriptBox["P", "23"], "+", 
   SuperscriptBox["P", "27"], "+", 
   SuperscriptBox["P", "28"], "+", 
   SuperscriptBox["P", "35"], "+", 
   SuperscriptBox["P", "42"]}], 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "-", 
     SuperscriptBox["P", "3"]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     SuperscriptBox["P", "11"]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     SuperscriptBox["P", "31"]}], ")"}]}]]], "Output",
 CellChangeTimes->{3.526209939442436*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["example: \[CapitalSigma](360\[Phi])", "Subsubsection",
 CellChangeTimes->{{3.526209875728454*^9, 3.526209886118503*^9}, {
  3.5262099540222273`*^9, 3.526209961576837*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Molien", "[", "\"\<\[CapitalSigma](360\[Phi])\>\"", 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Molien", "[", "61", "]"}], "\[IndentingNewLine]", 
 RowBox[{"Molien", "[", 
  RowBox[{"1080", ",", "260"}], "]"}]}], "Input",
 CellChangeTimes->{{3.526209963503772*^9, 3.526209992226366*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"1", "+", 
   SuperscriptBox["P", "45"]}], 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "-", 
     SuperscriptBox["P", "6"]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     SuperscriptBox["P", "12"]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     SuperscriptBox["P", "30"]}], ")"}]}]]], "Output",
 CellChangeTimes->{3.526209992973246*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{"1", "+", 
   SuperscriptBox["P", "45"]}], 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "-", 
     SuperscriptBox["P", "6"]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     SuperscriptBox["P", "12"]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     SuperscriptBox["P", "30"]}], ")"}]}]]], "Output",
 CellChangeTimes->{3.5262099929750433`*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{"1", "+", 
   SuperscriptBox["P", "45"]}], 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "-", 
     SuperscriptBox["P", "6"]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     SuperscriptBox["P", "12"]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     SuperscriptBox["P", "30"]}], ")"}]}]]], "Output",
 CellChangeTimes->{3.52620999297692*^9}]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Primary and secondary invariants:", "Section",
 CellChangeTimes->{{3.526209618963429*^9, 3.526209624673583*^9}}],

Cell[CellGroupData[{

Cell["display the primary invariants of a certain group:", "Subsection",
 CellChangeTimes->{{3.5262096491390457`*^9, 3.526209663184577*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "PrimInv"}]], "Input",
 CellChangeTimes->{{3.526209666009444*^9, 3.5262096713616333`*^9}}],

Cell[BoxData[
 StyleBox["\<\"PrimInv['name'], PrimInv[n], and PrimInv[g,j] return the \
primary\\ninvariants of the group 'name', the group with group number n, or \
the\\ngroup labeled by the GAP numbers [g,j].\"\>", "MSG"]], "Print", \
"PrintUsage",
 CellChangeTimes->{3.527143735932227*^9},
 CellTags->"Info3527150935-8240089"]
}, Open  ]],

Cell[CellGroupData[{

Cell["example: C(49,10,6)", "Subsubsection",
 CellChangeTimes->{{3.5262096804173927`*^9, 3.5262097047357273`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"PrimInv", "[", "\"\<C(49,10,6)\>\"", "]"}], "\[IndentingNewLine]", 
 RowBox[{"PrimInv", "[", "19", "]"}], "\[IndentingNewLine]", 
 RowBox[{"PrimInv", "[", 
  RowBox[{"147", ",", "1"}], "]"}]}], "Input",
 CellChangeTimes->{{3.5262097127468443`*^9, 3.5262097446567783`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"x", " ", "y", " ", "z"}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["x", "8"], " ", 
     SuperscriptBox["y", "3"]}], "+", 
    RowBox[{
     SuperscriptBox["y", "8"], " ", 
     SuperscriptBox["z", "3"]}], "+", 
    RowBox[{
     SuperscriptBox["x", "3"], " ", 
     SuperscriptBox["z", "8"]}]}], ",", 
   RowBox[{
    SuperscriptBox["x", "49"], "+", 
    SuperscriptBox["y", "49"], "+", 
    SuperscriptBox["z", "49"]}]}], "}"}]], "Output",
 CellChangeTimes->{3.526209745386615*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"x", " ", "y", " ", "z"}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["x", "8"], " ", 
     SuperscriptBox["y", "3"]}], "+", 
    RowBox[{
     SuperscriptBox["y", "8"], " ", 
     SuperscriptBox["z", "3"]}], "+", 
    RowBox[{
     SuperscriptBox["x", "3"], " ", 
     SuperscriptBox["z", "8"]}]}], ",", 
   RowBox[{
    SuperscriptBox["x", "49"], "+", 
    SuperscriptBox["y", "49"], "+", 
    SuperscriptBox["z", "49"]}]}], "}"}]], "Output",
 CellChangeTimes->{3.5262097453875923`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"x", " ", "y", " ", "z"}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["x", "8"], " ", 
     SuperscriptBox["y", "3"]}], "+", 
    RowBox[{
     SuperscriptBox["y", "8"], " ", 
     SuperscriptBox["z", "3"]}], "+", 
    RowBox[{
     SuperscriptBox["x", "3"], " ", 
     SuperscriptBox["z", "8"]}]}], ",", 
   RowBox[{
    SuperscriptBox["x", "49"], "+", 
    SuperscriptBox["y", "49"], "+", 
    SuperscriptBox["z", "49"]}]}], "}"}]], "Output",
 CellChangeTimes->{3.5262097453889027`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["example: D(9,1,1;2,1,1)", "Subsubsection",
 CellChangeTimes->{{3.5262096804173927`*^9, 3.5262097047357273`*^9}, {
  3.5262097518090343`*^9, 3.52620975649419*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"PrimInv", "[", "\"\<D(9,1,1;2,1,1)\>\"", 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"PrimInv", "[", "23", "]"}], "\[IndentingNewLine]", 
 RowBox[{"PrimInv", "[", 
  RowBox[{"162", ",", "14"}], "]"}]}], "Input",
 CellChangeTimes->{{3.5262097127468443`*^9, 3.5262097787923107`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["x", "2"], " ", 
    SuperscriptBox["y", "2"], " ", 
    SuperscriptBox["z", "2"]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["x", "6"], " ", 
     SuperscriptBox["y", "3"]}], "-", 
    RowBox[{
     SuperscriptBox["x", "3"], " ", 
     SuperscriptBox["y", "6"]}], "-", 
    RowBox[{
     SuperscriptBox["x", "6"], " ", 
     SuperscriptBox["z", "3"]}], "+", 
    RowBox[{
     SuperscriptBox["y", "6"], " ", 
     SuperscriptBox["z", "3"]}], "+", 
    RowBox[{
     SuperscriptBox["x", "3"], " ", 
     SuperscriptBox["z", "6"]}], "-", 
    RowBox[{
     SuperscriptBox["y", "3"], " ", 
     SuperscriptBox["z", "6"]}]}], ",", 
   RowBox[{
    SuperscriptBox["x", "18"], "+", 
    SuperscriptBox["y", "18"], "+", 
    SuperscriptBox["z", "18"]}]}], "}"}]], "Output",
 CellChangeTimes->{3.526209745386615*^9, 3.526209779541869*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["x", "2"], " ", 
    SuperscriptBox["y", "2"], " ", 
    SuperscriptBox["z", "2"]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["x", "6"], " ", 
     SuperscriptBox["y", "3"]}], "-", 
    RowBox[{
     SuperscriptBox["x", "3"], " ", 
     SuperscriptBox["y", "6"]}], "-", 
    RowBox[{
     SuperscriptBox["x", "6"], " ", 
     SuperscriptBox["z", "3"]}], "+", 
    RowBox[{
     SuperscriptBox["y", "6"], " ", 
     SuperscriptBox["z", "3"]}], "+", 
    RowBox[{
     SuperscriptBox["x", "3"], " ", 
     SuperscriptBox["z", "6"]}], "-", 
    RowBox[{
     SuperscriptBox["y", "3"], " ", 
     SuperscriptBox["z", "6"]}]}], ",", 
   RowBox[{
    SuperscriptBox["x", "18"], "+", 
    SuperscriptBox["y", "18"], "+", 
    SuperscriptBox["z", "18"]}]}], "}"}]], "Output",
 CellChangeTimes->{3.526209745386615*^9, 3.5262097795438957`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["x", "2"], " ", 
    SuperscriptBox["y", "2"], " ", 
    SuperscriptBox["z", "2"]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["x", "6"], " ", 
     SuperscriptBox["y", "3"]}], "-", 
    RowBox[{
     SuperscriptBox["x", "3"], " ", 
     SuperscriptBox["y", "6"]}], "-", 
    RowBox[{
     SuperscriptBox["x", "6"], " ", 
     SuperscriptBox["z", "3"]}], "+", 
    RowBox[{
     SuperscriptBox["y", "6"], " ", 
     SuperscriptBox["z", "3"]}], "+", 
    RowBox[{
     SuperscriptBox["x", "3"], " ", 
     SuperscriptBox["z", "6"]}], "-", 
    RowBox[{
     SuperscriptBox["y", "3"], " ", 
     SuperscriptBox["z", "6"]}]}], ",", 
   RowBox[{
    SuperscriptBox["x", "18"], "+", 
    SuperscriptBox["y", "18"], "+", 
    SuperscriptBox["z", "18"]}]}], "}"}]], "Output",
 CellChangeTimes->{3.526209745386615*^9, 3.526209779545388*^9}]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["display the secondary invariants of a certain group:", "Subsection",
 CellChangeTimes->{{3.5262096491390457`*^9, 3.526209663184577*^9}, {
  3.526209794071685*^9, 3.526209796133196*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "SecInv"}]], "Input",
 CellChangeTimes->{{3.526209666009444*^9, 3.5262096713616333`*^9}, {
  3.526209797951208*^9, 3.526209799446501*^9}}],

Cell[BoxData[
 StyleBox["\<\"SecInv['name'], SecInv[n], and SecInv[g,j] return the \
secondary\\ninvariants of the group 'name', the group with group number n, or \
the\\ngroup labeled by the GAP numbers [g,j].\"\>", "MSG"]], "Print", \
"PrintUsage",
 CellChangeTimes->{3.527143738823201*^9},
 CellTags->"Info3527150938-6414844"]
}, Open  ]],

Cell[CellGroupData[{

Cell["example: C(49,10,6)", "Subsubsection",
 CellChangeTimes->{{3.5262096804173927`*^9, 3.5262097047357273`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"SecInv", "[", "\"\<C(49,10,6)\>\"", "]"}], "\[IndentingNewLine]", 
 RowBox[{"SecInv", "[", "19", "]"}], "\[IndentingNewLine]", 
 RowBox[{"SecInv", "[", 
  RowBox[{"147", ",", "1"}], "]"}]}], "Input",
 CellChangeTimes->{{3.5262097127468443`*^9, 3.5262097446567783`*^9}, {
  3.526209813871636*^9, 3.526209817895063*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["x", "5"], " ", 
     SuperscriptBox["y", "8"]}], "+", 
    RowBox[{
     SuperscriptBox["x", "8"], " ", 
     SuperscriptBox["z", "5"]}], "+", 
    RowBox[{
     SuperscriptBox["y", "5"], " ", 
     SuperscriptBox["z", "8"]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["x", "2"], " ", 
     SuperscriptBox["y", "13"]}], "+", 
    RowBox[{
     SuperscriptBox["x", "13"], " ", 
     SuperscriptBox["z", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["y", "2"], " ", 
     SuperscriptBox["z", "13"]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["x", "19"], " ", "y"}], "+", 
    RowBox[{
     SuperscriptBox["y", "19"], " ", "z"}], "+", 
    RowBox[{"x", " ", 
     SuperscriptBox["z", "19"]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["x", "7"], " ", 
     SuperscriptBox["y", "21"]}], "+", 
    RowBox[{
     SuperscriptBox["x", "21"], " ", 
     SuperscriptBox["z", "7"]}], "+", 
    RowBox[{
     SuperscriptBox["y", "7"], " ", 
     SuperscriptBox["z", "21"]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["x", "4"], " ", 
     SuperscriptBox["y", "26"]}], "+", 
    RowBox[{
     SuperscriptBox["x", "26"], " ", 
     SuperscriptBox["z", "4"]}], "+", 
    RowBox[{
     SuperscriptBox["y", "4"], " ", 
     SuperscriptBox["z", "26"]}]}], ",", 
   RowBox[{
    RowBox[{"x", " ", 
     SuperscriptBox["y", "31"]}], "+", 
    RowBox[{
     SuperscriptBox["x", "31"], " ", "z"}], "+", 
    RowBox[{"y", " ", 
     SuperscriptBox["z", "31"]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["x", "38"], " ", 
     SuperscriptBox["y", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["y", "38"], " ", 
     SuperscriptBox["z", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["x", "2"], " ", 
     SuperscriptBox["z", "38"]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["x", "6"], " ", 
     SuperscriptBox["y", "39"]}], "+", 
    RowBox[{
     SuperscriptBox["x", "39"], " ", 
     SuperscriptBox["z", "6"]}], "+", 
    RowBox[{
     SuperscriptBox["y", "6"], " ", 
     SuperscriptBox["z", "39"]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["x", "3"], " ", 
     SuperscriptBox["y", "44"]}], "+", 
    RowBox[{
     SuperscriptBox["x", "44"], " ", 
     SuperscriptBox["z", "3"]}], "+", 
    RowBox[{
     SuperscriptBox["y", "3"], " ", 
     SuperscriptBox["z", "44"]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["x", "57"], " ", 
     SuperscriptBox["y", "3"]}], "+", 
    RowBox[{
     SuperscriptBox["y", "57"], " ", 
     SuperscriptBox["z", "3"]}], "+", 
    RowBox[{
     SuperscriptBox["x", "3"], " ", 
     SuperscriptBox["z", "57"]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.526209745386615*^9, 3.526209818640162*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["x", "5"], " ", 
     SuperscriptBox["y", "8"]}], "+", 
    RowBox[{
     SuperscriptBox["x", "8"], " ", 
     SuperscriptBox["z", "5"]}], "+", 
    RowBox[{
     SuperscriptBox["y", "5"], " ", 
     SuperscriptBox["z", "8"]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["x", "2"], " ", 
     SuperscriptBox["y", "13"]}], "+", 
    RowBox[{
     SuperscriptBox["x", "13"], " ", 
     SuperscriptBox["z", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["y", "2"], " ", 
     SuperscriptBox["z", "13"]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["x", "19"], " ", "y"}], "+", 
    RowBox[{
     SuperscriptBox["y", "19"], " ", "z"}], "+", 
    RowBox[{"x", " ", 
     SuperscriptBox["z", "19"]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["x", "7"], " ", 
     SuperscriptBox["y", "21"]}], "+", 
    RowBox[{
     SuperscriptBox["x", "21"], " ", 
     SuperscriptBox["z", "7"]}], "+", 
    RowBox[{
     SuperscriptBox["y", "7"], " ", 
     SuperscriptBox["z", "21"]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["x", "4"], " ", 
     SuperscriptBox["y", "26"]}], "+", 
    RowBox[{
     SuperscriptBox["x", "26"], " ", 
     SuperscriptBox["z", "4"]}], "+", 
    RowBox[{
     SuperscriptBox["y", "4"], " ", 
     SuperscriptBox["z", "26"]}]}], ",", 
   RowBox[{
    RowBox[{"x", " ", 
     SuperscriptBox["y", "31"]}], "+", 
    RowBox[{
     SuperscriptBox["x", "31"], " ", "z"}], "+", 
    RowBox[{"y", " ", 
     SuperscriptBox["z", "31"]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["x", "38"], " ", 
     SuperscriptBox["y", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["y", "38"], " ", 
     SuperscriptBox["z", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["x", "2"], " ", 
     SuperscriptBox["z", "38"]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["x", "6"], " ", 
     SuperscriptBox["y", "39"]}], "+", 
    RowBox[{
     SuperscriptBox["x", "39"], " ", 
     SuperscriptBox["z", "6"]}], "+", 
    RowBox[{
     SuperscriptBox["y", "6"], " ", 
     SuperscriptBox["z", "39"]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["x", "3"], " ", 
     SuperscriptBox["y", "44"]}], "+", 
    RowBox[{
     SuperscriptBox["x", "44"], " ", 
     SuperscriptBox["z", "3"]}], "+", 
    RowBox[{
     SuperscriptBox["y", "3"], " ", 
     SuperscriptBox["z", "44"]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["x", "57"], " ", 
     SuperscriptBox["y", "3"]}], "+", 
    RowBox[{
     SuperscriptBox["y", "57"], " ", 
     SuperscriptBox["z", "3"]}], "+", 
    RowBox[{
     SuperscriptBox["x", "3"], " ", 
     SuperscriptBox["z", "57"]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.526209745386615*^9, 3.526209818644806*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["x", "5"], " ", 
     SuperscriptBox["y", "8"]}], "+", 
    RowBox[{
     SuperscriptBox["x", "8"], " ", 
     SuperscriptBox["z", "5"]}], "+", 
    RowBox[{
     SuperscriptBox["y", "5"], " ", 
     SuperscriptBox["z", "8"]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["x", "2"], " ", 
     SuperscriptBox["y", "13"]}], "+", 
    RowBox[{
     SuperscriptBox["x", "13"], " ", 
     SuperscriptBox["z", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["y", "2"], " ", 
     SuperscriptBox["z", "13"]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["x", "19"], " ", "y"}], "+", 
    RowBox[{
     SuperscriptBox["y", "19"], " ", "z"}], "+", 
    RowBox[{"x", " ", 
     SuperscriptBox["z", "19"]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["x", "7"], " ", 
     SuperscriptBox["y", "21"]}], "+", 
    RowBox[{
     SuperscriptBox["x", "21"], " ", 
     SuperscriptBox["z", "7"]}], "+", 
    RowBox[{
     SuperscriptBox["y", "7"], " ", 
     SuperscriptBox["z", "21"]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["x", "4"], " ", 
     SuperscriptBox["y", "26"]}], "+", 
    RowBox[{
     SuperscriptBox["x", "26"], " ", 
     SuperscriptBox["z", "4"]}], "+", 
    RowBox[{
     SuperscriptBox["y", "4"], " ", 
     SuperscriptBox["z", "26"]}]}], ",", 
   RowBox[{
    RowBox[{"x", " ", 
     SuperscriptBox["y", "31"]}], "+", 
    RowBox[{
     SuperscriptBox["x", "31"], " ", "z"}], "+", 
    RowBox[{"y", " ", 
     SuperscriptBox["z", "31"]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["x", "38"], " ", 
     SuperscriptBox["y", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["y", "38"], " ", 
     SuperscriptBox["z", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["x", "2"], " ", 
     SuperscriptBox["z", "38"]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["x", "6"], " ", 
     SuperscriptBox["y", "39"]}], "+", 
    RowBox[{
     SuperscriptBox["x", "39"], " ", 
     SuperscriptBox["z", "6"]}], "+", 
    RowBox[{
     SuperscriptBox["y", "6"], " ", 
     SuperscriptBox["z", "39"]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["x", "3"], " ", 
     SuperscriptBox["y", "44"]}], "+", 
    RowBox[{
     SuperscriptBox["x", "44"], " ", 
     SuperscriptBox["z", "3"]}], "+", 
    RowBox[{
     SuperscriptBox["y", "3"], " ", 
     SuperscriptBox["z", "44"]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["x", "57"], " ", 
     SuperscriptBox["y", "3"]}], "+", 
    RowBox[{
     SuperscriptBox["y", "57"], " ", 
     SuperscriptBox["z", "3"]}], "+", 
    RowBox[{
     SuperscriptBox["x", "3"], " ", 
     SuperscriptBox["z", "57"]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.526209745386615*^9, 3.526209818674562*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["example: D(9,1,1;2,1,1)", "Subsubsection",
 CellChangeTimes->{{3.5262096804173927`*^9, 3.5262097047357273`*^9}, {
  3.5262097518090343`*^9, 3.52620975649419*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"SecInv", "[", "\"\<D(9,1,1;2,1,1)\>\"", 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"SecInv", "[", "23", "]"}], "\[IndentingNewLine]", 
 RowBox[{"SecInv", "[", 
  RowBox[{"162", ",", "14"}], "]"}]}], "Input",
 CellChangeTimes->{{3.5262097127468443`*^9, 3.5262097787923107`*^9}, {
  3.5262098234632072`*^9, 3.526209827574814*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["x", "10"], " ", "y", " ", "z"}], "+", 
    RowBox[{"x", " ", 
     SuperscriptBox["y", "10"], " ", "z"}], "+", 
    RowBox[{"x", " ", "y", " ", 
     SuperscriptBox["z", "10"]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["x", "7"], " ", 
     SuperscriptBox["y", "4"], " ", "z"}], "+", 
    RowBox[{
     SuperscriptBox["x", "4"], " ", 
     SuperscriptBox["y", "7"], " ", "z"}], "+", 
    RowBox[{
     SuperscriptBox["x", "7"], " ", "y", " ", 
     SuperscriptBox["z", "4"]}], "+", 
    RowBox[{"x", " ", 
     SuperscriptBox["y", "7"], " ", 
     SuperscriptBox["z", "4"]}], "+", 
    RowBox[{
     SuperscriptBox["x", "4"], " ", "y", " ", 
     SuperscriptBox["z", "7"]}], "+", 
    RowBox[{"x", " ", 
     SuperscriptBox["y", "4"], " ", 
     SuperscriptBox["z", "7"]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["x", "15"], " ", 
     SuperscriptBox["y", "3"]}], "+", 
    RowBox[{
     SuperscriptBox["x", "3"], " ", 
     SuperscriptBox["y", "15"]}], "+", 
    RowBox[{
     SuperscriptBox["x", "15"], " ", 
     SuperscriptBox["z", "3"]}], "+", 
    RowBox[{
     SuperscriptBox["y", "15"], " ", 
     SuperscriptBox["z", "3"]}], "+", 
    RowBox[{
     SuperscriptBox["x", "3"], " ", 
     SuperscriptBox["z", "15"]}], "+", 
    RowBox[{
     SuperscriptBox["y", "3"], " ", 
     SuperscriptBox["z", "15"]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["x", "12"], " ", 
     SuperscriptBox["y", "6"]}], "+", 
    RowBox[{
     SuperscriptBox["x", "6"], " ", 
     SuperscriptBox["y", "12"]}], "+", 
    RowBox[{
     SuperscriptBox["x", "12"], " ", 
     SuperscriptBox["z", "6"]}], "+", 
    RowBox[{
     SuperscriptBox["y", "12"], " ", 
     SuperscriptBox["z", "6"]}], "+", 
    RowBox[{
     SuperscriptBox["x", "6"], " ", 
     SuperscriptBox["z", "12"]}], "+", 
    RowBox[{
     SuperscriptBox["y", "6"], " ", 
     SuperscriptBox["z", "12"]}]}], ",", 
   RowBox[{"x", " ", "y", " ", "z", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["x", "27"], "+", 
      SuperscriptBox["y", "27"], "+", 
      SuperscriptBox["z", "27"]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.526209745386615*^9, 3.526209779541869*^9, 
  3.526209828371725*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["x", "10"], " ", "y", " ", "z"}], "+", 
    RowBox[{"x", " ", 
     SuperscriptBox["y", "10"], " ", "z"}], "+", 
    RowBox[{"x", " ", "y", " ", 
     SuperscriptBox["z", "10"]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["x", "7"], " ", 
     SuperscriptBox["y", "4"], " ", "z"}], "+", 
    RowBox[{
     SuperscriptBox["x", "4"], " ", 
     SuperscriptBox["y", "7"], " ", "z"}], "+", 
    RowBox[{
     SuperscriptBox["x", "7"], " ", "y", " ", 
     SuperscriptBox["z", "4"]}], "+", 
    RowBox[{"x", " ", 
     SuperscriptBox["y", "7"], " ", 
     SuperscriptBox["z", "4"]}], "+", 
    RowBox[{
     SuperscriptBox["x", "4"], " ", "y", " ", 
     SuperscriptBox["z", "7"]}], "+", 
    RowBox[{"x", " ", 
     SuperscriptBox["y", "4"], " ", 
     SuperscriptBox["z", "7"]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["x", "15"], " ", 
     SuperscriptBox["y", "3"]}], "+", 
    RowBox[{
     SuperscriptBox["x", "3"], " ", 
     SuperscriptBox["y", "15"]}], "+", 
    RowBox[{
     SuperscriptBox["x", "15"], " ", 
     SuperscriptBox["z", "3"]}], "+", 
    RowBox[{
     SuperscriptBox["y", "15"], " ", 
     SuperscriptBox["z", "3"]}], "+", 
    RowBox[{
     SuperscriptBox["x", "3"], " ", 
     SuperscriptBox["z", "15"]}], "+", 
    RowBox[{
     SuperscriptBox["y", "3"], " ", 
     SuperscriptBox["z", "15"]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["x", "12"], " ", 
     SuperscriptBox["y", "6"]}], "+", 
    RowBox[{
     SuperscriptBox["x", "6"], " ", 
     SuperscriptBox["y", "12"]}], "+", 
    RowBox[{
     SuperscriptBox["x", "12"], " ", 
     SuperscriptBox["z", "6"]}], "+", 
    RowBox[{
     SuperscriptBox["y", "12"], " ", 
     SuperscriptBox["z", "6"]}], "+", 
    RowBox[{
     SuperscriptBox["x", "6"], " ", 
     SuperscriptBox["z", "12"]}], "+", 
    RowBox[{
     SuperscriptBox["y", "6"], " ", 
     SuperscriptBox["z", "12"]}]}], ",", 
   RowBox[{"x", " ", "y", " ", "z", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["x", "27"], "+", 
      SuperscriptBox["y", "27"], "+", 
      SuperscriptBox["z", "27"]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.526209745386615*^9, 3.526209779541869*^9, 
  3.526209828374628*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["x", "10"], " ", "y", " ", "z"}], "+", 
    RowBox[{"x", " ", 
     SuperscriptBox["y", "10"], " ", "z"}], "+", 
    RowBox[{"x", " ", "y", " ", 
     SuperscriptBox["z", "10"]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["x", "7"], " ", 
     SuperscriptBox["y", "4"], " ", "z"}], "+", 
    RowBox[{
     SuperscriptBox["x", "4"], " ", 
     SuperscriptBox["y", "7"], " ", "z"}], "+", 
    RowBox[{
     SuperscriptBox["x", "7"], " ", "y", " ", 
     SuperscriptBox["z", "4"]}], "+", 
    RowBox[{"x", " ", 
     SuperscriptBox["y", "7"], " ", 
     SuperscriptBox["z", "4"]}], "+", 
    RowBox[{
     SuperscriptBox["x", "4"], " ", "y", " ", 
     SuperscriptBox["z", "7"]}], "+", 
    RowBox[{"x", " ", 
     SuperscriptBox["y", "4"], " ", 
     SuperscriptBox["z", "7"]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["x", "15"], " ", 
     SuperscriptBox["y", "3"]}], "+", 
    RowBox[{
     SuperscriptBox["x", "3"], " ", 
     SuperscriptBox["y", "15"]}], "+", 
    RowBox[{
     SuperscriptBox["x", "15"], " ", 
     SuperscriptBox["z", "3"]}], "+", 
    RowBox[{
     SuperscriptBox["y", "15"], " ", 
     SuperscriptBox["z", "3"]}], "+", 
    RowBox[{
     SuperscriptBox["x", "3"], " ", 
     SuperscriptBox["z", "15"]}], "+", 
    RowBox[{
     SuperscriptBox["y", "3"], " ", 
     SuperscriptBox["z", "15"]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["x", "12"], " ", 
     SuperscriptBox["y", "6"]}], "+", 
    RowBox[{
     SuperscriptBox["x", "6"], " ", 
     SuperscriptBox["y", "12"]}], "+", 
    RowBox[{
     SuperscriptBox["x", "12"], " ", 
     SuperscriptBox["z", "6"]}], "+", 
    RowBox[{
     SuperscriptBox["y", "12"], " ", 
     SuperscriptBox["z", "6"]}], "+", 
    RowBox[{
     SuperscriptBox["x", "6"], " ", 
     SuperscriptBox["z", "12"]}], "+", 
    RowBox[{
     SuperscriptBox["y", "6"], " ", 
     SuperscriptBox["z", "12"]}]}], ",", 
   RowBox[{"x", " ", "y", " ", "z", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["x", "27"], "+", 
      SuperscriptBox["y", "27"], "+", 
      SuperscriptBox["z", "27"]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.526209745386615*^9, 3.526209779541869*^9, 
  3.526209828408729*^9}]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["display the syzygies for all secondary invariants:", "Subsection",
 CellChangeTimes->{{3.526210023313241*^9, 3.526210033790951*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "Syzygy"}]], "Input",
 CellChangeTimes->{{3.526210036794483*^9, 3.5262100380882387`*^9}}],

Cell[BoxData[
 StyleBox["\<\"Syzygy['name'], Syzygy[n], and Syzygy[g,j] return the syzygies \
of the\\nsecondary invariants of the group 'name', the group with group \
number n,\\nor the group labeled by the GAP numbers [g,j].\"\>", 
  "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.527143740954898*^9},
 CellTags->"Info3527150940-2017537"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "example: ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[CapitalDelta]", "(", 
    RowBox[{"6", "\[CenterDot]", 
     SuperscriptBox["6", "2"]}], ")"}], TraditionalForm]],
  FormatType->"TraditionalForm"]
}], "Subsubsection",
 CellChangeTimes->{{3.526210045940151*^9, 3.5262100629505043`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Syzygy", "[", 
  "\"\<\[CapitalDelta](6\[CenterDot]\!\(\*SuperscriptBox[\(6\), \
\(2\)]\))\>\"", "]"}], "\[IndentingNewLine]", 
 RowBox[{"Syzygy", "[", "\"\<\[CapitalDelta](216)\>\"", 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Syzygy", "[", "30", "]"}], "\[IndentingNewLine]", 
 RowBox[{"Syzygy", "[", 
  RowBox[{"216", ",", "95"}], "]"}]}], "Input",
 CellChangeTimes->{{3.52621006709452*^9, 3.526210092126514*^9}, {
  3.5262101764686203`*^9, 3.526210216756763*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SuperscriptBox["Is21", "2"], "\[Equal]", 
   RowBox[{
    FractionBox[
     RowBox[{
      SuperscriptBox["Ip12", "3"], " ", "Ip6b"}], "2"], "-", 
    RowBox[{
     FractionBox["5", "4"], " ", 
     SuperscriptBox["Ip12", "2"], " ", 
     SuperscriptBox["Ip6a", "2"], " ", "Ip6b"}], "+", 
    RowBox[{"Ip12", " ", 
     SuperscriptBox["Ip6a", "4"], " ", "Ip6b"}], "-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["Ip6a", "6"], " ", "Ip6b"}], "4"], "-", 
    RowBox[{"9", " ", "Ip12", " ", "Ip6a", " ", 
     SuperscriptBox["Ip6b", "4"]}], "+", 
    RowBox[{"5", " ", 
     SuperscriptBox["Ip6a", "3"], " ", 
     SuperscriptBox["Ip6b", "4"]}], "-", 
    RowBox[{"27", " ", 
     SuperscriptBox["Ip6b", "7"]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.526210077431629*^9, 3.526210219057781*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SuperscriptBox["Is21", "2"], "\[Equal]", 
   RowBox[{
    FractionBox[
     RowBox[{
      SuperscriptBox["Ip12", "3"], " ", "Ip6b"}], "2"], "-", 
    RowBox[{
     FractionBox["5", "4"], " ", 
     SuperscriptBox["Ip12", "2"], " ", 
     SuperscriptBox["Ip6a", "2"], " ", "Ip6b"}], "+", 
    RowBox[{"Ip12", " ", 
     SuperscriptBox["Ip6a", "4"], " ", "Ip6b"}], "-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["Ip6a", "6"], " ", "Ip6b"}], "4"], "-", 
    RowBox[{"9", " ", "Ip12", " ", "Ip6a", " ", 
     SuperscriptBox["Ip6b", "4"]}], "+", 
    RowBox[{"5", " ", 
     SuperscriptBox["Ip6a", "3"], " ", 
     SuperscriptBox["Ip6b", "4"]}], "-", 
    RowBox[{"27", " ", 
     SuperscriptBox["Ip6b", "7"]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.526210077431629*^9, 3.5262102190605783`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SuperscriptBox["Is21", "2"], "\[Equal]", 
   RowBox[{
    FractionBox[
     RowBox[{
      SuperscriptBox["Ip12", "3"], " ", "Ip6b"}], "2"], "-", 
    RowBox[{
     FractionBox["5", "4"], " ", 
     SuperscriptBox["Ip12", "2"], " ", 
     SuperscriptBox["Ip6a", "2"], " ", "Ip6b"}], "+", 
    RowBox[{"Ip12", " ", 
     SuperscriptBox["Ip6a", "4"], " ", "Ip6b"}], "-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["Ip6a", "6"], " ", "Ip6b"}], "4"], "-", 
    RowBox[{"9", " ", "Ip12", " ", "Ip6a", " ", 
     SuperscriptBox["Ip6b", "4"]}], "+", 
    RowBox[{"5", " ", 
     SuperscriptBox["Ip6a", "3"], " ", 
     SuperscriptBox["Ip6b", "4"]}], "-", 
    RowBox[{"27", " ", 
     SuperscriptBox["Ip6b", "7"]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.526210077431629*^9, 3.526210219062674*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SuperscriptBox["Is21", "2"], "\[Equal]", 
   RowBox[{
    FractionBox[
     RowBox[{
      SuperscriptBox["Ip12", "3"], " ", "Ip6b"}], "2"], "-", 
    RowBox[{
     FractionBox["5", "4"], " ", 
     SuperscriptBox["Ip12", "2"], " ", 
     SuperscriptBox["Ip6a", "2"], " ", "Ip6b"}], "+", 
    RowBox[{"Ip12", " ", 
     SuperscriptBox["Ip6a", "4"], " ", "Ip6b"}], "-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["Ip6a", "6"], " ", "Ip6b"}], "4"], "-", 
    RowBox[{"9", " ", "Ip12", " ", "Ip6a", " ", 
     SuperscriptBox["Ip6b", "4"]}], "+", 
    RowBox[{"5", " ", 
     SuperscriptBox["Ip6a", "3"], " ", 
     SuperscriptBox["Ip6b", "4"]}], "-", 
    RowBox[{"27", " ", 
     SuperscriptBox["Ip6b", "7"]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.526210077431629*^9, 3.526210219064646*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "example: ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["A", "5"], TraditionalForm]],
  FormatType->"TraditionalForm"]
}], "Subsubsection",
 CellChangeTimes->{{3.526211520456183*^9, 3.526211544920665*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "some", " ", "syzygies", " ", "are", " ", "only", " ", "found", " ", 
    RowBox[{"numerically", ":"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Syzygy", "[", "\"\<\!\(\*SubscriptBox[\(A\), \(5\)]\)\>\"", "]"}],
    "\[IndentingNewLine]", 
   RowBox[{"Syzygy", "[", "\"\<\[CapitalSigma](60)\>\"", "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Syzygy", "[", "9", "]"}], "\[IndentingNewLine]", 
   RowBox[{"Syzygy", "[", 
    RowBox[{"60", ",", "5"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.526211547805678*^9, 3.526211587763343*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SuperscriptBox["Is15", "2"], "\[Equal]", 
   RowBox[{
    RowBox[{"0.16`", " ", 
     SuperscriptBox["Ip10", "3"]}], "-", 
    RowBox[{"0.448`", " ", 
     SuperscriptBox["Ip10", "2"], " ", 
     SuperscriptBox["Ip2", "5"]}], "+", 
    RowBox[{"0.416`", " ", "Ip10", " ", 
     SuperscriptBox["Ip2", "10"]}], "-", 
    RowBox[{"0.128`", " ", 
     SuperscriptBox["Ip2", "15"]}], "+", 
    RowBox[{"0.0755417527999325`", " ", 
     SuperscriptBox["Ip10", "2"], " ", 
     SuperscriptBox["Ip2", "2"], " ", "Ip6"}], "-", 
    RowBox[{"0.12842097975988534`", " ", "Ip10", " ", 
     SuperscriptBox["Ip2", "7"], " ", "Ip6"}], "+", 
    RowBox[{"0.05287922695995321`", " ", 
     SuperscriptBox["Ip2", "12"], " ", "Ip6"}], "-", 
    RowBox[{"0.3299102928049794`", " ", "Ip10", " ", 
     SuperscriptBox["Ip2", "4"], " ", 
     SuperscriptBox["Ip6", "2"]}], "+", 
    RowBox[{"0.27819462528419925`", " ", 
     SuperscriptBox["Ip2", "9"], " ", 
     SuperscriptBox["Ip6", "2"]}], "+", 
    RowBox[{"0.473602229871294`", " ", "Ip10", " ", "Ip2", " ", 
     SuperscriptBox["Ip6", "3"]}], "-", 
    RowBox[{"0.34941320070504306`", " ", 
     SuperscriptBox["Ip2", "6"], " ", 
     SuperscriptBox["Ip6", "3"]}], "-", 
    RowBox[{"0.3975193619381577`", " ", 
     SuperscriptBox["Ip2", "3"], " ", 
     SuperscriptBox["Ip6", "4"]}], "+", 
    RowBox[{"0.07917884307259976`", " ", 
     SuperscriptBox["Ip6", "5"]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.526211588755293*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SuperscriptBox["Is15", "2"], "\[Equal]", 
   RowBox[{
    RowBox[{"0.16`", " ", 
     SuperscriptBox["Ip10", "3"]}], "-", 
    RowBox[{"0.448`", " ", 
     SuperscriptBox["Ip10", "2"], " ", 
     SuperscriptBox["Ip2", "5"]}], "+", 
    RowBox[{"0.416`", " ", "Ip10", " ", 
     SuperscriptBox["Ip2", "10"]}], "-", 
    RowBox[{"0.128`", " ", 
     SuperscriptBox["Ip2", "15"]}], "+", 
    RowBox[{"0.0755417527999325`", " ", 
     SuperscriptBox["Ip10", "2"], " ", 
     SuperscriptBox["Ip2", "2"], " ", "Ip6"}], "-", 
    RowBox[{"0.12842097975988534`", " ", "Ip10", " ", 
     SuperscriptBox["Ip2", "7"], " ", "Ip6"}], "+", 
    RowBox[{"0.05287922695995321`", " ", 
     SuperscriptBox["Ip2", "12"], " ", "Ip6"}], "-", 
    RowBox[{"0.3299102928049794`", " ", "Ip10", " ", 
     SuperscriptBox["Ip2", "4"], " ", 
     SuperscriptBox["Ip6", "2"]}], "+", 
    RowBox[{"0.27819462528419925`", " ", 
     SuperscriptBox["Ip2", "9"], " ", 
     SuperscriptBox["Ip6", "2"]}], "+", 
    RowBox[{"0.473602229871294`", " ", "Ip10", " ", "Ip2", " ", 
     SuperscriptBox["Ip6", "3"]}], "-", 
    RowBox[{"0.34941320070504306`", " ", 
     SuperscriptBox["Ip2", "6"], " ", 
     SuperscriptBox["Ip6", "3"]}], "-", 
    RowBox[{"0.3975193619381577`", " ", 
     SuperscriptBox["Ip2", "3"], " ", 
     SuperscriptBox["Ip6", "4"]}], "+", 
    RowBox[{"0.07917884307259976`", " ", 
     SuperscriptBox["Ip6", "5"]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.526211588785458*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SuperscriptBox["Is15", "2"], "\[Equal]", 
   RowBox[{
    RowBox[{"0.16`", " ", 
     SuperscriptBox["Ip10", "3"]}], "-", 
    RowBox[{"0.448`", " ", 
     SuperscriptBox["Ip10", "2"], " ", 
     SuperscriptBox["Ip2", "5"]}], "+", 
    RowBox[{"0.416`", " ", "Ip10", " ", 
     SuperscriptBox["Ip2", "10"]}], "-", 
    RowBox[{"0.128`", " ", 
     SuperscriptBox["Ip2", "15"]}], "+", 
    RowBox[{"0.0755417527999325`", " ", 
     SuperscriptBox["Ip10", "2"], " ", 
     SuperscriptBox["Ip2", "2"], " ", "Ip6"}], "-", 
    RowBox[{"0.12842097975988534`", " ", "Ip10", " ", 
     SuperscriptBox["Ip2", "7"], " ", "Ip6"}], "+", 
    RowBox[{"0.05287922695995321`", " ", 
     SuperscriptBox["Ip2", "12"], " ", "Ip6"}], "-", 
    RowBox[{"0.3299102928049794`", " ", "Ip10", " ", 
     SuperscriptBox["Ip2", "4"], " ", 
     SuperscriptBox["Ip6", "2"]}], "+", 
    RowBox[{"0.27819462528419925`", " ", 
     SuperscriptBox["Ip2", "9"], " ", 
     SuperscriptBox["Ip6", "2"]}], "+", 
    RowBox[{"0.473602229871294`", " ", "Ip10", " ", "Ip2", " ", 
     SuperscriptBox["Ip6", "3"]}], "-", 
    RowBox[{"0.34941320070504306`", " ", 
     SuperscriptBox["Ip2", "6"], " ", 
     SuperscriptBox["Ip6", "3"]}], "-", 
    RowBox[{"0.3975193619381577`", " ", 
     SuperscriptBox["Ip2", "3"], " ", 
     SuperscriptBox["Ip6", "4"]}], "+", 
    RowBox[{"0.07917884307259976`", " ", 
     SuperscriptBox["Ip6", "5"]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.526211588821272*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SuperscriptBox["Is15", "2"], "\[Equal]", 
   RowBox[{
    RowBox[{"0.16`", " ", 
     SuperscriptBox["Ip10", "3"]}], "-", 
    RowBox[{"0.448`", " ", 
     SuperscriptBox["Ip10", "2"], " ", 
     SuperscriptBox["Ip2", "5"]}], "+", 
    RowBox[{"0.416`", " ", "Ip10", " ", 
     SuperscriptBox["Ip2", "10"]}], "-", 
    RowBox[{"0.128`", " ", 
     SuperscriptBox["Ip2", "15"]}], "+", 
    RowBox[{"0.0755417527999325`", " ", 
     SuperscriptBox["Ip10", "2"], " ", 
     SuperscriptBox["Ip2", "2"], " ", "Ip6"}], "-", 
    RowBox[{"0.12842097975988534`", " ", "Ip10", " ", 
     SuperscriptBox["Ip2", "7"], " ", "Ip6"}], "+", 
    RowBox[{"0.05287922695995321`", " ", 
     SuperscriptBox["Ip2", "12"], " ", "Ip6"}], "-", 
    RowBox[{"0.3299102928049794`", " ", "Ip10", " ", 
     SuperscriptBox["Ip2", "4"], " ", 
     SuperscriptBox["Ip6", "2"]}], "+", 
    RowBox[{"0.27819462528419925`", " ", 
     SuperscriptBox["Ip2", "9"], " ", 
     SuperscriptBox["Ip6", "2"]}], "+", 
    RowBox[{"0.473602229871294`", " ", "Ip10", " ", "Ip2", " ", 
     SuperscriptBox["Ip6", "3"]}], "-", 
    RowBox[{"0.34941320070504306`", " ", 
     SuperscriptBox["Ip2", "6"], " ", 
     SuperscriptBox["Ip6", "3"]}], "-", 
    RowBox[{"0.3975193619381577`", " ", 
     SuperscriptBox["Ip2", "3"], " ", 
     SuperscriptBox["Ip6", "4"]}], "+", 
    RowBox[{"0.07917884307259976`", " ", 
     SuperscriptBox["Ip6", "5"]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.526211588859398*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["example: \[CapitalSigma](360\[Phi])", "Subsubsection",
 CellChangeTimes->{{3.526211520456183*^9, 3.526211544920665*^9}, {
   3.526211600558815*^9, 3.526211606095685*^9}, {3.526959148515781*^9, 
   3.526959150402499*^9}, 3.526959206858901*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"some", " ", "syzygies", " ", "are", " ", "still", " ", 
    RowBox[{"unknown", ":"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Syzygy", "[", "\"\<\[CapitalSigma](360\[Phi])\>\"", "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Syzygy", "[", "61", "]"}], "\[IndentingNewLine]", 
   RowBox[{"Syzygy", "[", 
    RowBox[{"1080", ",", "260"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.526211547805678*^9, 3.526211587763343*^9}, {
  3.526211632707055*^9, 3.5262116516641703`*^9}, {3.526959153805073*^9, 
  3.526959163411899*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SuperscriptBox["Is45", "2"], "\[Equal]", "UNKNOWN"}], "}"}]], "Output",
 CellChangeTimes->{3.526211588755293*^9, 3.526211652574527*^9, 
  3.526959165210309*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SuperscriptBox["Is45", "2"], "\[Equal]", "UNKNOWN"}], "}"}]], "Output",
 CellChangeTimes->{3.526211588755293*^9, 3.526211652574527*^9, 
  3.5269591652127657`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SuperscriptBox["Is45", "2"], "\[Equal]", "UNKNOWN"}], "}"}]], "Output",
 CellChangeTimes->{3.526211588755293*^9, 3.526211652574527*^9, 
  3.526959165214713*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "example: ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["T", 
    RowBox[{"163", "[", "58", "]"}]], TraditionalForm]],
  FormatType->"TraditionalForm"]
}], "Subsubsection",
 CellChangeTimes->{{3.526211520456183*^9, 3.526211544920665*^9}, {
   3.526211600558815*^9, 3.526211606095685*^9}, {3.526959148515781*^9, 
   3.526959150402499*^9}, 3.526959206858901*^9, {3.5269805061586647`*^9, 
   3.5269805634687347`*^9}, 3.526980599099471*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    SubscriptBox["T", 
     RowBox[{"163", "[", "58", "]"}]], " ", "has", " ", "116", " ", 
    RowBox[{"Syzygies", ":"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Length", "[", 
   RowBox[{
   "Syzygy", "[", "\"\<\!\(\*SubscriptBox[\(T\), \(163[58]\)]\)\>\"", "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.526980573105345*^9, 3.52698060966968*^9}, 
   3.526980650478587*^9}],

Cell[BoxData["116"], "Output",
 CellChangeTimes->{3.526980670081428*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"only", " ", "the", " ", "last", " ", "four", " ", "are", " ", 
    RowBox[{"unknown", ":"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
    "Syzygy", "[", "\"\<\!\(\*SubscriptBox[\(T\), \(163[58]\)]\)\>\"", "]"}], 
    "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Syzygy", "[", "\"\<\!\(\*SubscriptBox[\(T\), \(163[58]\)]\)\>\"", "]"}], 
    "\[LeftDoubleBracket]", "112", "\[RightDoubleBracket]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Syzygy", "[", "\"\<\!\(\*SubscriptBox[\(T\), \(163[58]\)]\)\>\"", "]"}], 
    "\[LeftDoubleBracket]", "113", "\[RightDoubleBracket]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Syzygy", "[", "\"\<\!\(\*SubscriptBox[\(T\), \(163[58]\)]\)\>\"", "]"}], 
    "\[LeftDoubleBracket]", "114", "\[RightDoubleBracket]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Syzygy", "[", "\"\<\!\(\*SubscriptBox[\(T\), \(163[58]\)]\)\>\"", "]"}], 
    "\[LeftDoubleBracket]", "115", "\[RightDoubleBracket]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Syzygy", "[", "\"\<\!\(\*SubscriptBox[\(T\), \(163[58]\)]\)\>\"", "]"}], 
    "\[LeftDoubleBracket]", "116", "\[RightDoubleBracket]"}]}]}]], "Input",
 CellChangeTimes->{{3.526211547805678*^9, 3.526211587763343*^9}, {
  3.526211632707055*^9, 3.5262116516641703`*^9}, {3.526959153805073*^9, 
  3.526959163411899*^9}, {3.526980653780509*^9, 3.526980702051013*^9}}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["Is17", "2"], "\[Equal]", 
  RowBox[{
   RowBox[{"2", " ", 
    SuperscriptBox["Ip3", "3"], " ", "Is25"}], "+", "Is34"}]}]], "Output",
 CellChangeTimes->{3.526211588755293*^9, 3.526211652574527*^9, 
  3.526959165210309*^9, 3.526980703114418*^9, 3.5269808464140673`*^9}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["Is246", "2"], "\[Equal]", 
  RowBox[{
   RowBox[{"2", " ", 
    SuperscriptBox["Ip3", "130"], " ", "Is102"}], "-", 
   RowBox[{"4", " ", "Ip117", " ", 
    SuperscriptBox["Ip3", "89"], " ", "Is108"}], "+", 
   RowBox[{
    SuperscriptBox["Ip117", "2"], " ", 
    SuperscriptBox["Ip3", "49"], " ", "Is111"}], "-", 
   RowBox[{"4", " ", "Ip117", " ", 
    SuperscriptBox["Ip3", "88"], " ", "Is111"}], "+", 
   RowBox[{
    SuperscriptBox["Ip3", "119"], " ", "Is135"}], "-", 
   RowBox[{
    SuperscriptBox["Ip117", "3"], " ", "Is141"}], "-", 
   RowBox[{"2", " ", 
    SuperscriptBox["Ip117", "2"], " ", 
    SuperscriptBox["Ip3", "39"], " ", "Is141"}], "-", 
   RowBox[{"2", " ", 
    SuperscriptBox["Ip3", "117"], " ", "Is141"}], "-", 
   RowBox[{
    SuperscriptBox["Ip3", "116"], " ", "Is144"}], "-", 
   RowBox[{"Ip163", " ", 
    SuperscriptBox["Ip3", "60"], " ", "Is149"}], "+", 
   RowBox[{"Ip163", " ", 
    SuperscriptBox["Ip3", "59"], " ", "Is152"}], "-", 
   RowBox[{
    SuperscriptBox["Ip163", "2"], " ", 
    SuperscriptBox["Ip3", "2"], " ", "Is160"}], "+", 
   RowBox[{"Ip163", " ", 
    SuperscriptBox["Ip3", "104"], " ", "Is17"}], "-", 
   RowBox[{"2", " ", 
    SuperscriptBox["Ip3", "107"], " ", "Is171"}], "-", 
   RowBox[{
    SuperscriptBox["Ip3", "104"], " ", "Is180"}], "+", 
   RowBox[{"Ip163", " ", 
    SuperscriptBox["Ip3", "47"], " ", "Is188"}], "-", 
   RowBox[{"Ip117", " ", 
    SuperscriptBox["Ip3", "60"], " ", "Is195"}], "+", 
   RowBox[{"2", " ", "Ip117", " ", 
    SuperscriptBox["Ip3", "59"], " ", "Is198"}], "+", 
   RowBox[{"2", " ", 
    SuperscriptBox["Ip3", "98"], " ", "Is198"}], "+", 
   RowBox[{"Ip117", " ", "Ip163", " ", 
    SuperscriptBox["Ip3", "2"], " ", "Is206"}], "+", 
   RowBox[{"Ip117", " ", "Ip163", " ", "Is212"}], "-", 
   RowBox[{
    SuperscriptBox["Ip163", "2"], " ", 
    SuperscriptBox["Ip3", "47"], " ", "Is25"}], "-", 
   RowBox[{"2", " ", 
    SuperscriptBox["Ip117", "2"], " ", 
    SuperscriptBox["Ip3", "72"], " ", "Is42"}], "+", 
   RowBox[{"2", " ", 
    SuperscriptBox["Ip117", "3"], " ", 
    SuperscriptBox["Ip3", "30"], " ", "Is51"}], "-", 
   RowBox[{"2", " ", "Ip117", " ", 
    SuperscriptBox["Ip3", "108"], " ", "Is51"}], "+", 
   RowBox[{"4", " ", 
    SuperscriptBox["Ip3", "147"], " ", "Is51"}], "+", 
   RowBox[{"3", " ", 
    SuperscriptBox["Ip117", "2"], " ", 
    SuperscriptBox["Ip3", "58"], " ", "Is84"}], "-", 
   RowBox[{"2", " ", "Ip117", " ", 
    SuperscriptBox["Ip3", "92"], " ", "Is99"}]}]}]], "Output",
 CellChangeTimes->{3.526211588755293*^9, 3.526211652574527*^9, 
  3.526959165210309*^9, 3.526980703114418*^9, 3.526980846419132*^9}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["Is247", "2"], "\[Equal]", "UNKNOWN"}]], "Output",
 CellChangeTimes->{3.526211588755293*^9, 3.526211652574527*^9, 
  3.526959165210309*^9, 3.526980703114418*^9, 3.526980846421063*^9}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["Is255", "2"], "\[Equal]", "UNKNOWN"}]], "Output",
 CellChangeTimes->{3.526211588755293*^9, 3.526211652574527*^9, 
  3.526959165210309*^9, 3.526980703114418*^9, 3.5269808464229116`*^9}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["Is263", "2"], "\[Equal]", "UNKNOWN"}]], "Output",
 CellChangeTimes->{3.526211588755293*^9, 3.526211652574527*^9, 
  3.526959165210309*^9, 3.526980703114418*^9, 3.526980846424741*^9}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["Is280", "2"], "\[Equal]", "UNKNOWN"}]], "Output",
 CellChangeTimes->{3.526211588755293*^9, 3.526211652574527*^9, 
  3.526959165210309*^9, 3.526980703114418*^9, 3.526980846426548*^9}]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Vacuum expectation values (VEVs) and invariant polynomials:", "Section",
 CellChangeTimes->{{3.526211674961494*^9, 3.526211682757722*^9}, {
  3.526212303154759*^9, 3.526212310367063*^9}}],

Cell[CellGroupData[{

Cell["\<\
display a fully orthonormalized basis for a polynomial of a certain degree:\
\>", "Subsection",
 CellChangeTimes->{{3.526211693327767*^9, 3.5262117192049503`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "NormBasis"}]], "Input",
 CellChangeTimes->{{3.526211722222499*^9, 3.5262117300165167`*^9}}],

Cell[BoxData[
 StyleBox["\<\"NormBasis[deg] returns an orthonormalized basis for \
polynomials of degree deg.\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.5267951882459707`*^9},
 CellTags->"Info3526802388-2904771"]
}, Open  ]],

Cell[CellGroupData[{

Cell["examples:", "Subsubsection",
 CellChangeTimes->{{3.526211734620963*^9, 3.526211746380396*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"NormBasis", "[", "3", "]"}]], "Input",
 CellChangeTimes->{{3.526211739500423*^9, 3.5262117505817223`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    SuperscriptBox["x", "3"], 
    SqrtBox["6"]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "2"], " ", "y"}], 
     SqrtBox["2"]]}], ",", 
   FractionBox[
    RowBox[{"x", " ", 
     SuperscriptBox["y", "2"]}], 
    SqrtBox["2"]], ",", 
   RowBox[{"-", 
    FractionBox[
     SuperscriptBox["y", "3"], 
     SqrtBox["6"]]}], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "2"], " ", "z"}], 
     SqrtBox["2"]]}], ",", 
   RowBox[{"x", " ", "y", " ", "z"}], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["y", "2"], " ", "z"}], 
     SqrtBox["2"]]}], ",", 
   FractionBox[
    RowBox[{"x", " ", 
     SuperscriptBox["z", "2"]}], 
    SqrtBox["2"]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"y", " ", 
      SuperscriptBox["z", "2"]}], 
     SqrtBox["2"]]}], ",", 
   RowBox[{"-", 
    FractionBox[
     SuperscriptBox["z", "3"], 
     SqrtBox["6"]]}]}], "}"}]], "Output",
 CellChangeTimes->{3.526211751185503*^9, 3.52679518965757*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"NormBasis", "[", "15", "]"}]], "Input",
 CellChangeTimes->{{3.526211756421636*^9, 3.526211763332136*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    SuperscriptBox["x", "15"], 
    RowBox[{"30240", " ", 
     SqrtBox["1430"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "14"], " ", "y"}], 
     RowBox[{"10080", " ", 
      SqrtBox["858"]}]]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["x", "13"], " ", 
     SuperscriptBox["y", "2"]}], 
    RowBox[{"1440", " ", 
     SqrtBox["6006"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "12"], " ", 
      SuperscriptBox["y", "3"]}], 
     RowBox[{"4320", " ", 
      SqrtBox["154"]}]]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["x", "11"], " ", 
     SuperscriptBox["y", "4"]}], 
    RowBox[{"1440", " ", 
     SqrtBox["462"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "10"], " ", 
      SuperscriptBox["y", "5"]}], 
     RowBox[{"1440", " ", 
      SqrtBox["210"]}]]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["x", "9"], " ", 
     SuperscriptBox["y", "6"]}], 
    RowBox[{"4320", " ", 
     SqrtBox["14"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "8"], " ", 
      SuperscriptBox["y", "7"]}], 
     RowBox[{"10080", " ", 
      SqrtBox["2"]}]]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["x", "7"], " ", 
     SuperscriptBox["y", "8"]}], 
    RowBox[{"10080", " ", 
     SqrtBox["2"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "6"], " ", 
      SuperscriptBox["y", "9"]}], 
     RowBox[{"4320", " ", 
      SqrtBox["14"]}]]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["x", "5"], " ", 
     SuperscriptBox["y", "10"]}], 
    RowBox[{"1440", " ", 
     SqrtBox["210"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "4"], " ", 
      SuperscriptBox["y", "11"]}], 
     RowBox[{"1440", " ", 
      SqrtBox["462"]}]]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["x", "3"], " ", 
     SuperscriptBox["y", "12"]}], 
    RowBox[{"4320", " ", 
     SqrtBox["154"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "2"], " ", 
      SuperscriptBox["y", "13"]}], 
     RowBox[{"1440", " ", 
      SqrtBox["6006"]}]]}], ",", 
   FractionBox[
    RowBox[{"x", " ", 
     SuperscriptBox["y", "14"]}], 
    RowBox[{"10080", " ", 
     SqrtBox["858"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     SuperscriptBox["y", "15"], 
     RowBox[{"30240", " ", 
      SqrtBox["1430"]}]]}], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "14"], " ", "z"}], 
     RowBox[{"10080", " ", 
      SqrtBox["858"]}]]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["x", "13"], " ", "y", " ", "z"}], 
    RowBox[{"1440", " ", 
     SqrtBox["3003"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "12"], " ", 
      SuperscriptBox["y", "2"], " ", "z"}], 
     RowBox[{"1440", " ", 
      SqrtBox["462"]}]]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["x", "11"], " ", 
     SuperscriptBox["y", "3"], " ", "z"}], 
    RowBox[{"720", " ", 
     SqrtBox["462"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "10"], " ", 
      SuperscriptBox["y", "4"], " ", "z"}], 
     RowBox[{"1440", " ", 
      SqrtBox["42"]}]]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["x", "9"], " ", 
     SuperscriptBox["y", "5"], " ", "z"}], 
    RowBox[{"1440", " ", 
     SqrtBox["21"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "8"], " ", 
      SuperscriptBox["y", "6"], " ", "z"}], 
     RowBox[{"1440", " ", 
      SqrtBox["14"]}]]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["x", "7"], " ", 
     SuperscriptBox["y", "7"], " ", "z"}], "5040"], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "6"], " ", 
      SuperscriptBox["y", "8"], " ", "z"}], 
     RowBox[{"1440", " ", 
      SqrtBox["14"]}]]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["x", "5"], " ", 
     SuperscriptBox["y", "9"], " ", "z"}], 
    RowBox[{"1440", " ", 
     SqrtBox["21"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "4"], " ", 
      SuperscriptBox["y", "10"], " ", "z"}], 
     RowBox[{"1440", " ", 
      SqrtBox["42"]}]]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["x", "3"], " ", 
     SuperscriptBox["y", "11"], " ", "z"}], 
    RowBox[{"720", " ", 
     SqrtBox["462"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "2"], " ", 
      SuperscriptBox["y", "12"], " ", "z"}], 
     RowBox[{"1440", " ", 
      SqrtBox["462"]}]]}], ",", 
   FractionBox[
    RowBox[{"x", " ", 
     SuperscriptBox["y", "13"], " ", "z"}], 
    RowBox[{"1440", " ", 
     SqrtBox["3003"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["y", "14"], " ", "z"}], 
     RowBox[{"10080", " ", 
      SqrtBox["858"]}]]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["x", "13"], " ", 
     SuperscriptBox["z", "2"]}], 
    RowBox[{"1440", " ", 
     SqrtBox["6006"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "12"], " ", "y", " ", 
      SuperscriptBox["z", "2"]}], 
     RowBox[{"1440", " ", 
      SqrtBox["462"]}]]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["x", "11"], " ", 
     SuperscriptBox["y", "2"], " ", 
     SuperscriptBox["z", "2"]}], 
    RowBox[{"1440", " ", 
     SqrtBox["77"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "10"], " ", 
      SuperscriptBox["y", "3"], " ", 
      SuperscriptBox["z", "2"]}], 
     RowBox[{"1440", " ", 
      SqrtBox["21"]}]]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["x", "9"], " ", 
     SuperscriptBox["y", "4"], " ", 
     SuperscriptBox["z", "2"]}], 
    RowBox[{"288", " ", 
     SqrtBox["210"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "8"], " ", 
      SuperscriptBox["y", "5"], " ", 
      SuperscriptBox["z", "2"]}], 
     RowBox[{"480", " ", 
      SqrtBox["42"]}]]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["x", "7"], " ", 
     SuperscriptBox["y", "6"], " ", 
     SuperscriptBox["z", "2"]}], 
    RowBox[{"720", " ", 
     SqrtBox["14"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "6"], " ", 
      SuperscriptBox["y", "7"], " ", 
      SuperscriptBox["z", "2"]}], 
     RowBox[{"720", " ", 
      SqrtBox["14"]}]]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["x", "5"], " ", 
     SuperscriptBox["y", "8"], " ", 
     SuperscriptBox["z", "2"]}], 
    RowBox[{"480", " ", 
     SqrtBox["42"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "4"], " ", 
      SuperscriptBox["y", "9"], " ", 
      SuperscriptBox["z", "2"]}], 
     RowBox[{"288", " ", 
      SqrtBox["210"]}]]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["x", "3"], " ", 
     SuperscriptBox["y", "10"], " ", 
     SuperscriptBox["z", "2"]}], 
    RowBox[{"1440", " ", 
     SqrtBox["21"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "2"], " ", 
      SuperscriptBox["y", "11"], " ", 
      SuperscriptBox["z", "2"]}], 
     RowBox[{"1440", " ", 
      SqrtBox["77"]}]]}], ",", 
   FractionBox[
    RowBox[{"x", " ", 
     SuperscriptBox["y", "12"], " ", 
     SuperscriptBox["z", "2"]}], 
    RowBox[{"1440", " ", 
     SqrtBox["462"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["y", "13"], " ", 
      SuperscriptBox["z", "2"]}], 
     RowBox[{"1440", " ", 
      SqrtBox["6006"]}]]}], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "12"], " ", 
      SuperscriptBox["z", "3"]}], 
     RowBox[{"4320", " ", 
      SqrtBox["154"]}]]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["x", "11"], " ", "y", " ", 
     SuperscriptBox["z", "3"]}], 
    RowBox[{"720", " ", 
     SqrtBox["462"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "10"], " ", 
      SuperscriptBox["y", "2"], " ", 
      SuperscriptBox["z", "3"]}], 
     RowBox[{"1440", " ", 
      SqrtBox["21"]}]]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["x", "9"], " ", 
     SuperscriptBox["y", "3"], " ", 
     SuperscriptBox["z", "3"]}], 
    RowBox[{"432", " ", 
     SqrtBox["70"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "8"], " ", 
      SuperscriptBox["y", "4"], " ", 
      SuperscriptBox["z", "3"]}], 
     RowBox[{"288", " ", 
      SqrtBox["70"]}]]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["x", "7"], " ", 
     SuperscriptBox["y", "5"], " ", 
     SuperscriptBox["z", "3"]}], 
    RowBox[{"720", " ", 
     SqrtBox["7"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "6"], " ", 
      SuperscriptBox["y", "6"], " ", 
      SuperscriptBox["z", "3"]}], 
     RowBox[{"720", " ", 
      SqrtBox["6"]}]]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["x", "5"], " ", 
     SuperscriptBox["y", "7"], " ", 
     SuperscriptBox["z", "3"]}], 
    RowBox[{"720", " ", 
     SqrtBox["7"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "4"], " ", 
      SuperscriptBox["y", "8"], " ", 
      SuperscriptBox["z", "3"]}], 
     RowBox[{"288", " ", 
      SqrtBox["70"]}]]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["x", "3"], " ", 
     SuperscriptBox["y", "9"], " ", 
     SuperscriptBox["z", "3"]}], 
    RowBox[{"432", " ", 
     SqrtBox["70"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "2"], " ", 
      SuperscriptBox["y", "10"], " ", 
      SuperscriptBox["z", "3"]}], 
     RowBox[{"1440", " ", 
      SqrtBox["21"]}]]}], ",", 
   FractionBox[
    RowBox[{"x", " ", 
     SuperscriptBox["y", "11"], " ", 
     SuperscriptBox["z", "3"]}], 
    RowBox[{"720", " ", 
     SqrtBox["462"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["y", "12"], " ", 
      SuperscriptBox["z", "3"]}], 
     RowBox[{"4320", " ", 
      SqrtBox["154"]}]]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["x", "11"], " ", 
     SuperscriptBox["z", "4"]}], 
    RowBox[{"1440", " ", 
     SqrtBox["462"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "10"], " ", "y", " ", 
      SuperscriptBox["z", "4"]}], 
     RowBox[{"1440", " ", 
      SqrtBox["42"]}]]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["x", "9"], " ", 
     SuperscriptBox["y", "2"], " ", 
     SuperscriptBox["z", "4"]}], 
    RowBox[{"288", " ", 
     SqrtBox["210"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "8"], " ", 
      SuperscriptBox["y", "3"], " ", 
      SuperscriptBox["z", "4"]}], 
     RowBox[{"288", " ", 
      SqrtBox["70"]}]]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["x", "7"], " ", 
     SuperscriptBox["y", "4"], " ", 
     SuperscriptBox["z", "4"]}], 
    RowBox[{"288", " ", 
     SqrtBox["35"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "6"], " ", 
      SuperscriptBox["y", "5"], " ", 
      SuperscriptBox["z", "4"]}], "1440"]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["x", "5"], " ", 
     SuperscriptBox["y", "6"], " ", 
     SuperscriptBox["z", "4"]}], "1440"], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "4"], " ", 
      SuperscriptBox["y", "7"], " ", 
      SuperscriptBox["z", "4"]}], 
     RowBox[{"288", " ", 
      SqrtBox["35"]}]]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["x", "3"], " ", 
     SuperscriptBox["y", "8"], " ", 
     SuperscriptBox["z", "4"]}], 
    RowBox[{"288", " ", 
     SqrtBox["70"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "2"], " ", 
      SuperscriptBox["y", "9"], " ", 
      SuperscriptBox["z", "4"]}], 
     RowBox[{"288", " ", 
      SqrtBox["210"]}]]}], ",", 
   FractionBox[
    RowBox[{"x", " ", 
     SuperscriptBox["y", "10"], " ", 
     SuperscriptBox["z", "4"]}], 
    RowBox[{"1440", " ", 
     SqrtBox["42"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["y", "11"], " ", 
      SuperscriptBox["z", "4"]}], 
     RowBox[{"1440", " ", 
      SqrtBox["462"]}]]}], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "10"], " ", 
      SuperscriptBox["z", "5"]}], 
     RowBox[{"1440", " ", 
      SqrtBox["210"]}]]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["x", "9"], " ", "y", " ", 
     SuperscriptBox["z", "5"]}], 
    RowBox[{"1440", " ", 
     SqrtBox["21"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "8"], " ", 
      SuperscriptBox["y", "2"], " ", 
      SuperscriptBox["z", "5"]}], 
     RowBox[{"480", " ", 
      SqrtBox["42"]}]]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["x", "7"], " ", 
     SuperscriptBox["y", "3"], " ", 
     SuperscriptBox["z", "5"]}], 
    RowBox[{"720", " ", 
     SqrtBox["7"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "6"], " ", 
      SuperscriptBox["y", "4"], " ", 
      SuperscriptBox["z", "5"]}], "1440"]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["x", "5"], " ", 
     SuperscriptBox["y", "5"], " ", 
     SuperscriptBox["z", "5"]}], 
    RowBox[{"240", " ", 
     SqrtBox["30"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "4"], " ", 
      SuperscriptBox["y", "6"], " ", 
      SuperscriptBox["z", "5"]}], "1440"]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["x", "3"], " ", 
     SuperscriptBox["y", "7"], " ", 
     SuperscriptBox["z", "5"]}], 
    RowBox[{"720", " ", 
     SqrtBox["7"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "2"], " ", 
      SuperscriptBox["y", "8"], " ", 
      SuperscriptBox["z", "5"]}], 
     RowBox[{"480", " ", 
      SqrtBox["42"]}]]}], ",", 
   FractionBox[
    RowBox[{"x", " ", 
     SuperscriptBox["y", "9"], " ", 
     SuperscriptBox["z", "5"]}], 
    RowBox[{"1440", " ", 
     SqrtBox["21"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["y", "10"], " ", 
      SuperscriptBox["z", "5"]}], 
     RowBox[{"1440", " ", 
      SqrtBox["210"]}]]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["x", "9"], " ", 
     SuperscriptBox["z", "6"]}], 
    RowBox[{"4320", " ", 
     SqrtBox["14"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "8"], " ", "y", " ", 
      SuperscriptBox["z", "6"]}], 
     RowBox[{"1440", " ", 
      SqrtBox["14"]}]]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["x", "7"], " ", 
     SuperscriptBox["y", "2"], " ", 
     SuperscriptBox["z", "6"]}], 
    RowBox[{"720", " ", 
     SqrtBox["14"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "6"], " ", 
      SuperscriptBox["y", "3"], " ", 
      SuperscriptBox["z", "6"]}], 
     RowBox[{"720", " ", 
      SqrtBox["6"]}]]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["x", "5"], " ", 
     SuperscriptBox["y", "4"], " ", 
     SuperscriptBox["z", "6"]}], "1440"], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "4"], " ", 
      SuperscriptBox["y", "5"], " ", 
      SuperscriptBox["z", "6"]}], "1440"]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["x", "3"], " ", 
     SuperscriptBox["y", "6"], " ", 
     SuperscriptBox["z", "6"]}], 
    RowBox[{"720", " ", 
     SqrtBox["6"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "2"], " ", 
      SuperscriptBox["y", "7"], " ", 
      SuperscriptBox["z", "6"]}], 
     RowBox[{"720", " ", 
      SqrtBox["14"]}]]}], ",", 
   FractionBox[
    RowBox[{"x", " ", 
     SuperscriptBox["y", "8"], " ", 
     SuperscriptBox["z", "6"]}], 
    RowBox[{"1440", " ", 
     SqrtBox["14"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["y", "9"], " ", 
      SuperscriptBox["z", "6"]}], 
     RowBox[{"4320", " ", 
      SqrtBox["14"]}]]}], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "8"], " ", 
      SuperscriptBox["z", "7"]}], 
     RowBox[{"10080", " ", 
      SqrtBox["2"]}]]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["x", "7"], " ", "y", " ", 
     SuperscriptBox["z", "7"]}], "5040"], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "6"], " ", 
      SuperscriptBox["y", "2"], " ", 
      SuperscriptBox["z", "7"]}], 
     RowBox[{"720", " ", 
      SqrtBox["14"]}]]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["x", "5"], " ", 
     SuperscriptBox["y", "3"], " ", 
     SuperscriptBox["z", "7"]}], 
    RowBox[{"720", " ", 
     SqrtBox["7"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "4"], " ", 
      SuperscriptBox["y", "4"], " ", 
      SuperscriptBox["z", "7"]}], 
     RowBox[{"288", " ", 
      SqrtBox["35"]}]]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["x", "3"], " ", 
     SuperscriptBox["y", "5"], " ", 
     SuperscriptBox["z", "7"]}], 
    RowBox[{"720", " ", 
     SqrtBox["7"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "2"], " ", 
      SuperscriptBox["y", "6"], " ", 
      SuperscriptBox["z", "7"]}], 
     RowBox[{"720", " ", 
      SqrtBox["14"]}]]}], ",", 
   FractionBox[
    RowBox[{"x", " ", 
     SuperscriptBox["y", "7"], " ", 
     SuperscriptBox["z", "7"]}], "5040"], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["y", "8"], " ", 
      SuperscriptBox["z", "7"]}], 
     RowBox[{"10080", " ", 
      SqrtBox["2"]}]]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["x", "7"], " ", 
     SuperscriptBox["z", "8"]}], 
    RowBox[{"10080", " ", 
     SqrtBox["2"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "6"], " ", "y", " ", 
      SuperscriptBox["z", "8"]}], 
     RowBox[{"1440", " ", 
      SqrtBox["14"]}]]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["x", "5"], " ", 
     SuperscriptBox["y", "2"], " ", 
     SuperscriptBox["z", "8"]}], 
    RowBox[{"480", " ", 
     SqrtBox["42"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "4"], " ", 
      SuperscriptBox["y", "3"], " ", 
      SuperscriptBox["z", "8"]}], 
     RowBox[{"288", " ", 
      SqrtBox["70"]}]]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["x", "3"], " ", 
     SuperscriptBox["y", "4"], " ", 
     SuperscriptBox["z", "8"]}], 
    RowBox[{"288", " ", 
     SqrtBox["70"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "2"], " ", 
      SuperscriptBox["y", "5"], " ", 
      SuperscriptBox["z", "8"]}], 
     RowBox[{"480", " ", 
      SqrtBox["42"]}]]}], ",", 
   FractionBox[
    RowBox[{"x", " ", 
     SuperscriptBox["y", "6"], " ", 
     SuperscriptBox["z", "8"]}], 
    RowBox[{"1440", " ", 
     SqrtBox["14"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["y", "7"], " ", 
      SuperscriptBox["z", "8"]}], 
     RowBox[{"10080", " ", 
      SqrtBox["2"]}]]}], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "6"], " ", 
      SuperscriptBox["z", "9"]}], 
     RowBox[{"4320", " ", 
      SqrtBox["14"]}]]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["x", "5"], " ", "y", " ", 
     SuperscriptBox["z", "9"]}], 
    RowBox[{"1440", " ", 
     SqrtBox["21"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "4"], " ", 
      SuperscriptBox["y", "2"], " ", 
      SuperscriptBox["z", "9"]}], 
     RowBox[{"288", " ", 
      SqrtBox["210"]}]]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["x", "3"], " ", 
     SuperscriptBox["y", "3"], " ", 
     SuperscriptBox["z", "9"]}], 
    RowBox[{"432", " ", 
     SqrtBox["70"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "2"], " ", 
      SuperscriptBox["y", "4"], " ", 
      SuperscriptBox["z", "9"]}], 
     RowBox[{"288", " ", 
      SqrtBox["210"]}]]}], ",", 
   FractionBox[
    RowBox[{"x", " ", 
     SuperscriptBox["y", "5"], " ", 
     SuperscriptBox["z", "9"]}], 
    RowBox[{"1440", " ", 
     SqrtBox["21"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["y", "6"], " ", 
      SuperscriptBox["z", "9"]}], 
     RowBox[{"4320", " ", 
      SqrtBox["14"]}]]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["x", "5"], " ", 
     SuperscriptBox["z", "10"]}], 
    RowBox[{"1440", " ", 
     SqrtBox["210"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "4"], " ", "y", " ", 
      SuperscriptBox["z", "10"]}], 
     RowBox[{"1440", " ", 
      SqrtBox["42"]}]]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["x", "3"], " ", 
     SuperscriptBox["y", "2"], " ", 
     SuperscriptBox["z", "10"]}], 
    RowBox[{"1440", " ", 
     SqrtBox["21"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "2"], " ", 
      SuperscriptBox["y", "3"], " ", 
      SuperscriptBox["z", "10"]}], 
     RowBox[{"1440", " ", 
      SqrtBox["21"]}]]}], ",", 
   FractionBox[
    RowBox[{"x", " ", 
     SuperscriptBox["y", "4"], " ", 
     SuperscriptBox["z", "10"]}], 
    RowBox[{"1440", " ", 
     SqrtBox["42"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["y", "5"], " ", 
      SuperscriptBox["z", "10"]}], 
     RowBox[{"1440", " ", 
      SqrtBox["210"]}]]}], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "4"], " ", 
      SuperscriptBox["z", "11"]}], 
     RowBox[{"1440", " ", 
      SqrtBox["462"]}]]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["x", "3"], " ", "y", " ", 
     SuperscriptBox["z", "11"]}], 
    RowBox[{"720", " ", 
     SqrtBox["462"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "2"], " ", 
      SuperscriptBox["y", "2"], " ", 
      SuperscriptBox["z", "11"]}], 
     RowBox[{"1440", " ", 
      SqrtBox["77"]}]]}], ",", 
   FractionBox[
    RowBox[{"x", " ", 
     SuperscriptBox["y", "3"], " ", 
     SuperscriptBox["z", "11"]}], 
    RowBox[{"720", " ", 
     SqrtBox["462"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["y", "4"], " ", 
      SuperscriptBox["z", "11"]}], 
     RowBox[{"1440", " ", 
      SqrtBox["462"]}]]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["x", "3"], " ", 
     SuperscriptBox["z", "12"]}], 
    RowBox[{"4320", " ", 
     SqrtBox["154"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "2"], " ", "y", " ", 
      SuperscriptBox["z", "12"]}], 
     RowBox[{"1440", " ", 
      SqrtBox["462"]}]]}], ",", 
   FractionBox[
    RowBox[{"x", " ", 
     SuperscriptBox["y", "2"], " ", 
     SuperscriptBox["z", "12"]}], 
    RowBox[{"1440", " ", 
     SqrtBox["462"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["y", "3"], " ", 
      SuperscriptBox["z", "12"]}], 
     RowBox[{"4320", " ", 
      SqrtBox["154"]}]]}], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "2"], " ", 
      SuperscriptBox["z", "13"]}], 
     RowBox[{"1440", " ", 
      SqrtBox["6006"]}]]}], ",", 
   FractionBox[
    RowBox[{"x", " ", "y", " ", 
     SuperscriptBox["z", "13"]}], 
    RowBox[{"1440", " ", 
     SqrtBox["3003"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["y", "2"], " ", 
      SuperscriptBox["z", "13"]}], 
     RowBox[{"1440", " ", 
      SqrtBox["6006"]}]]}], ",", 
   FractionBox[
    RowBox[{"x", " ", 
     SuperscriptBox["z", "14"]}], 
    RowBox[{"10080", " ", 
     SqrtBox["858"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"y", " ", 
      SuperscriptBox["z", "14"]}], 
     RowBox[{"10080", " ", 
      SqrtBox["858"]}]]}], ",", 
   RowBox[{"-", 
    FractionBox[
     SuperscriptBox["z", "15"], 
     RowBox[{"30240", " ", 
      SqrtBox["1430"]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.526211757167231*^9, 3.526211763921574*^9}, 
   3.526795191886979*^9}]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
translate an invariant polynomial into the corresponding VEV:\
\>", "Subsection",
 CellChangeTimes->{{3.5262117793258543`*^9, 3.526211790523322*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "VEVFromInv"}]], "Input",
 CellChangeTimes->{{3.526211797379072*^9, 3.526211802524592*^9}}],

Cell[BoxData[
 StyleBox["\<\"VEVFromInv[deg,poly] returns the VEV corresponding to the \
invariant polynomial\\npoly of degree deg.\"\>", "MSG"]], "Print", \
"PrintUsage",
 CellChangeTimes->{3.526795199815443*^9},
 CellTags->"Info3526802399-6783049"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "example: primary invariants of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["A", "4"], TraditionalForm]],
  FormatType->"TraditionalForm"]
}], "Subsubsection",
 CellChangeTimes->{{3.526211816060972*^9, 3.5262118243097763`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"invs", "=", 
  RowBox[{
  "PrimInv", "[", "\"\<\!\(\*SubscriptBox[\(A\), \(4\)]\)\>\"", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.5262118294970922`*^9, 3.5262118410354757`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["x", "2"], "+", 
    SuperscriptBox["y", "2"], "+", 
    SuperscriptBox["z", "2"]}], ",", 
   RowBox[{"x", " ", "y", " ", "z"}], ",", 
   RowBox[{
    SuperscriptBox["x", "4"], "+", 
    SuperscriptBox["y", "4"], "+", 
    SuperscriptBox["z", "4"]}]}], "}"}]], "Output",
 CellChangeTimes->{3.52621184196634*^9, 3.5262270057533712`*^9, 
  3.526795203898423*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"VEVFromInv", "[", 
  RowBox[{"2", ",", 
   RowBox[{"invs", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"VEVFromInv", "[", 
  RowBox[{"3", ",", 
   RowBox[{"invs", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"VEVFromInv", "[", 
  RowBox[{"4", ",", 
   RowBox[{"invs", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.526211849541448*^9, 3.526211872803055*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SqrtBox["2"], ",", "0", ",", 
   SqrtBox["2"], ",", "0", ",", "0", ",", 
   SqrtBox["2"]}], "}"}]], "Output",
 CellChangeTimes->{3.526211873984054*^9, 3.5262270080757227`*^9, 
  3.526795205465355*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "1", ",", "0", ",", "0", 
   ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.526211873984054*^9, 3.5262270080757227`*^9, 
  3.52679520546828*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"2", " ", 
    SqrtBox["6"]}], ",", "0", ",", "0", ",", "0", ",", 
   RowBox[{"2", " ", 
    SqrtBox["6"]}], ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", 
   RowBox[{"2", " ", 
    SqrtBox["6"]}]}], "}"}]], "Output",
 CellChangeTimes->{3.526211873984054*^9, 3.5262270080757227`*^9, 
  3.526795205524077*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "example: secondary invariant of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[CapitalDelta]", "(", 
    RowBox[{"3", "\[CenterDot]", 
     SuperscriptBox["10", "2"]}], ")"}], TraditionalForm]]],
 " - creating a basis for polynomials of high degree may take some time"
}], "Subsubsection",
 CellChangeTimes->{{3.526211880251277*^9, 3.526211934320437*^9}, {
  3.526212132828559*^9, 3.526212132995522*^9}, {3.5267953142032747`*^9, 
  3.52679532980231*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"inv2", "=", 
  RowBox[{
   RowBox[{"SecInv", "[", "\"\<\[CapitalDelta](300)\>\"", "]"}], 
   "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}]], "Input",
 CellChangeTimes->{{3.5262119388754597`*^9, 3.526211950449356*^9}, {
  3.526212151502787*^9, 3.526212161332445*^9}}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["x", "30"], "+", 
  SuperscriptBox["y", "30"], "+", 
  SuperscriptBox["z", "30"]}]], "Output",
 CellChangeTimes->{3.5262119513523607`*^9, 3.5262120363231277`*^9, 
  3.526212161986627*^9, 3.526795211374008*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"VEVFromInv", "[", 
  RowBox[{"30", ",", "inv2"}], "]"}]], "Input",
 CellChangeTimes->{{3.526212164877881*^9, 3.526212168230616*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"15692092416000", " ", 
    SqrtBox["1077205"]}], ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", 
   RowBox[{"15692092416000", " ", 
    SqrtBox["1077205"]}], ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", 
   RowBox[{"15692092416000", " ", 
    SqrtBox["1077205"]}]}], "}"}]], "Output",
 CellChangeTimes->{3.526212169876102*^9, 3.526795234363584*^9, 
  3.5267953433342257`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
example: lowest order invariant of \[CapitalSigma](168) - example from our \
paper\
\>", "Subsubsection",
 CellChangeTimes->{{3.526211880251277*^9, 3.526211934320437*^9}, {
   3.526212132828559*^9, 3.526212132995522*^9}, {3.526575362982177*^9, 
   3.526575370432556*^9}, {3.5265756118587513`*^9, 3.526575615201408*^9}, 
   3.526576784810669*^9, {3.526959329528047*^9, 3.526959336749235*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"inv168", "=", 
  RowBox[{
   RowBox[{"PrimInv", "[", "\"\<\[CapitalSigma](168)\>\"", "]"}], 
   "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}]], "Input",
 CellChangeTimes->{{3.5262119388754597`*^9, 3.526211950449356*^9}, {
  3.526212151502787*^9, 3.526212161332445*^9}, {3.52657537897692*^9, 
  3.5265753921285057`*^9}, {3.5265767528305197`*^9, 3.5265767795647297`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"x", " ", 
   SuperscriptBox["y", "3"]}], "+", 
  RowBox[{
   SuperscriptBox["x", "3"], " ", "z"}], "+", 
  RowBox[{"y", " ", 
   SuperscriptBox["z", "3"]}]}]], "Output",
 CellChangeTimes->{
  3.5262119513523607`*^9, 3.5262120363231277`*^9, 3.526212161986627*^9, 
   3.526575393008985*^9, {3.526576755853568*^9, 3.5265767871887617`*^9}, 
   3.526795238570075*^9, 3.526798061308714*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"B40basis", "=", 
  RowBox[{"NormBasis", "[", "4", "]"}]}]], "Input",
 CellChangeTimes->{{3.5265754085524397`*^9, 3.526575417096271*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    SuperscriptBox["x", "4"], 
    RowBox[{"2", " ", 
     SqrtBox["6"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "3"], " ", "y"}], 
     SqrtBox["6"]]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["x", "2"], " ", 
     SuperscriptBox["y", "2"]}], "2"], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"x", " ", 
      SuperscriptBox["y", "3"]}], 
     SqrtBox["6"]]}], ",", 
   FractionBox[
    SuperscriptBox["y", "4"], 
    RowBox[{"2", " ", 
     SqrtBox["6"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "3"], " ", "z"}], 
     SqrtBox["6"]]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["x", "2"], " ", "y", " ", "z"}], 
    SqrtBox["2"]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"x", " ", 
      SuperscriptBox["y", "2"], " ", "z"}], 
     SqrtBox["2"]]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["y", "3"], " ", "z"}], 
    SqrtBox["6"]], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["x", "2"], " ", 
     SuperscriptBox["z", "2"]}], "2"], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"x", " ", "y", " ", 
      SuperscriptBox["z", "2"]}], 
     SqrtBox["2"]]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["y", "2"], " ", 
     SuperscriptBox["z", "2"]}], "2"], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"x", " ", 
      SuperscriptBox["z", "3"]}], 
     SqrtBox["6"]]}], ",", 
   FractionBox[
    RowBox[{"y", " ", 
     SuperscriptBox["z", "3"]}], 
    SqrtBox["6"]], ",", 
   FractionBox[
    SuperscriptBox["z", "4"], 
    RowBox[{"2", " ", 
     SqrtBox["6"]}]]}], "}"}]], "Output",
 CellChangeTimes->{3.52657541783385*^9, 3.5267952401218977`*^9, 
  3.5267953549276457`*^9, 3.526795465423081*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"v40", "=", 
  RowBox[{
   RowBox[{"VEVFromInv", "[", 
    RowBox[{"4", ",", "inv168"}], "]"}], "/", 
   RowBox[{"(", 
    RowBox[{"-", 
     SqrtBox["6"]}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.526212164877881*^9, 3.526212168230616*^9}, {
  3.526575398385756*^9, 3.52657547926996*^9}, {3.5267952553295393`*^9, 
  3.5267952575818043`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0", ",", "0", ",", "0", ",", "1", ",", "0", ",", "1", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   RowBox[{"-", "1"}], ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{
  3.526212169876102*^9, {3.526575451638013*^9, 3.526575479699646*^9}, {
   3.526795243191202*^9, 3.526795258065373*^9}, 3.5267953560762987`*^9, 
   3.526795466676064*^9, 3.5267980646987123`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
example: lowest order invariant of \[CapitalDelta](96) - example from our \
paper\
\>", "Subsubsection",
 CellChangeTimes->{{3.526211880251277*^9, 3.526211934320437*^9}, {
  3.526212132828559*^9, 3.526212132995522*^9}, {3.526575362982177*^9, 
  3.526575370432556*^9}, {3.5265767907939873`*^9, 3.526576794024407*^9}, {
  3.5269593388053513`*^9, 3.526959343773016*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"inv96", "=", 
  RowBox[{
   RowBox[{"PrimInv", "[", "\"\<\[CapitalDelta](96)\>\"", "]"}], 
   "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}]], "Input",
 CellChangeTimes->{{3.5262119388754597`*^9, 3.526211950449356*^9}, {
  3.526212151502787*^9, 3.526212161332445*^9}, {3.52657537897692*^9, 
  3.5265753921285057`*^9}, {3.52657679731454*^9, 3.5265768032337313`*^9}}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["x", "4"], "+", 
  SuperscriptBox["y", "4"], "+", 
  SuperscriptBox["z", "4"]}]], "Output",
 CellChangeTimes->{3.5262119513523607`*^9, 3.5262120363231277`*^9, 
  3.526212161986627*^9, 3.526575393008985*^9, 3.526576804900599*^9, 
  3.526798169233309*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"B40basis", "=", 
  RowBox[{"NormBasis", "[", "4", "]"}]}]], "Input",
 CellChangeTimes->{{3.5265754085524397`*^9, 3.526575417096271*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    SuperscriptBox["x", "4"], 
    RowBox[{"2", " ", 
     SqrtBox["6"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "3"], " ", "y"}], 
     SqrtBox["6"]]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["x", "2"], " ", 
     SuperscriptBox["y", "2"]}], "2"], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"x", " ", 
      SuperscriptBox["y", "3"]}], 
     SqrtBox["6"]]}], ",", 
   FractionBox[
    SuperscriptBox["y", "4"], 
    RowBox[{"2", " ", 
     SqrtBox["6"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "3"], " ", "z"}], 
     SqrtBox["6"]]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["x", "2"], " ", "y", " ", "z"}], 
    SqrtBox["2"]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"x", " ", 
      SuperscriptBox["y", "2"], " ", "z"}], 
     SqrtBox["2"]]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["y", "3"], " ", "z"}], 
    SqrtBox["6"]], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["x", "2"], " ", 
     SuperscriptBox["z", "2"]}], "2"], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"x", " ", "y", " ", 
      SuperscriptBox["z", "2"]}], 
     SqrtBox["2"]]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["y", "2"], " ", 
     SuperscriptBox["z", "2"]}], "2"], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"x", " ", 
      SuperscriptBox["z", "3"]}], 
     SqrtBox["6"]]}], ",", 
   FractionBox[
    RowBox[{"y", " ", 
     SuperscriptBox["z", "3"]}], 
    SqrtBox["6"]], ",", 
   FractionBox[
    SuperscriptBox["z", "4"], 
    RowBox[{"2", " ", 
     SqrtBox["6"]}]]}], "}"}]], "Output",
 CellChangeTimes->{3.52657541783385*^9, 3.526576816754014*^9, 
  3.526798170507202*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"v40\[CapitalDelta]", "=", 
  RowBox[{
   RowBox[{"VEVFromInv", "[", 
    RowBox[{"4", ",", "inv96"}], "]"}], "/", 
   RowBox[{"(", 
    RowBox[{"2", 
     SqrtBox["6"]}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.526212164877881*^9, 3.526212168230616*^9}, {
  3.526575398385756*^9, 3.52657547926996*^9}, {3.5265768231153603`*^9, 
  3.52657682685972*^9}, {3.526576957911521*^9, 3.526576968757325*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "0", ",", "0", ",", "0", ",", "1", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "1"}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.526212169876102*^9, {3.526575451638013*^9, 3.526575479699646*^9}, 
   3.526576829377803*^9, {3.5265769636915073`*^9, 3.526576969317218*^9}, 
   3.526798174207849*^9}]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["translate a VEV into the corresponding invariant polynomial:", \
"Subsection",
 CellChangeTimes->{{3.5262117793258543`*^9, 3.526211790523322*^9}, {
  3.526212186052319*^9, 3.5262121962578697`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "InvFromVEV"}]], "Input",
 CellChangeTimes->{{3.526211797379072*^9, 3.526211802524592*^9}, {
  3.5262121991636047`*^9, 3.526212202914946*^9}}],

Cell[BoxData[
 StyleBox["\<\"InvFromVEV[deg,VEV] returns the invariant polynomial of degree \
deg corresponding \\nto a certain VEV.\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.526226949653845*^9},
 CellTags->"Info3526234149-5112292"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "example: primary invariants of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["A", "4"], TraditionalForm]],
  FormatType->"TraditionalForm"]
}], "Subsubsection",
 CellChangeTimes->{{3.526211816060972*^9, 3.5262118243097763`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"InvFromVEV", "[", 
  RowBox[{"2", ",", 
   RowBox[{"{", 
    RowBox[{
     SqrtBox["2"], ",", "0", ",", 
     SqrtBox["2"], ",", "0", ",", "0", ",", 
     SqrtBox["2"]}], "}"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"InvFromVEV", "[", 
  RowBox[{"3", ",", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "1", ",", "0", ",", "0",
      ",", "0", ",", "0"}], "}"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"InvFromVEV", "[", 
  RowBox[{"4", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", " ", 
      SqrtBox["6"]}], ",", "0", ",", "0", ",", "0", ",", 
     RowBox[{"2", " ", 
      SqrtBox["6"]}], ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
     "0", ",", "0", ",", "0", ",", "0", ",", 
     RowBox[{"2", " ", 
      SqrtBox["6"]}]}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.526211849541448*^9, 3.526211872803055*^9}, {
  3.5262122169824266`*^9, 3.526212240590391*^9}}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["x", "2"], "+", 
  SuperscriptBox["y", "2"], "+", 
  SuperscriptBox["z", "2"]}]], "Output",
 CellChangeTimes->{3.526212248861827*^9}],

Cell[BoxData[
 RowBox[{"x", " ", "y", " ", "z"}]], "Output",
 CellChangeTimes->{3.526212248863936*^9}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["x", "4"], "+", 
  SuperscriptBox["y", "4"], "+", 
  SuperscriptBox["z", "4"]}]], "Output",
 CellChangeTimes->{3.526212248866246*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PrimInv", "[", "\"\<\!\(\*SubscriptBox[\(A\), \(4\)]\)\>\"", 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["x", "2"], "+", 
    SuperscriptBox["y", "2"], "+", 
    SuperscriptBox["z", "2"]}], ",", 
   RowBox[{"x", " ", "y", " ", "z"}], ",", 
   RowBox[{
    SuperscriptBox["x", "4"], "+", 
    SuperscriptBox["y", "4"], "+", 
    SuperscriptBox["z", "4"]}]}], "}"}]], "Output",
 CellChangeTimes->{3.526212260730377*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "example: secondary invariant of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[CapitalDelta]", "(", 
    RowBox[{"3", "\[CenterDot]", 
     SuperscriptBox["10", "2"]}], ")"}], TraditionalForm]],
  FormatType->"TraditionalForm"]
}], "Subsubsection",
 CellChangeTimes->{{3.526211880251277*^9, 3.526211934320437*^9}, {
  3.526212132828559*^9, 3.526212132995522*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"InvFromVEV", "[", 
  RowBox[{"30", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"15692092416000", " ", 
      SqrtBox["1077205"]}], ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", 
     RowBox[{"15692092416000", " ", 
      SqrtBox["1077205"]}], ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", 
     RowBox[{"15692092416000", " ", 
      SqrtBox["1077205"]}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.526212164877881*^9, 3.526212168230616*^9}, 
   3.526212224141157*^9, 3.526212270902733*^9, 3.526798094991228*^9}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["x", "30"], "+", 
  SuperscriptBox["y", "30"], "+", 
  SuperscriptBox["z", "30"]}]], "Output",
 CellChangeTimes->{3.526212169876102*^9, 3.526212272179515*^9, 
  3.526798132514576*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SecInv", "[", "\"\<\[CapitalDelta](300)\>\"", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SuperscriptBox["x", "30"], "+", 
   SuperscriptBox["y", "30"], "+", 
   SuperscriptBox["z", "30"]}], "}"}]], "Output",
 CellChangeTimes->{3.526212277474608*^9, 3.52679813272999*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
example: lowest order invariant of \[CapitalSigma](168) - example from our \
paper\
\>", "Subsubsection",
 CellChangeTimes->{{3.526211880251277*^9, 3.526211934320437*^9}, {
  3.526212132828559*^9, 3.526212132995522*^9}, {3.526575362982177*^9, 
  3.526575370432556*^9}, {3.526959364631748*^9, 3.52695936950049*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"B40basis", "=", 
  RowBox[{"NormBasis", "[", "4", "]"}]}]], "Input",
 CellChangeTimes->{{3.5265754085524397`*^9, 3.526575417096271*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    SuperscriptBox["x", "4"], 
    RowBox[{"2", " ", 
     SqrtBox["6"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "3"], " ", "y"}], 
     SqrtBox["6"]]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["x", "2"], " ", 
     SuperscriptBox["y", "2"]}], "2"], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"x", " ", 
      SuperscriptBox["y", "3"]}], 
     SqrtBox["6"]]}], ",", 
   FractionBox[
    SuperscriptBox["y", "4"], 
    RowBox[{"2", " ", 
     SqrtBox["6"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "3"], " ", "z"}], 
     SqrtBox["6"]]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["x", "2"], " ", "y", " ", "z"}], 
    SqrtBox["2"]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"x", " ", 
      SuperscriptBox["y", "2"], " ", "z"}], 
     SqrtBox["2"]]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["y", "3"], " ", "z"}], 
    SqrtBox["6"]], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["x", "2"], " ", 
     SuperscriptBox["z", "2"]}], "2"], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"x", " ", "y", " ", 
      SuperscriptBox["z", "2"]}], 
     SqrtBox["2"]]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["y", "2"], " ", 
     SuperscriptBox["z", "2"]}], "2"], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"x", " ", 
      SuperscriptBox["z", "3"]}], 
     SqrtBox["6"]]}], ",", 
   FractionBox[
    RowBox[{"y", " ", 
     SuperscriptBox["z", "3"]}], 
    SqrtBox["6"]], ",", 
   FractionBox[
    SuperscriptBox["z", "4"], 
    RowBox[{"2", " ", 
     SqrtBox["6"]}]]}], "}"}]], "Output",
 CellChangeTimes->{3.52657541783385*^9, 3.5267981455622997`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"v40", "=", 
  RowBox[{"{", 
   RowBox[{
   "0", ",", "0", ",", "0", ",", "1", ",", "0", ",", "1", ",", "0", ",", "0", 
    ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
    RowBox[{"-", "1"}], ",", "0"}], "}"}]}]], "Input",
 CellChangeTimes->{{3.526212164877881*^9, 3.526212168230616*^9}, {
   3.526575398385756*^9, 3.52657547926996*^9}, 3.5265755571113567`*^9, 
   3.5267981440614233`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0", ",", "0", ",", "0", ",", "1", ",", "0", ",", "1", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   RowBox[{"-", "1"}], ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{
  3.526212169876102*^9, {3.526575451638013*^9, 3.526575479699646*^9}, 
   3.526575567124612*^9, 3.5267981469474363`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"InvFromVEV", "[", 
  RowBox[{"4", ",", 
   RowBox[{
    RowBox[{"-", 
     SqrtBox["6"]}], "v40"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.526575545014359*^9, 3.5265755780296717`*^9}, 
   3.526798152468733*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"x", " ", 
   SuperscriptBox["y", "3"]}], "+", 
  RowBox[{
   SuperscriptBox["x", "3"], " ", "z"}], "+", 
  RowBox[{"y", " ", 
   SuperscriptBox["z", "3"]}]}]], "Output",
 CellChangeTimes->{{3.526575567842751*^9, 3.526575578793227*^9}, {
  3.526798147935279*^9, 3.526798153059658*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"PrimInv", "[", "\"\<\[CapitalSigma](168)\>\"", "]"}], 
  "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"x", " ", 
   SuperscriptBox["y", "3"]}], "+", 
  RowBox[{
   SuperscriptBox["x", "3"], " ", "z"}], "+", 
  RowBox[{"y", " ", 
   SuperscriptBox["z", "3"]}]}]], "Output",
 CellChangeTimes->{3.5265755800125723`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
example: lowest order invariant of \[CapitalDelta](96) - example from our \
paper\
\>", "Subsubsection",
 CellChangeTimes->{{3.526211880251277*^9, 3.526211934320437*^9}, {
  3.526212132828559*^9, 3.526212132995522*^9}, {3.526575362982177*^9, 
  3.526575370432556*^9}, {3.52657699189242*^9, 3.526577002506641*^9}, {
  3.52695937100428*^9, 3.5269593756681957`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"B40basis", "=", 
  RowBox[{"NormBasis", "[", "4", "]"}]}]], "Input",
 CellChangeTimes->{{3.5265754085524397`*^9, 3.526575417096271*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    SuperscriptBox["x", "4"], 
    RowBox[{"2", " ", 
     SqrtBox["6"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "3"], " ", "y"}], 
     SqrtBox["6"]]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["x", "2"], " ", 
     SuperscriptBox["y", "2"]}], "2"], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"x", " ", 
      SuperscriptBox["y", "3"]}], 
     SqrtBox["6"]]}], ",", 
   FractionBox[
    SuperscriptBox["y", "4"], 
    RowBox[{"2", " ", 
     SqrtBox["6"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "3"], " ", "z"}], 
     SqrtBox["6"]]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["x", "2"], " ", "y", " ", "z"}], 
    SqrtBox["2"]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"x", " ", 
      SuperscriptBox["y", "2"], " ", "z"}], 
     SqrtBox["2"]]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["y", "3"], " ", "z"}], 
    SqrtBox["6"]], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["x", "2"], " ", 
     SuperscriptBox["z", "2"]}], "2"], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"x", " ", "y", " ", 
      SuperscriptBox["z", "2"]}], 
     SqrtBox["2"]]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["y", "2"], " ", 
     SuperscriptBox["z", "2"]}], "2"], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"x", " ", 
      SuperscriptBox["z", "3"]}], 
     SqrtBox["6"]]}], ",", 
   FractionBox[
    RowBox[{"y", " ", 
     SuperscriptBox["z", "3"]}], 
    SqrtBox["6"]], ",", 
   FractionBox[
    SuperscriptBox["z", "4"], 
    RowBox[{"2", " ", 
     SqrtBox["6"]}]]}], "}"}]], "Output",
 CellChangeTimes->{3.52657541783385*^9, 3.52672902430602*^9, 
  3.526798180435616*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"v40\[CapitalDelta]", "=", 
  RowBox[{"{", 
   RowBox[{
   "1", ",", "0", ",", "0", ",", "0", ",", "1", ",", "0", ",", "0", ",", "0", 
    ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "1"}], 
   "}"}]}]], "Input",
 CellChangeTimes->{{3.526212164877881*^9, 3.526212168230616*^9}, {
   3.526575398385756*^9, 3.52657547926996*^9}, 3.5265755571113567`*^9, {
   3.5265770077265882`*^9, 3.526577015895763*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "0", ",", "0", ",", "0", ",", "1", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "1"}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.526212169876102*^9, {3.526575451638013*^9, 3.526575479699646*^9}, 
   3.526575567124612*^9, 3.526577016828137*^9, 3.526798181353654*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"InvFromVEV", "[", 
  RowBox[{"4", ",", 
   RowBox[{"2", 
    SqrtBox["6"], "v40\[CapitalDelta]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.526575545014359*^9, 3.5265755780296717`*^9}, {
  3.5265770211910563`*^9, 3.526577023611421*^9}}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["x", "4"], "+", 
  SuperscriptBox["y", "4"], "+", 
  SuperscriptBox["z", "4"]}]], "Output",
 CellChangeTimes->{{3.526575567842751*^9, 3.526575578793227*^9}, 
   3.526577024693117*^9, 3.5267981820399933`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"PrimInv", "[", "\"\<\[CapitalDelta](96)\>\"", "]"}], 
  "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], "Input",
 CellChangeTimes->{3.526577039638359*^9}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["x", "4"], "+", 
  SuperscriptBox["y", "4"], "+", 
  SuperscriptBox["z", "4"]}]], "Output",
 CellChangeTimes->{3.5265755800125723`*^9, 3.5265770404330673`*^9, 
  3.5267981832217903`*^9}]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["display an arbitrary (p,q)-basis:", "Subsection",
 CellChangeTimes->{{3.527260607064713*^9, 3.527260617094036*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "pqBasis"}]], "Input",
 CellChangeTimes->{{3.527260628239936*^9, 3.527260628960065*^9}}],

Cell[BoxData[
 StyleBox["\<\"pqBasis[p,q] returns an orthonormalized (p,q)-basis. Note that \
xc=\!\(\*SuperscriptBox[\\\"x\\\", \\\"*\\\"]\), and so on.\"\>", 
  "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.5272607956123447`*^9},
 CellTags->"Info3527267995-4843461"]
}, Open  ]],

Cell[CellGroupData[{

Cell["examples:", "Subsubsection",
 CellChangeTimes->{{3.527260634593647*^9, 3.527260635765519*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"the", " ", 
    SubscriptBox["B", 
     RowBox[{"(", 
      RowBox[{"1", ",", "1"}], ")"}]], " ", "from", " ", "the", " ", 
    RowBox[{"paper", ":"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"pqBasis", "[", 
   RowBox[{"1", ",", "1"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.527260644128778*^9, 3.52726064562302*^9}, {
  3.527260831913714*^9, 3.527260854216999*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"x", " ", "zc"}], ",", 
   RowBox[{
    RowBox[{"-", "y"}], " ", "zc"}], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"x", " ", "xc"}], "+", 
     RowBox[{"y", " ", "yc"}], "-", 
     RowBox[{"2", " ", "z", " ", "zc"}]}], 
    SqrtBox["6"]], ",", 
   RowBox[{"x", " ", "yc"}], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"x", " ", "xc"}], "-", 
     RowBox[{"y", " ", "yc"}]}], 
    SqrtBox["2"]], ",", 
   RowBox[{
    RowBox[{"-", "xc"}], " ", "y"}], ",", 
   RowBox[{
    RowBox[{"-", "yc"}], " ", "z"}], ",", 
   RowBox[{
    RowBox[{"-", "xc"}], " ", "z"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527260646620954*^9, 3.527260798281122*^9, 
  3.5272608546236963`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"one", " ", "can", " ", "reproduce", " ", "the", " ", "l"}], "=", 
    
    RowBox[{
     RowBox[{"4", " ", "basis", " ", "for", " ", 
      RowBox[{"(", 
       RowBox[{"p", ",", "q"}], ")"}]}], "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4", ",", "0"}], ")"}], ":"}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"pqBasis", "[", 
   RowBox[{"4", ",", "0"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.527260805980097*^9, 3.527260817964017*^9}, {
  3.527260857291459*^9, 3.52726088041889*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    SuperscriptBox["x", "4"], 
    RowBox[{"2", " ", 
     SqrtBox["6"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "3"], " ", "y"}], 
     SqrtBox["6"]]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["x", "2"], " ", 
     SuperscriptBox["y", "2"]}], "2"], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"x", " ", 
      SuperscriptBox["y", "3"]}], 
     SqrtBox["6"]]}], ",", 
   FractionBox[
    SuperscriptBox["y", "4"], 
    RowBox[{"2", " ", 
     SqrtBox["6"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "3"], " ", "z"}], 
     SqrtBox["6"]]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["x", "2"], " ", "y", " ", "z"}], 
    SqrtBox["2"]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"x", " ", 
      SuperscriptBox["y", "2"], " ", "z"}], 
     SqrtBox["2"]]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["y", "3"], " ", "z"}], 
    SqrtBox["6"]], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["x", "2"], " ", 
     SuperscriptBox["z", "2"]}], "2"], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"x", " ", "y", " ", 
      SuperscriptBox["z", "2"]}], 
     SqrtBox["2"]]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["y", "2"], " ", 
     SuperscriptBox["z", "2"]}], "2"], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"x", " ", 
      SuperscriptBox["z", "3"]}], 
     SqrtBox["6"]]}], ",", 
   FractionBox[
    RowBox[{"y", " ", 
     SuperscriptBox["z", "3"]}], 
    SqrtBox["6"]], ",", 
   FractionBox[
    SuperscriptBox["z", "4"], 
    RowBox[{"2", " ", 
     SqrtBox["6"]}]]}], "}"}]], "Output",
 CellChangeTimes->{{3.527260806444192*^9, 3.527260818853429*^9}, 
   3.52726088334059*^9}]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
translate an invariant (p,q)-polynomial into the corresponding VEV:\
\>", "Subsection",
 CellChangeTimes->{{3.527260912743615*^9, 3.527260935662572*^9}, {
  3.52727012075174*^9, 3.5272701210597773`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "pqVEVFromInv"}]], "Input",
 CellChangeTimes->{{3.5272609392988253`*^9, 3.527260964045857*^9}}],

Cell[BoxData[
 StyleBox["\<\"pqVEVFromInv[{p,q},poly] returns the VEV corresponding to the \
invariant \\n(p,q)-polynomial poly. Note that \
xc=\\!\\(\\*SuperscriptBox[\\\"x\\\", \\\"*\\\"]\\), and so on.\"\>", 
  "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.527260965109823*^9},
 CellTags->"Info3527268164-6807651"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "example from the paper: ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["S", "3"], TraditionalForm]]]
}], "Subsubsection",
 CellChangeTimes->{{3.527260974893983*^9, 3.527260990868146*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pqVEVFromInv", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{
    RowBox[{"x", " ", "yc"}], "+", 
    RowBox[{"y", " ", "xc"}], "+", 
    RowBox[{"y", " ", "zc"}], "+", 
    RowBox[{"z", " ", "yc"}], "+", 
    RowBox[{"x", " ", "zc"}], "+", 
    RowBox[{"z", " ", "xc"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5272610048942833`*^9, 3.527261060237824*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", 
   RowBox[{"-", "1"}], ",", "0", ",", "1", ",", "0", ",", 
   RowBox[{"-", "1"}], ",", 
   RowBox[{"-", "1"}], ",", 
   RowBox[{"-", "1"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5272610609254227`*^9}]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
translate an (p,q)-VEV into the corresponding invariant polynomial:\
\>", "Subsection",
 CellChangeTimes->{{3.527260912743615*^9, 3.527260935662572*^9}, {
  3.52726108849899*^9, 3.5272610977292547`*^9}, {3.527270124412303*^9, 
  3.52727012472372*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "pqInvFromVEV"}]], "Input",
 CellChangeTimes->{{3.5272609392988253`*^9, 3.527260964045857*^9}, {
  3.527261101235241*^9, 3.527261105730138*^9}}],

Cell[BoxData[
 StyleBox["\<\"pqInvFromVEV[{p,q},VEV] returns the invariant (p,q)-polynomial \
corresponding \\nto a certain VEV.  Note that xc=\!\(\*SuperscriptBox[\\\"x\\\
\", \\\"*\\\"]\), and so on.\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.52726110673558*^9},
 CellTags->"Info3527268306-3045818"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "example from the paper: ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["S", "3"], TraditionalForm]],
  FormatType->"TraditionalForm"]
}], "Subsubsection",
 CellChangeTimes->{{3.527260974893983*^9, 3.527260990868146*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pqInvFromVEV", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", 
     RowBox[{"-", "1"}], ",", "0", ",", "1", ",", "0", ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.527261118859083*^9, 3.527261128028754*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"xc", " ", "y"}], "+", 
  RowBox[{"x", " ", "yc"}], "+", 
  RowBox[{"xc", " ", "z"}], "+", 
  RowBox[{"yc", " ", "z"}], "+", 
  RowBox[{"x", " ", "zc"}], "+", 
  RowBox[{"y", " ", "zc"}]}]], "Output",
 CellChangeTimes->{3.527261128935692*^9}]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Group structures:", "Section",
 CellChangeTimes->{{3.5270822770064373`*^9, 3.527082281667376*^9}, {
  3.5271427478756733`*^9, 3.527142764986968*^9}}],

Cell[CellGroupData[{

Cell["lists of representations (implicit):", "Subsection",
 CellChangeTimes->{{3.527142770556471*^9, 3.5271427762667828`*^9}, {
  3.5273232029562597`*^9, 3.527323212147208*^9}, {3.527323248339057*^9, 
  3.527323250450425*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "FiniteIrreps"}]], "Input",
 CellChangeTimes->{{3.527143036044468*^9, 3.527143037093717*^9}}],

Cell[BoxData[
 StyleBox["\<\"FiniteIrreps['name'], FiniteIrreps[n], and FiniteIrreps[g,j] \
return the \\nlist of irreducble representations (dimension and number in the \
list) of \\nthe group 'name', the group with group number n, or the group \
labeled by \\nthe GAP numbers [g,j].\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.527143747318192*^9},
 CellTags->"Info3527150947-9618731"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "example: irreducible representations of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["A", "4"], TraditionalForm]],
  FormatType->"TraditionalForm"]
}], "Subsubsection",
 CellChangeTimes->{{3.527143043836672*^9, 3.5271430602539387`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"FiniteIrreps", "[", "1", "]"}], "\[IndentingNewLine]", 
 RowBox[{"FiniteIrreps", "[", "\"\<\!\(\*SubscriptBox[\(A\), \(4\)]\)\>\"", 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"FiniteIrreps", "[", 
  RowBox[{"12", ",", "3"}], "]"}]}], "Input",
 CellChangeTimes->{{3.5271430683572474`*^9, 3.527143079828249*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143097759595*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5271430978343782`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5271430978930187`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
example: irreducible representations of \[CapitalSigma](36\[Phi])\
\>", "Subsubsection",
 CellChangeTimes->{{3.527143043836672*^9, 3.5271430602539387`*^9}, {
  3.52714310543007*^9, 3.527143110873543*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"FiniteIrreps", "[", "15", "]"}], "\[IndentingNewLine]", 
 RowBox[{"FiniteIrreps", "[", "\"\<\[CapitalSigma](36\[Phi])\>\"", 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"FiniteIrreps", "[", 
  RowBox[{"108", ",", "15"}], "]"}]}], "Input",
 CellChangeTimes->{{3.5271430683572474`*^9, 3.527143079828249*^9}, {
  3.52714311296346*^9, 3.5271431405702353`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "2"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143097759595*^9, 3.5271431416682673`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "2"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143097759595*^9, 3.527143141733643*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "2"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143097759595*^9, 3.527143141805097*^9}]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Character tables:", "Subsection",
 CellChangeTimes->{{3.527142740869067*^9, 3.52714274463542*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "CharacterTable"}]], "Input",
 CellChangeTimes->{{3.52708228518836*^9, 3.5270822876844673`*^9}}],

Cell[BoxData[
 StyleBox["\<\"CharacterTable['name'], CharacterTable[n], and \
CharacterTable[g,j] return \\nthe character table of the group 'name', the \
group with group number n,\\nor the group labeled by the GAP numbers [g,j], \
in the form of a list. Note \\nthat the first element of the list containts \
the numbers of elements of the\\nrespective conjugacy classes. The data for \
this function was taken from\\nGAP (www.gap-system.org).\"\>", 
  "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.527143750195863*^9},
 CellTags->"Info3527150950-2894565"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "example: character table of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["A", "4"], TraditionalForm]],
  FormatType->"TraditionalForm"]
}], "Subsubsection",
 CellChangeTimes->{{3.5270823049962797`*^9, 3.527082312222353*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
  "CharacterTable", "[", "\"\<\!\(\*SubscriptBox[\(A\), \(4\)]\)\>\"", "]"}], 
  "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.527082335435383*^9, 3.527082337707663*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", "4", "3", "4"},
     {"1", "1", "1", "1"},
     {"1", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]], "1", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]},
     {"1", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]], "1", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]},
     {"3", "0", 
      RowBox[{"-", "1"}], "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.527082338697649*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"CharacterTable", "[", "1", "]"}], "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.527082317894692*^9, 3.527082326227832*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", "4", "3", "4"},
     {"1", "1", "1", "1"},
     {"1", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]], "1", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]},
     {"1", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]], "1", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]},
     {"3", "0", 
      RowBox[{"-", "1"}], "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.527082319887981*^9, 3.5270823268425903`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"CharacterTable", "[", 
   RowBox[{"12", ",", "3"}], "]"}], "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.52708234482203*^9, 3.527082345220149*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", "4", "3", "4"},
     {"1", "1", "1", "1"},
     {"1", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]], "1", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]},
     {"1", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]], "1", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]},
     {"3", "0", 
      RowBox[{"-", "1"}], "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.5270823459254723`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["example: character table of C(62,1,5)", "Subsubsection",
 CellChangeTimes->{{3.527086966087978*^9, 3.527086981598179*^9}, {
  3.5270870887810497`*^9, 3.5270870914272833`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "some", " ", "tables", " ", "might", " ", "be", " ", "relatively", " ", 
    RowBox[{"large", ":"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"CharacterTable", "[", "46", "]"}], "//", 
   "MatrixForm"}]}]], "Input",
 CellChangeTimes->{{3.527086935809935*^9, 3.527086951472041*^9}, {
  3.527087003896531*^9, 3.5270870166145782`*^9}}],

Cell[BoxData[
 InterpretationBox[
  TagBox[
   PanelBox[GridBox[{
      {
       StyleBox[
        StyleBox[
         DynamicBox[ToBoxes[
           FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
           StandardForm],
          ImageSizeCache->{278., {3., 8.}}],
         StripOnInput->False,
         DynamicUpdating->True], "Panel",
        StripOnInput->False,
        Background->None]},
      {
       ItemBox[
        TagBox[
         TagBox[
          RowBox[{"(", "\[NoBreak]", 
           RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], "\[NoBreak]",
            ")"}],
          Function[BoxForm`e$, 
           MatrixForm[BoxForm`e$]]],
         Short[#, 5]& ],
        Background->GrayLevel[1],
        BaseStyle->{Deployed -> False},
        Frame->True,
        FrameStyle->GrayLevel[0, 0.2],
        StripOnInput->False]},
      {
       RowBox[{
        ButtonBox[
         StyleBox[
          StyleBox[
           DynamicBox[ToBoxes[
             FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
             StandardForm],
            ImageSizeCache->{49., {1., 8.}}],
           StripOnInput->False,
           DynamicUpdating->True], "Panel",
          StripOnInput->False,
          Background->None],
         Appearance->Automatic,
         ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Function[{OutputSizeLimit`Dump`x$}, 
            MatrixForm[OutputSizeLimit`Dump`x$]], 9, 23115162001022624733, 5/
           2],
         Enabled->True,
         Evaluator->Automatic,
         Method->"Queued"], "\[ThinSpace]", 
        ButtonBox[
         StyleBox[
          StyleBox[
           DynamicBox[ToBoxes[
             FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
             StandardForm],
            ImageSizeCache->{52., {1., 8.}}],
           StripOnInput->False,
           DynamicUpdating->True], "Panel",
          StripOnInput->False,
          Background->None],
         Appearance->Automatic,
         ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Function[{OutputSizeLimit`Dump`x$}, 
            MatrixForm[OutputSizeLimit`Dump`x$]], 9, 23115162001022624733, 5 
           2],
         Enabled->True,
         Evaluator->Automatic,
         Method->"Queued"], "\[ThinSpace]", 
        ButtonBox[
         StyleBox[
          StyleBox[
           DynamicBox[ToBoxes[
             FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
             StandardForm],
            ImageSizeCache->{82., {2., 8.}}],
           StripOnInput->False,
           DynamicUpdating->True], "Panel",
          StripOnInput->False,
          Background->None],
         Appearance->Automatic,
         ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Function[{OutputSizeLimit`Dump`x$}, 
            MatrixForm[OutputSizeLimit`Dump`x$]], 9, 23115162001022624733, 
           Infinity],
         Enabled->True,
         Evaluator->Automatic,
         Method->"Queued"], "\[ThinSpace]", 
        ButtonBox[
         StyleBox[
          StyleBox[
           DynamicBox[ToBoxes[
             FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
             StandardForm],
            ImageSizeCache->{74., {1., 8.}}],
           StripOnInput->False,
           DynamicUpdating->True], "Panel",
          StripOnInput->False,
          Background->None],
         Appearance->Automatic,
         ButtonFunction:>FrontEndExecute[{
            FrontEnd`SetOptions[
            FrontEnd`$FrontEnd, 
             FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
            FrontEnd`FrontEndToken["PreferencesDialog"]}],
         Evaluator->None,
         Method->"Preemptive"]}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
       "RowsIndexed" -> {}},
     GridBoxItemSize->{
      "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[1.2]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    DefaultBaseStyle->{},
    FrameMargins->5],
   Deploy,
   DefaultBaseStyle->{Deployed -> True}],
  Out[9]]], "Output",
 CellChangeTimes->{{3.5270869379131193`*^9, 3.527086953805578*^9}, 
   3.5270870187516747`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"however", ",", " ", 
    RowBox[{
    "you", " ", "can", " ", "always", " ", "try", " ", "to", " ", "click", 
     " ", "on", " ", "\"\<Show Full Output\>\"", " ", "to", " ", "see", " ", 
     "that", " ", "the", " ", "table", " ", "is", " ", "displayed", " ", 
     RowBox[{"correctly", ":"}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"CharacterTable", "[", "46", "]"}], "//", 
   "MatrixForm"}]}]], "Input",
 CellChangeTimes->{{3.527087028617124*^9, 3.527087058630299*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", "124", "3", "3", "124", "3", "3", "3", "3", "3", "3", "3", "3", 
      "3", "3", "3", "3", "3", "3", "3", "3", "3", "3", "3", "3", "3", "3", 
      "3", "3", "3", "3", "3", "3", "3", "3", "3", "3", "3", "3", "3", "3", 
      "3", "3", "3"},
     {"1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", 
      "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", 
      "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", 
      "1", "1"},
     {"1", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]], "1", "1", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]], "1", "1", 
      "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", 
      "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", 
      "1", "1", "1", "1", "1", "1", "1", "1", "1"},
     {"1", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]], "1", "1", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]], "1", "1",
       "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", 
      "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", 
      "1", "1", "1", "1", "1", "1", "1", "1", "1"},
     {"3", "0", 
      RowBox[{"-", "1"}], "3", "0", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "3", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "3", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "3", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "3", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "3", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "3", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "3", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "3", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "3", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}]},
     {"3", "0", "3", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}]},
     {"3", "0", "3", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}]},
     {"3", "0", "3", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}]},
     {"3", "0", "3", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}]},
     {"3", "0", "3", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}]},
     {"3", "0", "3", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}]},
     {"3", "0", "3", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}]},
     {"3", "0", "3", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}]},
     {"3", "0", "3", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}]},
     {"3", "0", "3", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}]},
     {"3", "0", 
      RowBox[{"-", "1"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
       "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
       "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}]},
     {"3", "0", 
      RowBox[{"-", "1"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "0", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
       "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
       "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}]},
     {"3", "0", 
      RowBox[{"-", "1"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "0", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
       "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
       "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}]},
     {"3", "0", 
      RowBox[{"-", "1"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "0", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
       "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
       "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}]},
     {"3", "0", 
      RowBox[{"-", "1"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
       "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
       "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}]},
     {"3", "0", 
      RowBox[{"-", "1"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "0", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
       "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
       "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}]},
     {"3", "0", 
      RowBox[{"-", "1"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
       "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
       "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}]},
     {"3", "0", 
      RowBox[{"-", "1"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "0", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
       "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
       "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}]},
     {"3", "0", 
      RowBox[{"-", "1"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "0", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
       "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
       "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}]},
     {"3", "0", 
      RowBox[{"-", "1"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "0", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
       "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
       "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}]},
     {"3", "0", 
      RowBox[{"-", "1"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
       "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
       "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}]},
     {"3", "0", 
      RowBox[{"-", "1"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "0", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
       "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
       "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}]},
     {"3", "0", 
      RowBox[{"-", "1"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "0", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
       "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
       "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}]},
     {"3", "0", 
      RowBox[{"-", "1"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "0", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
       "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
       "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}]},
     {"3", "0", 
      RowBox[{"-", "1"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
       "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
       "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}]},
     {"3", "0", 
      RowBox[{"-", "1"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "0", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
       "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
       "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}]},
     {"3", "0", 
      RowBox[{"-", "1"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
       "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
       "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}]},
     {"3", "0", 
      RowBox[{"-", "1"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "0", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
       "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
       "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}]},
     {"3", "0", 
      RowBox[{"-", "1"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
       "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
       "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}]},
     {"3", "0", 
      RowBox[{"-", "1"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "0", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
       "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
       "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}]},
     {"3", "0", 
      RowBox[{"-", "1"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "0", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
       "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
       "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}]},
     {"3", "0", 
      RowBox[{"-", "1"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "0", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
       "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
       "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}]},
     {"3", "0", 
      RowBox[{"-", "1"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "0", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
       "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
       "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}]},
     {"3", "0", 
      RowBox[{"-", "1"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
       "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
       "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}]},
     {"3", "0", 
      RowBox[{"-", "1"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "0", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
       "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
       "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}]},
     {"3", "0", 
      RowBox[{"-", "1"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
       "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
       "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}]},
     {"3", "0", 
      RowBox[{"-", "1"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "0", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
       "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
       "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}]},
     {"3", "0", 
      RowBox[{"-", "1"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "0", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
       "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
       "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}]},
     {"3", "0", 
      RowBox[{"-", "1"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "0", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
       "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
       "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}]},
     {"3", "0", 
      RowBox[{"-", "1"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
       "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
       "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"20", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"28", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"10", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"30", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "31"]}]]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.527087060277977*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
example: character table of \[CapitalSigma](360\[Phi])\
\>", "Subsubsection",
 CellChangeTimes->{{3.527082352323016*^9, 3.527082365385745*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"CharacterTable", "[", "\"\<\[CapitalSigma](360\[Phi])\>\"", "]"}], 
  "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.527082335435383*^9, 3.527082337707663*^9}, 
   3.527082374070416*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", "1", "1", "45", "45", "45", "120", "120", "90", "90", "90", "72", 
      "72", "72", "72", "72", "72"},
     {"1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", 
      "1", "1", "1"},
     {"3", 
      RowBox[{"3", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}], 
      RowBox[{"3", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}], 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}], "0", "0", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]], 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]], "1", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]}]]}], "-", 
       
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]}]]}], "-", 
       
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]]}]},
     {"3", 
      RowBox[{"3", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}], 
      RowBox[{"3", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}], 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}], "0", "0", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]], 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]], "1", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]}]]}], "-", 
       
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]}]]}], "-", 
       
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]]}]},
     {"3", 
      RowBox[{"3", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}], 
      RowBox[{"3", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}], 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}], "0", 
      "0", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]], "1", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]}]]}], "-", 
       
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]}]]}], "-", 
       
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]}]]}]},
     {"3", 
      RowBox[{"3", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}], 
      RowBox[{"3", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}], 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}], "0", 
      "0", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]], "1", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]}]]}], "-", 
       
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]}]]}], "-", 
       
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]}]]}]},
     {"5", "5", "5", "1", "1", "1", 
      RowBox[{"-", "1"}], "2", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "0", "0", "0", "0", "0", "0"},
     {"5", "5", "5", "1", "1", "1", "2", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "0", "0", "0", "0", "0", "0"},
     {"6", 
      RowBox[{"6", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}], 
      RowBox[{"6", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}], "2", 
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}], 
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}], "0", "0",
       "0", "0", "0", "1", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]], 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]], 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]], "1", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]},
     {"6", 
      RowBox[{"6", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}], 
      RowBox[{"6", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}], "2", 
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}], 
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}], "0", 
      "0", "0", "0", "0", "1", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]], "1", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]},
     {"8", "8", "8", "0", "0", "0", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "0", "0", "0", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]}]]}], "-", 
       
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]}]]}], "-", 
       
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]}]]}], "-", 
       
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]}]]}], "-", 
       
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]}]]}], "-", 
       
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]}]]}], "-", 
       
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]]}]},
     {"8", "8", "8", "0", "0", "0", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "0", "0", "0", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]}]]}], "-", 
       
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]}]]}], "-", 
       
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]}]]}], "-", 
       
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]}]]}], "-", 
       
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]}]]}], "-", 
       
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]}]]}], "-", 
       
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]]}]},
     {"9", "9", "9", "1", "1", "1", "0", "0", "1", "1", "1", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}]},
     {"9", 
      RowBox[{"9", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}], 
      RowBox[{"9", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}], "1", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]], 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]], "0", "0", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]], 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]], "1", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}], 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}], 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}]},
     {"9", 
      RowBox[{"9", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}], 
      RowBox[{"9", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}], "1", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]], "0", "0", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]], "1", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}], 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}], 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}]},
     {"10", "10", "10", 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "2"}], "1", "1", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0"},
     {"15", 
      RowBox[{"15", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}], 
      RowBox[{"15", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}], 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}], "0", "0", 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}], 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}], 
      RowBox[{"-", "1"}], "0", "0", "0", "0", "0", "0"},
     {"15", 
      RowBox[{"15", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}], 
      RowBox[{"15", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}], 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}], "0", 
      "0", 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}], 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}], 
      RowBox[{"-", "1"}], "0", "0", "0", "0", "0", "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.527082338697649*^9, 3.527082374900732*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"CharacterTable", "[", "61", "]"}], "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.52708238296338*^9, 3.527082383113721*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", "1", "1", "45", "45", "45", "120", "120", "90", "90", "90", "72", 
      "72", "72", "72", "72", "72"},
     {"1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", 
      "1", "1", "1"},
     {"3", 
      RowBox[{"3", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}], 
      RowBox[{"3", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}], 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}], "0", "0", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]], 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]], "1", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]}]]}], "-", 
       
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]}]]}], "-", 
       
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]]}]},
     {"3", 
      RowBox[{"3", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}], 
      RowBox[{"3", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}], 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}], "0", "0", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]], 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]], "1", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]}]]}], "-", 
       
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]}]]}], "-", 
       
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]]}]},
     {"3", 
      RowBox[{"3", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}], 
      RowBox[{"3", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}], 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}], "0", 
      "0", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]], "1", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]}]]}], "-", 
       
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]}]]}], "-", 
       
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]}]]}]},
     {"3", 
      RowBox[{"3", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}], 
      RowBox[{"3", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}], 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}], "0", 
      "0", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]], "1", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]}]]}], "-", 
       
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]}]]}], "-", 
       
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]}]]}]},
     {"5", "5", "5", "1", "1", "1", 
      RowBox[{"-", "1"}], "2", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "0", "0", "0", "0", "0", "0"},
     {"5", "5", "5", "1", "1", "1", "2", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "0", "0", "0", "0", "0", "0"},
     {"6", 
      RowBox[{"6", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}], 
      RowBox[{"6", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}], "2", 
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}], 
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}], "0", "0",
       "0", "0", "0", "1", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]], 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]], 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]], "1", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]},
     {"6", 
      RowBox[{"6", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}], 
      RowBox[{"6", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}], "2", 
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}], 
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}], "0", 
      "0", "0", "0", "0", "1", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]], "1", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]},
     {"8", "8", "8", "0", "0", "0", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "0", "0", "0", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]}]]}], "-", 
       
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]}]]}], "-", 
       
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]}]]}], "-", 
       
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]}]]}], "-", 
       
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]}]]}], "-", 
       
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]}]]}], "-", 
       
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]]}]},
     {"8", "8", "8", "0", "0", "0", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "0", "0", "0", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]}]]}], "-", 
       
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]}]]}], "-", 
       
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]}]]}], "-", 
       
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]}]]}], "-", 
       
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]}]]}], "-", 
       
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]}]]}], "-", 
       
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]]}]},
     {"9", "9", "9", "1", "1", "1", "0", "0", "1", "1", "1", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}]},
     {"9", 
      RowBox[{"9", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}], 
      RowBox[{"9", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}], "1", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]], 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]], "0", "0", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]], 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]], "1", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}], 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}], 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}]},
     {"9", 
      RowBox[{"9", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}], 
      RowBox[{"9", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}], "1", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]], "0", "0", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]], "1", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}], 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}], 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}]},
     {"10", "10", "10", 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "2"}], "1", "1", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0"},
     {"15", 
      RowBox[{"15", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}], 
      RowBox[{"15", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}], 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}], "0", "0", 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}], 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}], 
      RowBox[{"-", "1"}], "0", "0", "0", "0", "0", "0"},
     {"15", 
      RowBox[{"15", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}], 
      RowBox[{"15", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}], 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}], "0", 
      "0", 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}], 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}], 
      RowBox[{"-", "1"}], "0", "0", "0", "0", "0", "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.527082383865589*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"CharacterTable", "[", 
   RowBox[{"1080", ",", "260"}], "]"}], "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.527082390115553*^9, 3.52708239192171*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", "1", "1", "45", "45", "45", "120", "120", "90", "90", "90", "72", 
      "72", "72", "72", "72", "72"},
     {"1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", 
      "1", "1", "1"},
     {"3", 
      RowBox[{"3", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}], 
      RowBox[{"3", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}], 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}], "0", "0", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]], 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]], "1", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]}]]}], "-", 
       
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]}]]}], "-", 
       
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]]}]},
     {"3", 
      RowBox[{"3", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}], 
      RowBox[{"3", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}], 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}], "0", "0", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]], 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]], "1", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]}]]}], "-", 
       
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]}]]}], "-", 
       
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]]}]},
     {"3", 
      RowBox[{"3", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}], 
      RowBox[{"3", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}], 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}], "0", 
      "0", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]], "1", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]}]]}], "-", 
       
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]}]]}], "-", 
       
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]}]]}]},
     {"3", 
      RowBox[{"3", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}], 
      RowBox[{"3", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}], 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}], "0", 
      "0", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]], "1", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]}]]}], "-", 
       
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]}]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]}]]}], "-", 
       
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "15"]}]]}]},
     {"5", "5", "5", "1", "1", "1", 
      RowBox[{"-", "1"}], "2", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "0", "0", "0", "0", "0", "0"},
     {"5", "5", "5", "1", "1", "1", "2", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "0", "0", "0", "0", "0", "0"},
     {"6", 
      RowBox[{"6", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}], 
      RowBox[{"6", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}], "2", 
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}], 
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}], "0", "0",
       "0", "0", "0", "1", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]], 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]], 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]], "1", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]},
     {"6", 
      RowBox[{"6", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}], 
      RowBox[{"6", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}], "2", 
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}], 
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}], "0", 
      "0", "0", "0", "0", "1", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]], "1", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]},
     {"8", "8", "8", "0", "0", "0", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "0", "0", "0", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]}]]}], "-", 
       
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]}]]}], "-", 
       
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]}]]}], "-", 
       
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]}]]}], "-", 
       
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]}]]}], "-", 
       
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]}]]}], "-", 
       
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]]}]},
     {"8", "8", "8", "0", "0", "0", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "0", "0", "0", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]}]]}], "-", 
       
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]}]]}], "-", 
       
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]}]]}], "-", 
       
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]}]]}], "-", 
       
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]}]]}], "-", 
       
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]}]]}], "-", 
       
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]]}]},
     {"9", "9", "9", "1", "1", "1", "0", "0", "1", "1", "1", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}]},
     {"9", 
      RowBox[{"9", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}], 
      RowBox[{"9", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}], "1", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]], 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]], "0", "0", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]], 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]], "1", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}], 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}], 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}]},
     {"9", 
      RowBox[{"9", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}], 
      RowBox[{"9", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}], "1", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]], "0", "0", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]], "1", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}], 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}], 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}]},
     {"10", "10", "10", 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "2"}], "1", "1", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0"},
     {"15", 
      RowBox[{"15", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}], 
      RowBox[{"15", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}], 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}], "0", "0", 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}], 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}], 
      RowBox[{"-", "1"}], "0", "0", "0", "0", "0", "0"},
     {"15", 
      RowBox[{"15", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}], 
      RowBox[{"15", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}], 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}], "0", 
      "0", 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}], 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]}], 
      RowBox[{"-", "1"}], "0", "0", "0", "0", "0", "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.527082392527347*^9}]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Kronecker products:", "Subsection",
 CellChangeTimes->{{3.527143159962714*^9, 3.527143175183969*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "Kronecker"}]], "Input",
 CellChangeTimes->{{3.527143766463134*^9, 3.5271437703379393`*^9}}],

Cell[BoxData[
 StyleBox["\<\"Kronecker[Rep1,Rep2,'name'], Kronecker[Rep1,Rep2,n], and \
Kronecker[Rep1,Rep2,g,j] \\nreturn the decomposition of the product Rep1xRep2 \
of the two representations\\nRep1 and Rep2 in terms of irreducible \
representations of the group 'name', \\nthe group with group number n, or the \
group labeled by the GAP numbers [g,j]. \\nThe form of the output \
is:\\n{Rep1,Rep2,{Coefficient,Irrep}}.\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.527143771342642*^9},
 CellTags->"Info3527150971-5335439"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "example: all Kronecker products of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["A", "4"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "(including interpretation)"
}], "Subsubsection",
 CellChangeTimes->{{3.527143776850338*^9, 3.527143792650815*^9}, {
  3.5271448812525578`*^9, 3.527144887042684*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FiniteIrreps", "[", "\"\<\!\(\*SubscriptBox[\(A\), \(4\)]\)\>\"", 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143812640769*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"interpretation", ":", " ", 
      RowBox[{
       SubscriptBox[
        UnderscriptBox["1", "_"], "1"], "\[Times]", 
       SubscriptBox[
        UnderscriptBox["1", "_"], "1"]}]}], "=", 
     SubscriptBox[
      UnderscriptBox["1", "_"], "1"]}], ",", " ", 
    RowBox[{
     RowBox[{
      SubscriptBox[
       UnderscriptBox["1", "_"], "1"], "\[Times]", 
      SubscriptBox[
       UnderscriptBox["1", "_"], "2"]}], "=", 
     SubscriptBox[
      UnderscriptBox["1", "_"], "2"]}], ",", " ", 
    RowBox[{
     RowBox[{
      SubscriptBox[
       UnderscriptBox["1", "_"], "1"], "\[Times]", 
      SubscriptBox[
       UnderscriptBox["1", "_"], "3"]}], "=", 
     SubscriptBox[
      UnderscriptBox["1", "_"], "3"]}], ",", " ", 
    RowBox[{
     RowBox[{
      SubscriptBox[
       UnderscriptBox["1", "_"], "1"], "\[Times]", 
      SubscriptBox[
       UnderscriptBox["3", "_"], "1"]}], "=", 
     SubscriptBox[
      UnderscriptBox["3", "_"], "1"]}], ",", " ", 
    RowBox[{
     RowBox[{
      SubscriptBox[
       UnderscriptBox["1", "_"], "2"], "\[Times]", 
      SubscriptBox[
       UnderscriptBox["1", "_"], "2"]}], "=", 
     SubscriptBox[
      UnderscriptBox["1", "_"], "3"]}], ",", " ", 
    RowBox[{
     RowBox[{
      SubscriptBox[
       UnderscriptBox["1", "_"], "2"], "\[Times]", 
      SubscriptBox[
       UnderscriptBox["1", "_"], "3"]}], "=", 
     SubscriptBox[
      UnderscriptBox["1", "_"], "1"]}], ",", " ", 
    RowBox[{
     RowBox[{
      SubscriptBox[
       UnderscriptBox["1", "_"], "2"], "\[Times]", 
      SubscriptBox[
       UnderscriptBox["3", "_"], "1"]}], "=", 
     SubscriptBox[
      UnderscriptBox["3", "_"], "1"]}], ",", " ", 
    RowBox[{
     RowBox[{
      SubscriptBox[
       UnderscriptBox["1", "_"], "3"], "\[Times]", 
      SubscriptBox[
       UnderscriptBox["1", "_"], "3"]}], "=", 
     SubscriptBox[
      UnderscriptBox["1", "_"], "2"]}], ",", " ", 
    RowBox[{
     RowBox[{
      SubscriptBox[
       UnderscriptBox["1", "_"], "3"], "\[Times]", 
      SubscriptBox[
       UnderscriptBox["3", "_"], "1"]}], "=", 
     SubscriptBox[
      UnderscriptBox["3", "_"], "1"]}], ",", " ", 
    RowBox[{
     RowBox[{
      SubscriptBox[
       UnderscriptBox["3", "_"], "1"], "\[Times]", 
      SubscriptBox[
       UnderscriptBox["3", "_"], "1"]}], "=", 
     RowBox[{
      SubscriptBox[
       UnderscriptBox["1", "_"], "1"], "+", 
      SubscriptBox[
       UnderscriptBox["1", "_"], "2"], "+", 
      SubscriptBox[
       UnderscriptBox["1", "_"], "3"], "+", 
      SubscriptBox[
       UnderscriptBox["3", "_"], "1"]}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Kronecker", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}], ",", "1"}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Kronecker", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", "1"}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Kronecker", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}], ",", "1"}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Kronecker", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "1"}], "}"}], ",", "1"}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Kronecker", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", "1"}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Kronecker", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}], ",", "1"}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Kronecker", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "1"}], "}"}], ",", "1"}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Kronecker", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}], ",", "1"}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Kronecker", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "1"}], "}"}], ",", "1"}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Kronecker", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "1"}], "}"}], ",", "1"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.5271438158299313`*^9, 3.5271438919708567`*^9}, {
  3.527144523668745*^9, 3.52714479594823*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.527143893129118*^9, {3.5271447878290873`*^9, 3.52714479731341*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.527143893129118*^9, {3.5271447878290873`*^9, 3.527144797657765*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.527143893129118*^9, {3.5271447878290873`*^9, 3.527144798024734*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.527143893129118*^9, {3.5271447878290873`*^9, 3.527144798893944*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.527143893129118*^9, {3.5271447878290873`*^9, 3.527144798899391*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.527143893129118*^9, {3.5271447878290873`*^9, 3.527144799178207*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.527143893129118*^9, {3.5271447878290873`*^9, 3.527144799486318*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.527143893129118*^9, {3.5271447878290873`*^9, 3.527144799866354*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.527143893129118*^9, {3.5271447878290873`*^9, 3.527144800215073*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.527143893129118*^9, {3.5271447878290873`*^9, 3.527144800549179*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"interpretation", ":", " ", 
      RowBox[{
       SubscriptBox[
        UnderscriptBox["1", "_"], "1"], "\[Times]", 
       SubscriptBox[
        UnderscriptBox["1", "_"], "1"]}]}], "=", 
     SubscriptBox[
      UnderscriptBox["1", "_"], "1"]}], ",", " ", 
    RowBox[{
     RowBox[{
      SubscriptBox[
       UnderscriptBox["1", "_"], "1"], "\[Times]", 
      SubscriptBox[
       UnderscriptBox["1", "_"], "2"]}], "=", 
     SubscriptBox[
      UnderscriptBox["1", "_"], "2"]}], ",", " ", 
    RowBox[{
     RowBox[{
      SubscriptBox[
       UnderscriptBox["1", "_"], "1"], "\[Times]", 
      SubscriptBox[
       UnderscriptBox["1", "_"], "3"]}], "=", 
     SubscriptBox[
      UnderscriptBox["1", "_"], "3"]}], ",", " ", 
    RowBox[{
     RowBox[{
      SubscriptBox[
       UnderscriptBox["1", "_"], "1"], "\[Times]", 
      SubscriptBox[
       UnderscriptBox["3", "_"], "1"]}], "=", 
     SubscriptBox[
      UnderscriptBox["3", "_"], "1"]}], ",", " ", 
    RowBox[{
     RowBox[{
      SubscriptBox[
       UnderscriptBox["1", "_"], "2"], "\[Times]", 
      SubscriptBox[
       UnderscriptBox["1", "_"], "2"]}], "=", 
     SubscriptBox[
      UnderscriptBox["1", "_"], "3"]}], ",", " ", 
    RowBox[{
     RowBox[{
      SubscriptBox[
       UnderscriptBox["1", "_"], "2"], "\[Times]", 
      SubscriptBox[
       UnderscriptBox["1", "_"], "3"]}], "=", 
     SubscriptBox[
      UnderscriptBox["1", "_"], "1"]}], ",", " ", 
    RowBox[{
     RowBox[{
      SubscriptBox[
       UnderscriptBox["1", "_"], "2"], "\[Times]", 
      SubscriptBox[
       UnderscriptBox["3", "_"], "1"]}], "=", 
     SubscriptBox[
      UnderscriptBox["3", "_"], "1"]}], ",", " ", 
    RowBox[{
     RowBox[{
      SubscriptBox[
       UnderscriptBox["1", "_"], "3"], "\[Times]", 
      SubscriptBox[
       UnderscriptBox["1", "_"], "3"]}], "=", 
     SubscriptBox[
      UnderscriptBox["1", "_"], "2"]}], ",", " ", 
    RowBox[{
     RowBox[{
      SubscriptBox[
       UnderscriptBox["1", "_"], "3"], "\[Times]", 
      SubscriptBox[
       UnderscriptBox["3", "_"], "1"]}], "=", 
     SubscriptBox[
      UnderscriptBox["3", "_"], "1"]}], ",", " ", 
    RowBox[{
     RowBox[{
      SubscriptBox[
       UnderscriptBox["3", "_"], "1"], "\[Times]", 
      SubscriptBox[
       UnderscriptBox["3", "_"], "1"]}], "=", 
     RowBox[{
      SubscriptBox[
       UnderscriptBox["1", "_"], "1"], "+", 
      SubscriptBox[
       UnderscriptBox["1", "_"], "2"], "+", 
      SubscriptBox[
       UnderscriptBox["1", "_"], "3"], "+", 
      SubscriptBox[
       UnderscriptBox["3", "_"], "1"]}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Kronecker", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}], ",", 
     "\"\<\!\(\*SubscriptBox[\(A\), \(4\)]\)\>\""}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Kronecker", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     "\"\<\!\(\*SubscriptBox[\(A\), \(4\)]\)\>\""}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Kronecker", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}], ",", 
     "\"\<\!\(\*SubscriptBox[\(A\), \(4\)]\)\>\""}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Kronecker", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "1"}], "}"}], ",", 
     "\"\<\!\(\*SubscriptBox[\(A\), \(4\)]\)\>\""}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Kronecker", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     "\"\<\!\(\*SubscriptBox[\(A\), \(4\)]\)\>\""}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Kronecker", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}], ",", 
     "\"\<\!\(\*SubscriptBox[\(A\), \(4\)]\)\>\""}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Kronecker", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "1"}], "}"}], ",", 
     "\"\<\!\(\*SubscriptBox[\(A\), \(4\)]\)\>\""}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Kronecker", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}], ",", 
     "\"\<\!\(\*SubscriptBox[\(A\), \(4\)]\)\>\""}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Kronecker", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "1"}], "}"}], ",", 
     "\"\<\!\(\*SubscriptBox[\(A\), \(4\)]\)\>\""}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Kronecker", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "1"}], "}"}], ",", 
     "\"\<\!\(\*SubscriptBox[\(A\), \(4\)]\)\>\""}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.52714392672344*^9, 3.527143942429597*^9}, {
  3.527144802643879*^9, 3.5271448033383017`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143943611269*^9, 3.527144804692154*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143943611269*^9, 3.5271448050212584`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143943611269*^9, 3.527144805455843*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143943611269*^9, 3.527144805767254*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143943611269*^9, 3.527144806118703*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143943611269*^9, 3.527144806469563*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143943611269*^9, 3.5271448067859507`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143943611269*^9, 3.5271448071437397`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143943611269*^9, 3.527144807472056*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143943611269*^9, 3.527144807807736*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"interpretation", ":", " ", 
      RowBox[{
       SubscriptBox[
        UnderscriptBox["1", "_"], "1"], "\[Times]", 
       SubscriptBox[
        UnderscriptBox["1", "_"], "1"]}]}], "=", 
     SubscriptBox[
      UnderscriptBox["1", "_"], "1"]}], ",", " ", 
    RowBox[{
     RowBox[{
      SubscriptBox[
       UnderscriptBox["1", "_"], "1"], "\[Times]", 
      SubscriptBox[
       UnderscriptBox["1", "_"], "2"]}], "=", 
     SubscriptBox[
      UnderscriptBox["1", "_"], "2"]}], ",", " ", 
    RowBox[{
     RowBox[{
      SubscriptBox[
       UnderscriptBox["1", "_"], "1"], "\[Times]", 
      SubscriptBox[
       UnderscriptBox["1", "_"], "3"]}], "=", 
     SubscriptBox[
      UnderscriptBox["1", "_"], "3"]}], ",", " ", 
    RowBox[{
     RowBox[{
      SubscriptBox[
       UnderscriptBox["1", "_"], "1"], "\[Times]", 
      SubscriptBox[
       UnderscriptBox["3", "_"], "1"]}], "=", 
     SubscriptBox[
      UnderscriptBox["3", "_"], "1"]}], ",", " ", 
    RowBox[{
     RowBox[{
      SubscriptBox[
       UnderscriptBox["1", "_"], "2"], "\[Times]", 
      SubscriptBox[
       UnderscriptBox["1", "_"], "2"]}], "=", 
     SubscriptBox[
      UnderscriptBox["1", "_"], "3"]}], ",", " ", 
    RowBox[{
     RowBox[{
      SubscriptBox[
       UnderscriptBox["1", "_"], "2"], "\[Times]", 
      SubscriptBox[
       UnderscriptBox["1", "_"], "3"]}], "=", 
     SubscriptBox[
      UnderscriptBox["1", "_"], "1"]}], ",", " ", 
    RowBox[{
     RowBox[{
      SubscriptBox[
       UnderscriptBox["1", "_"], "2"], "\[Times]", 
      SubscriptBox[
       UnderscriptBox["3", "_"], "1"]}], "=", 
     SubscriptBox[
      UnderscriptBox["3", "_"], "1"]}], ",", " ", 
    RowBox[{
     RowBox[{
      SubscriptBox[
       UnderscriptBox["1", "_"], "3"], "\[Times]", 
      SubscriptBox[
       UnderscriptBox["1", "_"], "3"]}], "=", 
     SubscriptBox[
      UnderscriptBox["1", "_"], "2"]}], ",", " ", 
    RowBox[{
     RowBox[{
      SubscriptBox[
       UnderscriptBox["1", "_"], "3"], "\[Times]", 
      SubscriptBox[
       UnderscriptBox["3", "_"], "1"]}], "=", 
     SubscriptBox[
      UnderscriptBox["3", "_"], "1"]}], ",", " ", 
    RowBox[{
     RowBox[{
      SubscriptBox[
       UnderscriptBox["3", "_"], "1"], "\[Times]", 
      SubscriptBox[
       UnderscriptBox["3", "_"], "1"]}], "=", 
     RowBox[{
      SubscriptBox[
       UnderscriptBox["1", "_"], "1"], "+", 
      SubscriptBox[
       UnderscriptBox["1", "_"], "2"], "+", 
      SubscriptBox[
       UnderscriptBox["1", "_"], "3"], "+", 
      SubscriptBox[
       UnderscriptBox["3", "_"], "1"]}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Kronecker", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}], ",", "12", ",", "3"}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Kronecker", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", "12", ",", "3"}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Kronecker", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}], ",", "12", ",", "3"}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Kronecker", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "1"}], "}"}], ",", "12", ",", "3"}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Kronecker", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", "12", ",", "3"}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Kronecker", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}], ",", "12", ",", "3"}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Kronecker", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "1"}], "}"}], ",", "12", ",", "3"}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Kronecker", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}], ",", "12", ",", "3"}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Kronecker", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "1"}], "}"}], ",", "12", ",", "3"}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Kronecker", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "1"}], "}"}], ",", "12", ",", "3"}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.527143954145824*^9, 3.527143965009699*^9}, {
  3.527144809692307*^9, 3.527144810545959*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143966229583*^9, 3.5271448117813473`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143966229583*^9, 3.5271448120990887`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143966229583*^9, 3.527144812458846*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143966229583*^9, 3.5271448127785397`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143966229583*^9, 3.527144813104693*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143966229583*^9, 3.5271448134313717`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143966229583*^9, 3.527144813738738*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143966229583*^9, 3.527144814065843*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143966229583*^9, 3.5271448143639393`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143966229583*^9, 3.527144814693118*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "example: all Kronecker products of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["A", "5"], TraditionalForm]],
  FormatType->"TraditionalForm"]
}], "Subsubsection",
 CellChangeTimes->{{3.527143776850338*^9, 3.527143792650815*^9}, 
   3.5271441768311777`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FiniteIrreps", "[", "\"\<\!\(\*SubscriptBox[\(A\), \(5\)]\)\>\"", 
  "]"}]], "Input",
 CellChangeTimes->{3.5271441818305473`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143812640769*^9, 3.52714418271318*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Kronecker", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", "9"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Kronecker", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", "9"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Kronecker", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "2"}], "}"}], ",", "9"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Kronecker", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], ",", "9"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Kronecker", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "1"}], "}"}], ",", "9"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Kronecker", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", "9"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Kronecker", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "2"}], "}"}], ",", "9"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Kronecker", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], ",", "9"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Kronecker", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "1"}], "}"}], ",", "9"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Kronecker", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "2"}], "}"}], ",", "9"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Kronecker", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], ",", "9"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Kronecker", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "1"}], "}"}], ",", "9"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Kronecker", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], ",", "9"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Kronecker", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "1"}], "}"}], ",", "9"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Kronecker", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"5", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "1"}], "}"}], ",", "9"}], "]"}]}], "Input",
 CellChangeTimes->{{3.5271438158299313`*^9, 3.5271438919708567`*^9}, {
  3.527144187204851*^9, 3.527144284859511*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143893129118*^9, 3.527144286396141*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143893129118*^9, 3.527144286818364*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143893129118*^9, 3.527144287243414*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143893129118*^9, 3.5271442876230717`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143893129118*^9, 3.5271442879819107`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143893129118*^9, 3.527144288408194*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143893129118*^9, 3.527144288825742*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143893129118*^9, 3.527144289261376*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143893129118*^9, 3.527144289620597*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143893129118*^9, 3.527144290036971*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143893129118*^9, 3.5271442904564743`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143893129118*^9, 3.5271442908151207`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143893129118*^9, 3.5271442911969023`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143893129118*^9, 3.527144291553967*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"5", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143893129118*^9, 3.527144291901188*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Kronecker", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   "\"\<\!\(\*SubscriptBox[\(A\), \(5\)]\)\>\""}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Kronecker", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   "\"\<\!\(\*SubscriptBox[\(A\), \(5\)]\)\>\""}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Kronecker", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "2"}], "}"}], ",", 
   "\"\<\!\(\*SubscriptBox[\(A\), \(5\)]\)\>\""}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Kronecker", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], ",", 
   "\"\<\!\(\*SubscriptBox[\(A\), \(5\)]\)\>\""}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Kronecker", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "1"}], "}"}], ",", 
   "\"\<\!\(\*SubscriptBox[\(A\), \(5\)]\)\>\""}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Kronecker", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   "\"\<\!\(\*SubscriptBox[\(A\), \(5\)]\)\>\""}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Kronecker", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "2"}], "}"}], ",", 
   "\"\<\!\(\*SubscriptBox[\(A\), \(5\)]\)\>\""}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Kronecker", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], ",", 
   "\"\<\!\(\*SubscriptBox[\(A\), \(5\)]\)\>\""}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Kronecker", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "1"}], "}"}], ",", 
   "\"\<\!\(\*SubscriptBox[\(A\), \(5\)]\)\>\""}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Kronecker", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "2"}], "}"}], ",", 
   "\"\<\!\(\*SubscriptBox[\(A\), \(5\)]\)\>\""}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Kronecker", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], ",", 
   "\"\<\!\(\*SubscriptBox[\(A\), \(5\)]\)\>\""}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Kronecker", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "1"}], "}"}], ",", 
   "\"\<\!\(\*SubscriptBox[\(A\), \(5\)]\)\>\""}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Kronecker", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], ",", 
   "\"\<\!\(\*SubscriptBox[\(A\), \(5\)]\)\>\""}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Kronecker", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "1"}], "}"}], ",", 
   "\"\<\!\(\*SubscriptBox[\(A\), \(5\)]\)\>\""}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Kronecker", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"5", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "1"}], "}"}], ",", 
   "\"\<\!\(\*SubscriptBox[\(A\), \(5\)]\)\>\""}], "]"}]}], "Input",
 CellChangeTimes->{{3.52714392672344*^9, 3.527143942429597*^9}, {
  3.5271443245942087`*^9, 3.5271443457895737`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143943611269*^9, 3.5271443470558577`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143943611269*^9, 3.527144347419845*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143943611269*^9, 3.527144347789592*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143943611269*^9, 3.527144348129815*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143943611269*^9, 3.527144348435005*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143943611269*^9, 3.527144348804579*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143943611269*^9, 3.5271443491677437`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143943611269*^9, 3.5271443495373173`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143943611269*^9, 3.527144349847406*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143943611269*^9, 3.5271443502108393`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143943611269*^9, 3.5271443506809807`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143943611269*^9, 3.527144351029292*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143943611269*^9, 3.527144351457397*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143943611269*^9, 3.527144351788971*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"5", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143943611269*^9, 3.527144352113018*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Kronecker", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", "60", ",", "5"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Kronecker", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", "60", ",", "5"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Kronecker", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "2"}], "}"}], ",", "60", ",", "5"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Kronecker", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], ",", "60", ",", "5"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Kronecker", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "1"}], "}"}], ",", "60", ",", "5"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Kronecker", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", "60", ",", "5"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Kronecker", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "2"}], "}"}], ",", "60", ",", "5"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Kronecker", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], ",", "60", ",", "5"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Kronecker", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "1"}], "}"}], ",", "60", ",", "5"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Kronecker", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "2"}], "}"}], ",", "60", ",", "5"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Kronecker", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], ",", "60", ",", "5"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Kronecker", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "1"}], "}"}], ",", "60", ",", "5"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Kronecker", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], ",", "60", ",", "5"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Kronecker", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "1"}], "}"}], ",", "60", ",", "5"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Kronecker", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"5", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "1"}], "}"}], ",", "60", ",", "5"}], "]"}]}], "Input",
 CellChangeTimes->{{3.527143954145824*^9, 3.527143965009699*^9}, 
   3.5271443284179163`*^9, {3.527144364232102*^9, 3.527144379283334*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143966229583*^9, 3.5271443807222548`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143966229583*^9, 3.5271443812051907`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143966229583*^9, 3.527144381627193*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143966229583*^9, 3.5271443820588007`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143966229583*^9, 3.5271443824264793`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143966229583*^9, 3.527144382880871*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143966229583*^9, 3.5271443833308992`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143966229583*^9, 3.527144383763754*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143966229583*^9, 3.527144384131125*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143966229583*^9, 3.527144384598517*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143966229583*^9, 3.527144385016963*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143966229583*^9, 3.527144385410611*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143966229583*^9, 3.527144385835672*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143966229583*^9, 3.527144386195723*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"5", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143966229583*^9, 3.527144386576189*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
example: some Kronecker products of \[CapitalSigma](36\[Phi])\
\>", "Subsubsection",
 CellChangeTimes->{{3.527143776850338*^9, 3.527143792650815*^9}, {
  3.527143988484511*^9, 3.527144001090045*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FiniteIrreps", "[", "\"\<\[CapitalSigma](36\[Phi])\>\"", 
  "]"}]], "Input",
 CellChangeTimes->{3.527144008127706*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "2"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143812640769*^9, 3.527144008961584*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Kronecker", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", "15"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Kronecker", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "4"}], "}"}], ",", "15"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Kronecker", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "3"}], "}"}], ",", "15"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Kronecker", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "2"}], "}"}], ",", "15"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Kronecker", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], ",", "15"}], "]"}]}], "Input",
 CellChangeTimes->{{3.5271438158299313`*^9, 3.5271438919708567`*^9}, {
  3.527144019009205*^9, 3.527144056316106*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "4"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "3"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "4"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "5"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "6"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "7"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "8"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "2"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143893129118*^9, 3.52714405920536*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "4"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "3"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "4"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "5"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "6"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "7"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "8"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "2"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143893129118*^9, 3.527144060164474*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "4"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "3"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "4"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "5"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "6"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "7"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "8"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "2"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143893129118*^9, 3.527144061125424*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "4"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "3"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "4"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "5"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "6"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "7"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "8"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "2"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143893129118*^9, 3.52714406210535*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "4"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "3"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "4"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "5"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "6"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "7"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "8"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "2"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527143893129118*^9, 3.5271440631068907`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Kronecker", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   "\"\<\[CapitalSigma](36\[Phi])\>\""}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Kronecker", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "4"}], "}"}], ",", 
   "\"\<\[CapitalSigma](36\[Phi])\>\""}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Kronecker", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "3"}], "}"}], ",", 
   "\"\<\[CapitalSigma](36\[Phi])\>\""}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Kronecker", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "2"}], "}"}], ",", 
   "\"\<\[CapitalSigma](36\[Phi])\>\""}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Kronecker", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], ",", 
   "\"\<\[CapitalSigma](36\[Phi])\>\""}], "]"}]}], "Input",
 CellChangeTimes->{{3.527144075109659*^9, 3.527144078526743*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "4"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "3"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "4"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "5"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "6"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "7"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "8"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "2"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527144080359105*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "4"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "3"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "4"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "5"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "6"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "7"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "8"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "2"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527144081392014*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "4"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "3"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "4"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "5"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "6"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "7"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "8"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "2"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527144082461793*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "4"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "3"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "4"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "5"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "6"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "7"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "8"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "2"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5271440835454683`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "4"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "3"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "4"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "5"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "6"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "7"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "8"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "2"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5271440846717567`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Kronecker", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", "108", ",", "15"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Kronecker", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "4"}], "}"}], ",", "108", ",", "15"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Kronecker", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "3"}], "}"}], ",", "108", ",", "15"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Kronecker", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "2"}], "}"}], ",", "108", ",", "15"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Kronecker", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], ",", "108", ",", "15"}], "]"}]}], "Input",\

 CellChangeTimes->{{3.527144086053423*^9, 3.527144094373564*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "4"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "3"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "4"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "5"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "6"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "7"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "8"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "2"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5271440965455713`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "4"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "3"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "4"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "5"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "6"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "7"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "8"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "2"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.52714409749303*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "4"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "3"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "4"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "5"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "6"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "7"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "8"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "2"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527144098465426*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "4"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "3"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "4"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "5"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "6"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "7"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "8"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "2"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527144099461677*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "4"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "3"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "4"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "5"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "6"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "7"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "8"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "2"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527144100456993*^9}]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Generating functions and branching rules:\
\>", "Section",
 CellChangeTimes->{{3.5268830345730743`*^9, 3.526883045998879*^9}, {
  3.526886538460775*^9, 3.5268865512440166`*^9}, {3.5268873717651052`*^9, 
  3.5268873752099524`*^9}, {3.526959259884366*^9, 3.526959266703074*^9}, {
  3.527153453850707*^9, 3.5271534692106457`*^9}, {3.5271567118979816`*^9, 
  3.5271567120089397`*^9}, {3.527235737650029*^9, 3.527235749030077*^9}}],

Cell[CellGroupData[{

Cell["\<\
display the generation functions for the 3D-irreps of the groups in our list:\
\
\>", "Subsection",
 CellChangeTimes->{{3.5268865651914062`*^9, 3.526886610202888*^9}, {
  3.5272357574301853`*^9, 3.5272357576058407`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "GenFunction"}]], "Input"],

Cell[BoxData[
 StyleBox["\<\"GenFunction['name'], GenFunction[n], and GenFunction[g,j] \
return the list \\nof generating functions of the group 'name', the group \
with group number n, \\nor the group labeled by the GAP numbers [g,j] \
involving the 3D-irrep from our \\nlist. The form of the output is: \
\\n{dimension of the second representation, generating function}.\"\>", 
  "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.527258198006329*^9},
 CellTags->"Info3527265397-5772695"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "example: representation dimensions and generating functions of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["A", "4"], TraditionalForm]],
  FormatType->"TraditionalForm"]
}], "Subsubsection",
 CellChangeTimes->{{3.5268834733343067`*^9, 3.5268834826773863`*^9}, {
  3.526885983093769*^9, 3.5268859904862328`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"GenFunction", "[", "1", "]"}], "\[IndentingNewLine]", 
 RowBox[{"GenFunction", "[", 
  RowBox[{"12", ",", "3"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"GenFunction", "[", "\"\<\!\(\*SubscriptBox[\(A\), \(4\)]\)\>\"", 
  "]"}]}], "Input",
 CellChangeTimes->{
  3.526883298844578*^9, {3.526883486413959*^9, 3.526883488413335*^9}, {
   3.526883523341875*^9, 3.526883525675097*^9}, {3.526885928050741*^9, 
   3.526885928176415*^9}, {3.5268866305332203`*^9, 3.526886641965211*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", 
     FractionBox[
      RowBox[{"1", "+", 
       SuperscriptBox["P", "6"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "3"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "4"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", 
     FractionBox[
      RowBox[{
       SuperscriptBox["P", "2"], "+", 
       SuperscriptBox["P", "4"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "3"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "4"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", 
     FractionBox[
      RowBox[{
       SuperscriptBox["P", "2"], "+", 
       SuperscriptBox["P", "4"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "3"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "4"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", 
     FractionBox[
      RowBox[{"P", "+", 
       SuperscriptBox["P", "2"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "3"]}], "+", 
       SuperscriptBox["P", "4"], "+", 
       SuperscriptBox["P", "5"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "3"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "4"]}], ")"}]}]]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.526883300629195*^9, 3.526883360095717*^9, 3.5268834904665127`*^9, 
   3.526883526629225*^9, 3.5268859641076937`*^9, {3.526886633025214*^9, 
   3.52688664287366*^9}, 3.527269798939859*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", 
     FractionBox[
      RowBox[{"1", "+", 
       SuperscriptBox["P", "6"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "3"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "4"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", 
     FractionBox[
      RowBox[{
       SuperscriptBox["P", "2"], "+", 
       SuperscriptBox["P", "4"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "3"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "4"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", 
     FractionBox[
      RowBox[{
       SuperscriptBox["P", "2"], "+", 
       SuperscriptBox["P", "4"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "3"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "4"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", 
     FractionBox[
      RowBox[{"P", "+", 
       SuperscriptBox["P", "2"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "3"]}], "+", 
       SuperscriptBox["P", "4"], "+", 
       SuperscriptBox["P", "5"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "3"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "4"]}], ")"}]}]]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.526883300629195*^9, 3.526883360095717*^9, 3.5268834904665127`*^9, 
   3.526883526629225*^9, 3.5268859641076937`*^9, {3.526886633025214*^9, 
   3.52688664287366*^9}, 3.5272697989835157`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", 
     FractionBox[
      RowBox[{"1", "+", 
       SuperscriptBox["P", "6"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "3"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "4"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", 
     FractionBox[
      RowBox[{
       SuperscriptBox["P", "2"], "+", 
       SuperscriptBox["P", "4"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "3"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "4"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", 
     FractionBox[
      RowBox[{
       SuperscriptBox["P", "2"], "+", 
       SuperscriptBox["P", "4"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "3"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "4"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", 
     FractionBox[
      RowBox[{"P", "+", 
       SuperscriptBox["P", "2"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "3"]}], "+", 
       SuperscriptBox["P", "4"], "+", 
       SuperscriptBox["P", "5"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "3"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "4"]}], ")"}]}]]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.526883300629195*^9, 3.526883360095717*^9, 3.5268834904665127`*^9, 
   3.526883526629225*^9, 3.5268859641076937`*^9, {3.526886633025214*^9, 
   3.52688664287366*^9}, 3.52726979900909*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "example: representation dimensions and generating functions of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["T", 
    RowBox[{"7", "[", "2", "]"}]], TraditionalForm]]]
}], "Subsubsection",
 CellChangeTimes->{{3.5268834733343067`*^9, 3.5268834826773863`*^9}, {
  3.526885983093769*^9, 3.5268859904862328`*^9}, {3.527235786998931*^9, 
  3.527235790451234*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"GenFunction", "[", "2", "]"}], "\[IndentingNewLine]", 
 RowBox[{"GenFunction", "[", 
  RowBox[{"21", ",", "1"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"GenFunction", "[", "\"\<\!\(\*SubscriptBox[\(T\), \(7[2]\)]\)\>\"", 
  "]"}]}], "Input",
 CellChangeTimes->{
  3.526883298844578*^9, {3.526883486413959*^9, 3.526883488413335*^9}, {
   3.526883523341875*^9, 3.526883525675097*^9}, {3.526885928050741*^9, 
   3.526885928176415*^9}, {3.5268866305332203`*^9, 3.526886641965211*^9}, {
   3.527235795280298*^9, 3.5272358130383167`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", 
     FractionBox[
      RowBox[{"1", "+", 
       SuperscriptBox["P", "4"], "+", 
       SuperscriptBox["P", "6"], "+", 
       SuperscriptBox["P", "8"], "+", 
       SuperscriptBox["P", "12"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "3"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "5"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "7"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", 
     FractionBox[
      RowBox[{
       SuperscriptBox["P", "4"], "+", 
       SuperscriptBox["P", "5"], "+", 
       SuperscriptBox["P", "6"], "+", 
       SuperscriptBox["P", "7"], "+", 
       SuperscriptBox["P", "8"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "3"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "5"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "7"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", 
     FractionBox[
      RowBox[{
       SuperscriptBox["P", "4"], "+", 
       SuperscriptBox["P", "5"], "+", 
       SuperscriptBox["P", "6"], "+", 
       SuperscriptBox["P", "7"], "+", 
       SuperscriptBox["P", "8"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "3"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "5"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "7"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", 
     FractionBox[
      RowBox[{"P", "+", 
       SuperscriptBox["P", "2"], "+", 
       SuperscriptBox["P", "3"], "+", 
       SuperscriptBox["P", "4"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "5"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "6"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "7"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "8"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "9"]}], "+", 
       SuperscriptBox["P", "10"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "3"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "5"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "7"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", 
     FractionBox[
      RowBox[{
       SuperscriptBox["P", "2"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "3"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "5"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "6"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "7"]}], "+", 
       SuperscriptBox["P", "8"], "+", 
       SuperscriptBox["P", "9"], "+", 
       SuperscriptBox["P", "10"], "+", 
       SuperscriptBox["P", "11"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "3"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "5"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "7"]}], ")"}]}]]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.526883300629195*^9, 3.526883360095717*^9, 3.5268834904665127`*^9, 
   3.526883526629225*^9, 3.5268859641076937`*^9, {3.526886633025214*^9, 
   3.52688664287366*^9}, 3.527258200346364*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", 
     FractionBox[
      RowBox[{"1", "+", 
       SuperscriptBox["P", "4"], "+", 
       SuperscriptBox["P", "6"], "+", 
       SuperscriptBox["P", "8"], "+", 
       SuperscriptBox["P", "12"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "3"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "5"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "7"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", 
     FractionBox[
      RowBox[{
       SuperscriptBox["P", "4"], "+", 
       SuperscriptBox["P", "5"], "+", 
       SuperscriptBox["P", "6"], "+", 
       SuperscriptBox["P", "7"], "+", 
       SuperscriptBox["P", "8"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "3"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "5"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "7"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", 
     FractionBox[
      RowBox[{
       SuperscriptBox["P", "4"], "+", 
       SuperscriptBox["P", "5"], "+", 
       SuperscriptBox["P", "6"], "+", 
       SuperscriptBox["P", "7"], "+", 
       SuperscriptBox["P", "8"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "3"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "5"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "7"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", 
     FractionBox[
      RowBox[{"P", "+", 
       SuperscriptBox["P", "2"], "+", 
       SuperscriptBox["P", "3"], "+", 
       SuperscriptBox["P", "4"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "5"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "6"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "7"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "8"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "9"]}], "+", 
       SuperscriptBox["P", "10"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "3"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "5"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "7"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", 
     FractionBox[
      RowBox[{
       SuperscriptBox["P", "2"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "3"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "5"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "6"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "7"]}], "+", 
       SuperscriptBox["P", "8"], "+", 
       SuperscriptBox["P", "9"], "+", 
       SuperscriptBox["P", "10"], "+", 
       SuperscriptBox["P", "11"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "3"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "5"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "7"]}], ")"}]}]]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.526883300629195*^9, 3.526883360095717*^9, 3.5268834904665127`*^9, 
   3.526883526629225*^9, 3.5268859641076937`*^9, {3.526886633025214*^9, 
   3.52688664287366*^9}, 3.5272582003929577`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", 
     FractionBox[
      RowBox[{"1", "+", 
       SuperscriptBox["P", "4"], "+", 
       SuperscriptBox["P", "6"], "+", 
       SuperscriptBox["P", "8"], "+", 
       SuperscriptBox["P", "12"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "3"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "5"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "7"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", 
     FractionBox[
      RowBox[{
       SuperscriptBox["P", "4"], "+", 
       SuperscriptBox["P", "5"], "+", 
       SuperscriptBox["P", "6"], "+", 
       SuperscriptBox["P", "7"], "+", 
       SuperscriptBox["P", "8"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "3"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "5"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "7"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", 
     FractionBox[
      RowBox[{
       SuperscriptBox["P", "4"], "+", 
       SuperscriptBox["P", "5"], "+", 
       SuperscriptBox["P", "6"], "+", 
       SuperscriptBox["P", "7"], "+", 
       SuperscriptBox["P", "8"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "3"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "5"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "7"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", 
     FractionBox[
      RowBox[{"P", "+", 
       SuperscriptBox["P", "2"], "+", 
       SuperscriptBox["P", "3"], "+", 
       SuperscriptBox["P", "4"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "5"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "6"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "7"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "8"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "9"]}], "+", 
       SuperscriptBox["P", "10"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "3"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "5"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "7"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", 
     FractionBox[
      RowBox[{
       SuperscriptBox["P", "2"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "3"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "5"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "6"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "7"]}], "+", 
       SuperscriptBox["P", "8"], "+", 
       SuperscriptBox["P", "9"], "+", 
       SuperscriptBox["P", "10"], "+", 
       SuperscriptBox["P", "11"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "3"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "5"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "7"]}], ")"}]}]]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.526883300629195*^9, 3.526883360095717*^9, 3.5268834904665127`*^9, 
   3.526883526629225*^9, 3.5268859641076937`*^9, {3.526886633025214*^9, 
   3.52688664287366*^9}, 3.527258200396924*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "example: the generating functions (and hence the branching rules) for ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["T", 
    RowBox[{"163", "[", "58", "]"}]], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["T", 
    RowBox[{"169", "[", "22", "]"}]], TraditionalForm]]],
 " are currently unknown"
}], "Subsubsection",
 CellChangeTimes->{{3.5268834733343067`*^9, 3.5268834826773863`*^9}, {
  3.526885983093769*^9, 3.5268859904862328`*^9}, {3.527235786998931*^9, 
  3.527235790451234*^9}, {3.527258217940591*^9, 3.5272582724805*^9}, {
  3.527258327664177*^9, 3.52725833564762*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"GenFunction", "[", "57", "]"}], "\[IndentingNewLine]", 
 RowBox[{"GenFunction", "[", "58", "]"}]}], "Input",
 CellChangeTimes->{
  3.526883298844578*^9, {3.526883486413959*^9, 3.526883488413335*^9}, {
   3.526883523341875*^9, 3.526883525675097*^9}, {3.526885928050741*^9, 
   3.526885928176415*^9}, {3.5268866305332203`*^9, 3.526886641965211*^9}, {
   3.527235795280298*^9, 3.5272358130383167`*^9}, {3.527258282408774*^9, 
   3.5272583126970882`*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.526883300629195*^9, 3.526883360095717*^9, 3.5268834904665127`*^9, 
   3.526883526629225*^9, 3.5268859641076937`*^9, {3.526886633025214*^9, 
   3.52688664287366*^9}, 3.527258200346364*^9, 3.5272583135174847`*^9, 
   3.527269807408256*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.526883300629195*^9, 3.526883360095717*^9, 3.5268834904665127`*^9, 
   3.526883526629225*^9, 3.5268859641076937`*^9, {3.526886633025214*^9, 
   3.52688664287366*^9}, 3.527258200346364*^9, 3.5272583135174847`*^9, 
   3.527269807445181*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "example: representation dimensions and generating functions of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[CapitalSigma]", "(", 
    RowBox[{"360", "\[Phi]"}], ")"}], TraditionalForm]]]
}], "Subsubsection",
 CellChangeTimes->{{3.5268834733343067`*^9, 3.5268834826773863`*^9}, {
   3.526885983093769*^9, 3.5268859904862328`*^9}, 3.526886653058605*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"GenFunction", "[", "61", "]"}], "\[IndentingNewLine]", 
 RowBox[{"GenFunction", "[", 
  RowBox[{"1080", ",", "260"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"GenFunction", "[", "\"\<\[CapitalSigma](360\[Phi])\>\"", 
  "]"}]}], "Input",
 CellChangeTimes->{
  3.526883298844578*^9, {3.526883486413959*^9, 3.526883488413335*^9}, {
   3.526883523341875*^9, 3.526883525675097*^9}, {3.526885928050741*^9, 
   3.526885928176415*^9}, {3.5268866305332203`*^9, 3.5268866834446363`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", 
     FractionBox[
      RowBox[{"1", "+", 
       SuperscriptBox["P", "45"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "6"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "12"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "30"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", 
     FractionBox[
      RowBox[{"P", "+", 
       SuperscriptBox["P", "16"], "+", 
       SuperscriptBox["P", "19"], "+", 
       SuperscriptBox["P", "25"], "+", 
       SuperscriptBox["P", "34"], "+", 
       SuperscriptBox["P", "40"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "6"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "12"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "30"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", 
     FractionBox[
      RowBox[{
       SuperscriptBox["P", "7"], "+", 
       SuperscriptBox["P", "13"], "+", 
       SuperscriptBox["P", "22"], "+", 
       SuperscriptBox["P", "25"], "+", 
       SuperscriptBox["P", "28"], "+", 
       SuperscriptBox["P", "40"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "6"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "12"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "30"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", 
     FractionBox[
      RowBox[{
       SuperscriptBox["P", "5"], "+", 
       SuperscriptBox["P", "11"], "+", 
       SuperscriptBox["P", "20"], "+", 
       SuperscriptBox["P", "26"], "+", 
       SuperscriptBox["P", "29"], "+", 
       SuperscriptBox["P", "44"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "6"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "12"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "30"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", 
     FractionBox[
      RowBox[{
       SuperscriptBox["P", "5"], "+", 
       SuperscriptBox["P", "17"], "+", 
       SuperscriptBox["P", "20"], "+", 
       SuperscriptBox["P", "23"], "+", 
       SuperscriptBox["P", "32"], "+", 
       SuperscriptBox["P", "38"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "6"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "12"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "30"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", 
     FractionBox[
      RowBox[{
       SuperscriptBox["P", "6"], "+", 
       SuperscriptBox["P", "12"], "+", 
       SuperscriptBox["P", "15"], "+", 
       SuperscriptBox["P", "18"], "+", 
       SuperscriptBox["P", "21"], "+", 
       SuperscriptBox["P", "24"], "+", 
       SuperscriptBox["P", "27"], "+", 
       SuperscriptBox["P", "30"], "+", 
       SuperscriptBox["P", "33"], "+", 
       SuperscriptBox["P", "39"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "6"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "12"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "30"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", 
     FractionBox[
      RowBox[{
       SuperscriptBox["P", "6"], "+", 
       SuperscriptBox["P", "12"], "+", 
       SuperscriptBox["P", "15"], "+", 
       SuperscriptBox["P", "18"], "+", 
       SuperscriptBox["P", "21"], "+", 
       SuperscriptBox["P", "24"], "+", 
       SuperscriptBox["P", "27"], "+", 
       SuperscriptBox["P", "30"], "+", 
       SuperscriptBox["P", "33"], "+", 
       SuperscriptBox["P", "39"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "6"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "12"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "30"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6", ",", 
     FractionBox[
      RowBox[{
       SuperscriptBox["P", "4"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "10"]}], "+", 
       SuperscriptBox["P", "16"], "+", 
       SuperscriptBox["P", "19"], "+", 
       SuperscriptBox["P", "22"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "25"]}], "+", 
       SuperscriptBox["P", "28"], "+", 
       SuperscriptBox["P", "31"], "+", 
       SuperscriptBox["P", "37"], "+", 
       SuperscriptBox["P", "43"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "6"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "12"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "30"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6", ",", 
     FractionBox[
      RowBox[{
       SuperscriptBox["P", "2"], "+", 
       SuperscriptBox["P", "8"], "+", 
       SuperscriptBox["P", "14"], "+", 
       SuperscriptBox["P", "17"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "20"]}], "+", 
       SuperscriptBox["P", "23"], "+", 
       SuperscriptBox["P", "26"], "+", 
       SuperscriptBox["P", "29"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "35"]}], "+", 
       SuperscriptBox["P", "41"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "6"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "12"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "30"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8", ",", 
     FractionBox[
      RowBox[{
       SuperscriptBox["P", "6"], "+", 
       SuperscriptBox["P", "9"], "+", 
       SuperscriptBox["P", "12"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "15"]}], "+", 
       SuperscriptBox["P", "18"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "21"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "24"]}], "+", 
       SuperscriptBox["P", "27"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "30"]}], "+", 
       SuperscriptBox["P", "33"], "+", 
       SuperscriptBox["P", "36"], "+", 
       SuperscriptBox["P", "39"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "6"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "12"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "30"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8", ",", 
     FractionBox[
      RowBox[{
       SuperscriptBox["P", "9"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "12"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "15"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "18"]}], "+", 
       SuperscriptBox["P", "21"], "+", 
       SuperscriptBox["P", "24"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "27"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "30"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "33"]}], "+", 
       SuperscriptBox["P", "36"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "6"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "12"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "30"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"9", ",", 
     FractionBox[
      RowBox[{
       SuperscriptBox["P", "6"], "+", 
       SuperscriptBox["P", "9"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "12"]}], "+", 
       SuperscriptBox["P", "15"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "18"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "21"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "24"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "27"]}], "+", 
       SuperscriptBox["P", "30"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "33"]}], "+", 
       SuperscriptBox["P", "36"], "+", 
       SuperscriptBox["P", "39"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "6"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "12"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "30"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"9", ",", 
     FractionBox[
      RowBox[{
       SuperscriptBox["P", "4"], "+", 
       SuperscriptBox["P", "10"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "13"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "16"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "19"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "22"]}], "+", 
       SuperscriptBox["P", "25"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "28"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "31"]}], "+", 
       SuperscriptBox["P", "34"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "37"]}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "6"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "12"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "30"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"9", ",", 
     FractionBox[
      RowBox[{
       RowBox[{"2", " ", 
        SuperscriptBox["P", "8"]}], "+", 
       SuperscriptBox["P", "11"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "14"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "17"]}], "+", 
       SuperscriptBox["P", "20"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "23"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "26"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "29"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "32"]}], "+", 
       SuperscriptBox["P", "35"], "+", 
       SuperscriptBox["P", "41"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "6"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "12"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "30"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"10", ",", 
     FractionBox[
      RowBox[{
       SuperscriptBox["P", "3"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "9"]}], "+", 
       SuperscriptBox["P", "12"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "15"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "18"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "21"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "24"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "27"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "30"]}], "+", 
       SuperscriptBox["P", "33"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "36"]}], "+", 
       SuperscriptBox["P", "42"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "6"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "12"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "30"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"15", ",", 
     FractionBox[
      RowBox[{
       RowBox[{"2", " ", 
        SuperscriptBox["P", "7"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "10"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["P", "13"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["P", "16"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["P", "19"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["P", "22"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["P", "25"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["P", "28"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["P", "31"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["P", "34"]}], "+", 
       SuperscriptBox["P", "37"], "+", 
       SuperscriptBox["P", "40"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "6"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "12"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "30"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"15", ",", 
     FractionBox[
      RowBox[{
       SuperscriptBox["P", "5"], "+", 
       SuperscriptBox["P", "8"], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["P", "11"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["P", "14"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["P", "17"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["P", "20"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["P", "23"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["P", "26"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["P", "29"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["P", "32"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "35"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "38"]}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "6"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "12"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "30"]}], ")"}]}]]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.526883300629195*^9, 3.526883360095717*^9, 3.5268834904665127`*^9, 
   3.526883526629225*^9, 3.5268859641076937`*^9, {3.526886633025214*^9, 
   3.52688664287366*^9}, 3.526886684831551*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", 
     FractionBox[
      RowBox[{"1", "+", 
       SuperscriptBox["P", "45"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "6"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "12"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "30"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", 
     FractionBox[
      RowBox[{"P", "+", 
       SuperscriptBox["P", "16"], "+", 
       SuperscriptBox["P", "19"], "+", 
       SuperscriptBox["P", "25"], "+", 
       SuperscriptBox["P", "34"], "+", 
       SuperscriptBox["P", "40"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "6"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "12"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "30"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", 
     FractionBox[
      RowBox[{
       SuperscriptBox["P", "7"], "+", 
       SuperscriptBox["P", "13"], "+", 
       SuperscriptBox["P", "22"], "+", 
       SuperscriptBox["P", "25"], "+", 
       SuperscriptBox["P", "28"], "+", 
       SuperscriptBox["P", "40"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "6"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "12"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "30"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", 
     FractionBox[
      RowBox[{
       SuperscriptBox["P", "5"], "+", 
       SuperscriptBox["P", "11"], "+", 
       SuperscriptBox["P", "20"], "+", 
       SuperscriptBox["P", "26"], "+", 
       SuperscriptBox["P", "29"], "+", 
       SuperscriptBox["P", "44"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "6"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "12"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "30"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", 
     FractionBox[
      RowBox[{
       SuperscriptBox["P", "5"], "+", 
       SuperscriptBox["P", "17"], "+", 
       SuperscriptBox["P", "20"], "+", 
       SuperscriptBox["P", "23"], "+", 
       SuperscriptBox["P", "32"], "+", 
       SuperscriptBox["P", "38"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "6"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "12"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "30"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", 
     FractionBox[
      RowBox[{
       SuperscriptBox["P", "6"], "+", 
       SuperscriptBox["P", "12"], "+", 
       SuperscriptBox["P", "15"], "+", 
       SuperscriptBox["P", "18"], "+", 
       SuperscriptBox["P", "21"], "+", 
       SuperscriptBox["P", "24"], "+", 
       SuperscriptBox["P", "27"], "+", 
       SuperscriptBox["P", "30"], "+", 
       SuperscriptBox["P", "33"], "+", 
       SuperscriptBox["P", "39"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "6"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "12"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "30"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", 
     FractionBox[
      RowBox[{
       SuperscriptBox["P", "6"], "+", 
       SuperscriptBox["P", "12"], "+", 
       SuperscriptBox["P", "15"], "+", 
       SuperscriptBox["P", "18"], "+", 
       SuperscriptBox["P", "21"], "+", 
       SuperscriptBox["P", "24"], "+", 
       SuperscriptBox["P", "27"], "+", 
       SuperscriptBox["P", "30"], "+", 
       SuperscriptBox["P", "33"], "+", 
       SuperscriptBox["P", "39"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "6"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "12"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "30"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6", ",", 
     FractionBox[
      RowBox[{
       SuperscriptBox["P", "4"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "10"]}], "+", 
       SuperscriptBox["P", "16"], "+", 
       SuperscriptBox["P", "19"], "+", 
       SuperscriptBox["P", "22"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "25"]}], "+", 
       SuperscriptBox["P", "28"], "+", 
       SuperscriptBox["P", "31"], "+", 
       SuperscriptBox["P", "37"], "+", 
       SuperscriptBox["P", "43"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "6"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "12"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "30"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6", ",", 
     FractionBox[
      RowBox[{
       SuperscriptBox["P", "2"], "+", 
       SuperscriptBox["P", "8"], "+", 
       SuperscriptBox["P", "14"], "+", 
       SuperscriptBox["P", "17"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "20"]}], "+", 
       SuperscriptBox["P", "23"], "+", 
       SuperscriptBox["P", "26"], "+", 
       SuperscriptBox["P", "29"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "35"]}], "+", 
       SuperscriptBox["P", "41"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "6"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "12"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "30"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8", ",", 
     FractionBox[
      RowBox[{
       SuperscriptBox["P", "6"], "+", 
       SuperscriptBox["P", "9"], "+", 
       SuperscriptBox["P", "12"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "15"]}], "+", 
       SuperscriptBox["P", "18"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "21"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "24"]}], "+", 
       SuperscriptBox["P", "27"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "30"]}], "+", 
       SuperscriptBox["P", "33"], "+", 
       SuperscriptBox["P", "36"], "+", 
       SuperscriptBox["P", "39"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "6"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "12"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "30"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8", ",", 
     FractionBox[
      RowBox[{
       SuperscriptBox["P", "9"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "12"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "15"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "18"]}], "+", 
       SuperscriptBox["P", "21"], "+", 
       SuperscriptBox["P", "24"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "27"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "30"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "33"]}], "+", 
       SuperscriptBox["P", "36"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "6"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "12"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "30"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"9", ",", 
     FractionBox[
      RowBox[{
       SuperscriptBox["P", "6"], "+", 
       SuperscriptBox["P", "9"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "12"]}], "+", 
       SuperscriptBox["P", "15"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "18"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "21"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "24"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "27"]}], "+", 
       SuperscriptBox["P", "30"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "33"]}], "+", 
       SuperscriptBox["P", "36"], "+", 
       SuperscriptBox["P", "39"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "6"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "12"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "30"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"9", ",", 
     FractionBox[
      RowBox[{
       SuperscriptBox["P", "4"], "+", 
       SuperscriptBox["P", "10"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "13"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "16"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "19"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "22"]}], "+", 
       SuperscriptBox["P", "25"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "28"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "31"]}], "+", 
       SuperscriptBox["P", "34"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "37"]}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "6"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "12"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "30"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"9", ",", 
     FractionBox[
      RowBox[{
       RowBox[{"2", " ", 
        SuperscriptBox["P", "8"]}], "+", 
       SuperscriptBox["P", "11"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "14"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "17"]}], "+", 
       SuperscriptBox["P", "20"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "23"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "26"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "29"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "32"]}], "+", 
       SuperscriptBox["P", "35"], "+", 
       SuperscriptBox["P", "41"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "6"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "12"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "30"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"10", ",", 
     FractionBox[
      RowBox[{
       SuperscriptBox["P", "3"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "9"]}], "+", 
       SuperscriptBox["P", "12"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "15"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "18"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "21"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "24"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "27"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "30"]}], "+", 
       SuperscriptBox["P", "33"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "36"]}], "+", 
       SuperscriptBox["P", "42"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "6"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "12"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "30"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"15", ",", 
     FractionBox[
      RowBox[{
       RowBox[{"2", " ", 
        SuperscriptBox["P", "7"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "10"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["P", "13"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["P", "16"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["P", "19"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["P", "22"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["P", "25"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["P", "28"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["P", "31"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["P", "34"]}], "+", 
       SuperscriptBox["P", "37"], "+", 
       SuperscriptBox["P", "40"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "6"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "12"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "30"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"15", ",", 
     FractionBox[
      RowBox[{
       SuperscriptBox["P", "5"], "+", 
       SuperscriptBox["P", "8"], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["P", "11"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["P", "14"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["P", "17"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["P", "20"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["P", "23"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["P", "26"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["P", "29"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["P", "32"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "35"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "38"]}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "6"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "12"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "30"]}], ")"}]}]]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.526883300629195*^9, 3.526883360095717*^9, 3.5268834904665127`*^9, 
   3.526883526629225*^9, 3.5268859641076937`*^9, {3.526886633025214*^9, 
   3.52688664287366*^9}, 3.526886684870442*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", 
     FractionBox[
      RowBox[{"1", "+", 
       SuperscriptBox["P", "45"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "6"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "12"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "30"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", 
     FractionBox[
      RowBox[{"P", "+", 
       SuperscriptBox["P", "16"], "+", 
       SuperscriptBox["P", "19"], "+", 
       SuperscriptBox["P", "25"], "+", 
       SuperscriptBox["P", "34"], "+", 
       SuperscriptBox["P", "40"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "6"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "12"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "30"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", 
     FractionBox[
      RowBox[{
       SuperscriptBox["P", "7"], "+", 
       SuperscriptBox["P", "13"], "+", 
       SuperscriptBox["P", "22"], "+", 
       SuperscriptBox["P", "25"], "+", 
       SuperscriptBox["P", "28"], "+", 
       SuperscriptBox["P", "40"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "6"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "12"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "30"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", 
     FractionBox[
      RowBox[{
       SuperscriptBox["P", "5"], "+", 
       SuperscriptBox["P", "11"], "+", 
       SuperscriptBox["P", "20"], "+", 
       SuperscriptBox["P", "26"], "+", 
       SuperscriptBox["P", "29"], "+", 
       SuperscriptBox["P", "44"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "6"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "12"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "30"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", 
     FractionBox[
      RowBox[{
       SuperscriptBox["P", "5"], "+", 
       SuperscriptBox["P", "17"], "+", 
       SuperscriptBox["P", "20"], "+", 
       SuperscriptBox["P", "23"], "+", 
       SuperscriptBox["P", "32"], "+", 
       SuperscriptBox["P", "38"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "6"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "12"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "30"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", 
     FractionBox[
      RowBox[{
       SuperscriptBox["P", "6"], "+", 
       SuperscriptBox["P", "12"], "+", 
       SuperscriptBox["P", "15"], "+", 
       SuperscriptBox["P", "18"], "+", 
       SuperscriptBox["P", "21"], "+", 
       SuperscriptBox["P", "24"], "+", 
       SuperscriptBox["P", "27"], "+", 
       SuperscriptBox["P", "30"], "+", 
       SuperscriptBox["P", "33"], "+", 
       SuperscriptBox["P", "39"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "6"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "12"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "30"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", 
     FractionBox[
      RowBox[{
       SuperscriptBox["P", "6"], "+", 
       SuperscriptBox["P", "12"], "+", 
       SuperscriptBox["P", "15"], "+", 
       SuperscriptBox["P", "18"], "+", 
       SuperscriptBox["P", "21"], "+", 
       SuperscriptBox["P", "24"], "+", 
       SuperscriptBox["P", "27"], "+", 
       SuperscriptBox["P", "30"], "+", 
       SuperscriptBox["P", "33"], "+", 
       SuperscriptBox["P", "39"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "6"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "12"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "30"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6", ",", 
     FractionBox[
      RowBox[{
       SuperscriptBox["P", "4"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "10"]}], "+", 
       SuperscriptBox["P", "16"], "+", 
       SuperscriptBox["P", "19"], "+", 
       SuperscriptBox["P", "22"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "25"]}], "+", 
       SuperscriptBox["P", "28"], "+", 
       SuperscriptBox["P", "31"], "+", 
       SuperscriptBox["P", "37"], "+", 
       SuperscriptBox["P", "43"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "6"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "12"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "30"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6", ",", 
     FractionBox[
      RowBox[{
       SuperscriptBox["P", "2"], "+", 
       SuperscriptBox["P", "8"], "+", 
       SuperscriptBox["P", "14"], "+", 
       SuperscriptBox["P", "17"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "20"]}], "+", 
       SuperscriptBox["P", "23"], "+", 
       SuperscriptBox["P", "26"], "+", 
       SuperscriptBox["P", "29"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "35"]}], "+", 
       SuperscriptBox["P", "41"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "6"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "12"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "30"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8", ",", 
     FractionBox[
      RowBox[{
       SuperscriptBox["P", "6"], "+", 
       SuperscriptBox["P", "9"], "+", 
       SuperscriptBox["P", "12"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "15"]}], "+", 
       SuperscriptBox["P", "18"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "21"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "24"]}], "+", 
       SuperscriptBox["P", "27"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "30"]}], "+", 
       SuperscriptBox["P", "33"], "+", 
       SuperscriptBox["P", "36"], "+", 
       SuperscriptBox["P", "39"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "6"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "12"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "30"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8", ",", 
     FractionBox[
      RowBox[{
       SuperscriptBox["P", "9"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "12"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "15"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "18"]}], "+", 
       SuperscriptBox["P", "21"], "+", 
       SuperscriptBox["P", "24"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "27"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "30"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "33"]}], "+", 
       SuperscriptBox["P", "36"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "6"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "12"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "30"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"9", ",", 
     FractionBox[
      RowBox[{
       SuperscriptBox["P", "6"], "+", 
       SuperscriptBox["P", "9"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "12"]}], "+", 
       SuperscriptBox["P", "15"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "18"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "21"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "24"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "27"]}], "+", 
       SuperscriptBox["P", "30"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "33"]}], "+", 
       SuperscriptBox["P", "36"], "+", 
       SuperscriptBox["P", "39"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "6"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "12"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "30"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"9", ",", 
     FractionBox[
      RowBox[{
       SuperscriptBox["P", "4"], "+", 
       SuperscriptBox["P", "10"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "13"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "16"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "19"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "22"]}], "+", 
       SuperscriptBox["P", "25"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "28"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "31"]}], "+", 
       SuperscriptBox["P", "34"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "37"]}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "6"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "12"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "30"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"9", ",", 
     FractionBox[
      RowBox[{
       RowBox[{"2", " ", 
        SuperscriptBox["P", "8"]}], "+", 
       SuperscriptBox["P", "11"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "14"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "17"]}], "+", 
       SuperscriptBox["P", "20"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "23"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "26"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "29"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "32"]}], "+", 
       SuperscriptBox["P", "35"], "+", 
       SuperscriptBox["P", "41"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "6"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "12"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "30"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"10", ",", 
     FractionBox[
      RowBox[{
       SuperscriptBox["P", "3"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "9"]}], "+", 
       SuperscriptBox["P", "12"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "15"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "18"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "21"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "24"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "27"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "30"]}], "+", 
       SuperscriptBox["P", "33"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "36"]}], "+", 
       SuperscriptBox["P", "42"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "6"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "12"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "30"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"15", ",", 
     FractionBox[
      RowBox[{
       RowBox[{"2", " ", 
        SuperscriptBox["P", "7"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "10"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["P", "13"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["P", "16"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["P", "19"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["P", "22"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["P", "25"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["P", "28"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["P", "31"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["P", "34"]}], "+", 
       SuperscriptBox["P", "37"], "+", 
       SuperscriptBox["P", "40"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "6"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "12"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "30"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"15", ",", 
     FractionBox[
      RowBox[{
       SuperscriptBox["P", "5"], "+", 
       SuperscriptBox["P", "8"], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["P", "11"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["P", "14"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["P", "17"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["P", "20"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["P", "23"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["P", "26"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["P", "29"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["P", "32"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "35"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["P", "38"]}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "6"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "12"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["P", "30"]}], ")"}]}]]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.526883300629195*^9, 3.526883360095717*^9, 3.5268834904665127`*^9, 
   3.526883526629225*^9, 3.5268859641076937`*^9, {3.526886633025214*^9, 
   3.52688664287366*^9}, 3.526886684908326*^9}]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Branching rules for SO(3):", "Subsection",
 CellChangeTimes->{{3.526886785553671*^9, 3.526886791342626*^9}, {
   3.526886854477668*^9, 3.526886880930513*^9}, 3.5272583538093452`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "BranchingSO3"}]], "Input",
 CellChangeTimes->{{3.5268867969942217`*^9, 3.526886797952726*^9}}],

Cell[BoxData[
 StyleBox["\<\"BranchingSO3[l,'name'], BranchingSO3[l,n], BranchingSO3[l,g,j] \
return \\nthe 'dimension' of the SO(3) representation labeled by l, together \
with \\nthe composition of this representation in terms of the \
representations of \\nthe subgroup, for the group 'name', the group with \
group number n, or the \\ngroup labeled by the GAP numbers [g,j]. \\nThe form \
of the output is: \\n{SO(3)-label, dimension[SO(3)],{dimension[subgroup],#rep \
with that dimension}}.\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.52725848134688*^9},
 CellTags->"Info3527265681-7129527"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "example: branching rules for the SO(3) representations l=0,1,2,3,4,5 in \
terms of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["A", "4"], TraditionalForm]]],
 "-representations"
}], "Subsubsection",
 CellChangeTimes->{{3.526886816935697*^9, 3.526886848357449*^9}, {
  3.5270925424198503`*^9, 3.527092542665144*^9}, {3.527107187321073*^9, 
  3.5271071874705667`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"BranchingSO3", "[", 
  RowBox[{"0", ",", "1"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSO3", "[", 
  RowBox[{"1", ",", "1"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSO3", "[", 
  RowBox[{"2", ",", "1"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSO3", "[", 
  RowBox[{"3", ",", "1"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSO3", "[", 
  RowBox[{"4", ",", "1"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSO3", "[", 
  RowBox[{"5", ",", "1"}], "]"}]}], "Input",
 CellChangeTimes->{{3.527106689511739*^9, 3.527106696501195*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "1", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527106946115368*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "3", ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527106946117304*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2", ",", "5", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5271069461193237`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"3", ",", "7", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527106946121402*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"4", ",", "9", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527106946123673*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"5", ",", "11", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527106946125787*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"BranchingSO3", "[", 
  RowBox[{"0", ",", "\"\<\!\(\*SubscriptBox[\(A\), \(4\)]\)\>\""}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSO3", "[", 
  RowBox[{"1", ",", "\"\<\!\(\*SubscriptBox[\(A\), \(4\)]\)\>\""}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSO3", "[", 
  RowBox[{"2", ",", "\"\<\!\(\*SubscriptBox[\(A\), \(4\)]\)\>\""}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSO3", "[", 
  RowBox[{"3", ",", "\"\<\!\(\*SubscriptBox[\(A\), \(4\)]\)\>\""}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSO3", "[", 
  RowBox[{"4", ",", "\"\<\!\(\*SubscriptBox[\(A\), \(4\)]\)\>\""}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSO3", "[", 
  RowBox[{"5", ",", "\"\<\!\(\*SubscriptBox[\(A\), \(4\)]\)\>\""}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.526886903267613*^9, 3.526886928683835*^9}, {
  3.52709254709326*^9, 3.527092551189189*^9}, {3.527106709322308*^9, 
  3.527106715904933*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "1", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527106947585072*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "3", ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5271069475872593`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2", ",", "5", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.52710694763925*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"3", ",", "7", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5271069476412907`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"4", ",", "9", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5271069476729517`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"5", ",", "11", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.52710694770639*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"BranchingSO3", "[", 
  RowBox[{"0", ",", "12", ",", "3"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSO3", "[", 
  RowBox[{"1", ",", "12", ",", "3"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSO3", "[", 
  RowBox[{"2", ",", "12", ",", "3"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSO3", "[", 
  RowBox[{"3", ",", "12", ",", "3"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSO3", "[", 
  RowBox[{"4", ",", "12", ",", "3"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSO3", "[", 
  RowBox[{"5", ",", "12", ",", "3"}], "]"}]}], "Input",
 CellChangeTimes->{{3.5271067331039457`*^9, 3.527106737455101*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "1", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527106948535746*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "3", ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5271069485770693`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2", ",", "5", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527106948611575*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"3", ",", "7", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527106948650279*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"4", ",", "9", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527106948675447*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"5", ",", "11", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5271069487114267`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "example: branching rules for the SO(3) representations l=0,1,2,3,4,5 in \
terms of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["A", "5"], TraditionalForm]]],
 "-representations"
}], "Subsubsection",
 CellChangeTimes->{{3.526886816935697*^9, 3.526886848357449*^9}, 
   3.5268869415771837`*^9, {3.5270925550905933`*^9, 3.5270925562729673`*^9}, {
   3.527107189526276*^9, 3.527107189670289*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"BranchingSO3", "[", 
  RowBox[{"0", ",", "9"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSO3", "[", 
  RowBox[{"1", ",", "9"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSO3", "[", 
  RowBox[{"2", ",", "9"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSO3", "[", 
  RowBox[{"3", ",", "9"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSO3", "[", 
  RowBox[{"4", ",", "9"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSO3", "[", 
  RowBox[{"5", ",", "9"}], "]"}]}], "Input",
 CellChangeTimes->{{3.527106752428132*^9, 3.527106761906638*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "1", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527106950376728*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "3", ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527106950407537*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2", ",", "5", ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527106950448284*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"3", ",", "7", ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.52710695048041*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"4", ",", "9", ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527106950513789*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"5", ",", "11", ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527106950547423*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"BranchingSO3", "[", 
  RowBox[{"0", ",", "\"\<\!\(\*SubscriptBox[\(A\), \(5\)]\)\>\""}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSO3", "[", 
  RowBox[{"1", ",", "\"\<\!\(\*SubscriptBox[\(A\), \(5\)]\)\>\""}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSO3", "[", 
  RowBox[{"2", ",", "\"\<\!\(\*SubscriptBox[\(A\), \(5\)]\)\>\""}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSO3", "[", 
  RowBox[{"3", ",", "\"\<\!\(\*SubscriptBox[\(A\), \(5\)]\)\>\""}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSO3", "[", 
  RowBox[{"4", ",", "\"\<\!\(\*SubscriptBox[\(A\), \(5\)]\)\>\""}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSO3", "[", 
  RowBox[{"5", ",", "\"\<\!\(\*SubscriptBox[\(A\), \(5\)]\)\>\""}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.5271067702934504`*^9, 3.5271067766144876`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "1", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527106951291421*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "3", ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527106951324601*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2", ",", "5", ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.52710695136624*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"3", ",", "7", ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527106951399839*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"4", ",", "9", ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527106951431897*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"5", ",", "11", ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5271069514628553`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"BranchingSO3", "[", 
  RowBox[{"0", ",", "60", ",", "5"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSO3", "[", 
  RowBox[{"1", ",", "60", ",", "5"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSO3", "[", 
  RowBox[{"2", ",", "60", ",", "5"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSO3", "[", 
  RowBox[{"3", ",", "60", ",", "5"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSO3", "[", 
  RowBox[{"4", ",", "60", ",", "5"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSO3", "[", 
  RowBox[{"5", ",", "60", ",", "5"}], "]"}]}], "Input",
 CellChangeTimes->{{3.527106793556176*^9, 3.527106807866397*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "1", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527106952224908*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "3", ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.52710695226*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2", ",", "5", ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527106952298674*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"3", ",", "7", ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527106952331746*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"4", ",", "9", ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527106952368382*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"5", ",", "11", ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5271069524044228`*^9}]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Branching rules for SU(3):", "Subsection",
 CellChangeTimes->{{3.526886785553671*^9, 3.526886791342626*^9}, {
   3.526886854477668*^9, 3.526886880930513*^9}, {3.526887215273734*^9, 
   3.526887261143632*^9}, {3.527107011572331*^9, 3.527107012723151*^9}, 
   3.527258358598604*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "BranchingSU3"}]], "Input",
 CellChangeTimes->{{3.5268867969942217`*^9, 3.526886797952726*^9}, {
  3.526887263661763*^9, 3.526887264053986*^9}}],

Cell[BoxData[
 StyleBox["\<\"BranchingSU3[{p,q},'name'], BranchingSU3[{p,q},n], \
BranchingSU3[{p,q},g,j] \\nreturn the 'dimension' of the SU(3) representation \
labeled by (p,q), \\ntogether with the composition of this representation in \
terms of the \\nrepresentations of the subgroup, for the group 'name', the \
group with group \\nnumber n, or the group labeled by the GAP numbers [g,j]. \
\\nThe form of the output is: \\n{{p,q}, \
dimension[SU(3)],{dimension[subgroup],#rep with that dimension}}.\"\>", 
  "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.527258484750201*^9},
 CellTags->"Info3527265684-2771641"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "example: branching rules for the SU(3) representations \
(p,q)=(0,0),(1,0),(2,0),(1,1),(3,0),(2,1),(4,0),(0,5) in terms of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["A", "4"], TraditionalForm]]],
 "-representations"
}], "Subsubsection",
 CellChangeTimes->{{3.526886816935697*^9, 3.526886848357449*^9}, {
  3.5268872663367233`*^9, 3.5268872666392117`*^9}, {3.526887304240018*^9, 
  3.526887315629518*^9}, {3.5270952083751698`*^9, 3.5270952466206427`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"BranchingSU3", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", "1"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSU3", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "0"}], "}"}], ",", "1"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSU3", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"2", ",", "0"}], "}"}], ",", "1"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSU3", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", "1"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSU3", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "0"}], "}"}], ",", "1"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSU3", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"2", ",", "1"}], "}"}], ",", "1"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSU3", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"4", ",", "0"}], "}"}], ",", "1"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSU3", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "5"}], "}"}], ",", "1"}], "]"}]}], "Input",
 CellChangeTimes->{{3.527102174068519*^9, 3.527102189774724*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", "1", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527102251312235*^9, 3.527102409591249*^9, 
  3.527106053490074*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "0"}], "}"}], ",", "3", ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527102251312235*^9, 3.527102409591249*^9, 
  3.5271060538814993`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"2", ",", "0"}], "}"}], ",", "6", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527102251312235*^9, 3.527102409591249*^9, 
  3.527106054348526*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", "8", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527102251312235*^9, 3.527102409591249*^9, 
  3.527106054723057*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "0"}], "}"}], ",", "10", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527102251312235*^9, 3.527102409591249*^9, 
  3.527106055321475*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"2", ",", "1"}], "}"}], ",", "15", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527102251312235*^9, 3.527102409591249*^9, 
  3.527106055713911*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"4", ",", "0"}], "}"}], ",", "15", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527102251312235*^9, 3.527102409591249*^9, 
  3.527106056537855*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "5"}], "}"}], ",", "21", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527102251312235*^9, 3.527102409591249*^9, 
  3.527106057878029*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"BranchingSU3", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   "\"\<\!\(\*SubscriptBox[\(A\), \(4\)]\)\>\""}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSU3", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "0"}], "}"}], ",", 
   "\"\<\!\(\*SubscriptBox[\(A\), \(4\)]\)\>\""}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSU3", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"2", ",", "0"}], "}"}], ",", 
   "\"\<\!\(\*SubscriptBox[\(A\), \(4\)]\)\>\""}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSU3", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   "\"\<\!\(\*SubscriptBox[\(A\), \(4\)]\)\>\""}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSU3", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "0"}], "}"}], ",", 
   "\"\<\!\(\*SubscriptBox[\(A\), \(4\)]\)\>\""}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSU3", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"2", ",", "1"}], "}"}], ",", 
   "\"\<\!\(\*SubscriptBox[\(A\), \(4\)]\)\>\""}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSU3", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"4", ",", "0"}], "}"}], ",", 
   "\"\<\!\(\*SubscriptBox[\(A\), \(4\)]\)\>\""}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSU3", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "5"}], "}"}], ",", 
   "\"\<\!\(\*SubscriptBox[\(A\), \(4\)]\)\>\""}], "]"}]}], "Input",
 CellChangeTimes->{{3.527093939791428*^9, 3.527093983730609*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", "1", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527093985569775*^9, 3.527094664438993*^9, 
  3.52709519925946*^9, 3.527095421256246*^9, 3.5270986235125313`*^9, 
  3.5271024278145733`*^9, 3.527106066992084*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "0"}], "}"}], ",", "3", ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527093985569775*^9, 3.527094664438993*^9, 
  3.52709519925946*^9, 3.527095421256246*^9, 3.5270986235125313`*^9, 
  3.5271024278145733`*^9, 3.52710606735314*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"2", ",", "0"}], "}"}], ",", "6", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527093985569775*^9, 3.527094664438993*^9, 
  3.52709519925946*^9, 3.527095421256246*^9, 3.5270986235125313`*^9, 
  3.5271024278145733`*^9, 3.527106067745646*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", "8", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527093985569775*^9, 3.527094664438993*^9, 
  3.52709519925946*^9, 3.527095421256246*^9, 3.5270986235125313`*^9, 
  3.5271024278145733`*^9, 3.527106068116891*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "0"}], "}"}], ",", "10", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527093985569775*^9, 3.527094664438993*^9, 
  3.52709519925946*^9, 3.527095421256246*^9, 3.5270986235125313`*^9, 
  3.5271024278145733`*^9, 3.527106068581667*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"2", ",", "1"}], "}"}], ",", "15", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527093985569775*^9, 3.527094664438993*^9, 
  3.52709519925946*^9, 3.527095421256246*^9, 3.5270986235125313`*^9, 
  3.5271024278145733`*^9, 3.527106068998086*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"4", ",", "0"}], "}"}], ",", "15", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527093985569775*^9, 3.527094664438993*^9, 
  3.52709519925946*^9, 3.527095421256246*^9, 3.5270986235125313`*^9, 
  3.5271024278145733`*^9, 3.527106069855792*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "5"}], "}"}], ",", "21", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527093985569775*^9, 3.527094664438993*^9, 
  3.52709519925946*^9, 3.527095421256246*^9, 3.5270986235125313`*^9, 
  3.5271024278145733`*^9, 3.527106070889388*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"BranchingSU3", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", "12", ",", "3"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSU3", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "0"}], "}"}], ",", "12", ",", "3"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSU3", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"2", ",", "0"}], "}"}], ",", "12", ",", "3"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSU3", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", "12", ",", "3"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSU3", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "0"}], "}"}], ",", "12", ",", "3"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSU3", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"2", ",", "1"}], "}"}], ",", "12", ",", "3"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSU3", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"4", ",", "0"}], "}"}], ",", "12", ",", "3"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSU3", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "5"}], "}"}], ",", "12", ",", "3"}], "]"}]}], "Input",
 CellChangeTimes->{{3.527102174068519*^9, 3.527102189774724*^9}, {
  3.5271024406280003`*^9, 3.527102451989003*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", "1", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527102452938637*^9, 3.527106073073189*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "0"}], "}"}], ",", "3", ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527102452938637*^9, 3.527106073442412*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"2", ",", "0"}], "}"}], ",", "6", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527102452938637*^9, 3.527106073832243*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", "8", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527102452938637*^9, 3.527106074203515*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "0"}], "}"}], ",", "10", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527102452938637*^9, 3.527106074684058*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"2", ",", "1"}], "}"}], ",", "15", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527102452938637*^9, 3.5271060750811357`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"4", ",", "0"}], "}"}], ",", "15", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527102452938637*^9, 3.527106075747313*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "5"}], "}"}], ",", "21", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527102452938637*^9, 3.527106076802039*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "example: branching rules for the SU(3) representations ",
 "(p,q)=(0,0),(1,0),(2,0),(1,1),(3,0),(2,1),(4,0),(0,5)",
 " in terms of ",
 Cell[BoxData[
  FormBox["\[CapitalSigma]", TraditionalForm]]],
 "(36\[Phi])-representations"
}], "Subsubsection",
 CellChangeTimes->{{3.526886816935697*^9, 3.526886848357449*^9}, 
   3.5268869415771837`*^9, {3.526887269318404*^9, 3.5268872706542892`*^9}, {
   3.526887306749323*^9, 3.526887333539502*^9}, 3.527095329098833*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"BranchingSU3", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", "15"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSU3", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "0"}], "}"}], ",", "15"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSU3", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"2", ",", "0"}], "}"}], ",", "15"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSU3", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", "15"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSU3", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "0"}], "}"}], ",", "15"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSU3", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"2", ",", "1"}], "}"}], ",", "15"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSU3", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"4", ",", "0"}], "}"}], ",", "15"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSU3", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "5"}], "}"}], ",", "15"}], "]"}]}], "Input",
 CellChangeTimes->{{3.527102471548397*^9, 3.527102473922336*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", "1", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.52710263717815*^9, 3.527106090878169*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "0"}], "}"}], ",", "3", ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "4"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.52710263717815*^9, 3.527106098960189*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"2", ",", "0"}], "}"}], ",", "6", ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "7"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.52710263717815*^9, 3.527106108962998*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", "8", ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "2"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.52710263717815*^9, 3.527106117778398*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "0"}], "}"}], ",", "10", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "2"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.52710263717815*^9, 3.52710612642376*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"2", ",", "1"}], "}"}], ",", "15", ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "8"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.52710263717815*^9, 3.5271061343020897`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"4", ",", "0"}], "}"}], ",", "15", ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "8"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.52710263717815*^9, 3.527106143441276*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "5"}], "}"}], ",", "21", ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "8"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.52710263717815*^9, 3.5271061533563347`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"BranchingSU3", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   "\"\<\[CapitalSigma](36\[Phi])\>\""}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSU3", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "0"}], "}"}], ",", 
   "\"\<\[CapitalSigma](36\[Phi])\>\""}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSU3", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"2", ",", "0"}], "}"}], ",", 
   "\"\<\[CapitalSigma](36\[Phi])\>\""}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSU3", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   "\"\<\[CapitalSigma](36\[Phi])\>\""}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSU3", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "0"}], "}"}], ",", 
   "\"\<\[CapitalSigma](36\[Phi])\>\""}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSU3", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"2", ",", "1"}], "}"}], ",", 
   "\"\<\[CapitalSigma](36\[Phi])\>\""}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSU3", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"4", ",", "0"}], "}"}], ",", 
   "\"\<\[CapitalSigma](36\[Phi])\>\""}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSU3", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "5"}], "}"}], ",", 
   "\"\<\[CapitalSigma](36\[Phi])\>\""}], "]"}]}], "Input",
 CellChangeTimes->{{3.5271025906900673`*^9, 3.5271025977934637`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", "1", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527106223944586*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "0"}], "}"}], ",", "3", ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "4"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527106232116663*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"2", ",", "0"}], "}"}], ",", "6", ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "7"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527106241081036*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", "8", ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "2"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527106249418461*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "0"}], "}"}], ",", "10", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "2"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527106257934767*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"2", ",", "1"}], "}"}], ",", "15", ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "8"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527106267192597*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"4", ",", "0"}], "}"}], ",", "15", ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "8"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5271062761411457`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "5"}], "}"}], ",", "21", ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "8"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527106285831386*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"BranchingSU3", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", "108", ",", "15"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSU3", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "0"}], "}"}], ",", "108", ",", "15"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSU3", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"2", ",", "0"}], "}"}], ",", "108", ",", "15"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSU3", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", "108", ",", "15"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSU3", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "0"}], "}"}], ",", "108", ",", "15"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSU3", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"2", ",", "1"}], "}"}], ",", "108", ",", "15"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSU3", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"4", ",", "0"}], "}"}], ",", "108", ",", "15"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"BranchingSU3", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "5"}], "}"}], ",", "108", ",", "15"}], "]"}]}], "Input",\

 CellChangeTimes->{{3.527102622852219*^9, 3.52710263255149*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", "1", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.52710647080366*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "0"}], "}"}], ",", "3", ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "4"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5271064805924597`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"2", ",", "0"}], "}"}], ",", "6", ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "7"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527106490268149*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", "8", ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "2"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527106499990518*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "0"}], "}"}], ",", "10", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "2"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527106509536787*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"2", ",", "1"}], "}"}], ",", "15", ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "8"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527106518818091*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"4", ",", "0"}], "}"}], ",", "15", ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "8"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527106528099873*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "5"}], "}"}], ",", "21", ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "8"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527106538597238*^9}]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{997, 707},
WindowMargins->{{Automatic, 61}, {23, Automatic}},
ShowSelection->True,
FrontEndVersion->"7.0 for Mac OS X x86 (32-bit) (February 18, 2009)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Info3531577041-8153022"->{
  Cell[3439, 114, 1269, 19, 446, "Print",
   CellTags->"Info3531577041-8153022"]},
 "Info3527150922-9962282"->{
  Cell[5224, 155, 340, 6, 78, "Print",
   CellTags->"Info3527150922-9962282"]},
 "Info3527150922-5989200"->{
  Cell[1231274, 30362, 283, 5, 60, "Print",
   CellTags->"Info3527150922-5989200"]},
 "Info3531577050-5498891"->{
  Cell[1231770, 30377, 265, 5, 60, "Print",
   CellTags->"Info3531577050-5498891"]},
 "Info3527150923-6293931"->{
  Cell[1232191, 30391, 255, 5, 60, "Print",
   CellTags->"Info3527150923-6293931"]},
 "Info3527150932-1637611"->{
  Cell[1236028, 30512, 322, 5, 78, "Print",
   CellTags->"Info3527150932-1637611"]},
 "Info3527150935-8240089"->{
  Cell[1243057, 30755, 330, 6, 78, "Print",
   CellTags->"Info3527150935-8240089"]},
 "Info3527150938-6414844"->{
  Cell[1249248, 30968, 329, 6, 78, "Print",
   CellTags->"Info3527150938-6414844"]},
 "Info3527150940-2017537"->{
  Cell[1266308, 31550, 346, 6, 78, "Print",
   CellTags->"Info3527150940-2017537"]},
 "Info3526802388-2904771"->{
  Cell[1286589, 32127, 228, 4, 42, "Print",
   CellTags->"Info3526802388-2904771"]},
 "Info3526802399-6783049"->{
  Cell[1313494, 33129, 250, 5, 60, "Print",
   CellTags->"Info3526802399-6783049"]},
 "Info3526234149-5112292"->{
  Cell[1331714, 33640, 249, 4, 59, "Print",
   CellTags->"Info3526234149-5112292"]},
 "Info3527267995-4843461"->{
  Cell[1349920, 34172, 275, 5, 42, "Print",
   CellTags->"Info3527267995-4843461"]},
 "Info3527268164-6807651"->{
  Cell[1354396, 34338, 324, 6, 60, "Print",
   CellTags->"Info3527268164-6807651"]},
 "Info3527268306-3045818"->{
  Cell[1356188, 34401, 317, 5, 59, "Print",
   CellTags->"Info3527268306-3045818"]},
 "Info3527150947-9618731"->{
  Cell[1358106, 34468, 401, 6, 96, "Print",
   CellTags->"Info3527150947-9618731"]},
 "Info3527150950-2894565"->{
  Cell[1363988, 34671, 565, 9, 131, "Print",
   CellTags->"Info3527150950-2894565"]},
 "Info3527150971-5335439"->{
  Cell[2219298, 56428, 540, 8, 132, "Print",
   CellTags->"Info3527150971-5335439"]},
 "Info3527265397-5772695"->{
  Cell[2344647, 60791, 492, 8, 114, "Print",
   CellTags->"Info3527265397-5772695"]},
 "Info3527265681-7129527"->{
  Cell[2413283, 62923, 611, 9, 150, "Print",
   CellTags->"Info3527265681-7129527"]},
 "Info3527265684-2771641"->{
  Cell[2429108, 63451, 625, 10, 150, "Print",
   CellTags->"Info3527265684-2771641"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Info3531577041-8153022", 2460954, 64538},
 {"Info3527150922-9962282", 2461066, 64541},
 {"Info3527150922-5989200", 2461175, 64544},
 {"Info3531577050-5498891", 2461289, 64547},
 {"Info3527150923-6293931", 2461403, 64550},
 {"Info3527150932-1637611", 2461517, 64553},
 {"Info3527150935-8240089", 2461631, 64556},
 {"Info3527150938-6414844", 2461745, 64559},
 {"Info3527150940-2017537", 2461859, 64562},
 {"Info3526802388-2904771", 2461973, 64565},
 {"Info3526802399-6783049", 2462087, 64568},
 {"Info3526234149-5112292", 2462201, 64571},
 {"Info3527267995-4843461", 2462315, 64574},
 {"Info3527268164-6807651", 2462429, 64577},
 {"Info3527268306-3045818", 2462543, 64580},
 {"Info3527150947-9618731", 2462657, 64583},
 {"Info3527150950-2894565", 2462771, 64586},
 {"Info3527150971-5335439", 2462886, 64589},
 {"Info3527265397-5772695", 2463001, 64592},
 {"Info3527265681-7129527", 2463116, 64595},
 {"Info3527265684-2771641", 2463231, 64598}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 107, 1, 76, "Title"],
Cell[677, 25, 550, 11, 155, "Section"],
Cell[CellGroupData[{
Cell[1252, 40, 99, 1, 37, "Section"],
Cell[CellGroupData[{
Cell[1376, 45, 158, 3, 34, "Subsection"],
Cell[1537, 50, 287, 6, 27, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1861, 61, 139, 1, 34, "Subsection"],
Cell[2003, 64, 245, 5, 27, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2285, 74, 244, 3, 34, "Subsection"],
Cell[CellGroupData[{
Cell[2554, 81, 52, 1, 27, "Input"],
Cell[CellGroupData[{
Cell[2631, 86, 141, 2, 20, "Print"],
Cell[2775, 90, 138, 2, 20, "Print"],
Cell[2916, 94, 119, 1, 20, "Print"],
Cell[3038, 97, 90, 1, 20, "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[3189, 105, 103, 1, 34, "Subsection"],
Cell[CellGroupData[{
Cell[3317, 110, 119, 2, 27, "Input"],
Cell[3439, 114, 1269, 19, 446, "Print",
 CellTags->"Info3531577041-8153022"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[4769, 140, 118, 1, 67, "Section"],
Cell[CellGroupData[{
Cell[4912, 145, 171, 2, 34, "Subsection"],
Cell[CellGroupData[{
Cell[5108, 151, 113, 2, 27, "Input"],
Cell[5224, 155, 340, 6, 78, "Print",
 CellTags->"Info3527150922-9962282"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5601, 166, 220, 7, 24, "Subsubsection"],
Cell[CellGroupData[{
Cell[5846, 177, 655, 13, 109, "Input"],
Cell[6504, 192, 3698, 117, 73, "Output"],
Cell[10205, 311, 3698, 117, 73, "Output"],
Cell[13906, 430, 3698, 117, 73, "Output"],
Cell[17607, 549, 3698, 117, 73, "Output"],
Cell[21308, 668, 3698, 117, 73, "Output"],
Cell[25009, 787, 3698, 117, 73, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[28756, 910, 156, 2, 18, "Subsubsection"],
Cell[CellGroupData[{
Cell[28937, 916, 426, 8, 73, "Input"],
Cell[29366, 926, 203913, 4702, 4723, "Output"],
Cell[233282, 5630, 203910, 4702, 4723, "Output"],
Cell[437195, 10334, 203913, 4702, 4723, "Output"],
Cell[641111, 15038, 203909, 4702, 4723, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[845069, 19746, 413, 14, 20, "Subsubsection"],
Cell[CellGroupData[{
Cell[845507, 19764, 880, 22, 63, "Input"],
Cell[846390, 19788, 12881, 360, 313, "Output"],
Cell[859274, 20150, 12882, 360, 313, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[872193, 20515, 717, 19, 63, "Input"],
Cell[872913, 20536, 178956, 4898, 4078, "Output"],
Cell[1051872, 25436, 179072, 4910, 4078, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1231005, 30353, 121, 1, 34, "Subsection"],
Cell[CellGroupData[{
Cell[1231151, 30358, 120, 2, 27, "Input"],
Cell[1231274, 30362, 283, 5, 60, "Print",
 CellTags->"Info3527150922-5989200"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1231594, 30372, 173, 3, 27, "Input"],
Cell[1231770, 30377, 265, 5, 60, "Print",
 CellTags->"Info3531577050-5498891"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1232072, 30387, 116, 2, 27, "Input"],
Cell[1232191, 30391, 255, 5, 60, "Print",
 CellTags->"Info3527150923-6293931"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1232483, 30401, 175, 3, 24, "Subsubsection"],
Cell[CellGroupData[{
Cell[1232683, 30408, 219, 4, 43, "Input"],
Cell[1232905, 30414, 197, 4, 33, "Output"],
Cell[1233105, 30420, 197, 4, 33, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1233339, 30429, 221, 4, 43, "Input"],
Cell[1233563, 30435, 230, 3, 29, "Output"],
Cell[1233796, 30440, 230, 3, 29, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1234075, 30449, 138, 1, 18, "Subsubsection"],
Cell[CellGroupData[{
Cell[1234238, 30454, 354, 7, 45, "Input"],
Cell[1234595, 30463, 148, 2, 27, "Output"],
Cell[1234746, 30467, 150, 2, 27, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1234945, 30475, 141, 1, 18, "Subsubsection"],
Cell[CellGroupData[{
Cell[1235111, 30480, 239, 4, 45, "Input"],
Cell[1235353, 30486, 94, 1, 27, "Output"],
Cell[1235450, 30489, 94, 1, 27, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1235617, 30498, 106, 1, 67, "Section"],
Cell[CellGroupData[{
Cell[1235748, 30503, 135, 1, 34, "Subsection"],
Cell[CellGroupData[{
Cell[1235908, 30508, 117, 2, 27, "Input"],
Cell[1236028, 30512, 322, 5, 78, "Print",
 CellTags->"Info3527150932-1637611"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1236387, 30522, 222, 7, 26, "Subsubsection"],
Cell[CellGroupData[{
Cell[1236634, 30533, 503, 9, 92, "Input"],
Cell[1237140, 30544, 725, 23, 55, "Output"],
Cell[1237868, 30569, 724, 23, 55, "Output"],
Cell[1238595, 30594, 725, 23, 55, "Output"],
Cell[1239323, 30619, 725, 23, 55, "Output"],
Cell[1240051, 30644, 725, 23, 55, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1240825, 30673, 177, 2, 18, "Subsubsection"],
Cell[CellGroupData[{
Cell[1241027, 30679, 312, 6, 58, "Input"],
Cell[1241342, 30687, 402, 14, 55, "Output"],
Cell[1241747, 30703, 404, 14, 55, "Output"],
Cell[1242154, 30719, 401, 14, 55, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1242628, 30741, 118, 1, 67, "Section"],
Cell[CellGroupData[{
Cell[1242771, 30746, 140, 1, 34, "Subsection"],
Cell[CellGroupData[{
Cell[1242936, 30751, 118, 2, 27, "Input"],
Cell[1243057, 30755, 330, 6, 78, "Print",
 CellTags->"Info3527150935-8240089"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1243424, 30766, 114, 1, 24, "Subsubsection"],
Cell[CellGroupData[{
Cell[1243563, 30771, 297, 5, 58, "Input"],
Cell[1243863, 30778, 545, 18, 33, "Output"],
Cell[1244411, 30798, 547, 18, 33, "Output"],
Cell[1244961, 30818, 547, 18, 33, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1245557, 30842, 168, 2, 18, "Subsubsection"],
Cell[CellGroupData[{
Cell[1245750, 30848, 305, 6, 58, "Input"],
Cell[1246058, 30856, 912, 30, 33, "Output"],
Cell[1246973, 30888, 914, 30, 33, "Output"],
Cell[1247890, 30920, 912, 30, 33, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1248863, 30957, 191, 2, 34, "Subsection"],
Cell[CellGroupData[{
Cell[1249079, 30963, 166, 3, 27, "Input"],
Cell[1249248, 30968, 329, 6, 78, "Print",
 CellTags->"Info3527150938-6414844"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1249614, 30979, 114, 1, 24, "Subsubsection"],
Cell[CellGroupData[{
Cell[1249753, 30984, 343, 6, 58, "Input"],
Cell[1250099, 30992, 2792, 97, 53, "Output"],
Cell[1252894, 31091, 2792, 97, 53, "Output"],
Cell[1255689, 31190, 2792, 97, 53, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1258530, 31293, 168, 2, 18, "Subsubsection"],
Cell[CellGroupData[{
Cell[1258723, 31299, 353, 7, 58, "Input"],
Cell[1259079, 31308, 2293, 74, 53, "Output"],
Cell[1261375, 31384, 2293, 74, 53, "Output"],
Cell[1263671, 31460, 2293, 74, 53, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1266025, 31541, 138, 1, 34, "Subsection"],
Cell[CellGroupData[{
Cell[1266188, 31546, 117, 2, 27, "Input"],
Cell[1266308, 31550, 346, 6, 78, "Print",
 CellTags->"Info3527150940-2017537"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1266691, 31561, 306, 9, 31, "Subsubsection"],
Cell[CellGroupData[{
Cell[1267022, 31574, 492, 10, 79, "Input"],
Cell[1267517, 31586, 847, 24, 49, "Output"],
Cell[1268367, 31612, 849, 24, 49, "Output"],
Cell[1269219, 31638, 847, 24, 49, "Output"],
Cell[1270069, 31664, 847, 24, 49, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1270965, 31694, 221, 7, 20, "Subsubsection"],
Cell[CellGroupData[{
Cell[1271211, 31705, 619, 14, 91, "Input"],
Cell[1271833, 31721, 1511, 37, 71, "Output"],
Cell[1273347, 31760, 1511, 37, 71, "Output"],
Cell[1274861, 31799, 1511, 37, 71, "Output"],
Cell[1276375, 31838, 1511, 37, 71, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1277935, 31881, 248, 3, 18, "Subsubsection"],
Cell[CellGroupData[{
Cell[1278208, 31888, 603, 13, 73, "Input"],
Cell[1278814, 31903, 203, 5, 33, "Output"],
Cell[1279020, 31910, 205, 5, 33, "Output"],
Cell[1279228, 31917, 203, 5, 33, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1279480, 31928, 452, 11, 20, "Subsubsection"],
Cell[CellGroupData[{
Cell[1279957, 31943, 448, 12, 46, "Input"],
Cell[1280408, 31957, 72, 1, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1280517, 31963, 1560, 37, 130, "Input"],
Cell[1282080, 32002, 310, 7, 30, "Output"],
Cell[1282393, 32011, 2674, 67, 103, "Output"],
Cell[1285070, 32080, 224, 4, 30, "Output"],
Cell[1285297, 32086, 226, 4, 30, "Output"],
Cell[1285526, 32092, 224, 4, 30, "Output"],
Cell[1285753, 32098, 224, 4, 30, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1286050, 32110, 193, 2, 67, "Section"],
Cell[CellGroupData[{
Cell[1286268, 32116, 173, 3, 34, "Subsection"],
Cell[CellGroupData[{
Cell[1286466, 32123, 120, 2, 27, "Input"],
Cell[1286589, 32127, 228, 4, 42, "Print",
 CellTags->"Info3526802388-2904771"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1286854, 32136, 100, 1, 24, "Subsubsection"],
Cell[CellGroupData[{
Cell[1286979, 32141, 130, 2, 27, "Input"],
Cell[1287112, 32145, 1100, 43, 53, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1288249, 32193, 129, 2, 27, "Input"],
Cell[1288381, 32197, 24746, 914, 669, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1313188, 33118, 159, 3, 34, "Subsection"],
Cell[CellGroupData[{
Cell[1313372, 33125, 119, 2, 27, "Input"],
Cell[1313494, 33129, 250, 5, 60, "Print",
 CellTags->"Info3526802399-6783049"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1313781, 33139, 245, 7, 24, "Subsubsection"],
Cell[CellGroupData[{
Cell[1314051, 33150, 204, 5, 27, "Input"],
Cell[1314258, 33157, 431, 13, 33, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1314726, 33175, 550, 13, 58, "Input"],
Cell[1315279, 33190, 243, 7, 35, "Output"],
Cell[1315525, 33199, 250, 6, 27, "Output"],
Cell[1315778, 33207, 412, 11, 35, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1316239, 33224, 468, 11, 25, "Subsubsection"],
Cell[CellGroupData[{
Cell[1316732, 33239, 301, 6, 27, "Input"],
Cell[1317036, 33247, 250, 6, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1317323, 33258, 156, 3, 27, "Input"],
Cell[1317482, 33263, 5539, 76, 227, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1323070, 33345, 401, 7, 18, "Subsubsection"],
Cell[CellGroupData[{
Cell[1323496, 33356, 404, 7, 27, "Input"],
Cell[1323903, 33365, 419, 11, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1324359, 33381, 160, 3, 27, "Input"],
Cell[1324522, 33386, 1844, 70, 53, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1326403, 33461, 368, 10, 39, "Input"],
Cell[1326774, 33473, 444, 9, 27, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1327267, 33488, 377, 7, 18, "Subsubsection"],
Cell[CellGroupData[{
Cell[1327669, 33499, 399, 7, 27, "Input"],
Cell[1328071, 33508, 294, 7, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1328402, 33520, 160, 3, 27, "Input"],
Cell[1328565, 33525, 1818, 70, 53, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1330420, 33600, 425, 10, 39, "Input"],
Cell[1330848, 33612, 404, 9, 27, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1331313, 33628, 203, 3, 34, "Subsection"],
Cell[CellGroupData[{
Cell[1331541, 33635, 170, 3, 27, "Input"],
Cell[1331714, 33640, 249, 4, 59, "Print",
 CellTags->"Info3526234149-5112292"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1332000, 33649, 245, 7, 24, "Subsubsection"],
Cell[CellGroupData[{
Cell[1332270, 33660, 964, 26, 81, "Input"],
Cell[1333237, 33688, 174, 5, 30, "Output"],
Cell[1333414, 33695, 102, 2, 27, "Output"],
Cell[1333519, 33699, 174, 5, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1333730, 33709, 104, 2, 27, "Input"],
Cell[1333837, 33713, 383, 12, 33, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1334269, 33731, 377, 10, 25, "Subsubsection"],
Cell[CellGroupData[{
Cell[1334671, 33745, 5815, 82, 252, "Input"],
Cell[1340489, 33829, 224, 6, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1340750, 33840, 86, 1, 27, "Input"],
Cell[1340839, 33843, 224, 6, 33, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1341112, 33855, 324, 6, 18, "Subsubsection"],
Cell[CellGroupData[{
Cell[1341461, 33865, 160, 3, 27, "Input"],
Cell[1341624, 33870, 1795, 69, 53, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1343456, 33944, 424, 9, 27, "Input"],
Cell[1343883, 33955, 370, 8, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1344290, 33968, 236, 7, 39, "Input"],
Cell[1344529, 33977, 319, 9, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1344885, 33991, 157, 3, 27, "Input"],
Cell[1345045, 33996, 248, 8, 30, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1345342, 34010, 373, 7, 18, "Subsubsection"],
Cell[CellGroupData[{
Cell[1345740, 34021, 160, 3, 27, "Input"],
Cell[1345903, 34026, 1817, 70, 53, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1347757, 34101, 447, 9, 27, "Input"],
Cell[1348207, 34112, 374, 8, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1348618, 34125, 260, 6, 39, "Input"],
Cell[1348881, 34133, 248, 6, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1349166, 34144, 198, 4, 27, "Input"],
Cell[1349367, 34150, 227, 6, 30, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1349655, 34163, 121, 1, 34, "Subsection"],
Cell[CellGroupData[{
Cell[1349801, 34168, 116, 2, 27, "Input"],
Cell[1349920, 34172, 275, 5, 42, "Print",
 CellTags->"Info3527267995-4843461"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1350232, 34182, 100, 1, 24, "Subsubsection"],
Cell[CellGroupData[{
Cell[1350357, 34187, 436, 11, 46, "Input"],
Cell[1350796, 34200, 731, 25, 50, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1351564, 34230, 583, 17, 43, "Input"],
Cell[1352150, 34249, 1821, 70, 53, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1354032, 34326, 213, 4, 34, "Subsection"],
Cell[CellGroupData[{
Cell[1354270, 34334, 123, 2, 27, "Input"],
Cell[1354396, 34338, 324, 6, 60, "Print",
 CellTags->"Info3527268164-6807651"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1354757, 34349, 203, 6, 26, "Subsubsection"],
Cell[CellGroupData[{
Cell[1354985, 34359, 425, 12, 27, "Input"],
Cell[1355413, 34373, 253, 7, 27, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1355727, 34387, 261, 5, 34, "Subsection"],
Cell[CellGroupData[{
Cell[1356013, 34396, 172, 3, 27, "Input"],
Cell[1356188, 34401, 317, 5, 59, "Print",
 CellTags->"Info3527268306-3045818"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1356542, 34411, 236, 7, 26, "Subsubsection"],
Cell[CellGroupData[{
Cell[1356803, 34422, 396, 11, 27, "Input"],
Cell[1357202, 34435, 276, 8, 27, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1357551, 34451, 155, 2, 67, "Section"],
Cell[CellGroupData[{
Cell[1357731, 34457, 226, 3, 34, "Subsection"],
Cell[CellGroupData[{
Cell[1357982, 34464, 121, 2, 27, "Input"],
Cell[1358106, 34468, 401, 6, 96, "Print",
 CellTags->"Info3527150947-9618731"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1358544, 34479, 254, 7, 24, "Subsubsection"],
Cell[CellGroupData[{
Cell[1358823, 34490, 335, 6, 58, "Input"],
Cell[1359161, 34498, 331, 11, 27, "Output"],
Cell[1359495, 34511, 333, 11, 27, "Output"],
Cell[1359831, 34524, 333, 11, 27, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1360213, 34541, 214, 4, 18, "Subsubsection"],
Cell[CellGroupData[{
Cell[1360452, 34549, 379, 7, 58, "Input"],
Cell[1360834, 34558, 945, 31, 27, "Output"],
Cell[1361782, 34591, 943, 31, 27, "Output"],
Cell[1362728, 34624, 943, 31, 27, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1363732, 34662, 104, 1, 34, "Subsection"],
Cell[CellGroupData[{
Cell[1363861, 34667, 124, 2, 27, "Input"],
Cell[1363988, 34671, 565, 9, 131, "Print",
 CellTags->"Info3527150950-2894565"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1364590, 34685, 242, 7, 24, "Subsubsection"],
Cell[CellGroupData[{
Cell[1364857, 34696, 213, 5, 27, "Input"],
Cell[1365073, 34703, 1292, 36, 117, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1366402, 34744, 166, 3, 27, "Input"],
Cell[1366571, 34749, 1318, 36, 117, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1367926, 34790, 190, 4, 27, "Input"],
Cell[1368119, 34796, 1294, 36, 117, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1369462, 34838, 181, 2, 18, "Subsubsection"],
Cell[CellGroupData[{
Cell[1369668, 34844, 413, 10, 43, "Input"],
Cell[1370084, 34856, 4603, 131, 119, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1374724, 34992, 555, 12, 43, "Input"],
Cell[1375282, 35006, 763880, 19208, 1237, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[2139211, 54220, 153, 3, 18, "Subsubsection"],
Cell[CellGroupData[{
Cell[2139389, 54227, 228, 5, 27, "Input"],
Cell[2139620, 54234, 26322, 719, 457, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2165979, 54958, 166, 3, 27, "Input"],
Cell[2166148, 54963, 26300, 719, 457, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2192485, 55687, 194, 4, 27, "Input"],
Cell[2192682, 55693, 26300, 719, 457, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2219043, 56419, 107, 1, 34, "Subsection"],
Cell[CellGroupData[{
Cell[2219175, 56424, 120, 2, 27, "Input"],
Cell[2219298, 56428, 540, 8, 132, "Print",
 CellTags->"Info3527150971-5335439"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2219875, 56441, 329, 9, 24, "Subsubsection"],
Cell[CellGroupData[{
Cell[2220229, 56454, 109, 2, 27, "Input"],
Cell[2220341, 56458, 331, 11, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2220709, 56474, 4925, 164, 199, "Input"],
Cell[2225637, 56640, 782, 26, 27, "Output"],
Cell[2226422, 56668, 783, 26, 27, "Output"],
Cell[2227208, 56696, 783, 26, 27, "Output"],
Cell[2227994, 56724, 783, 26, 27, "Output"],
Cell[2228780, 56752, 783, 26, 27, "Output"],
Cell[2229566, 56780, 783, 26, 27, "Output"],
Cell[2230352, 56808, 783, 26, 27, "Output"],
Cell[2231138, 56836, 783, 26, 27, "Output"],
Cell[2231924, 56864, 783, 26, 27, "Output"],
Cell[2232710, 56892, 783, 26, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2233530, 56923, 5393, 174, 199, "Input"],
Cell[2238926, 57099, 754, 25, 27, "Output"],
Cell[2239683, 57126, 756, 25, 27, "Output"],
Cell[2240442, 57153, 754, 25, 27, "Output"],
Cell[2241199, 57180, 754, 25, 27, "Output"],
Cell[2241956, 57207, 754, 25, 27, "Output"],
Cell[2242713, 57234, 754, 25, 27, "Output"],
Cell[2243470, 57261, 756, 25, 27, "Output"],
Cell[2244229, 57288, 756, 25, 27, "Output"],
Cell[2244988, 57315, 754, 25, 27, "Output"],
Cell[2245745, 57342, 754, 25, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2246536, 57372, 5037, 165, 199, "Input"],
Cell[2251576, 57539, 756, 25, 27, "Output"],
Cell[2252335, 57566, 756, 25, 27, "Output"],
Cell[2253094, 57593, 754, 25, 27, "Output"],
Cell[2253851, 57620, 756, 25, 27, "Output"],
Cell[2254610, 57647, 754, 25, 27, "Output"],
Cell[2255367, 57674, 756, 25, 27, "Output"],
Cell[2256126, 57701, 754, 25, 27, "Output"],
Cell[2256883, 57728, 754, 25, 27, "Output"],
Cell[2257640, 57755, 756, 25, 27, "Output"],
Cell[2258399, 57782, 754, 25, 27, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[2259202, 57813, 275, 8, 20, "Subsubsection"],
Cell[CellGroupData[{
Cell[2259502, 57825, 153, 3, 29, "Input"],
Cell[2259658, 57830, 411, 13, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2260106, 57848, 3072, 106, 238, "Input"],
Cell[2263181, 57956, 874, 29, 27, "Output"],
Cell[2264058, 57987, 874, 29, 27, "Output"],
Cell[2264935, 58018, 874, 29, 27, "Output"],
Cell[2265812, 58049, 876, 29, 27, "Output"],
Cell[2266691, 58080, 876, 29, 27, "Output"],
Cell[2267570, 58111, 874, 29, 27, "Output"],
Cell[2268447, 58142, 874, 29, 27, "Output"],
Cell[2269324, 58173, 874, 29, 27, "Output"],
Cell[2270201, 58204, 874, 29, 27, "Output"],
Cell[2271078, 58235, 874, 29, 27, "Output"],
Cell[2271955, 58266, 876, 29, 27, "Output"],
Cell[2272834, 58297, 876, 29, 27, "Output"],
Cell[2273713, 58328, 876, 29, 27, "Output"],
Cell[2274592, 58359, 874, 29, 27, "Output"],
Cell[2275469, 58390, 874, 29, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2276380, 58424, 3746, 121, 267, "Input"],
Cell[2280129, 58547, 876, 29, 27, "Output"],
Cell[2281008, 58578, 874, 29, 27, "Output"],
Cell[2281885, 58609, 874, 29, 27, "Output"],
Cell[2282762, 58640, 874, 29, 27, "Output"],
Cell[2283639, 58671, 874, 29, 27, "Output"],
Cell[2284516, 58702, 874, 29, 27, "Output"],
Cell[2285393, 58733, 876, 29, 27, "Output"],
Cell[2286272, 58764, 876, 29, 27, "Output"],
Cell[2287151, 58795, 874, 29, 27, "Output"],
Cell[2288028, 58826, 876, 29, 27, "Output"],
Cell[2288907, 58857, 876, 29, 27, "Output"],
Cell[2289786, 58888, 874, 29, 27, "Output"],
Cell[2290663, 58919, 874, 29, 27, "Output"],
Cell[2291540, 58950, 874, 29, 27, "Output"],
Cell[2292417, 58981, 874, 29, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2293328, 59015, 3258, 106, 238, "Input"],
Cell[2296589, 59123, 876, 29, 27, "Output"],
Cell[2297468, 59154, 876, 29, 27, "Output"],
Cell[2298347, 59185, 874, 29, 27, "Output"],
Cell[2299224, 59216, 876, 29, 27, "Output"],
Cell[2300103, 59247, 876, 29, 27, "Output"],
Cell[2300982, 59278, 874, 29, 27, "Output"],
Cell[2301859, 59309, 876, 29, 27, "Output"],
Cell[2302738, 59340, 874, 29, 27, "Output"],
Cell[2303615, 59371, 874, 29, 27, "Output"],
Cell[2304492, 59402, 874, 29, 27, "Output"],
Cell[2305369, 59433, 874, 29, 27, "Output"],
Cell[2306246, 59464, 874, 29, 27, "Output"],
Cell[2307123, 59495, 874, 29, 27, "Output"],
Cell[2308000, 59526, 874, 29, 27, "Output"],
Cell[2308877, 59557, 874, 29, 27, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[2309800, 59592, 209, 4, 18, "Subsubsection"],
Cell[CellGroupData[{
Cell[2310034, 59600, 142, 3, 27, "Input"],
Cell[2310179, 59605, 943, 31, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2311159, 59641, 1095, 32, 88, "Input"],
Cell[2312257, 59675, 1953, 65, 43, "Output"],
Cell[2314213, 59742, 1954, 65, 43, "Output"],
Cell[2316170, 59809, 1954, 65, 43, "Output"],
Cell[2318127, 59876, 1953, 65, 43, "Output"],
Cell[2320083, 59943, 1956, 65, 43, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2322076, 60013, 1217, 36, 88, "Input"],
Cell[2323296, 60051, 1932, 65, 43, "Output"],
Cell[2325231, 60118, 1932, 65, 43, "Output"],
Cell[2327166, 60185, 1932, 65, 43, "Output"],
Cell[2329101, 60252, 1934, 65, 43, "Output"],
Cell[2331038, 60319, 1934, 65, 43, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2333009, 60389, 1116, 36, 88, "Input"],
Cell[2334128, 60427, 1934, 65, 43, "Output"],
Cell[2336065, 60494, 1931, 65, 43, "Output"],
Cell[2337999, 60561, 1932, 65, 43, "Output"],
Cell[2339934, 60628, 1932, 65, 43, "Output"],
Cell[2341869, 60695, 1932, 65, 43, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2343874, 60768, 436, 7, 67, "Section"],
Cell[CellGroupData[{
Cell[2344335, 60779, 230, 5, 34, "Subsection"],
Cell[CellGroupData[{
Cell[2344590, 60788, 54, 1, 27, "Input"],
Cell[2344647, 60791, 492, 8, 114, "Print",
 CellTags->"Info3527265397-5772695"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2345176, 60804, 330, 8, 24, "Subsubsection"],
Cell[CellGroupData[{
Cell[2345531, 60816, 503, 9, 58, "Input"],
Cell[2346037, 60827, 2229, 72, 55, "Output"],
Cell[2348269, 60901, 2231, 72, 55, "Output"],
Cell[2350503, 60975, 2228, 72, 55, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[2352780, 61053, 376, 9, 20, "Subsubsection"],
Cell[CellGroupData[{
Cell[2353181, 61066, 558, 10, 60, "Input"],
Cell[2353742, 61078, 3821, 119, 102, "Output"],
Cell[2357566, 61199, 3823, 119, 102, "Output"],
Cell[2361392, 61320, 3821, 119, 102, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[2365262, 61445, 621, 16, 20, "Subsubsection"],
Cell[CellGroupData[{
Cell[2365908, 61465, 476, 8, 43, "Input"],
Cell[2366387, 61475, 290, 5, 27, "Output"],
Cell[2366680, 61482, 290, 5, 27, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[2367019, 61493, 367, 8, 18, "Subsubsection"],
Cell[CellGroupData[{
Cell[2367411, 61505, 502, 9, 58, "Input"],
Cell[2367916, 61516, 14987, 462, 525, "Output"],
Cell[2382906, 61980, 14987, 462, 525, "Output"],
Cell[2397896, 62444, 14987, 462, 525, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2412944, 62913, 188, 2, 34, "Subsection"],
Cell[CellGroupData[{
Cell[2413157, 62919, 123, 2, 27, "Input"],
Cell[2413283, 62923, 611, 9, 150, "Print",
 CellTags->"Info3527265681-7129527"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2413931, 62937, 385, 10, 24, "Subsubsection"],
Cell[CellGroupData[{
Cell[2414341, 62951, 601, 13, 103, "Input"],
Cell[2414945, 62966, 174, 5, 27, "Output"],
Cell[2415122, 62973, 174, 5, 27, "Output"],
Cell[2415299, 62980, 294, 9, 27, "Output"],
Cell[2415596, 62991, 292, 9, 27, "Output"],
Cell[2415891, 63002, 410, 13, 27, "Output"],
Cell[2416304, 63017, 411, 13, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2416752, 63035, 962, 21, 103, "Input"],
Cell[2417717, 63058, 174, 5, 27, "Output"],
Cell[2417894, 63065, 176, 5, 27, "Output"],
Cell[2418073, 63072, 291, 9, 27, "Output"],
Cell[2418367, 63083, 294, 9, 27, "Output"],
Cell[2418664, 63094, 412, 13, 27, "Output"],
Cell[2419079, 63109, 410, 13, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2419526, 63127, 669, 13, 103, "Input"],
Cell[2420198, 63142, 174, 5, 27, "Output"],
Cell[2420375, 63149, 176, 5, 27, "Output"],
Cell[2420554, 63156, 292, 9, 27, "Output"],
Cell[2420849, 63167, 292, 9, 27, "Output"],
Cell[2421144, 63178, 410, 13, 27, "Output"],
Cell[2421557, 63193, 413, 13, 27, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[2422019, 63212, 411, 10, 20, "Subsubsection"],
Cell[CellGroupData[{
Cell[2422455, 63226, 601, 13, 103, "Input"],
Cell[2423059, 63241, 174, 5, 27, "Output"],
Cell[2423236, 63248, 174, 5, 27, "Output"],
Cell[2423413, 63255, 174, 5, 27, "Output"],
Cell[2423590, 63262, 232, 7, 27, "Output"],
Cell[2423825, 63271, 233, 7, 27, "Output"],
Cell[2424061, 63280, 293, 9, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2424391, 63294, 869, 19, 114, "Input"],
Cell[2425263, 63315, 174, 5, 27, "Output"],
Cell[2425440, 63322, 174, 5, 27, "Output"],
Cell[2425617, 63329, 173, 5, 27, "Output"],
Cell[2425793, 63336, 233, 7, 27, "Output"],
Cell[2426029, 63345, 233, 7, 27, "Output"],
Cell[2426265, 63354, 295, 9, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2426597, 63368, 667, 13, 103, "Input"],
Cell[2427267, 63383, 174, 5, 27, "Output"],
Cell[2427444, 63390, 170, 5, 27, "Output"],
Cell[2427617, 63397, 174, 5, 27, "Output"],
Cell[2427794, 63404, 233, 7, 27, "Output"],
Cell[2428030, 63413, 233, 7, 27, "Output"],
Cell[2428266, 63422, 295, 9, 27, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2428622, 63438, 286, 4, 34, "Subsection"],
Cell[CellGroupData[{
Cell[2428933, 63446, 172, 3, 27, "Input"],
Cell[2429108, 63451, 625, 10, 150, "Print",
 CellTags->"Info3527265684-2771641"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2429770, 63466, 475, 10, 24, "Subsubsection"],
Cell[CellGroupData[{
Cell[2430270, 63480, 1192, 40, 133, "Input"],
Cell[2431465, 63522, 270, 8, 27, "Output"],
Cell[2431738, 63532, 272, 8, 27, "Output"],
Cell[2432013, 63542, 447, 14, 27, "Output"],
Cell[2432463, 63558, 447, 14, 27, "Output"],
Cell[2432913, 63574, 448, 14, 27, "Output"],
Cell[2433364, 63590, 625, 20, 27, "Output"],
Cell[2433992, 63612, 743, 24, 27, "Output"],
Cell[2434738, 63638, 743, 24, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2435518, 63667, 1552, 48, 133, "Input"],
Cell[2437073, 63717, 364, 9, 27, "Output"],
Cell[2437440, 63728, 363, 9, 27, "Output"],
Cell[2437806, 63739, 541, 15, 27, "Output"],
Cell[2438350, 63756, 541, 15, 27, "Output"],
Cell[2438894, 63773, 542, 15, 27, "Output"],
Cell[2439439, 63790, 719, 21, 27, "Output"],
Cell[2440161, 63813, 837, 25, 27, "Output"],
Cell[2441001, 63840, 837, 25, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2441875, 63870, 1331, 41, 133, "Input"],
Cell[2443209, 63913, 245, 7, 27, "Output"],
Cell[2443457, 63922, 245, 7, 27, "Output"],
Cell[2443705, 63931, 422, 13, 27, "Output"],
Cell[2444130, 63946, 422, 13, 27, "Output"],
Cell[2444555, 63961, 423, 13, 27, "Output"],
Cell[2444981, 63976, 602, 19, 27, "Output"],
Cell[2445586, 63997, 718, 23, 27, "Output"],
Cell[2446307, 64022, 718, 23, 27, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[2447074, 64051, 480, 10, 18, "Subsubsection"],
Cell[CellGroupData[{
Cell[2447579, 64065, 1179, 33, 133, "Input"],
Cell[2448761, 64100, 244, 7, 27, "Output"],
Cell[2449008, 64109, 244, 7, 27, "Output"],
Cell[2449255, 64118, 303, 9, 27, "Output"],
Cell[2449561, 64129, 303, 9, 27, "Output"],
Cell[2449867, 64140, 421, 13, 27, "Output"],
Cell[2450291, 64155, 483, 15, 27, "Output"],
Cell[2450777, 64172, 481, 15, 27, "Output"],
Cell[2451261, 64189, 601, 19, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2451899, 64213, 1463, 41, 133, "Input"],
Cell[2453365, 64256, 223, 7, 27, "Output"],
Cell[2453591, 64265, 223, 7, 27, "Output"],
Cell[2453817, 64274, 282, 9, 27, "Output"],
Cell[2454102, 64285, 282, 9, 27, "Output"],
Cell[2454387, 64296, 401, 13, 27, "Output"],
Cell[2454791, 64311, 460, 15, 27, "Output"],
Cell[2455254, 64328, 462, 15, 27, "Output"],
Cell[2455719, 64345, 578, 19, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2456334, 64369, 1297, 41, 133, "Input"],
Cell[2457634, 64412, 222, 7, 27, "Output"],
Cell[2457859, 64421, 225, 7, 27, "Output"],
Cell[2458087, 64430, 282, 9, 27, "Output"],
Cell[2458372, 64441, 282, 9, 27, "Output"],
Cell[2458657, 64452, 401, 13, 27, "Output"],
Cell[2459061, 64467, 460, 15, 27, "Output"],
Cell[2459524, 64484, 460, 15, 27, "Output"],
Cell[2459987, 64501, 578, 19, 27, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
