(* ::Package:: *)

(* SUtree 1.1: a package to investigate the invariants of finite SU (3) subgroups *)
(* Available at: http://theophys.kth.se/~amerle/SUtree/ *)
(* (accompanies arXiv:1110.4891 [hep-ph]) *)
(* Copyright \[Copyright] 2011: Alexander Merle & Roman Zwicky *)

(* This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version. *)

(*  This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details. *)

(*  For a copy of the GNU General Public License, please see
    <http://www.gnu.org/licenses/>. *)

(* Please report errors to amerle (AT)kth.se ! *)

(* Note that the user him/herself has to check the correctness of the 
   results obtained with SUtree. The authors take no responsibility
   for wrong results. Please report them instead of blaming us. *)

BeginPackage["SUtree`"]

SUtree::usage =
		"SUtree 1.1: a package to investigate the invariants of finite SU(3) subgroups
Available at: http://theophys.kth.se/~amerle/SUtree/SUtree.html
(accompanies arXiv:1110.4891 [hep-ph])

Copyright \[Copyright] 2011: Alexander Merle & Roman Zwicky

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

For a copy of the GNU General Public License, please see
<http://www.gnu.org/licenses/>.

Please report errors to: amerle(AT)kth.se

Note that the user him/herself has to check the correctness of the 
results obtained with SUtree. The authors take no responsibility
for wrong results. Please report them instead of blaming us."

Group::usage =
"Group['name'], Group[n], and Group[g,j] return a numerical list of all
group elements of the group 'name', the group with group number n, or the
group labeled by the GAP numbers [g,j]."

GroupName::usage =
"GroupName[n] or GroupName[g,j] return a the name of the group with
group number n or the group labeled by the GAP numbers [g,j]."

FinGroupOrder::usage =
"FinGroupOrder['name'] or FinGroupOrder[n] return the order of the group 
'name' or the group with group number n."

jNumber::usage =
"jNumber['name'] or jNumber[n] return the j-number of the group 'name' or
the group with group number n."

Molien::usage =
"Molien['name'], Molien[n], and Molien[g,j] return the Molien function of
the group 'name', the group with group number n, or the group labeled by 
the GAP numbers [g,j]."

PrimInv::usage =
"PrimInv['name'], PrimInv[n], and PrimInv[g,j] return the primary
invariants of the group 'name', the group with group number n, or the
group labeled by the GAP numbers [g,j]."

SecInv::usage =
"SecInv['name'], SecInv[n], and SecInv[g,j] return the secondary
invariants of the group 'name', the group with group number n, or the
group labeled by the GAP numbers [g,j]."

Syzygy::usage =
"Syzygy['name'], Syzygy[n], and Syzygy[g,j] return the syzygies of the
secondary invariants of the group 'name', the group with group number n,
or the group labeled by the GAP numbers [g,j]."

NormBasis::usage =
"NormBasis[deg] returns an orthonormalized basis for polynomials of degree deg."

InvFromVEV::usage =
"InvFromVEV[deg,VEV] returns the invariant polynomial of degree deg corresponding 
to a certain VEV."

VEVFromInv::usage =
"VEVFromInv[deg,poly] returns the VEV corresponding to the invariant polynomial
poly of degree deg."

pqBasis::usage =
"pqBasis[p,q] returns an orthonormalized (p,q)-basis. Note that xc=\!\(\*SuperscriptBox[\"x\", \"*\"]\), and so on."

pqInvFromVEV::usage =
"pqInvFromVEV[{p,q},VEV] returns the invariant (p,q)-polynomial corresponding 
to a certain VEV.  Note that xc=\!\(\*SuperscriptBox[\"x\", \"*\"]\), and so on."

pqVEVFromInv::usage =
"pqVEVFromInv[{p,q},poly] returns the VEV corresponding to the invariant 
(p,q)-polynomial poly. Note that xc=\!\(\*SuperscriptBox[\"x\", \"*\"]\), and so on."

GenFunction::usage =
"GenFunction['name'], GenFunction[n], and GenFunction[g,j] return the list 
of generating functions of the group 'name', the group with group number n, 
or the group labeled by the GAP numbers [g,j] involving the 3D-irrep from our 
list. The form of the output is: 
{dimension of the second representation, generating function}."

BranchingSO3::usage=
"BranchingSO3[l,'name'], BranchingSO3[l,n], BranchingSO3[l,g,j] return 
the 'dimension' of the SO(3) representation labeled by l, together with 
the composition of this representation in terms of the representations of 
the subgroup, for the group 'name', the group with group number n, or the 
group labeled by the GAP numbers [g,j]. 
The form of the output is: 
{SO(3)-label, dimension[SO(3)],{dimension[subgroup],#rep with that dimension}}."

BranchingSU3::usage=
"BranchingSU3[{p,q},'name'], BranchingSU3[{p,q},n], BranchingSU3[{p,q},g,j] 
return the 'dimension' of the SU(3) representation labeled by (p,q), 
together with the composition of this representation in terms of the 
representations of the subgroup, for the group 'name', the group with group 
number n, or the group labeled by the GAP numbers [g,j]. 
The form of the output is: 
{{p,q}, dimension[SU(3)],{dimension[subgroup],#rep with that dimension}}."

FiniteIrreps::usage=
"FiniteIrreps['name'], FiniteIrreps[n], and FiniteIrreps[g,j] return the 
list of irreducble representations (dimension and number in the list) of 
the group 'name', the group with group number n, or the group labeled by 
the GAP numbers [g,j]."

CharacterTable::usage=
"CharacterTable['name'], CharacterTable[n], and CharacterTable[g,j] return 
the character table of the group 'name', the group with group number n,
or the group labeled by the GAP numbers [g,j], in the form of a list. Note 
that the first element of the list containts the numbers of elements of the
respective conjugacy classes. The data for this function was taken from
GAP (www.gap-system.org)."

Kronecker::usage=
"Kronecker[Rep1,Rep2,'name'], Kronecker[Rep1,Rep2,n], and Kronecker[Rep1,Rep2,g,j] 
return the decomposition of the product Rep1xRep2 of the two representations
Rep1 and Rep2 in terms of irreducible representations of the group 'name', 
the group with group number n, or the group labeled by the GAP numbers [g,j]. 
The form of the output is:
{Rep1,Rep2,{Coefficient,Irrep}}."


x::usage =
        "x is a variable used in polynomials."

y::usage =
        "y is a variable used in polynomials."

z::usage =
        "z is a variable used in polynomials."

xc::usage =
        "xc is a complex conjugated variable used in polynomials."

yc::usage =
        "yc is a complex conjugated variable used in polynomials."

zc::usage =
        "zc is a complex conjugated variable used in polynomials."

P::usage =
        "P is a variable used in Molien functions."


Ip2::usage ="Invariant name."
Ip3::usage ="Invariant name."
Ip4::usage ="Invariant name."
Ip5::usage ="Invariant name."
Ip6::usage ="Invariant name."
Ip7::usage ="Invariant name."
Ip8::usage ="Invariant name."
Ip9::usage ="Invariant name."
Ip10::usage ="Invariant name."
Ip11::usage ="Invariant name."
Ip12::usage ="Invariant name."
Ip13::usage ="Invariant name."
Ip14::usage ="Invariant name."
Ip15::usage ="Invariant name."
Ip16::usage ="Invariant name."
Ip17::usage ="Invariant name."
Ip18::usage ="Invariant name."
Ip19::usage ="Invariant name."
Ip20::usage ="Invariant name."
Ip21::usage ="Invariant name."
Ip22::usage ="Invariant name."
Ip23::usage ="Invariant name."
Ip24::usage ="Invariant name."
Ip25::usage ="Invariant name."
Ip26::usage ="Invariant name."
Ip27::usage ="Invariant name."
Ip28::usage ="Invariant name."
Ip29::usage ="Invariant name."
Ip30::usage ="Invariant name."
Ip31::usage ="Invariant name."
Ip32::usage ="Invariant name."
Ip33::usage ="Invariant name."
Ip34::usage ="Invariant name."
Ip35::usage ="Invariant name."
Ip36::usage ="Invariant name."
Ip37::usage ="Invariant name."
Ip38::usage ="Invariant name."
Ip39::usage ="Invariant name."
Ip40::usage ="Invariant name."
Ip41::usage ="Invariant name."
Ip42::usage ="Invariant name."
Ip43::usage ="Invariant name."
Ip44::usage ="Invariant name."
Ip45::usage ="Invariant name."
Ip46::usage ="Invariant name."
Ip47::usage ="Invariant name."
Ip48::usage ="Invariant name."
Ip49::usage ="Invariant name."
Ip50::usage ="Invariant name."
Ip51::usage ="Invariant name."
Ip52::usage ="Invariant name."
Ip53::usage ="Invariant name."
Ip54::usage ="Invariant name."
Ip55::usage ="Invariant name."
Ip56::usage ="Invariant name."
Ip57::usage ="Invariant name."
Ip58::usage ="Invariant name."
Ip59::usage ="Invariant name."
Ip60::usage ="Invariant name."
Ip61::usage ="Invariant name."
Ip62::usage ="Invariant name."
Ip63::usage ="Invariant name."
Ip64::usage ="Invariant name."
Ip65::usage ="Invariant name."
Ip66::usage ="Invariant name."
Ip67::usage ="Invariant name."
Ip68::usage ="Invariant name."
Ip69::usage ="Invariant name."
Ip70::usage ="Invariant name."
Ip71::usage ="Invariant name."
Ip72::usage ="Invariant name."
Ip73::usage ="Invariant name."
Ip74::usage ="Invariant name."
Ip75::usage ="Invariant name."
Ip76::usage ="Invariant name."
Ip77::usage ="Invariant name."
Ip78::usage ="Invariant name."
Ip79::usage ="Invariant name."
Ip80::usage ="Invariant name."
Ip81::usage ="Invariant name."
Ip82::usage ="Invariant name."
Ip83::usage ="Invariant name."
Ip84::usage ="Invariant name."
Ip85::usage ="Invariant name."
Ip86::usage ="Invariant name."
Ip87::usage ="Invariant name."
Ip88::usage ="Invariant name."
Ip89::usage ="Invariant name."
Ip90::usage ="Invariant name."
Ip91::usage ="Invariant name."
Ip92::usage ="Invariant name."
Ip93::usage ="Invariant name."
Ip94::usage ="Invariant name."
Ip95::usage ="Invariant name."
Ip96::usage ="Invariant name."
Ip97::usage ="Invariant name."
Ip98::usage ="Invariant name."
Ip99::usage ="Invariant name."
Ip100::usage ="Invariant name."
Ip101::usage ="Invariant name."
Ip102::usage ="Invariant name."
Ip103::usage ="Invariant name."
Ip104::usage ="Invariant name."
Ip105::usage ="Invariant name."
Ip106::usage ="Invariant name."
Ip107::usage ="Invariant name."
Ip108::usage ="Invariant name."
Ip109::usage ="Invariant name."
Ip110::usage ="Invariant name."
Ip111::usage ="Invariant name."
Ip112::usage ="Invariant name."
Ip113::usage ="Invariant name."
Ip114::usage ="Invariant name."
Ip115::usage ="Invariant name."
Ip116::usage ="Invariant name."
Ip117::usage ="Invariant name."
Ip118::usage ="Invariant name."
Ip119::usage ="Invariant name."
Ip120::usage ="Invariant name."
Ip121::usage ="Invariant name."
Ip122::usage ="Invariant name."
Ip123::usage ="Invariant name."
Ip124::usage ="Invariant name."
Ip125::usage ="Invariant name."
Ip126::usage ="Invariant name."
Ip127::usage ="Invariant name."
Ip128::usage ="Invariant name."
Ip129::usage ="Invariant name."
Ip130::usage ="Invariant name."
Ip131::usage ="Invariant name."
Ip132::usage ="Invariant name."
Ip133::usage ="Invariant name."
Ip134::usage ="Invariant name."
Ip135::usage ="Invariant name."
Ip136::usage ="Invariant name."
Ip137::usage ="Invariant name."
Ip138::usage ="Invariant name."
Ip139::usage ="Invariant name."
Ip140::usage ="Invariant name."
Ip141::usage ="Invariant name."
Ip142::usage ="Invariant name."
Ip143::usage ="Invariant name."
Ip144::usage ="Invariant name."
Ip145::usage ="Invariant name."
Ip146::usage ="Invariant name."
Ip147::usage ="Invariant name."
Ip148::usage ="Invariant name."
Ip149::usage ="Invariant name."
Ip150::usage ="Invariant name."
Ip151::usage ="Invariant name."
Ip152::usage ="Invariant name."
Ip153::usage ="Invariant name."
Ip154::usage ="Invariant name."
Ip155::usage ="Invariant name."
Ip156::usage ="Invariant name."
Ip157::usage ="Invariant name."
Ip158::usage ="Invariant name."
Ip159::usage ="Invariant name."
Ip160::usage ="Invariant name."
Ip161::usage ="Invariant name."
Ip162::usage ="Invariant name."
Ip163::usage ="Invariant name."
Ip164::usage ="Invariant name."
Ip165::usage ="Invariant name."
Ip166::usage ="Invariant name."
Ip167::usage ="Invariant name."
Ip168::usage ="Invariant name."
Ip169::usage ="Invariant name."

Ip3a::usage ="Invariant name."
Ip3b::usage ="Invariant name."
Ip6a::usage ="Invariant name."
Ip6b::usage ="Invariant name."
Ip6c::usage ="Invariant name."
Ip9a::usage ="Invariant name."
Ip9b::usage ="Invariant name."
Ip10a::usage ="Invariant name."
Ip10b::usage ="Invariant name."
Ip14a::usage ="Invariant name."
Ip14b::usage ="Invariant name."
Ip18a::usage ="Invariant name."
Ip18b::usage ="Invariant name."

Is2::usage ="Invariant name."
Is3::usage ="Invariant name."
Is4::usage ="Invariant name."
Is5::usage ="Invariant name."
Is6::usage ="Invariant name."
Is7::usage ="Invariant name."
Is8::usage ="Invariant name."
Is9::usage ="Invariant name."
Is10::usage ="Invariant name."
Is11::usage ="Invariant name."
Is12::usage ="Invariant name."
Is13::usage ="Invariant name."
Is14::usage ="Invariant name."
Is15::usage ="Invariant name."
Is16::usage ="Invariant name."
Is17::usage ="Invariant name."
Is18::usage ="Invariant name."
Is19::usage ="Invariant name."
Is20::usage ="Invariant name."
Is21::usage ="Invariant name."
Is22::usage ="Invariant name."
Is23::usage ="Invariant name."
Is24::usage ="Invariant name."
Is25::usage ="Invariant name."
Is26::usage ="Invariant name."
Is27::usage ="Invariant name."
Is28::usage ="Invariant name."
Is29::usage ="Invariant name."
Is30::usage ="Invariant name."
Is31::usage ="Invariant name."
Is32::usage ="Invariant name."
Is33::usage ="Invariant name."
Is34::usage ="Invariant name."
Is35::usage ="Invariant name."
Is36::usage ="Invariant name."
Is37::usage ="Invariant name."
Is38::usage ="Invariant name."
Is39::usage ="Invariant name."
Is40::usage ="Invariant name."
Is41::usage ="Invariant name."
Is42::usage ="Invariant name."
Is43::usage ="Invariant name."
Is44::usage ="Invariant name."
Is45::usage ="Invariant name."
Is46::usage ="Invariant name."
Is47::usage ="Invariant name."
Is48::usage ="Invariant name."
Is49::usage ="Invariant name."
Is50::usage ="Invariant name."
Is51::usage ="Invariant name."
Is52::usage ="Invariant name."
Is53::usage ="Invariant name."
Is54::usage ="Invariant name."
Is55::usage ="Invariant name."
Is56::usage ="Invariant name."
Is57::usage ="Invariant name."
Is58::usage ="Invariant name."
Is59::usage ="Invariant name."
Is60::usage ="Invariant name."
Is61::usage ="Invariant name."
Is62::usage ="Invariant name."
Is63::usage ="Invariant name."
Is64::usage ="Invariant name."
Is65::usage ="Invariant name."
Is66::usage ="Invariant name."
Is67::usage ="Invariant name."
Is68::usage ="Invariant name."
Is69::usage ="Invariant name."
Is70::usage ="Invariant name."
Is71::usage ="Invariant name."
Is72::usage ="Invariant name."
Is73::usage ="Invariant name."
Is74::usage ="Invariant name."
Is75::usage ="Invariant name."
Is76::usage ="Invariant name."
Is77::usage ="Invariant name."
Is78::usage ="Invariant name."
Is79::usage ="Invariant name."
Is80::usage ="Invariant name."
Is81::usage ="Invariant name."
Is82::usage ="Invariant name."
Is83::usage ="Invariant name."
Is84::usage ="Invariant name."
Is85::usage ="Invariant name."
Is86::usage ="Invariant name."
Is87::usage ="Invariant name."
Is88::usage ="Invariant name."
Is89::usage ="Invariant name."
Is90::usage ="Invariant name."
Is91::usage ="Invariant name."
Is92::usage ="Invariant name."
Is93::usage ="Invariant name."
Is94::usage ="Invariant name."
Is95::usage ="Invariant name."
Is96::usage ="Invariant name."
Is97::usage ="Invariant name."
Is98::usage ="Invariant name."
Is99::usage ="Invariant name."
Is100::usage ="Invariant name."
Is101::usage ="Invariant name."
Is102::usage ="Invariant name."
Is103::usage ="Invariant name."
Is104::usage ="Invariant name."
Is105::usage ="Invariant name."
Is106::usage ="Invariant name."
Is107::usage ="Invariant name."
Is108::usage ="Invariant name."
Is109::usage ="Invariant name."
Is110::usage ="Invariant name."
Is111::usage ="Invariant name."
Is112::usage ="Invariant name."
Is113::usage ="Invariant name."
Is114::usage ="Invariant name."
Is115::usage ="Invariant name."
Is116::usage ="Invariant name."
Is117::usage ="Invariant name."
Is118::usage ="Invariant name."
Is119::usage ="Invariant name."
Is120::usage ="Invariant name."
Is121::usage ="Invariant name."
Is122::usage ="Invariant name."
Is123::usage ="Invariant name."
Is124::usage ="Invariant name."
Is125::usage ="Invariant name."
Is126::usage ="Invariant name."
Is127::usage ="Invariant name."
Is128::usage ="Invariant name."
Is129::usage ="Invariant name."
Is130::usage ="Invariant name."
Is131::usage ="Invariant name."
Is132::usage ="Invariant name."
Is133::usage ="Invariant name."
Is134::usage ="Invariant name."
Is135::usage ="Invariant name."
Is136::usage ="Invariant name."
Is137::usage ="Invariant name."
Is138::usage ="Invariant name."
Is139::usage ="Invariant name."
Is140::usage ="Invariant name."
Is141::usage ="Invariant name."
Is142::usage ="Invariant name."
Is143::usage ="Invariant name."
Is144::usage ="Invariant name."
Is145::usage ="Invariant name."
Is146::usage ="Invariant name."
Is147::usage ="Invariant name."
Is148::usage ="Invariant name."
Is149::usage ="Invariant name."
Is150::usage ="Invariant name."
Is151::usage ="Invariant name."
Is152::usage ="Invariant name."
Is153::usage ="Invariant name."
Is154::usage ="Invariant name."
Is155::usage ="Invariant name."
Is156::usage ="Invariant name."
Is157::usage ="Invariant name."
Is158::usage ="Invariant name."
Is159::usage ="Invariant name."
Is160::usage ="Invariant name."
Is161::usage ="Invariant name."
Is162::usage ="Invariant name."
Is163::usage ="Invariant name."
Is164::usage ="Invariant name."
Is165::usage ="Invariant name."
Is166::usage ="Invariant name."
Is167::usage ="Invariant name."
Is168::usage ="Invariant name."
Is169::usage ="Invariant name."
Is170::usage ="Invariant name."
Is171::usage ="Invariant name."
Is172::usage ="Invariant name."
Is173::usage ="Invariant name."
Is174::usage ="Invariant name."
Is175::usage ="Invariant name."
Is176::usage ="Invariant name."
Is177::usage ="Invariant name."
Is178::usage ="Invariant name."
Is179::usage ="Invariant name."
Is180::usage ="Invariant name."
Is181::usage ="Invariant name."
Is182::usage ="Invariant name."
Is183::usage ="Invariant name."
Is184::usage ="Invariant name."
Is185::usage ="Invariant name."
Is186::usage ="Invariant name."
Is187::usage ="Invariant name."
Is188::usage ="Invariant name."
Is189::usage ="Invariant name."
Is190::usage ="Invariant name."
Is191::usage ="Invariant name."
Is192::usage ="Invariant name."
Is193::usage ="Invariant name."
Is194::usage ="Invariant name."
Is195::usage ="Invariant name."
Is196::usage ="Invariant name."
Is197::usage ="Invariant name."
Is198::usage ="Invariant name."
Is199::usage ="Invariant name."
Is200::usage ="Invariant name."
Is201::usage ="Invariant name."
Is202::usage ="Invariant name."
Is203::usage ="Invariant name."
Is204::usage ="Invariant name."
Is205::usage ="Invariant name."
Is206::usage ="Invariant name."
Is207::usage ="Invariant name."
Is208::usage ="Invariant name."
Is209::usage ="Invariant name."
Is210::usage ="Invariant name."
Is211::usage ="Invariant name."
Is212::usage ="Invariant name."
Is213::usage ="Invariant name."
Is214::usage ="Invariant name."
Is215::usage ="Invariant name."
Is216::usage ="Invariant name."
Is217::usage ="Invariant name."
Is218::usage ="Invariant name."
Is219::usage ="Invariant name."
Is220::usage ="Invariant name."
Is221::usage ="Invariant name."
Is222::usage ="Invariant name."
Is223::usage ="Invariant name."
Is224::usage ="Invariant name."
Is225::usage ="Invariant name."
Is226::usage ="Invariant name."
Is227::usage ="Invariant name."
Is228::usage ="Invariant name."
Is229::usage ="Invariant name."
Is230::usage ="Invariant name."
Is231::usage ="Invariant name."
Is232::usage ="Invariant name."
Is233::usage ="Invariant name."
Is234::usage ="Invariant name."
Is235::usage ="Invariant name."
Is236::usage ="Invariant name."
Is237::usage ="Invariant name."
Is238::usage ="Invariant name."
Is239::usage ="Invariant name."
Is240::usage ="Invariant name."
Is241::usage ="Invariant name."
Is242::usage ="Invariant name."
Is243::usage ="Invariant name."
Is244::usage ="Invariant name."
Is245::usage ="Invariant name."
Is246::usage ="Invariant name."
Is247::usage ="Invariant name."
Is248::usage ="Invariant name."
Is249::usage ="Invariant name."

Is12a::usage ="Invariant name."
Is12b::usage ="Invariant name."
Is18a::usage ="Invariant name."
Is18b::usage ="Invariant name."
Is30a::usage ="Invariant name."
Is30b::usage ="Invariant name."
Is36a::usage ="Invariant name."
Is36b::usage ="Invariant name."
Is255::usage ="Invariant name."
Is263::usage ="Invariant name."
Is280::usage ="Invariant name."

UNKNOWN::usage ="Invariant name."


Begin["`Private`"]

Print["This is SUtree 1.1, which accompanies arXiv:1110.4891 [hep-ph]."]
Print["Copyright \[Copyright] 2011: Alexander Merle & Roman Zwicky."]
Print["Program is loading. This may take some time."]

(* Group imports: *)
Group01im=Chop[Import["./SUtreeData/Group01.dat", "Complex128"]];
Group02im=Chop[Import["./SUtreeData/Group02.dat", "Complex128"]];
Group03im=Chop[Import["./SUtreeData/Group03.dat", "Complex128"]];
Group04im=Chop[Import["./SUtreeData/Group04.dat", "Complex128"]];
Group05im=Chop[Import["./SUtreeData/Group05.dat", "Complex128"]];
Group06im=Chop[Import["./SUtreeData/Group06.dat", "Complex128"]];
Group07im=Chop[Import["./SUtreeData/Group07.dat", "Complex128"]];
Group08im=Chop[Import["./SUtreeData/Group08.dat", "Complex128"]];
Group09im=Chop[Import["./SUtreeData/Group09.dat", "Complex128"]];
Group10im=Chop[Import["./SUtreeData/Group10.dat", "Complex128"]];
Group11im=Chop[Import["./SUtreeData/Group11.dat", "Complex128"]];
Group12im=Chop[Import["./SUtreeData/Group12.dat", "Complex128"]];
Group13im=Chop[Import["./SUtreeData/Group13.dat", "Complex128"]];
Group14im=Chop[Import["./SUtreeData/Group14.dat", "Complex128"]];
Group15im=Chop[Import["./SUtreeData/Group15.dat", "Complex128"]];
Group16im=Chop[Import["./SUtreeData/Group16.dat", "Complex128"]];
Group17im=Chop[Import["./SUtreeData/Group17.dat", "Complex128"]];
Group18im=Chop[Import["./SUtreeData/Group18.dat", "Complex128"]];
Group19im=Chop[Import["./SUtreeData/Group19.dat", "Complex128"]];
Group20im=Chop[Import["./SUtreeData/Group20.dat", "Complex128"]];
Group21im=Chop[Import["./SUtreeData/Group21.dat", "Complex128"]];
Group22im=Chop[Import["./SUtreeData/Group22.dat", "Complex128"]];
Group23im=Chop[Import["./SUtreeData/Group23.dat", "Complex128"]];
Group24im=Chop[Import["./SUtreeData/Group24.dat", "Complex128"]];
Group25im=Chop[Import["./SUtreeData/Group25.dat", "Complex128"]];
Group26im=Chop[Import["./SUtreeData/Group26.dat", "Complex128"]];
Group27im=Chop[Import["./SUtreeData/Group27.dat", "Complex128"]];
Group28im=Chop[Import["./SUtreeData/Group28.dat", "Complex128"]];
Group29im=Chop[Import["./SUtreeData/Group29.dat", "Complex128"]];
Group30im=Chop[Import["./SUtreeData/Group30.dat", "Complex128"]];
Group31im=Chop[Import["./SUtreeData/Group31.dat", "Complex128"]];
Group32im=Chop[Import["./SUtreeData/Group32.dat", "Complex128"]];
Group33im=Chop[Import["./SUtreeData/Group33.dat", "Complex128"]];
Group34im=Chop[Import["./SUtreeData/Group34.dat", "Complex128"]];
Group35im=Chop[Import["./SUtreeData/Group35.dat", "Complex128"]];
Group36im=Chop[Import["./SUtreeData/Group36.dat", "Complex128"]];
Group37im=Chop[Import["./SUtreeData/Group37.dat", "Complex128"]];
Group38im=Chop[Import["./SUtreeData/Group38.dat", "Complex128"]];
Group39im=Chop[Import["./SUtreeData/Group39.dat", "Complex128"]];
Group40im=Chop[Import["./SUtreeData/Group40.dat", "Complex128"]];
Group41im=Chop[Import["./SUtreeData/Group41.dat", "Complex128"]];
Group42im=Chop[Import["./SUtreeData/Group42.dat", "Complex128"]];
Group43im=Chop[Import["./SUtreeData/Group43.dat", "Complex128"]];
Group44im=Chop[Import["./SUtreeData/Group44.dat", "Complex128"]];
Group45im=Chop[Import["./SUtreeData/Group45.dat", "Complex128"]];
Group46im=Chop[Import["./SUtreeData/Group46.dat", "Complex128"]];
Group47im=Chop[Import["./SUtreeData/Group47.dat", "Complex128"]];
Group48im=Chop[Import["./SUtreeData/Group48.dat", "Complex128"]];
Group49im=Chop[Import["./SUtreeData/Group49.dat", "Complex128"]];
Group50im=Chop[Import["./SUtreeData/Group50.dat", "Complex128"]];
Group51im=Chop[Import["./SUtreeData/Group51.dat", "Complex128"]];
Group52im=Chop[Import["./SUtreeData/Group52.dat", "Complex128"]];
Group53im=Chop[Import["./SUtreeData/Group53.dat", "Complex128"]];
Group54im=Chop[Import["./SUtreeData/Group54.dat", "Complex128"]];
Group55im=Chop[Import["./SUtreeData/Group55.dat", "Complex128"]];
Group56im=Chop[Import["./SUtreeData/Group56.dat", "Complex128"]];
Group57im=Chop[Import["./SUtreeData/Group57.dat", "Complex128"]];
Group58im=Chop[Import["./SUtreeData/Group58.dat", "Complex128"]];
Group59im=Chop[Import["./SUtreeData/Group59.dat", "Complex128"]];
Group60im=Chop[Import["./SUtreeData/Group60.dat", "Complex128"]];
Group61im=Chop[Import["./SUtreeData/Group61.dat", "Complex128"]];

GroupListFullIm={
Group01im,
Group02im,
Group03im,
Group04im,
Group05im,
Group06im,
Group07im,
Group08im,
Group09im,
Group10im,
Group11im,
Group12im,
Group13im,
Group14im,
Group15im,
Group16im,
Group17im,
Group18im,
Group19im,
Group20im,
Group21im,
Group22im,
Group23im,
Group24im,
Group25im,
Group26im,
Group27im,
Group28im,
Group29im,
Group30im,
Group31im,
Group32im,
Group33im,
Group34im,
Group35im,
Group36im,
Group37im,
Group38im,
Group39im,
Group40im,
Group41im,
Group42im,
Group43im,
Group44im,
Group45im,
Group46im,
Group47im,
Group48im,
Group49im,
Group50im,
Group51im,
Group52im,
Group53im,
Group54im,
Group55im,
Group56im,
Group57im,
Group58im,
Group59im,
Group60im,
Group61im
};

MakeProperGroup[GroupXYim_]:=(
ClearAll[inter,GroupXY,k];
inter=Flatten[GroupXYim];
GroupXY={};
For[kXYZ=1,kXYZ<=Length[inter]/9,kXYZ++,
	AppendTo[GroupXY,
	{
	{inter[[(kXYZ-1)*9+1]],inter[[(kXYZ-1)*9+2]],inter[[(kXYZ-1)*9+3]]},
	{inter[[(kXYZ-1)*9+4]],inter[[(kXYZ-1)*9+5]],inter[[(kXYZ-1)*9+6]]},
	{inter[[(kXYZ-1)*9+7]],inter[[(kXYZ-1)*9+8]],inter[[(kXYZ-1)*9+9]]}
	}
	];
];
Return[GroupXY]
)

GroupImport={
MakeProperGroup[Group01im],
MakeProperGroup[Group02im],
MakeProperGroup[Group03im],
MakeProperGroup[Group04im],
MakeProperGroup[Group05im],
MakeProperGroup[Group06im],
MakeProperGroup[Group07im],
MakeProperGroup[Group08im],
MakeProperGroup[Group09im],
MakeProperGroup[Group10im],
MakeProperGroup[Group11im],
MakeProperGroup[Group12im],
MakeProperGroup[Group13im],
MakeProperGroup[Group14im],
MakeProperGroup[Group15im],
MakeProperGroup[Group16im],
MakeProperGroup[Group17im],
MakeProperGroup[Group18im],
MakeProperGroup[Group19im],
MakeProperGroup[Group20im],
MakeProperGroup[Group21im],
MakeProperGroup[Group22im],
MakeProperGroup[Group23im],
MakeProperGroup[Group24im],
MakeProperGroup[Group25im],
MakeProperGroup[Group26im],
MakeProperGroup[Group27im],
MakeProperGroup[Group28im],
MakeProperGroup[Group29im],
MakeProperGroup[Group30im],
MakeProperGroup[Group31im],
MakeProperGroup[Group32im],
MakeProperGroup[Group33im],
MakeProperGroup[Group34im],
MakeProperGroup[Group35im],
MakeProperGroup[Group36im],
MakeProperGroup[Group37im],
MakeProperGroup[Group38im],
MakeProperGroup[Group39im],
MakeProperGroup[Group40im],
MakeProperGroup[Group41im],
MakeProperGroup[Group42im],
MakeProperGroup[Group43im],
MakeProperGroup[Group44im],
MakeProperGroup[Group45im],
MakeProperGroup[Group46im],
MakeProperGroup[Group47im],
MakeProperGroup[Group48im],
MakeProperGroup[Group49im],
MakeProperGroup[Group50im],
MakeProperGroup[Group51im],
MakeProperGroup[Group52im],
MakeProperGroup[Group53im],
MakeProperGroup[Group54im],
MakeProperGroup[Group55im],
MakeProperGroup[Group56im],
MakeProperGroup[Group57im],
MakeProperGroup[Group58im],
MakeProperGroup[Group59im],
MakeProperGroup[Group60im],
MakeProperGroup[Group61im]
};


(* Other imports: *)
GroupNames=ToExpression[Import["./SUtreeData/GroupNames.mml","MathML"]];
GroupOrders=ToExpression[Import["./SUtreeData/GroupOrders.mml","MathML"]];
jNumbers=ToExpression[Import["./SUtreeData/jNumbers.mml","MathML"]];
MolienFuncList=ToExpression[Import["./SUtreeData/MolienFuncList.mml","MathML"]];
NumeratorInvariantList=ToExpression[Import["./SUtreeData/NumeratorInvariantList.mml","MathML"]];
DenominatorInvariantList=ToExpression[Import["./SUtreeData/DenominatorInvariantList.mml","MathML"]];
SyzygyList=ToExpression[Import["./SUtreeData/SyzygyList.mml","MathML"]];


(* Generating functions (NOTE: Some are too lengthy to ex/import!!!): *)
Generating01=ToExpression[Import["./SUtreeData/Generating01.mml","MathML"]];
Generating02=ToExpression[Import["./SUtreeData/Generating02.mml","MathML"]];
Generating03=ToExpression[Import["./SUtreeData/Generating03.mml","MathML"]];
Generating04=ToExpression[Import["./SUtreeData/Generating04.mml","MathML"]];
Generating05=ToExpression[Import["./SUtreeData/Generating05.mml","MathML"]];
Generating06=ToExpression[Import["./SUtreeData/Generating06.mml","MathML"]];
Generating07=ToExpression[Import["./SUtreeData/Generating07.mml","MathML"]];
Generating08=ToExpression[Import["./SUtreeData/Generating08.mml","MathML"]];
Generating09=ToExpression[Import["./SUtreeData/Generating09.mml","MathML"]];
Generating10=ToExpression[Import["./SUtreeData/Generating10.mml","MathML"]];
Generating11=ToExpression[Import["./SUtreeData/Generating11.mml","MathML"]];
Generating12=ToExpression[Import["./SUtreeData/Generating12.mml","MathML"]];
Generating13=ToExpression[Import["./SUtreeData/Generating13.mml","MathML"]];
Generating14=ToExpression[Import["./SUtreeData/Generating14.mml","MathML"]];
Generating15=ToExpression[Import["./SUtreeData/Generating15.mml","MathML"]];
Generating16=ToExpression[Import["./SUtreeData/Generating16.mml","MathML"]];
Generating17=ToExpression[Import["./SUtreeData/Generating17.mml","MathML"]];
Generating18=ToExpression[Import["./SUtreeData/Generating18.mml","MathML"]];
Generating19=ToExpression[Import["./SUtreeData/Generating19.mml","MathML"]];
Generating20=ToExpression[Import["./SUtreeData/Generating20.mml","MathML"]];
Generating21=ToExpression[Import["./SUtreeData/Generating21.mml","MathML"]];
Generating22=ToExpression[Import["./SUtreeData/Generating22.mml","MathML"]];
Generating23=ToExpression[Import["./SUtreeData/Generating23.mml","MathML"]];
Generating24=ToExpression[Import["./SUtreeData/Generating24.mml","MathML"]];
Generating25=ToExpression[Import["./SUtreeData/Generating25.mml","MathML"]];
Generating26=ToExpression[Import["./SUtreeData/Generating26.mml","MathML"]];
Generating27=ToExpression[Import["./SUtreeData/Generating27.mml","MathML"]];
Generating28=ToExpression[Import["./SUtreeData/Generating28.mml","MathML"]];
Generating29=ToExpression[Import["./SUtreeData/Generating29.mml","MathML"]];
Generating30=ToExpression[Import["./SUtreeData/Generating30.mml","MathML"]];
Generating31=ToExpression[Import["./SUtreeData/Generating31.mml","MathML"]];
Generating32=ToExpression[Import["./SUtreeData/Generating32.mml","MathML"]];
Generating33=ToExpression[Import["./SUtreeData/Generating33.mml","MathML"]];
Generating34=ToExpression[Import["./SUtreeData/Generating34.mml","MathML"]];
Generating35=ToExpression[Import["./SUtreeData/Generating35.mml","MathML"]];
Generating36=ToExpression[Import["./SUtreeData/Generating36.mml","MathML"]];
Generating37={{1, (1 + P^14 + P^19 + P^24 + P^28 + P^29 + P^33 + P^37 + P^38 + P^42 + P^43 + P^47 + P^48 + P^51 + P^52 + P^53 + P^56 + P^57 + 
    P^58 + P^61 + P^62 + P^63 + P^65 + P^66 + P^67 + P^70 + P^72 + P^74 + P^75 + P^76 + P^77 + P^79 + P^80 + P^81 + P^82 + 
    P^84 + P^86 + P^87 + P^88 + P^89 + P^91 + P^92 + P^93 + P^94 + P^96 + P^98 + P^101 + P^102 + P^103 + P^105 + P^106 + P^107 + 
    P^110 + P^111 + P^112 + P^115 + P^116 + P^117 + P^120 + P^121 + P^125 + P^126 + P^130 + P^131 + P^135 + P^139 + P^140 + 
    P^144 + P^149 + P^154 + P^168)/((1 - P^3)*(1 - P^71)*(1 - P^97))}, 
 {1, (P^14 + P^19 + P^24 + P^28 + P^29 + P^33 + P^37 + P^38 + P^42 + P^43 + P^47 + P^48 + P^51 + P^52 + P^53 + P^56 + P^57 + 
    P^58 + P^61 + P^62 + P^63 + P^65 + P^66 + P^67 + P^70 + P^71 + P^72 + P^74 + P^75 + P^76 + P^77 + P^79 + P^80 + P^81 + 
    P^82 + P^84 + P^86 + P^87 + P^88 + P^89 + P^91 + P^92 + P^93 + P^94 + P^96 + P^97 + P^98 + P^101 + P^102 + P^103 + P^105 + 
    P^106 + P^107 + P^110 + P^111 + P^112 + P^115 + P^116 + P^117 + P^120 + P^121 + P^125 + P^126 + P^130 + P^131 + P^135 + 
    P^139 + P^140 + P^144 + P^149 + P^154)/((1 - P^3)*(1 - P^71)*(1 - P^97))}, 
 {1, (P^14 + P^19 + P^24 + P^28 + P^29 + P^33 + P^37 + P^38 + P^42 + P^43 + P^47 + P^48 + P^51 + P^52 + P^53 + P^56 + P^57 + 
    P^58 + P^61 + P^62 + P^63 + P^65 + P^66 + P^67 + P^70 + P^71 + P^72 + P^74 + P^75 + P^76 + P^77 + P^79 + P^80 + P^81 + 
    P^82 + P^84 + P^86 + P^87 + P^88 + P^89 + P^91 + P^92 + P^93 + P^94 + P^96 + P^97 + P^98 + P^101 + P^102 + P^103 + P^105 + 
    P^106 + P^107 + P^110 + P^111 + P^112 + P^115 + P^116 + P^117 + P^120 + P^121 + P^125 + P^126 + P^130 + P^131 + P^135 + 
    P^139 + P^140 + P^144 + P^149 + P^154)/((1 - P^3)*(1 - P^71)*(1 - P^97))}, 
 {3, (P^2 + P^10 + P^15 + 2*P^16 + P^20 + 2*P^21 + P^24 + P^25 + 2*P^26 + P^29 + 2*P^30 + 2*P^31 + P^34 + 2*P^35 + P^36 + P^38 + 
    3*P^39 + 2*P^40 + P^43 + 3*P^44 + 2*P^45 + P^47 + P^48 + 3*P^49 + 2*P^50 + P^52 + 3*P^53 + 3*P^54 + 2*P^55 + P^57 + 3*P^58 + 
    2*P^59 + 2*P^60 + P^61 + 2*P^62 + 3*P^63 + 2*P^64 + 2*P^65 + P^66 + 3*P^67 + 3*P^68 + 2*P^69 + P^70 + P^71 + 3*P^72 + 
    2*P^73 + 2*P^74 + P^75 + 3*P^76 + 3*P^77 + 3*P^78 + 2*P^79 + P^80 + 2*P^81 + 3*P^82 + 3*P^83 + 3*P^84 + P^85 + 2*P^86 + 
    P^87 + 3*P^88 + 3*P^89 + 3*P^90 + 2*P^91 + P^92 + 2*P^93 + 3*P^94 + 2*P^95 + 2*P^96 + P^97 + 3*P^98 + 3*P^99 + 2*P^100 + 
    P^101 + P^102 + 3*P^103 + 3*P^104 + 2*P^105 + P^106 + 2*P^107 + 3*P^108 + 2*P^109 + P^111 + 3*P^112 + 3*P^113 + 2*P^114 + 
    P^116 + 3*P^117 + 2*P^118 + 2*P^119 + P^121 + 3*P^122 + 2*P^123 + P^126 + 3*P^127 + 2*P^128 + P^130 + P^131 + 2*P^132 + 
    P^133 + P^135 + P^136 + 2*P^137 + P^140 + 2*P^141 + 2*P^142 + P^145 + 2*P^146 + P^150 + 2*P^151 + 2*P^156 + P^164)/
   ((1 - P^3)*(1 - P^71)*(1 - P^97))}, {3, (P^9 + P^11 + P^13 + P^14 + P^16 + P^18 + P^21 + P^22 + 2*P^23 + P^25 + P^27 + P^28 + 
    P^30 + 2*P^32 + P^33 + P^34 + P^35 + P^36 + 2*P^37 + P^38 + P^39 + P^40 + P^41 + 2*P^42 + P^43 + P^44 + P^45 + 2*P^46 + 
    2*P^47 + 2*P^48 + P^49 + 2*P^50 + 2*P^51 + 2*P^52 + P^53 + P^54 + 2*P^55 + 2*P^56 + 2*P^57 + P^58 + 2*P^59 + 2*P^60 + 
    2*P^61 + 2*P^62 + P^63 + 2*P^64 + 2*P^65 + 2*P^66 + 2*P^67 + P^68 + 3*P^69 + 2*P^70 + 3*P^71 + 2*P^72 + 2*P^73 + 3*P^74 + 
    2*P^75 + 3*P^76 + 2*P^77 + 2*P^78 + 3*P^79 + P^80 + 3*P^81 + P^82 + 3*P^83 + 2*P^84 + 2*P^85 + 3*P^86 + P^87 + 3*P^88 + 
    P^89 + 3*P^90 + 2*P^91 + 2*P^92 + 2*P^93 + P^94 + 3*P^95 + 2*P^96 + 3*P^97 + 2*P^98 + 2*P^99 + 3*P^100 + 2*P^101 + 3*P^102 + 
    P^103 + 2*P^104 + 2*P^105 + 2*P^106 + 2*P^107 + P^108 + 2*P^109 + 2*P^110 + 2*P^111 + 2*P^112 + P^113 + 2*P^114 + 2*P^115 + 
    2*P^116 + P^117 + P^118 + P^119 + 2*P^120 + P^121 + P^122 + P^123 + 2*P^124 + 2*P^125 + P^126 + P^127 + P^128 + 2*P^129 + 
    P^130 + P^131 + P^132 + P^133 + 2*P^134 + P^135 + P^136 + P^137 + P^138 + 2*P^139 + P^141 + P^143 + P^144 + P^146 + P^148 + 
    P^149 + P^151 + P^153 + P^158 + P^160 + P^162)/((1 - P^3)*(1 - P^71)*(1 - P^97))}, 
 {3, (P^7 + P^8 + P^9 + P^16 + P^17 + P^18 + P^21 + P^22 + P^23 + P^26 + P^27 + P^28 + P^30 + 2*P^31 + 2*P^32 + P^33 + P^35 + 
    2*P^36 + 2*P^37 + P^38 + P^40 + 2*P^41 + 2*P^42 + P^43 + P^44 + 2*P^45 + 2*P^46 + P^47 + P^49 + 2*P^50 + 2*P^51 + P^52 + 
    P^53 + 2*P^54 + 3*P^55 + 2*P^56 + P^57 + P^58 + 2*P^59 + 3*P^60 + 2*P^61 + P^62 + P^63 + 2*P^64 + 3*P^65 + 2*P^66 + 2*P^67 + 
    2*P^68 + 3*P^69 + 3*P^70 + 2*P^71 + 2*P^72 + 2*P^73 + 3*P^74 + 2*P^75 + 2*P^76 + 2*P^77 + 2*P^78 + 2*P^79 + P^80 + 2*P^81 + 
    2*P^82 + 3*P^83 + 3*P^84 + 2*P^85 + 2*P^86 + P^87 + 2*P^88 + 2*P^89 + 3*P^90 + 3*P^91 + 2*P^92 + 2*P^93 + 2*P^94 + 3*P^95 + 
    3*P^96 + 2*P^97 + 2*P^98 + 2*P^99 + 3*P^100 + 2*P^101 + P^102 + P^103 + 2*P^104 + 3*P^105 + 2*P^106 + P^107 + P^108 + 
    2*P^109 + 3*P^110 + 2*P^111 + P^112 + P^113 + 2*P^114 + 2*P^115 + P^116 + P^117 + 2*P^118 + 3*P^119 + 2*P^120 + P^121 + 
    P^122 + 2*P^123 + 2*P^124 + P^125 + P^127 + 2*P^128 + 2*P^129 + P^130 + P^132 + 2*P^133 + 2*P^134 + P^135 + P^137 + P^138 + 
    P^139 + P^142 + P^143 + P^144 + P^146 + P^147 + P^148 + P^151 + P^152 + P^153 + P^156 + P^157 + P^158)/
   ((1 - P^3)*(1 - P^71)*(1 - P^97))}, {3, (P^5 + P^9 + P^10 + P^14 + P^18 + 2*P^19 + P^23 + 2*P^24 + 2*P^28 + 2*P^29 + P^32 + 
    3*P^33 + 2*P^34 + P^37 + 3*P^38 + P^39 + 3*P^42 + 3*P^43 + P^44 + P^46 + 3*P^47 + 2*P^48 + 2*P^51 + 3*P^52 + 2*P^53 + P^55 + 
    3*P^56 + 3*P^57 + 2*P^58 + P^60 + 3*P^61 + 3*P^62 + 2*P^63 + 2*P^65 + 3*P^66 + 3*P^67 + 2*P^68 + P^69 + 3*P^70 + 3*P^71 + 
    3*P^72 + P^73 + P^74 + 3*P^75 + 2*P^76 + 3*P^77 + P^78 + 3*P^79 + 2*P^80 + 2*P^81 + 2*P^82 + P^83 + 3*P^84 + 2*P^85 + 
    3*P^86 + 2*P^87 + 2*P^88 + 2*P^89 + P^90 + 3*P^91 + 3*P^92 + 3*P^93 + 2*P^94 + P^95 + 3*P^96 + 3*P^97 + 3*P^98 + P^99 + 
    P^100 + 3*P^101 + 3*P^102 + 2*P^103 + P^105 + 3*P^106 + 3*P^107 + 2*P^108 + 2*P^110 + 3*P^111 + 3*P^112 + 2*P^115 + 
    3*P^116 + 2*P^117 + P^119 + 3*P^120 + 3*P^121 + P^122 + P^124 + 3*P^125 + 2*P^126 + P^129 + 3*P^130 + 2*P^131 + P^134 + 
    3*P^135 + P^136 + P^139 + 2*P^140 + 2*P^144 + 2*P^145 + 2*P^149 + P^153 + 2*P^154 + P^158 + P^159)/
   ((1 - P^3)*(1 - P^71)*(1 - P^97))}, {3, (P^3 + P^8 + P^13 + 2*P^17 + P^18 + 3*P^22 + P^26 + 3*P^27 + 2*P^31 + 3*P^32 + 
    3*P^36 + 2*P^37 + 2*P^40 + 3*P^41 + P^42 + 3*P^45 + 3*P^46 + P^47 + 3*P^50 + 3*P^51 + P^52 + 2*P^54 + 3*P^55 + 3*P^56 + 
    3*P^59 + 3*P^60 + 3*P^61 + P^63 + 3*P^64 + 3*P^65 + 3*P^66 + 2*P^68 + 3*P^69 + 3*P^70 + 2*P^71 + 3*P^73 + 2*P^74 + 3*P^75 + 
    P^76 + 2*P^77 + 3*P^78 + 2*P^79 + 3*P^80 + P^81 + 3*P^82 + 3*P^83 + 2*P^84 + 3*P^85 + P^86 + 3*P^87 + P^88 + 2*P^89 + 
    3*P^90 + 2*P^91 + 3*P^92 + 3*P^94 + 3*P^95 + 3*P^96 + 2*P^97 + 3*P^99 + 3*P^100 + 3*P^101 + P^102 + 3*P^104 + 3*P^105 + 
    3*P^106 + P^108 + 3*P^109 + 3*P^110 + P^111 + 2*P^113 + 3*P^114 + 3*P^115 + 2*P^118 + 3*P^119 + 3*P^120 + 2*P^123 + 
    3*P^124 + P^125 + 3*P^128 + 3*P^129 + 3*P^133 + 2*P^134 + 3*P^138 + P^139 + P^142 + 3*P^143 + 2*P^147 + P^148 + 2*P^152 + 
    2*P^157 + P^162)/((1 - P^3)*(1 - P^71)*(1 - P^97))}, 
 {3, (P^5 + P^7 + P^12 + P^16 + P^17 + P^19 + 2*P^21 + P^24 + 2*P^26 + P^28 + P^29 + P^30 + 2*P^31 + P^33 + P^34 + 2*P^35 + 
    2*P^36 + P^38 + P^39 + 2*P^40 + P^41 + P^42 + P^43 + 2*P^44 + 2*P^45 + P^46 + P^47 + P^48 + 2*P^49 + 2*P^50 + P^51 + P^52 + 
    2*P^53 + 2*P^54 + 2*P^55 + P^56 + P^57 + 3*P^58 + 2*P^59 + 2*P^60 + P^61 + P^62 + 3*P^63 + 2*P^64 + 3*P^65 + P^66 + 2*P^67 + 
    3*P^68 + 2*P^69 + 3*P^70 + P^71 + 3*P^72 + 2*P^73 + 2*P^74 + 2*P^75 + P^76 + 3*P^77 + P^78 + 3*P^79 + 2*P^80 + 3*P^81 + 
    3*P^82 + P^83 + 3*P^84 + P^85 + 3*P^86 + 2*P^87 + 2*P^88 + 3*P^89 + P^90 + 3*P^91 + P^92 + 3*P^93 + 3*P^94 + 2*P^95 + 
    3*P^96 + P^97 + 3*P^98 + 2*P^99 + 2*P^100 + 2*P^101 + P^102 + 3*P^103 + 2*P^104 + 2*P^105 + P^106 + P^107 + 3*P^108 + 
    2*P^109 + 2*P^110 + P^111 + 2*P^112 + 2*P^113 + 2*P^114 + P^115 + P^116 + 2*P^117 + 2*P^118 + 2*P^119 + P^120 + P^121 + 
    2*P^122 + 2*P^123 + P^124 + P^125 + P^126 + 2*P^127 + 2*P^128 + P^130 + P^131 + 2*P^132 + 2*P^133 + P^135 + 2*P^137 + 
    P^138 + P^140 + 2*P^142 + P^144 + P^145 + P^146 + P^147 + P^149 + P^151 + P^154 + 2*P^156 + P^161)/
   ((1 - P^3)*(1 - P^71)*(1 - P^97))}, {3, (P + P^12 + 2*P^15 + P^17 + 2*P^20 + P^22 + 2*P^25 + P^26 + P^27 + 2*P^29 + 2*P^30 + 
    P^31 + 2*P^34 + P^35 + P^36 + 2*P^38 + 2*P^39 + P^40 + P^41 + 2*P^43 + 2*P^44 + P^45 + P^46 + 2*P^48 + 3*P^49 + P^50 + 
    P^51 + 2*P^52 + 2*P^53 + 3*P^54 + P^55 + P^56 + 2*P^57 + 2*P^58 + 3*P^59 + P^60 + P^61 + 2*P^62 + 3*P^63 + 3*P^64 + P^65 + 
    2*P^66 + 2*P^67 + 3*P^68 + P^69 + P^70 + 2*P^71 + 2*P^72 + 3*P^73 + P^74 + 3*P^75 + 2*P^76 + 3*P^77 + 3*P^78 + P^79 + 
    3*P^80 + 2*P^81 + 3*P^82 + 2*P^83 + P^84 + 3*P^85 + P^86 + 3*P^87 + 2*P^88 + 3*P^89 + 3*P^90 + P^91 + 3*P^92 + 2*P^93 + 
    3*P^94 + 2*P^95 + P^96 + 2*P^97 + 2*P^98 + 3*P^99 + P^100 + P^101 + 2*P^102 + 3*P^103 + 3*P^104 + P^105 + 2*P^106 + 
    2*P^107 + 3*P^108 + P^109 + P^110 + 2*P^111 + 2*P^112 + 3*P^113 + P^114 + P^115 + 2*P^116 + 2*P^117 + 3*P^118 + P^119 + 
    2*P^121 + 2*P^122 + P^123 + P^124 + 2*P^126 + 2*P^127 + P^128 + P^129 + 2*P^131 + 2*P^132 + P^133 + 2*P^136 + P^137 + 
    P^138 + 2*P^140 + 2*P^141 + P^142 + 2*P^145 + P^147 + 2*P^150 + P^152 + 2*P^155 + P^166)/((1 - P^3)*(1 - P^71)*(1 - P^97))}, 
 {3, (P^10 + P^11 + P^12 + P^15 + P^16 + P^17 + P^20 + P^21 + P^22 + P^24 + P^25 + P^26 + P^29 + P^30 + P^31 + P^33 + 2*P^34 + 
    2*P^35 + P^36 + P^38 + 2*P^39 + 2*P^40 + P^41 + P^43 + 2*P^44 + 2*P^45 + P^46 + P^47 + 2*P^48 + 3*P^49 + 2*P^50 + P^51 + 
    P^52 + 2*P^53 + 2*P^54 + P^55 + P^56 + 2*P^57 + 3*P^58 + 2*P^59 + P^60 + P^61 + 2*P^62 + 3*P^63 + 2*P^64 + P^65 + P^66 + 
    2*P^67 + 3*P^68 + 2*P^69 + 2*P^70 + 2*P^71 + 3*P^72 + 3*P^73 + 2*P^74 + 2*P^75 + 2*P^76 + 3*P^77 + 3*P^78 + 2*P^79 + 
    2*P^80 + P^81 + 2*P^82 + 2*P^83 + 3*P^84 + 3*P^85 + 2*P^86 + 2*P^87 + P^88 + 2*P^89 + 2*P^90 + 2*P^91 + 2*P^92 + 2*P^93 + 
    3*P^94 + 2*P^95 + 2*P^96 + 2*P^97 + 3*P^98 + 3*P^99 + 2*P^100 + 2*P^101 + 2*P^102 + 3*P^103 + 2*P^104 + P^105 + P^106 + 
    2*P^107 + 3*P^108 + 2*P^109 + P^110 + P^111 + 2*P^112 + 3*P^113 + 2*P^114 + P^115 + P^116 + 2*P^117 + 2*P^118 + P^119 + 
    P^121 + 2*P^122 + 2*P^123 + P^124 + P^125 + 2*P^126 + 2*P^127 + P^128 + P^130 + 2*P^131 + 2*P^132 + P^133 + P^135 + 
    2*P^136 + 2*P^137 + P^138 + P^140 + P^141 + P^142 + P^145 + P^146 + P^147 + P^150 + P^151 + P^152 + P^159 + P^160 + P^161)/
   ((1 - P^3)*(1 - P^71)*(1 - P^97))}, {3, (P^6 + P^8 + P^10 + P^15 + P^17 + P^19 + P^20 + P^22 + P^24 + P^25 + P^27 + 2*P^29 + 
    P^30 + P^31 + P^32 + P^33 + 2*P^34 + P^35 + P^36 + P^37 + P^38 + 2*P^39 + P^40 + P^41 + P^42 + 2*P^43 + 2*P^44 + P^45 + 
    P^46 + P^47 + 2*P^48 + P^49 + P^50 + P^51 + 2*P^52 + 2*P^53 + 2*P^54 + P^55 + 2*P^56 + 2*P^57 + 2*P^58 + 2*P^59 + P^60 + 
    2*P^61 + 2*P^62 + 2*P^63 + 2*P^64 + P^65 + 3*P^66 + 2*P^67 + 3*P^68 + 2*P^69 + 2*P^70 + 3*P^71 + 2*P^72 + 3*P^73 + P^74 + 
    2*P^75 + 2*P^76 + 2*P^77 + 3*P^78 + P^79 + 3*P^80 + P^81 + 3*P^82 + 2*P^83 + 2*P^84 + 3*P^85 + P^86 + 3*P^87 + P^88 + 
    3*P^89 + 2*P^90 + 2*P^91 + 3*P^92 + 2*P^93 + 3*P^94 + 2*P^95 + 2*P^96 + 3*P^97 + 2*P^98 + 3*P^99 + P^100 + 2*P^101 + 
    2*P^102 + 2*P^103 + 2*P^104 + P^105 + 2*P^106 + 2*P^107 + 2*P^108 + 2*P^109 + P^110 + 2*P^111 + 2*P^112 + 2*P^113 + P^114 + 
    P^115 + 2*P^116 + 2*P^117 + 2*P^118 + P^119 + 2*P^120 + 2*P^121 + 2*P^122 + P^123 + P^124 + P^125 + 2*P^126 + P^127 + 
    P^128 + P^129 + P^130 + 2*P^131 + P^132 + P^133 + P^134 + P^135 + 2*P^136 + P^138 + P^140 + P^141 + P^143 + 2*P^145 + 
    P^146 + P^147 + P^150 + P^152 + P^154 + P^155 + P^157 + P^159)/((1 - P^3)*(1 - P^71)*(1 - P^97))}, 
 {3, (P^5 + P^10 + P^12 + P^16 + P^17 + P^19 + 2*P^21 + P^24 + P^25 + 2*P^26 + P^29 + P^30 + 2*P^31 + P^33 + P^34 + 2*P^35 + 
    P^36 + P^38 + 2*P^39 + 2*P^40 + P^41 + P^42 + P^43 + 2*P^44 + 2*P^45 + P^46 + P^47 + P^48 + 2*P^49 + 2*P^50 + P^51 + P^52 + 
    2*P^53 + 2*P^54 + 2*P^55 + P^56 + P^57 + 3*P^58 + 2*P^59 + 2*P^60 + P^61 + 2*P^62 + 3*P^63 + 2*P^64 + 2*P^65 + P^66 + 
    2*P^67 + 3*P^68 + 2*P^69 + 2*P^70 + P^71 + 3*P^72 + 3*P^73 + 2*P^74 + 2*P^75 + P^76 + 3*P^77 + 2*P^78 + 3*P^79 + 2*P^80 + 
    2*P^81 + 3*P^82 + P^83 + 3*P^84 + 2*P^85 + 3*P^86 + 2*P^87 + P^88 + 3*P^89 + P^90 + 3*P^91 + P^92 + 3*P^93 + 3*P^94 + 
    2*P^95 + 2*P^96 + P^97 + 3*P^98 + 3*P^99 + 2*P^100 + 2*P^101 + P^102 + 3*P^103 + 2*P^104 + 2*P^105 + P^106 + 2*P^107 + 
    3*P^108 + 2*P^109 + P^110 + P^111 + 2*P^112 + 2*P^113 + 2*P^114 + P^115 + P^116 + 2*P^117 + 2*P^118 + 2*P^119 + P^120 + 
    P^121 + 2*P^122 + 2*P^123 + P^124 + P^125 + P^126 + 2*P^127 + 2*P^128 + P^130 + P^131 + 2*P^132 + P^133 + P^135 + P^136 + 
    2*P^137 + P^138 + P^140 + P^141 + 2*P^142 + P^145 + P^146 + P^147 + P^149 + P^151 + P^154 + P^156 + P^159 + P^161)/
   ((1 - P^3)*(1 - P^71)*(1 - P^97))}, {3, (P^3 + P^11 + P^14 + P^16 + P^17 + P^19 + P^21 + P^22 + P^24 + P^25 + P^26 + P^27 + 
    P^28 + P^29 + P^30 + P^31 + P^32 + P^33 + P^35 + P^36 + 2*P^37 + P^38 + P^39 + 2*P^40 + P^41 + P^42 + P^43 + P^44 + 2*P^45 + 
    P^46 + P^47 + 2*P^48 + P^49 + 2*P^50 + 2*P^51 + P^52 + 2*P^53 + 2*P^54 + 2*P^55 + 2*P^56 + P^57 + 2*P^58 + 2*P^59 + 2*P^60 + 
    2*P^61 + 2*P^62 + 2*P^63 + 2*P^64 + 2*P^65 + 2*P^66 + 2*P^67 + 2*P^68 + 2*P^69 + 2*P^70 + 2*P^71 + 2*P^72 + 2*P^73 + 
    2*P^74 + 2*P^75 + 2*P^76 + 3*P^77 + 2*P^78 + 3*P^79 + 2*P^80 + 2*P^81 + 2*P^82 + 2*P^83 + 3*P^84 + 2*P^85 + 2*P^86 + 
    2*P^87 + 2*P^88 + 3*P^89 + 2*P^90 + 3*P^91 + 2*P^92 + 2*P^93 + 2*P^94 + 2*P^95 + 2*P^96 + 2*P^97 + 2*P^98 + 2*P^99 + 
    2*P^100 + 2*P^101 + 2*P^102 + 2*P^103 + 2*P^104 + 3*P^105 + 2*P^106 + 2*P^107 + P^108 + 2*P^109 + 2*P^110 + P^111 + 
    2*P^112 + 2*P^113 + 2*P^114 + 2*P^115 + P^116 + 2*P^117 + 2*P^118 + P^119 + 2*P^120 + P^121 + P^122 + 2*P^123 + P^124 + 
    P^125 + P^126 + P^127 + 2*P^128 + P^129 + P^130 + P^131 + P^132 + P^133 + P^134 + P^135 + P^136 + P^137 + P^138 + P^139 + 
    P^140 + P^141 + P^142 + P^143 + P^144 + P^146 + P^147 + P^149 + P^151 + P^152 + P^154 + P^157 + P^165)/
   ((1 - P^3)*(1 - P^71)*(1 - P^97))}, {3, (P^4 + P^9 + P^14 + P^15 + P^18 + P^19 + P^20 + 2*P^23 + P^24 + P^25 + 2*P^28 + 
    P^29 + P^30 + P^32 + 2*P^33 + P^34 + 2*P^37 + 3*P^38 + P^39 + P^41 + 2*P^42 + 2*P^43 + P^44 + 2*P^46 + 2*P^47 + 2*P^48 + 
    P^49 + 2*P^51 + 3*P^52 + 2*P^53 + P^54 + P^55 + 2*P^56 + 3*P^57 + P^58 + P^59 + 2*P^60 + 3*P^61 + 3*P^62 + P^63 + P^64 + 
    2*P^65 + 3*P^66 + 3*P^67 + P^68 + P^69 + 2*P^70 + 3*P^71 + 3*P^72 + P^73 + 2*P^74 + 2*P^75 + 3*P^76 + 2*P^77 + 2*P^78 + 
    2*P^79 + 2*P^80 + 3*P^81 + 2*P^82 + 3*P^83 + 2*P^84 + 2*P^85 + 2*P^86 + 2*P^87 + 3*P^88 + 2*P^89 + 2*P^90 + 2*P^91 + 
    2*P^92 + 3*P^93 + P^94 + 2*P^95 + 2*P^96 + 3*P^97 + 3*P^98 + P^99 + 2*P^100 + 2*P^101 + 3*P^102 + 2*P^103 + P^104 + 
    2*P^105 + 3*P^106 + 3*P^107 + P^108 + 2*P^110 + 3*P^111 + 2*P^112 + P^113 + P^114 + 2*P^115 + 3*P^116 + P^117 + P^118 + 
    P^119 + 2*P^120 + 3*P^121 + P^122 + P^124 + 2*P^125 + 2*P^126 + P^127 + 2*P^129 + 2*P^130 + P^131 + 2*P^134 + 2*P^135 + 
    P^136 + 2*P^139 + 2*P^140 + P^141 + 2*P^144 + P^145 + P^148 + P^149 + P^150 + P^153 + P^155 + P^158 + P^163)/
   ((1 - P^3)*(1 - P^71)*(1 - P^97))}, {3, (P^4 + P^9 + P^11 + P^16 + 2*P^18 + P^20 + 2*P^23 + P^25 + P^27 + 2*P^28 + P^30 + 
    2*P^32 + 2*P^33 + P^34 + P^35 + 2*P^37 + P^38 + P^39 + P^40 + 2*P^41 + 2*P^42 + P^43 + P^44 + P^45 + 2*P^46 + 2*P^47 + 
    P^48 + P^49 + P^50 + 2*P^51 + 2*P^52 + P^53 + P^54 + 2*P^55 + 2*P^56 + 3*P^57 + P^58 + P^59 + 2*P^60 + 2*P^61 + 3*P^62 + 
    P^63 + 2*P^64 + 2*P^65 + 2*P^66 + 3*P^67 + P^68 + 3*P^69 + 2*P^70 + 3*P^71 + 2*P^72 + P^73 + 3*P^74 + P^75 + 3*P^76 + P^77 + 
    3*P^78 + 3*P^79 + 2*P^80 + 3*P^81 + 3*P^83 + 2*P^84 + 3*P^85 + 3*P^86 + P^87 + 3*P^88 + 3*P^90 + 2*P^91 + 3*P^92 + 3*P^93 + 
    P^94 + 3*P^95 + 2*P^96 + 3*P^97 + 2*P^98 + P^99 + 3*P^100 + 2*P^101 + 3*P^102 + P^103 + P^104 + 2*P^105 + 2*P^106 + 
    3*P^107 + P^108 + 2*P^109 + 2*P^110 + 2*P^111 + P^112 + P^113 + 2*P^114 + 2*P^115 + 2*P^116 + P^117 + P^118 + 2*P^119 + 
    2*P^120 + 2*P^121 + P^122 + P^123 + 2*P^124 + 2*P^125 + P^126 + P^127 + 2*P^129 + 2*P^130 + P^131 + P^132 + 2*P^134 + 
    P^135 + P^136 + P^137 + 2*P^139 + P^141 + P^143 + 2*P^144 + P^146 + 2*P^148 + 2*P^153 + P^155 + P^158 + P^160)/
   ((1 - P^3)*(1 - P^71)*(1 - P^97))}, {3, (P^7 + P^8 + P^12 + P^13 + P^17 + P^18 + P^21 + P^22 + P^23 + P^26 + 2*P^27 + P^28 + 
    2*P^31 + 2*P^32 + P^33 + P^35 + 2*P^36 + 2*P^37 + P^40 + 3*P^41 + 2*P^42 + P^44 + 2*P^45 + 3*P^46 + P^47 + P^49 + 3*P^50 + 
    2*P^51 + P^52 + 2*P^54 + 3*P^55 + 2*P^56 + P^57 + P^58 + 2*P^59 + 3*P^60 + 2*P^61 + P^62 + P^63 + 3*P^64 + 3*P^65 + 2*P^66 + 
    P^67 + 2*P^68 + 3*P^69 + 3*P^70 + 2*P^71 + P^72 + 2*P^73 + 3*P^74 + 3*P^75 + 2*P^76 + P^77 + 2*P^78 + 2*P^79 + 3*P^80 + 
    2*P^81 + 2*P^82 + 2*P^83 + 2*P^84 + 2*P^85 + 2*P^86 + 3*P^87 + 2*P^88 + 2*P^89 + 2*P^90 + 3*P^91 + 2*P^92 + 2*P^93 + 
    2*P^94 + 3*P^95 + 3*P^96 + 2*P^97 + P^98 + 2*P^99 + 3*P^100 + 3*P^101 + P^102 + P^103 + 2*P^104 + 3*P^105 + 2*P^106 + 
    P^107 + P^108 + 3*P^109 + 3*P^110 + 2*P^111 + P^113 + 3*P^114 + 2*P^115 + P^116 + 2*P^118 + 3*P^119 + 2*P^120 + P^122 + 
    2*P^123 + 3*P^124 + P^125 + P^127 + 2*P^128 + 2*P^129 + P^130 + P^132 + 2*P^133 + 2*P^134 + P^137 + 2*P^138 + P^139 + 
    P^142 + 2*P^143 + P^144 + P^147 + 2*P^148 + P^152 + P^153 + P^156 + P^157 + P^161)/((1 - P^3)*(1 - P^71)*(1 - P^97))}, 
 {3, (P^6 + P^8 + P^13 + P^14 + P^18 + P^19 + P^20 + P^22 + P^24 + P^25 + P^27 + P^28 + 2*P^29 + P^30 + P^32 + P^33 + 2*P^34 + 
    P^35 + P^36 + P^37 + P^38 + P^39 + P^40 + P^41 + 2*P^42 + 2*P^43 + P^44 + P^45 + P^46 + 2*P^47 + 2*P^48 + P^49 + P^50 + 
    2*P^51 + 2*P^52 + 2*P^53 + P^54 + P^55 + 2*P^56 + 2*P^57 + 2*P^58 + 2*P^59 + P^60 + 2*P^61 + 2*P^62 + 2*P^63 + 2*P^64 + 
    2*P^65 + 3*P^66 + 2*P^67 + 2*P^68 + 2*P^69 + 2*P^70 + 3*P^71 + 2*P^72 + 2*P^73 + 2*P^74 + 2*P^75 + 3*P^76 + P^77 + 2*P^78 + 
    P^79 + 3*P^80 + 3*P^81 + 3*P^82 + 2*P^83 + P^84 + 2*P^85 + 2*P^86 + 3*P^87 + 3*P^88 + 2*P^89 + 2*P^90 + P^91 + 3*P^92 + 
    2*P^93 + 3*P^94 + 2*P^95 + 2*P^96 + 3*P^97 + 2*P^98 + 2*P^99 + P^100 + 2*P^101 + 3*P^102 + 2*P^103 + 2*P^104 + P^105 + 
    2*P^106 + 2*P^107 + 2*P^108 + 2*P^109 + 2*P^110 + 2*P^111 + 2*P^112 + P^113 + P^114 + 2*P^115 + 2*P^116 + 2*P^117 + P^118 + 
    P^119 + 2*P^120 + 2*P^121 + P^122 + P^123 + P^124 + 2*P^125 + 2*P^126 + P^127 + P^128 + P^129 + P^130 + 2*P^131 + P^132 + 
    P^133 + P^134 + P^135 + P^136 + P^138 + P^139 + P^140 + P^141 + P^143 + P^144 + P^145 + P^146 + P^148 + P^149 + P^150 + 
    P^154 + P^155 + P^157 + P^162)/((1 - P^3)*(1 - P^71)*(1 - P^97))}, 
 {3, (P^5 + P^10 + P^13 + P^15 + P^18 + P^19 + P^20 + P^23 + 2*P^24 + P^25 + P^27 + P^28 + 2*P^29 + P^32 + P^33 + 2*P^34 + 
    P^36 + P^37 + 2*P^38 + 2*P^39 + P^41 + 2*P^42 + 2*P^43 + P^44 + P^46 + 3*P^47 + 2*P^48 + P^49 + P^50 + P^51 + 3*P^52 + 
    2*P^53 + P^54 + P^55 + 2*P^56 + 3*P^57 + 2*P^58 + P^59 + P^60 + 3*P^61 + 2*P^62 + 2*P^63 + P^64 + 2*P^65 + 3*P^66 + 2*P^67 + 
    2*P^68 + P^69 + 2*P^70 + 3*P^71 + 2*P^72 + 3*P^73 + P^74 + 3*P^75 + 2*P^76 + 2*P^77 + 2*P^78 + 2*P^79 + 3*P^80 + 2*P^81 + 
    2*P^82 + 2*P^83 + 2*P^84 + 3*P^85 + 2*P^86 + 3*P^87 + 2*P^88 + 2*P^89 + 2*P^90 + 2*P^91 + 3*P^92 + 2*P^93 + 2*P^94 + P^95 + 
    2*P^96 + 3*P^97 + 2*P^98 + 2*P^99 + P^100 + 3*P^101 + 3*P^102 + 2*P^103 + 2*P^104 + P^105 + 3*P^106 + 2*P^107 + 2*P^108 + 
    P^109 + P^110 + 3*P^111 + 2*P^112 + P^113 + P^114 + 2*P^115 + 3*P^116 + 2*P^117 + P^119 + 2*P^120 + 2*P^121 + 2*P^122 + 
    P^124 + 2*P^125 + 2*P^126 + P^127 + P^129 + 2*P^130 + 2*P^131 + P^133 + P^134 + 2*P^135 + P^136 + P^138 + P^139 + 2*P^140 + 
    P^141 + P^143 + 2*P^145 + P^148 + P^149 + P^150 + P^153 + P^154 + P^159 + P^164)/((1 - P^3)*(1 - P^71)*(1 - P^97))}, 
 {3, (P^7 + P^9 + P^12 + P^14 + P^17 + P^19 + P^21 + P^22 + P^23 + 2*P^26 + P^27 + P^28 + P^30 + 2*P^31 + P^32 + P^33 + P^35 + 
    2*P^36 + P^37 + P^38 + 2*P^40 + 2*P^41 + P^42 + P^43 + P^44 + 2*P^45 + 2*P^46 + P^47 + P^48 + 2*P^49 + 2*P^50 + 2*P^51 + 
    P^52 + P^53 + 2*P^54 + 2*P^55 + 2*P^56 + P^57 + P^58 + 2*P^59 + 3*P^60 + 2*P^61 + P^62 + 2*P^63 + 2*P^64 + 3*P^65 + P^66 + 
    2*P^67 + 2*P^68 + 3*P^69 + 3*P^70 + P^71 + 2*P^72 + 2*P^73 + 3*P^74 + 3*P^75 + P^76 + 3*P^77 + P^78 + 3*P^79 + P^80 + 
    2*P^81 + 3*P^82 + 2*P^83 + 3*P^84 + P^85 + 3*P^86 + 2*P^87 + 2*P^88 + 3*P^89 + 2*P^90 + 3*P^91 + P^92 + 2*P^93 + 2*P^94 + 
    3*P^95 + 3*P^96 + P^97 + 2*P^98 + 2*P^99 + 3*P^100 + 2*P^101 + P^102 + 2*P^103 + 2*P^104 + 3*P^105 + 2*P^106 + P^107 + 
    2*P^108 + 2*P^109 + 3*P^110 + P^111 + P^112 + 2*P^113 + 2*P^114 + 2*P^115 + P^116 + P^117 + 2*P^118 + 2*P^119 + P^120 + 
    P^121 + P^122 + 2*P^123 + 2*P^124 + P^125 + P^126 + P^127 + 2*P^128 + 2*P^129 + P^130 + P^132 + 2*P^133 + P^134 + P^135 + 
    2*P^137 + P^138 + P^139 + 2*P^142 + P^143 + P^144 + 2*P^147 + P^149 + P^151 + P^152 + P^156 + P^158 + P^163)/
   ((1 - P^3)*(1 - P^71)*(1 - P^97))}, {3, (P^4 + P^9 + P^14 + P^15 + P^18 + P^19 + P^20 + 2*P^23 + P^25 + P^27 + 2*P^28 + 
    P^29 + P^30 + P^32 + 2*P^33 + P^34 + P^35 + 2*P^37 + 2*P^38 + P^39 + P^41 + 2*P^42 + 2*P^43 + P^44 + 2*P^46 + 2*P^47 + 
    2*P^48 + P^49 + 2*P^51 + 3*P^52 + 2*P^53 + P^54 + P^55 + 2*P^56 + 3*P^57 + P^58 + P^59 + 2*P^60 + 2*P^61 + 3*P^62 + P^63 + 
    2*P^64 + 2*P^65 + 3*P^66 + 3*P^67 + P^68 + 2*P^69 + 2*P^70 + 3*P^71 + 2*P^72 + P^73 + 2*P^74 + 2*P^75 + 3*P^76 + 2*P^77 + 
    2*P^78 + 2*P^79 + 2*P^80 + 3*P^81 + 2*P^82 + 3*P^83 + 2*P^84 + 2*P^85 + 2*P^86 + 2*P^87 + 3*P^88 + 2*P^89 + 2*P^90 + 
    2*P^91 + 2*P^92 + 3*P^93 + P^94 + 3*P^95 + 2*P^96 + 3*P^97 + 2*P^98 + P^99 + 2*P^100 + 2*P^101 + 3*P^102 + 2*P^103 + P^104 + 
    2*P^105 + 2*P^106 + 3*P^107 + P^108 + P^109 + 2*P^110 + 3*P^111 + 2*P^112 + P^113 + P^114 + 2*P^115 + 3*P^116 + P^117 + 
    P^118 + P^119 + 2*P^120 + 3*P^121 + P^122 + P^124 + 2*P^125 + 2*P^126 + P^127 + 2*P^129 + 2*P^130 + P^131 + P^132 + 
    2*P^134 + P^135 + P^136 + 2*P^139 + P^140 + P^141 + P^143 + 2*P^144 + P^145 + P^148 + P^149 + P^150 + P^153 + P^155 + 
    P^158 + P^163)/((1 - P^3)*(1 - P^71)*(1 - P^97))}, 
 {3, (P^2 + 2*P^13 + P^16 + 2*P^18 + P^21 + 2*P^23 + P^26 + 2*P^27 + 2*P^28 + P^30 + P^31 + 2*P^32 + P^35 + 2*P^36 + 2*P^37 + 
    P^39 + P^40 + 2*P^41 + 2*P^42 + P^44 + P^45 + 2*P^46 + 2*P^47 + P^49 + 3*P^50 + 2*P^51 + 2*P^52 + P^53 + P^54 + 3*P^55 + 
    2*P^56 + 2*P^57 + P^58 + P^59 + 3*P^60 + 2*P^61 + 2*P^62 + P^63 + 3*P^64 + 3*P^65 + 2*P^66 + P^67 + P^68 + 3*P^69 + 2*P^70 + 
    2*P^71 + P^72 + 2*P^73 + 3*P^74 + 2*P^75 + 3*P^76 + P^77 + 3*P^78 + 3*P^79 + 2*P^80 + 3*P^81 + P^82 + 3*P^83 + P^84 + 
    2*P^85 + 3*P^86 + 2*P^87 + 3*P^88 + P^89 + 3*P^90 + 3*P^91 + 2*P^92 + 3*P^93 + P^94 + 3*P^95 + 2*P^96 + 2*P^97 + P^98 + 
    P^99 + 3*P^100 + 2*P^101 + 2*P^102 + P^103 + 3*P^104 + 3*P^105 + 2*P^106 + P^107 + P^108 + 3*P^109 + 2*P^110 + 2*P^111 + 
    P^112 + P^113 + 3*P^114 + 2*P^115 + 2*P^116 + P^117 + P^118 + 3*P^119 + 2*P^120 + P^122 + P^123 + 2*P^124 + 2*P^125 + 
    P^127 + P^128 + 2*P^129 + 2*P^130 + P^132 + P^133 + 2*P^134 + P^137 + 2*P^138 + 2*P^139 + P^141 + P^142 + 2*P^143 + P^146 + 
    2*P^148 + P^151 + 2*P^153 + P^156 + P^167)/((1 - P^3)*(1 - P^71)*(1 - P^97))}, 
 {3, (P^5 + P^10 + P^13 + P^15 + P^18 + P^19 + P^20 + P^23 + 2*P^24 + P^27 + 2*P^28 + 2*P^29 + P^32 + 2*P^33 + 2*P^34 + P^37 + 
    2*P^38 + 2*P^39 + P^41 + 2*P^42 + 2*P^43 + P^44 + P^46 + 3*P^47 + 2*P^48 + P^49 + P^50 + P^51 + 3*P^52 + 2*P^53 + P^54 + 
    P^55 + 2*P^56 + 3*P^57 + 2*P^58 + P^60 + 3*P^61 + 3*P^62 + 2*P^63 + P^64 + 2*P^65 + 3*P^66 + 2*P^67 + 2*P^68 + P^69 + 
    3*P^70 + 3*P^71 + 2*P^72 + 2*P^73 + P^74 + 3*P^75 + 2*P^76 + 2*P^77 + 2*P^78 + 2*P^79 + 3*P^80 + 2*P^81 + 2*P^82 + 2*P^83 + 
    2*P^84 + 3*P^85 + 2*P^86 + 3*P^87 + 2*P^88 + 2*P^89 + 2*P^90 + 2*P^91 + 3*P^92 + 2*P^93 + 2*P^94 + P^95 + 3*P^96 + 3*P^97 + 
    2*P^98 + P^99 + P^100 + 3*P^101 + 3*P^102 + 2*P^103 + P^104 + P^105 + 3*P^106 + 3*P^107 + 2*P^108 + P^109 + P^110 + 
    3*P^111 + 2*P^112 + P^113 + P^114 + 2*P^115 + 3*P^116 + 2*P^117 + P^119 + 2*P^120 + 2*P^121 + 2*P^122 + P^124 + 2*P^125 + 
    2*P^126 + P^127 + P^129 + 3*P^130 + 2*P^131 + P^134 + 2*P^135 + P^136 + P^138 + P^139 + 2*P^140 + P^143 + P^144 + 2*P^145 + 
    P^148 + P^149 + P^150 + P^153 + P^154 + P^159 + P^164)/((1 - P^3)*(1 - P^71)*(1 - P^97))}, 
 {3, (P^8 + P^12 + 2*P^13 + P^17 + P^18 + P^21 + 2*P^22 + P^23 + P^26 + 2*P^27 + 2*P^31 + 2*P^32 + P^35 + 3*P^36 + 2*P^37 + 
    P^40 + 3*P^41 + 2*P^42 + 2*P^45 + 3*P^46 + 2*P^47 + P^49 + 3*P^50 + 3*P^51 + P^52 + P^54 + 3*P^55 + 2*P^56 + P^57 + P^58 + 
    3*P^59 + 3*P^60 + 2*P^61 + P^63 + 3*P^64 + 3*P^65 + 2*P^66 + 2*P^68 + 3*P^69 + 3*P^70 + 2*P^71 + P^72 + 3*P^73 + 3*P^74 + 
    3*P^75 + 2*P^76 + P^77 + 3*P^78 + 2*P^79 + 3*P^80 + 2*P^81 + 2*P^82 + 2*P^83 + P^84 + 3*P^85 + 2*P^86 + 3*P^87 + 2*P^88 + 
    2*P^89 + 2*P^90 + 2*P^91 + 2*P^92 + P^93 + 2*P^94 + 3*P^95 + 3*P^96 + 2*P^97 + P^98 + 3*P^99 + 3*P^100 + 3*P^101 + P^102 + 
    P^103 + 3*P^104 + 3*P^105 + 2*P^106 + P^108 + 3*P^109 + 3*P^110 + 2*P^111 + P^113 + 3*P^114 + 3*P^115 + P^116 + P^118 + 
    3*P^119 + 2*P^120 + 2*P^123 + 3*P^124 + 2*P^125 + P^127 + 2*P^128 + 2*P^129 + P^132 + 3*P^133 + 2*P^134 + P^137 + 3*P^138 + 
    P^139 + P^142 + 2*P^143 + P^147 + 2*P^148 + P^152 + P^153 + P^157 + P^161 + P^162)/((1 - P^3)*(1 - P^71)*(1 - P^97))}, 
 {3, (P^3 + P^11 + P^14 + P^16 + P^17 + P^19 + P^21 + P^22 + P^24 + P^25 + P^26 + P^27 + P^28 + P^29 + P^30 + P^31 + P^32 + 
    P^33 + P^34 + P^35 + P^36 + P^37 + P^38 + P^39 + 2*P^40 + P^41 + P^42 + P^43 + P^44 + 2*P^45 + P^46 + P^47 + 2*P^48 + P^49 + 
    2*P^50 + 2*P^51 + P^52 + 2*P^53 + 2*P^54 + 2*P^55 + 2*P^56 + P^57 + 2*P^58 + 2*P^59 + P^60 + 2*P^61 + 2*P^62 + 3*P^63 + 
    2*P^64 + 2*P^65 + 2*P^66 + 2*P^67 + 2*P^68 + 2*P^69 + 2*P^70 + 2*P^71 + 2*P^72 + 2*P^73 + 2*P^74 + 2*P^75 + 2*P^76 + 
    3*P^77 + 2*P^78 + 3*P^79 + 2*P^80 + 2*P^81 + 2*P^82 + 2*P^83 + 3*P^84 + 2*P^85 + 2*P^86 + 2*P^87 + 2*P^88 + 3*P^89 + 
    2*P^90 + 3*P^91 + 2*P^92 + 2*P^93 + 2*P^94 + 2*P^95 + 2*P^96 + 2*P^97 + 2*P^98 + 2*P^99 + 2*P^100 + 2*P^101 + 2*P^102 + 
    2*P^103 + 2*P^104 + 2*P^105 + 2*P^106 + 2*P^107 + 2*P^108 + 2*P^109 + 2*P^110 + P^111 + 2*P^112 + 2*P^113 + 2*P^114 + 
    2*P^115 + P^116 + 2*P^117 + 2*P^118 + P^119 + 2*P^120 + P^121 + P^122 + 2*P^123 + P^124 + P^125 + P^126 + P^127 + 2*P^128 + 
    P^129 + P^130 + 2*P^131 + P^132 + P^133 + P^135 + P^136 + P^137 + P^138 + P^139 + P^140 + P^141 + P^142 + P^143 + P^144 + 
    P^146 + P^147 + P^149 + P^151 + P^152 + P^154 + P^157 + P^165)/((1 - P^3)*(1 - P^71)*(1 - P^97))}, 
 {3, (P^8 + P^9 + P^13 + P^14 + P^16 + P^18 + P^21 + P^22 + P^23 + P^25 + P^26 + P^27 + P^28 + P^30 + P^31 + 2*P^32 + P^33 + 
    P^35 + P^36 + 2*P^37 + P^38 + P^39 + P^40 + P^41 + 2*P^42 + P^43 + P^44 + 2*P^45 + 2*P^46 + 2*P^47 + P^48 + P^49 + 2*P^50 + 
    2*P^51 + P^52 + P^53 + P^54 + 3*P^55 + 2*P^56 + P^57 + P^58 + 2*P^59 + 3*P^60 + 2*P^61 + 2*P^62 + P^63 + 2*P^64 + 2*P^65 + 
    2*P^66 + 2*P^67 + 2*P^68 + 3*P^69 + 2*P^70 + 2*P^71 + 2*P^72 + 2*P^73 + 3*P^74 + 2*P^75 + 3*P^76 + 2*P^77 + 2*P^78 + 
    2*P^79 + P^80 + 3*P^81 + 2*P^82 + 3*P^83 + 2*P^84 + 2*P^85 + 2*P^86 + P^87 + 3*P^88 + 2*P^89 + 3*P^90 + 2*P^91 + 2*P^92 + 
    2*P^93 + 2*P^94 + 3*P^95 + 2*P^96 + 2*P^97 + 2*P^98 + 2*P^99 + 3*P^100 + 2*P^101 + 2*P^102 + P^103 + 2*P^104 + 3*P^105 + 
    2*P^106 + 2*P^107 + P^108 + 2*P^109 + 2*P^110 + 2*P^111 + 2*P^112 + P^113 + 2*P^114 + 2*P^115 + P^116 + P^117 + P^118 + 
    2*P^119 + 2*P^120 + P^121 + P^122 + 2*P^123 + 2*P^124 + 2*P^125 + P^127 + 2*P^128 + 2*P^129 + P^130 + P^132 + P^133 + 
    2*P^134 + P^135 + P^136 + P^137 + P^138 + P^139 + P^141 + P^142 + P^143 + P^144 + P^146 + P^148 + P^149 + P^151 + P^153 + 
    P^157 + P^158 + P^162)/((1 - P^3)*(1 - P^71)*(1 - P^97))}, 
 {3, (P^8 + P^10 + P^13 + 2*P^15 + 2*P^20 + P^22 + 2*P^24 + P^25 + P^27 + 2*P^29 + P^31 + P^32 + P^33 + 2*P^34 + P^36 + P^37 + 
    2*P^38 + 2*P^39 + P^41 + P^42 + 2*P^43 + 2*P^44 + P^45 + P^46 + 2*P^47 + 2*P^48 + 2*P^49 + P^50 + P^51 + 2*P^52 + 2*P^53 + 
    2*P^54 + P^55 + P^56 + 2*P^57 + 2*P^58 + 2*P^59 + P^60 + 3*P^61 + 2*P^62 + 2*P^63 + P^64 + P^65 + 3*P^66 + 2*P^67 + 3*P^68 + 
    P^69 + 2*P^70 + 3*P^71 + 2*P^72 + 3*P^73 + P^74 + 3*P^75 + 3*P^76 + 2*P^77 + 3*P^78 + 3*P^80 + P^81 + 3*P^82 + 3*P^83 + 
    2*P^84 + 3*P^85 + 3*P^87 + 2*P^88 + 3*P^89 + 3*P^90 + P^91 + 3*P^92 + P^93 + 3*P^94 + P^95 + 2*P^96 + 3*P^97 + 2*P^98 + 
    3*P^99 + P^100 + 3*P^101 + 2*P^102 + 2*P^103 + 2*P^104 + P^105 + 3*P^106 + 2*P^107 + 2*P^108 + P^109 + P^110 + 3*P^111 + 
    2*P^112 + 2*P^113 + P^114 + P^115 + 2*P^116 + 2*P^117 + P^118 + P^119 + P^120 + 2*P^121 + 2*P^122 + P^123 + P^124 + P^125 + 
    2*P^126 + 2*P^127 + P^128 + P^129 + P^130 + 2*P^131 + P^133 + P^134 + 2*P^135 + 2*P^136 + P^138 + 2*P^140 + P^141 + P^143 + 
    2*P^145 + P^148 + 2*P^150 + P^152 + P^157 + P^159 + P^164)/((1 - P^3)*(1 - P^71)*(1 - P^97))}, 
 {3, (P^6 + P^10 + P^11 + P^15 + P^17 + P^19 + P^20 + P^22 + P^24 + P^25 + P^26 + P^27 + P^29 + P^30 + P^31 + P^32 + P^33 + 
    2*P^34 + P^35 + P^36 + P^38 + 2*P^39 + 2*P^40 + P^41 + 2*P^43 + 2*P^44 + 2*P^45 + P^46 + P^47 + 2*P^48 + 2*P^49 + P^50 + 
    P^51 + P^52 + 2*P^53 + 2*P^54 + P^55 + 2*P^56 + 2*P^57 + 2*P^58 + 2*P^59 + P^60 + 2*P^61 + 2*P^62 + 3*P^63 + 2*P^64 + P^65 + 
    2*P^66 + 2*P^67 + 3*P^68 + 2*P^69 + 2*P^70 + 2*P^71 + 2*P^72 + 3*P^73 + 2*P^74 + 2*P^75 + 2*P^76 + 2*P^77 + 3*P^78 + 
    2*P^79 + 3*P^80 + P^81 + 2*P^82 + 2*P^83 + 2*P^84 + 3*P^85 + 2*P^86 + 3*P^87 + P^88 + 2*P^89 + 2*P^90 + 2*P^91 + 3*P^92 + 
    2*P^93 + 3*P^94 + 2*P^95 + 2*P^96 + 2*P^97 + 2*P^98 + 3*P^99 + 2*P^100 + 2*P^101 + 2*P^102 + 2*P^103 + 2*P^104 + P^105 + 
    2*P^106 + 2*P^107 + 3*P^108 + 2*P^109 + P^110 + P^111 + 2*P^112 + 3*P^113 + P^114 + P^115 + P^116 + 2*P^117 + 2*P^118 + 
    P^119 + P^120 + 2*P^121 + 2*P^122 + 2*P^123 + P^124 + P^125 + 2*P^126 + P^127 + P^128 + P^129 + P^130 + 2*P^131 + P^132 + 
    P^133 + P^135 + 2*P^136 + P^137 + P^138 + P^140 + P^141 + P^142 + P^143 + P^145 + P^146 + P^147 + P^150 + P^152 + P^154 + 
    P^155 + P^159 + P^160)/((1 - P^3)*(1 - P^71)*(1 - P^97))}, 
 {3, (P^9 + P^10 + 2*P^14 + P^15 + 2*P^19 + 2*P^23 + 2*P^24 + 2*P^28 + P^29 + P^32 + 3*P^33 + P^34 + 2*P^37 + 3*P^38 + P^39 + 
    2*P^42 + 3*P^43 + P^44 + P^46 + 3*P^47 + 3*P^48 + P^49 + 2*P^51 + 3*P^52 + 2*P^53 + 3*P^56 + 3*P^57 + 2*P^58 + 2*P^60 + 
    3*P^61 + 3*P^62 + P^63 + 2*P^65 + 3*P^66 + 3*P^67 + P^68 + P^69 + 3*P^70 + 3*P^71 + 3*P^72 + P^73 + 2*P^74 + 3*P^75 + 
    3*P^76 + 3*P^77 + P^78 + 2*P^79 + 2*P^80 + 2*P^81 + 3*P^82 + 2*P^83 + 3*P^84 + P^85 + 2*P^86 + 2*P^87 + 2*P^88 + 3*P^89 + 
    P^90 + 3*P^91 + 2*P^92 + 3*P^93 + P^94 + P^95 + 3*P^96 + 3*P^97 + 3*P^98 + P^99 + 2*P^100 + 3*P^101 + 3*P^102 + 2*P^103 + 
    2*P^105 + 3*P^106 + 3*P^107 + P^108 + 2*P^110 + 3*P^111 + 3*P^112 + P^113 + 2*P^115 + 3*P^116 + 2*P^117 + 2*P^120 + 
    3*P^121 + P^122 + P^124 + 3*P^125 + 3*P^126 + P^129 + 3*P^130 + P^131 + 2*P^134 + 3*P^135 + P^136 + 2*P^139 + 2*P^140 + 
    2*P^144 + P^145 + 2*P^149 + P^150 + P^154 + P^158 + P^159 + P^163)/((1 - P^3)*(1 - P^71)*(1 - P^97))}, 
 {3, (P^7 + 2*P^12 + P^14 + P^17 + P^19 + P^21 + P^22 + P^23 + P^24 + 2*P^26 + P^28 + P^30 + 2*P^31 + P^33 + 2*P^35 + 2*P^36 + 
    P^37 + P^38 + 2*P^40 + 2*P^41 + P^42 + P^43 + P^44 + 2*P^45 + 2*P^46 + P^47 + P^48 + 2*P^49 + 2*P^50 + 2*P^51 + P^52 + 
    P^53 + 2*P^54 + 2*P^55 + 2*P^56 + P^57 + 2*P^58 + 2*P^59 + 3*P^60 + P^61 + P^62 + 2*P^63 + 2*P^64 + 3*P^65 + P^66 + 2*P^67 + 
    2*P^68 + 2*P^69 + 3*P^70 + P^71 + 3*P^72 + 2*P^73 + 3*P^74 + 3*P^75 + P^76 + 3*P^77 + P^78 + 3*P^79 + 2*P^80 + 2*P^81 + 
    3*P^82 + P^83 + 3*P^84 + P^85 + 3*P^86 + 3*P^87 + 2*P^88 + 3*P^89 + P^90 + 3*P^91 + P^92 + 2*P^93 + 2*P^94 + 2*P^95 + 
    3*P^96 + P^97 + 3*P^98 + 2*P^99 + 3*P^100 + 2*P^101 + P^102 + 3*P^103 + 2*P^104 + 3*P^105 + P^106 + P^107 + 2*P^108 + 
    2*P^109 + 3*P^110 + P^111 + P^112 + 2*P^113 + 2*P^114 + 2*P^115 + P^116 + P^117 + 2*P^118 + 2*P^119 + P^120 + P^121 + 
    P^122 + 2*P^123 + 2*P^124 + P^125 + P^126 + P^127 + 2*P^128 + P^129 + P^130 + 2*P^132 + 2*P^133 + P^134 + P^135 + 2*P^137 + 
    P^138 + P^139 + P^140 + 2*P^142 + P^144 + 2*P^147 + P^149 + P^151 + P^152 + P^156 + P^161 + P^163)/
   ((1 - P^3)*(1 - P^71)*(1 - P^97))}, {3, (P^4 + 2*P^12 + 2*P^17 + P^18 + 2*P^22 + P^23 + 2*P^26 + 2*P^27 + P^28 + 2*P^31 + 
    P^32 + P^33 + P^35 + 2*P^36 + P^37 + P^38 + 2*P^40 + 3*P^41 + P^42 + 2*P^45 + 3*P^46 + P^47 + 2*P^49 + 2*P^50 + 3*P^51 + 
    P^52 + 2*P^54 + 3*P^55 + 3*P^56 + P^57 + 2*P^59 + 3*P^60 + 2*P^61 + P^62 + 2*P^63 + 3*P^64 + 3*P^65 + P^66 + P^67 + 2*P^68 + 
    3*P^69 + 3*P^70 + P^71 + 2*P^72 + 2*P^73 + 3*P^74 + 2*P^75 + P^76 + 2*P^77 + 3*P^78 + 3*P^79 + 3*P^80 + P^81 + 2*P^82 + 
    P^83 + 3*P^84 + 3*P^85 + 3*P^86 + 2*P^87 + P^88 + 2*P^89 + 3*P^90 + 3*P^91 + 3*P^92 + P^93 + 2*P^94 + 2*P^95 + 3*P^96 + 
    P^97 + P^98 + 2*P^99 + 3*P^100 + 3*P^101 + P^102 + 2*P^103 + 2*P^104 + 3*P^105 + 2*P^106 + P^107 + 2*P^108 + 2*P^109 + 
    3*P^110 + P^111 + 2*P^113 + 3*P^114 + 3*P^115 + P^116 + 2*P^118 + 3*P^119 + P^120 + P^121 + 2*P^123 + 3*P^124 + P^125 + 
    2*P^128 + 3*P^129 + P^130 + P^132 + 2*P^133 + P^134 + 2*P^137 + 2*P^138 + P^139 + 2*P^142 + P^143 + P^144 + 2*P^147 + 
    P^148 + 2*P^152 + P^153 + P^158 + P^166)/((1 - P^3)*(1 - P^71)*(1 - P^97))}, 
 {3, (P^6 + 2*P^11 + 2*P^16 + P^20 + 2*P^21 + 3*P^25 + P^26 + P^29 + 3*P^30 + 2*P^34 + 3*P^35 + 3*P^39 + 3*P^40 + P^43 + 
    3*P^44 + 2*P^45 + 3*P^48 + 3*P^49 + 2*P^50 + 3*P^53 + 3*P^54 + 2*P^55 + P^57 + 3*P^58 + 3*P^59 + P^60 + 3*P^62 + 3*P^63 + 
    3*P^64 + P^66 + 3*P^67 + 3*P^68 + 3*P^69 + 2*P^71 + 3*P^72 + 3*P^73 + 3*P^74 + 3*P^76 + 2*P^77 + 3*P^78 + 2*P^79 + P^80 + 
    3*P^81 + P^82 + 3*P^83 + 2*P^84 + 3*P^85 + 3*P^86 + P^87 + 3*P^88 + 2*P^89 + 3*P^90 + 2*P^91 + P^92 + 3*P^93 + 2*P^94 + 
    3*P^95 + 2*P^97 + 3*P^98 + 3*P^99 + 2*P^100 + 3*P^102 + 3*P^103 + 3*P^104 + P^105 + 3*P^107 + 3*P^108 + 3*P^109 + 3*P^112 + 
    3*P^113 + 2*P^114 + P^116 + 3*P^117 + 3*P^118 + P^121 + 3*P^122 + 3*P^123 + P^126 + 3*P^127 + 2*P^128 + 2*P^131 + 3*P^132 + 
    3*P^136 + 2*P^137 + 3*P^141 + P^142 + 3*P^146 + P^150 + 2*P^151 + P^155 + P^160 + P^165)/((1 - P^3)*(1 - P^71)*(1 - P^97))}, 
 {3, (P^6 + P^11 + P^13 + P^14 + P^18 + P^19 + P^20 + P^22 + P^23 + P^24 + P^25 + P^27 + P^28 + P^29 + P^30 + P^32 + P^33 + 
    P^34 + P^35 + P^36 + 2*P^37 + P^38 + P^39 + P^40 + P^41 + 2*P^42 + 2*P^43 + P^44 + P^45 + P^46 + 2*P^47 + 2*P^48 + P^49 + 
    P^50 + 2*P^51 + 2*P^52 + 2*P^53 + P^54 + P^55 + 2*P^56 + 2*P^57 + 2*P^58 + 2*P^59 + 2*P^60 + 2*P^61 + 2*P^62 + P^63 + 
    2*P^64 + 2*P^65 + 3*P^66 + 2*P^67 + P^68 + 2*P^69 + 2*P^70 + 3*P^71 + 2*P^72 + 2*P^73 + 3*P^74 + 2*P^75 + 3*P^76 + P^77 + 
    2*P^78 + 2*P^79 + 3*P^80 + 3*P^81 + 2*P^82 + 2*P^83 + P^84 + 2*P^85 + 3*P^86 + 3*P^87 + 3*P^88 + P^89 + 2*P^90 + P^91 + 
    3*P^92 + 2*P^93 + 2*P^94 + 2*P^95 + 2*P^96 + 3*P^97 + 2*P^98 + 2*P^99 + 2*P^100 + 2*P^101 + 3*P^102 + 2*P^103 + 2*P^104 + 
    2*P^105 + 2*P^106 + 2*P^107 + P^108 + 2*P^109 + 2*P^110 + 2*P^111 + 2*P^112 + P^113 + P^114 + 2*P^115 + 2*P^116 + 2*P^117 + 
    P^118 + P^119 + 2*P^120 + 2*P^121 + P^122 + P^123 + P^124 + 2*P^125 + 2*P^126 + P^127 + P^128 + P^129 + P^130 + P^131 + 
    P^132 + P^133 + 2*P^134 + P^135 + P^136 + P^138 + 2*P^139 + P^140 + P^141 + P^143 + P^144 + P^146 + P^148 + P^149 + P^150 + 
    P^154 + P^155 + P^160 + P^162)/((1 - P^3)*(1 - P^71)*(1 - P^97))}, 
 {3, (P^7 + P^11 + P^12 + P^15 + P^16 + 2*P^20 + P^21 + P^24 + 2*P^25 + P^26 + P^29 + 2*P^30 + P^31 + 2*P^34 + 2*P^35 + P^36 + 
    P^38 + 2*P^39 + 2*P^40 + P^41 + P^43 + 3*P^44 + 2*P^45 + P^46 + 2*P^48 + 3*P^49 + 2*P^50 + P^52 + 2*P^53 + 3*P^54 + P^55 + 
    2*P^57 + 3*P^58 + 3*P^59 + P^60 + P^61 + 2*P^62 + 3*P^63 + 2*P^64 + P^65 + P^66 + 3*P^67 + 3*P^68 + 2*P^69 + P^70 + 2*P^71 + 
    3*P^72 + 3*P^73 + 2*P^74 + 2*P^75 + 2*P^76 + 3*P^77 + 2*P^78 + 2*P^79 + 2*P^80 + 3*P^81 + 2*P^82 + 2*P^83 + 2*P^84 + 
    2*P^85 + 2*P^86 + 2*P^87 + 3*P^88 + 2*P^89 + 2*P^90 + P^91 + 2*P^92 + 3*P^93 + 3*P^94 + 2*P^95 + P^96 + 2*P^97 + 3*P^98 + 
    3*P^99 + 2*P^100 + P^101 + 2*P^102 + 3*P^103 + 3*P^104 + P^105 + P^106 + 2*P^107 + 3*P^108 + 2*P^109 + P^110 + P^111 + 
    2*P^112 + 3*P^113 + 2*P^114 + P^116 + 2*P^117 + 3*P^118 + P^119 + P^121 + 3*P^122 + 2*P^123 + P^124 + 2*P^126 + 3*P^127 + 
    P^128 + 2*P^131 + 2*P^132 + P^133 + P^135 + 2*P^136 + 2*P^137 + P^140 + 2*P^141 + P^142 + P^145 + P^146 + P^147 + P^150 + 
    P^151 + P^155 + P^156 + P^160 + P^161)/((1 - P^3)*(1 - P^71)*(1 - P^97))}, 
 {3, (P^6 + P^7 + P^11 + P^15 + P^16 + 2*P^20 + P^21 + 2*P^25 + P^26 + P^29 + 3*P^30 + P^31 + 2*P^34 + 3*P^35 + P^36 + 2*P^39 + 
    2*P^40 + P^41 + 2*P^43 + 3*P^44 + 2*P^45 + 2*P^48 + 3*P^49 + P^50 + P^52 + 3*P^53 + 3*P^54 + P^55 + 2*P^57 + 3*P^58 + 
    3*P^59 + P^60 + 2*P^62 + 3*P^63 + 3*P^64 + P^65 + P^66 + 3*P^67 + 3*P^68 + 3*P^69 + P^70 + 2*P^71 + 3*P^72 + 3*P^73 + 
    2*P^74 + P^75 + 2*P^76 + 2*P^77 + 2*P^78 + 2*P^79 + 2*P^80 + 3*P^81 + 2*P^82 + 3*P^83 + P^84 + 2*P^85 + 2*P^86 + 2*P^87 + 
    3*P^88 + 2*P^89 + 3*P^90 + P^91 + 2*P^92 + 3*P^93 + 3*P^94 + 3*P^95 + P^96 + 2*P^97 + 3*P^98 + 3*P^99 + 2*P^100 + 2*P^102 + 
    3*P^103 + 3*P^104 + P^105 + 2*P^107 + 3*P^108 + 3*P^109 + P^110 + P^111 + 2*P^112 + 3*P^113 + P^114 + P^116 + 3*P^117 + 
    3*P^118 + P^119 + 2*P^121 + 3*P^122 + 2*P^123 + 2*P^126 + 3*P^127 + P^128 + 2*P^131 + 3*P^132 + P^133 + 2*P^136 + 2*P^137 + 
    2*P^141 + P^142 + P^145 + 2*P^146 + P^147 + P^150 + P^151 + 2*P^155 + P^156 + P^160)/((1 - P^3)*(1 - P^71)*(1 - P^97))}};
Generating38=ToExpression[Import["./SUtreeData/Generating38.mml","MathML"]];
Generating39=ToExpression[Import["./SUtreeData/Generating39.mml","MathML"]];
Generating40={{1, (1 + P^13 + P^20 + P^26 + P^27 + P^33 + P^34 + P^39 + P^40 + P^41 + P^46 + P^47 + P^48 + P^52 + P^53 + P^54 + P^58 + P^59 + 
    P^60 + P^61 + P^65 + P^66 + P^67 + P^68 + P^71 + P^72 + P^73 + P^74 + P^75 + P^78 + P^79 + P^80 + P^81 + P^82 + P^84 + 
    P^85 + P^86 + P^87 + P^88 + P^89 + P^91 + P^92 + P^94 + P^95 + P^96 + P^97 + P^98 + P^99 + P^100 + P^101 + P^102 + P^104 + 
    P^105 + P^107 + P^108 + P^109 + P^110 + P^111 + P^112 + P^114 + P^115 + P^116 + P^117 + P^118 + P^121 + P^122 + P^123 + 
    P^124 + P^125 + P^128 + P^129 + P^130 + P^131 + P^135 + P^136 + P^137 + P^138 + P^142 + P^143 + P^144 + P^148 + P^149 + 
    P^150 + P^155 + P^156 + P^157 + P^162 + P^163 + P^169 + P^170 + P^176 + P^183 + P^196)/((1 - P^3)*(1 - P^93)*(1 - P^103))}, 
 {1, (P^13 + P^20 + P^26 + P^27 + P^33 + P^34 + P^39 + P^40 + P^41 + P^46 + P^47 + P^48 + P^52 + P^53 + P^54 + P^58 + P^59 + 
    P^60 + P^61 + P^65 + P^66 + P^67 + P^68 + P^71 + P^72 + P^73 + P^74 + P^75 + P^78 + P^79 + P^80 + P^81 + P^82 + P^84 + 
    P^85 + P^86 + P^87 + P^88 + P^89 + P^91 + P^92 + P^93 + P^94 + P^95 + P^96 + P^97 + P^98 + P^99 + P^100 + P^101 + P^102 + 
    P^103 + P^104 + P^105 + P^107 + P^108 + P^109 + P^110 + P^111 + P^112 + P^114 + P^115 + P^116 + P^117 + P^118 + P^121 + 
    P^122 + P^123 + P^124 + P^125 + P^128 + P^129 + P^130 + P^131 + P^135 + P^136 + P^137 + P^138 + P^142 + P^143 + P^144 + 
    P^148 + P^149 + P^150 + P^155 + P^156 + P^157 + P^162 + P^163 + P^169 + P^170 + P^176 + P^183)/
   ((1 - P^3)*(1 - P^93)*(1 - P^103))}, {1, (P^13 + P^20 + P^26 + P^27 + P^33 + P^34 + P^39 + P^40 + P^41 + P^46 + P^47 + P^48 + 
    P^52 + P^53 + P^54 + P^58 + P^59 + P^60 + P^61 + P^65 + P^66 + P^67 + P^68 + P^71 + P^72 + P^73 + P^74 + P^75 + P^78 + 
    P^79 + P^80 + P^81 + P^82 + P^84 + P^85 + P^86 + P^87 + P^88 + P^89 + P^91 + P^92 + P^93 + P^94 + P^95 + P^96 + P^97 + 
    P^98 + P^99 + P^100 + P^101 + P^102 + P^103 + P^104 + P^105 + P^107 + P^108 + P^109 + P^110 + P^111 + P^112 + P^114 + 
    P^115 + P^116 + P^117 + P^118 + P^121 + P^122 + P^123 + P^124 + P^125 + P^128 + P^129 + P^130 + P^131 + P^135 + P^136 + 
    P^137 + P^138 + P^142 + P^143 + P^144 + P^148 + P^149 + P^150 + P^155 + P^156 + P^157 + P^162 + P^163 + P^169 + P^170 + 
    P^176 + P^183)/((1 - P^3)*(1 - P^93)*(1 - P^103))}, 
 {3, (P^4 + P^11 + P^14 + P^15 + P^17 + 2*P^21 + P^22 + P^24 + P^27 + 2*P^28 + P^29 + P^30 + P^31 + 2*P^34 + 2*P^35 + P^36 + 
    P^37 + P^38 + P^40 + 2*P^41 + 2*P^42 + P^43 + P^44 + P^45 + P^46 + 2*P^47 + 2*P^48 + 2*P^49 + P^50 + P^51 + P^52 + P^53 + 
    2*P^54 + 2*P^55 + 2*P^56 + P^57 + P^58 + 2*P^59 + 2*P^60 + 2*P^61 + 3*P^62 + 2*P^63 + P^64 + P^65 + 2*P^66 + 2*P^67 + 
    2*P^68 + 3*P^69 + 2*P^70 + P^71 + 2*P^72 + 2*P^73 + 2*P^74 + 3*P^75 + 3*P^76 + 2*P^77 + P^78 + 3*P^79 + 2*P^80 + 2*P^81 + 
    3*P^82 + 3*P^83 + 2*P^84 + 2*P^85 + 3*P^86 + 2*P^87 + 3*P^88 + 3*P^89 + 3*P^90 + 2*P^91 + 3*P^92 + 3*P^93 + 2*P^94 + 
    3*P^95 + 3*P^96 + 2*P^97 + 2*P^98 + 3*P^99 + 3*P^100 + 3*P^101 + 3*P^102 + 3*P^103 + 2*P^104 + 3*P^105 + 3*P^106 + 2*P^107 + 
    2*P^108 + 3*P^109 + 2*P^110 + 3*P^111 + 3*P^112 + 3*P^113 + P^114 + 2*P^115 + 3*P^116 + 2*P^117 + 3*P^118 + 3*P^119 + 
    2*P^120 + P^121 + 2*P^122 + 2*P^123 + 2*P^124 + 3*P^125 + 3*P^126 + P^127 + P^128 + 2*P^129 + 2*P^130 + 2*P^131 + 3*P^132 + 
    2*P^133 + P^134 + P^135 + 2*P^136 + 2*P^137 + 2*P^138 + 2*P^139 + P^140 + P^141 + P^142 + 2*P^143 + 2*P^144 + 2*P^145 + 
    2*P^146 + P^147 + P^148 + P^149 + 2*P^150 + 2*P^151 + P^152 + P^153 + P^154 + P^156 + 2*P^157 + 2*P^158 + P^159 + P^160 + 
    P^161 + P^163 + 2*P^164 + P^165 + P^166 + P^167 + P^170 + 2*P^171 + P^173 + P^174 + P^177 + P^178 + P^180 + P^184 + P^187 + 
    P^191)/((1 - P^3)*(1 - P^93)*(1 - P^103))}, 
 {3, (P + P^11 + 2*P^14 + P^18 + 2*P^21 + P^24 + P^25 + 2*P^27 + 2*P^28 + P^31 + P^32 + 2*P^34 + 2*P^35 + P^37 + P^38 + P^39 + 
    2*P^40 + 2*P^41 + 2*P^42 + P^44 + P^45 + P^46 + 2*P^47 + 2*P^48 + 2*P^49 + P^50 + P^51 + P^52 + 2*P^53 + 2*P^54 + 2*P^55 + 
    P^56 + P^57 + P^58 + 3*P^59 + 2*P^60 + 2*P^61 + 2*P^62 + P^63 + P^64 + P^65 + 3*P^66 + 2*P^67 + 2*P^68 + 3*P^69 + P^70 + 
    P^71 + 3*P^72 + 3*P^73 + 2*P^74 + 2*P^75 + 3*P^76 + P^77 + P^78 + 3*P^79 + 3*P^80 + 2*P^81 + 3*P^82 + 3*P^83 + P^84 + 
    3*P^85 + 3*P^86 + 3*P^87 + 2*P^88 + 3*P^89 + 3*P^90 + P^91 + 3*P^92 + 3*P^93 + 2*P^94 + 3*P^95 + 3*P^96 + 3*P^97 + 3*P^98 + 
    3*P^99 + 3*P^100 + 2*P^101 + 3*P^102 + 3*P^103 + 2*P^104 + 3*P^105 + 3*P^106 + P^107 + 3*P^108 + 3*P^109 + 3*P^110 + 
    2*P^111 + 3*P^112 + 3*P^113 + P^114 + 3*P^115 + 3*P^116 + 2*P^117 + 2*P^118 + 3*P^119 + P^120 + P^121 + 3*P^122 + 3*P^123 + 
    2*P^124 + 2*P^125 + 3*P^126 + P^127 + P^128 + 3*P^129 + 2*P^130 + 2*P^131 + 2*P^132 + P^133 + P^134 + P^135 + 3*P^136 + 
    2*P^137 + 2*P^138 + 2*P^139 + P^140 + P^141 + P^142 + 2*P^143 + 2*P^144 + 2*P^145 + P^146 + P^147 + P^148 + 2*P^149 + 
    2*P^150 + 2*P^151 + P^153 + P^154 + P^155 + 2*P^156 + 2*P^157 + 2*P^158 + P^160 + P^161 + 2*P^163 + 2*P^164 + P^167 + 
    P^168 + 2*P^170 + 2*P^171 + P^174 + 2*P^177 + P^181 + 2*P^184 + P^194)/((1 - P^3)*(1 - P^93)*(1 - P^103))}, 
 {3, (P^10 + P^11 + P^12 + P^17 + P^18 + P^19 + P^23 + 2*P^24 + 2*P^25 + P^26 + P^30 + 2*P^31 + 2*P^32 + P^33 + P^36 + 2*P^37 + 
    2*P^38 + P^39 + P^42 + 2*P^43 + 3*P^44 + 2*P^45 + P^46 + P^49 + 2*P^50 + 3*P^51 + 2*P^52 + P^53 + P^55 + 2*P^56 + 3*P^57 + 
    3*P^58 + 2*P^59 + P^60 + P^62 + 2*P^63 + 3*P^64 + 3*P^65 + 2*P^66 + P^67 + P^68 + 2*P^69 + 3*P^70 + 3*P^71 + 3*P^72 + 
    2*P^73 + P^74 + P^75 + 2*P^76 + 3*P^77 + 3*P^78 + 3*P^79 + 2*P^80 + 2*P^81 + 2*P^82 + 3*P^83 + 3*P^84 + 3*P^85 + 2*P^86 + 
    2*P^87 + 2*P^88 + 3*P^89 + 3*P^90 + 3*P^91 + 3*P^92 + 2*P^93 + 2*P^94 + 2*P^95 + 3*P^96 + 3*P^97 + 3*P^98 + 3*P^99 + 
    3*P^100 + 3*P^101 + 3*P^102 + 2*P^103 + 2*P^104 + 2*P^105 + 3*P^106 + 3*P^107 + 3*P^108 + 3*P^109 + 2*P^110 + 2*P^111 + 
    2*P^112 + 3*P^113 + 3*P^114 + 3*P^115 + 2*P^116 + P^117 + P^118 + 2*P^119 + 3*P^120 + 3*P^121 + 3*P^122 + 2*P^123 + P^124 + 
    P^125 + 2*P^126 + 3*P^127 + 3*P^128 + 2*P^129 + P^130 + P^131 + 2*P^132 + 3*P^133 + 3*P^134 + 2*P^135 + P^136 + P^138 + 
    2*P^139 + 3*P^140 + 3*P^141 + 2*P^142 + P^143 + P^145 + 2*P^146 + 3*P^147 + 2*P^148 + P^149 + P^152 + 2*P^153 + 3*P^154 + 
    2*P^155 + P^156 + P^159 + 2*P^160 + 2*P^161 + P^162 + P^166 + 2*P^167 + 2*P^168 + P^169 + P^173 + P^174 + P^175 + P^179 + 
    P^180 + P^181 + P^186 + P^187 + P^188)/((1 - P^3)*(1 - P^93)*(1 - P^103))}, 
 {3, (P^6 + P^10 + P^13 + 2*P^17 + P^19 + 2*P^23 + 2*P^24 + P^26 + 2*P^30 + 2*P^31 + P^32 + P^33 + 2*P^36 + 2*P^37 + 2*P^38 + 
    P^39 + P^40 + 2*P^43 + 2*P^44 + 2*P^45 + P^46 + P^47 + 2*P^49 + 2*P^50 + 3*P^51 + P^52 + P^53 + P^54 + P^55 + 2*P^56 + 
    2*P^57 + 3*P^58 + P^59 + P^60 + P^61 + 2*P^62 + 2*P^63 + 3*P^64 + 3*P^65 + P^66 + P^67 + 2*P^68 + 2*P^69 + 2*P^70 + 3*P^71 + 
    3*P^72 + P^73 + P^74 + 2*P^75 + 2*P^76 + 3*P^77 + 3*P^78 + 3*P^79 + P^80 + 3*P^81 + 2*P^82 + 2*P^83 + 3*P^84 + 3*P^85 + 
    3*P^86 + P^87 + 3*P^88 + 2*P^89 + 3*P^90 + 3*P^91 + 3*P^92 + 2*P^93 + 3*P^94 + 3*P^95 + 3*P^96 + 3*P^97 + 3*P^98 + 2*P^99 + 
    2*P^100 + 3*P^101 + 3*P^102 + 2*P^103 + 3*P^104 + 3*P^105 + 2*P^106 + 3*P^107 + 3*P^108 + 3*P^109 + P^110 + 3*P^111 + 
    2*P^112 + 3*P^113 + 3*P^114 + 3*P^115 + P^116 + P^117 + 3*P^118 + 2*P^119 + 3*P^120 + 3*P^121 + 3*P^122 + P^123 + P^124 + 
    2*P^125 + 2*P^126 + 3*P^127 + 3*P^128 + P^129 + P^130 + P^131 + 2*P^132 + 2*P^133 + 3*P^134 + 3*P^135 + P^136 + P^137 + 
    P^138 + 2*P^139 + 2*P^140 + 3*P^141 + P^142 + P^143 + 2*P^145 + 2*P^146 + 2*P^147 + 2*P^148 + P^149 + P^150 + 2*P^152 + 
    2*P^153 + 2*P^154 + P^155 + P^156 + 2*P^159 + 2*P^160 + P^161 + P^162 + P^163 + 2*P^166 + 2*P^167 + P^168 + P^169 + 
    2*P^173 + P^175 + P^176 + 2*P^180 + P^182 + P^186 + P^193)/((1 - P^3)*(1 - P^93)*(1 - P^103))}, 
 {3, (P^9 + P^11 + P^13 + P^16 + P^18 + P^20 + P^22 + P^23 + P^24 + P^25 + P^26 + P^27 + P^29 + P^30 + P^31 + P^32 + P^33 + 
    P^34 + P^35 + P^36 + P^37 + P^38 + P^39 + P^40 + P^41 + P^42 + 2*P^43 + P^44 + 2*P^45 + P^46 + P^47 + P^48 + P^49 + 2*P^50 + 
    P^51 + 2*P^52 + P^53 + 2*P^54 + P^55 + 2*P^56 + 2*P^57 + 2*P^58 + 2*P^59 + P^60 + 2*P^61 + P^62 + 2*P^63 + 2*P^64 + 2*P^65 + 
    2*P^66 + 2*P^67 + 2*P^68 + 2*P^69 + 2*P^70 + 3*P^71 + 2*P^72 + 2*P^73 + 2*P^74 + 2*P^75 + 2*P^76 + 2*P^77 + 3*P^78 + 
    2*P^79 + 3*P^80 + 2*P^81 + 3*P^82 + 2*P^83 + 3*P^84 + 2*P^85 + 2*P^86 + 2*P^87 + 3*P^88 + 3*P^89 + 3*P^90 + 3*P^91 + 
    2*P^92 + 3*P^93 + 2*P^94 + 3*P^95 + 2*P^96 + 3*P^97 + 3*P^98 + 3*P^99 + 3*P^100 + 3*P^101 + 2*P^102 + 3*P^103 + 2*P^104 + 
    3*P^105 + 2*P^106 + 3*P^107 + 3*P^108 + 2*P^109 + 3*P^110 + 2*P^111 + 3*P^112 + 2*P^113 + 3*P^114 + 2*P^115 + 2*P^116 + 
    2*P^117 + 2*P^118 + 2*P^119 + 2*P^120 + 3*P^121 + 2*P^122 + 2*P^123 + 2*P^124 + 2*P^125 + 2*P^126 + 2*P^127 + 2*P^128 + 
    2*P^129 + 2*P^130 + 2*P^131 + 2*P^132 + 2*P^133 + 2*P^134 + 2*P^135 + P^136 + 2*P^137 + P^138 + 2*P^139 + 2*P^140 + 
    2*P^141 + 2*P^142 + P^143 + 2*P^144 + P^145 + 2*P^146 + P^147 + 2*P^148 + P^149 + P^150 + P^151 + P^152 + 2*P^153 + P^154 + 
    2*P^155 + P^156 + P^157 + P^158 + P^159 + P^160 + P^161 + P^162 + P^163 + P^165 + P^166 + P^167 + P^168 + P^169 + P^170 + 
    P^172 + P^174 + P^176 + P^178 + P^179 + P^180 + P^185 + P^187 + P^189)/((1 - P^3)*(1 - P^93)*(1 - P^103))}, 
 {3, (P^6 + 2*P^13 + P^14 + P^19 + 2*P^20 + P^21 + 2*P^26 + 2*P^27 + P^28 + P^32 + 3*P^33 + 2*P^34 + P^35 + 2*P^39 + 3*P^40 + 
    2*P^41 + 2*P^45 + 3*P^46 + 3*P^47 + P^48 + P^51 + 2*P^52 + 3*P^53 + 3*P^54 + P^55 + 2*P^58 + 3*P^59 + 3*P^60 + 3*P^61 + 
    P^62 + P^64 + 2*P^65 + 3*P^66 + 3*P^67 + 3*P^68 + P^69 + 2*P^71 + 3*P^72 + 3*P^73 + 3*P^74 + 2*P^75 + P^76 + P^77 + 3*P^78 + 
    3*P^79 + 3*P^80 + 3*P^81 + 2*P^82 + P^83 + 2*P^84 + 3*P^85 + 3*P^86 + 3*P^87 + 3*P^88 + 2*P^89 + 2*P^90 + 3*P^91 + 3*P^92 + 
    3*P^93 + 3*P^94 + 3*P^95 + 2*P^96 + 2*P^97 + 3*P^98 + 2*P^99 + 3*P^100 + 3*P^101 + 3*P^102 + 3*P^103 + 3*P^104 + 3*P^105 + 
    P^106 + 2*P^107 + 3*P^108 + 3*P^109 + 3*P^110 + 3*P^111 + 2*P^112 + P^113 + 2*P^114 + 3*P^115 + 3*P^116 + 3*P^117 + 
    3*P^118 + P^119 + P^120 + 2*P^121 + 3*P^122 + 3*P^123 + 3*P^124 + 2*P^125 + P^127 + 2*P^128 + 3*P^129 + 3*P^130 + 3*P^131 + 
    P^132 + P^134 + 3*P^135 + 3*P^136 + 3*P^137 + P^138 + 2*P^141 + 3*P^142 + 3*P^143 + 2*P^144 + P^145 + 2*P^148 + 3*P^149 + 
    3*P^150 + P^151 + 2*P^155 + 3*P^156 + 2*P^157 + P^158 + 2*P^162 + 3*P^163 + P^164 + P^168 + 2*P^169 + 2*P^170 + P^175 + 
    2*P^176 + P^177 + P^182 + P^183 + P^189 + P^190)/((1 - P^3)*(1 - P^93)*(1 - P^103))}, 
 {3, (P^7 + P^9 + P^14 + P^16 + P^17 + P^20 + P^21 + P^22 + P^23 + P^24 + P^27 + P^28 + P^29 + P^30 + P^31 + P^33 + P^34 + 
    P^35 + 2*P^36 + P^37 + P^38 + P^40 + 2*P^41 + P^42 + 2*P^43 + P^44 + P^45 + P^46 + P^47 + 2*P^48 + 2*P^49 + 2*P^50 + P^51 + 
    P^52 + P^53 + 2*P^54 + 2*P^55 + 2*P^56 + 2*P^57 + P^58 + P^59 + P^60 + 2*P^61 + 3*P^62 + 2*P^63 + 2*P^64 + 2*P^65 + P^66 + 
    2*P^67 + 2*P^68 + 3*P^69 + 2*P^70 + 2*P^71 + 2*P^72 + P^73 + 2*P^74 + 3*P^75 + 3*P^76 + 2*P^77 + 2*P^78 + 2*P^79 + 2*P^80 + 
    3*P^81 + 3*P^82 + 2*P^83 + 2*P^84 + 2*P^85 + 3*P^86 + 2*P^87 + 3*P^88 + 3*P^89 + 2*P^90 + 3*P^91 + 2*P^92 + 3*P^93 + 
    3*P^94 + 3*P^95 + 3*P^96 + 2*P^97 + 3*P^98 + 3*P^99 + 2*P^100 + 3*P^101 + 2*P^102 + 3*P^103 + 3*P^104 + 3*P^105 + 3*P^106 + 
    2*P^107 + 3*P^108 + 2*P^109 + 2*P^110 + 3*P^111 + 3*P^112 + 2*P^113 + 2*P^114 + 2*P^115 + 2*P^116 + 2*P^117 + 3*P^118 + 
    3*P^119 + 2*P^120 + 2*P^121 + 2*P^122 + 2*P^123 + 2*P^124 + 3*P^125 + 2*P^126 + 2*P^127 + 2*P^128 + P^129 + 2*P^130 + 
    2*P^131 + 3*P^132 + 2*P^133 + P^134 + 2*P^135 + P^136 + 2*P^137 + 2*P^138 + 2*P^139 + 2*P^140 + P^141 + P^142 + P^143 + 
    2*P^144 + 2*P^145 + 2*P^146 + P^147 + P^148 + P^149 + P^150 + 2*P^151 + 2*P^152 + 2*P^153 + P^154 + P^156 + P^157 + P^158 + 
    2*P^159 + P^160 + P^161 + P^163 + P^164 + P^165 + 2*P^166 + P^167 + P^170 + P^171 + P^172 + P^173 + P^176 + P^177 + P^178 + 
    P^180 + P^183 + P^185 + P^190)/((1 - P^3)*(1 - P^93)*(1 - P^103))}, 
 {3, (P^5 + 2*P^12 + P^16 + P^18 + P^19 + P^22 + P^23 + 2*P^25 + P^26 + P^29 + P^30 + P^31 + 2*P^32 + P^33 + P^35 + P^36 + 
    P^37 + 2*P^38 + 2*P^39 + P^40 + P^42 + P^43 + 2*P^44 + 2*P^45 + 2*P^46 + P^48 + P^49 + 2*P^50 + 2*P^51 + 2*P^52 + 2*P^53 + 
    P^55 + P^56 + 3*P^57 + 2*P^58 + 2*P^59 + 2*P^60 + P^61 + P^62 + 2*P^63 + 3*P^64 + 2*P^65 + 2*P^66 + 2*P^67 + P^68 + P^69 + 
    3*P^70 + 3*P^71 + 2*P^72 + 2*P^73 + 2*P^74 + P^75 + 2*P^76 + 3*P^77 + 3*P^78 + 2*P^79 + 3*P^80 + 2*P^81 + P^82 + 3*P^83 + 
    3*P^84 + 3*P^85 + 2*P^86 + 3*P^87 + 2*P^88 + 2*P^89 + 3*P^90 + 3*P^91 + 3*P^92 + 3*P^93 + 3*P^94 + 2*P^95 + 3*P^96 + 
    3*P^97 + 2*P^98 + 2*P^99 + 3*P^100 + 3*P^101 + 3*P^102 + 3*P^103 + 3*P^104 + P^105 + 3*P^106 + 3*P^107 + 3*P^108 + 2*P^109 + 
    3*P^110 + 2*P^111 + 2*P^112 + 3*P^113 + 3*P^114 + 2*P^115 + 2*P^116 + 3*P^117 + P^118 + 2*P^119 + 3*P^120 + 3*P^121 + 
    2*P^122 + 2*P^123 + 2*P^124 + P^125 + 2*P^126 + 3*P^127 + 2*P^128 + 2*P^129 + 2*P^130 + P^131 + P^132 + 2*P^133 + 3*P^134 + 
    2*P^135 + 2*P^136 + P^137 + P^138 + P^139 + 3*P^140 + 2*P^141 + 2*P^142 + P^143 + P^144 + P^145 + P^146 + 3*P^147 + 
    2*P^148 + 2*P^149 + P^151 + P^152 + P^153 + 2*P^154 + 2*P^155 + P^156 + P^158 + P^159 + P^160 + 2*P^161 + 2*P^162 + P^165 + 
    P^166 + P^167 + 2*P^168 + P^169 + P^172 + P^174 + 2*P^175 + P^179 + P^181 + P^182 + P^188 + P^192)/
   ((1 - P^3)*(1 - P^93)*(1 - P^103))}, {3, (P^9 + P^10 + P^14 + P^16 + P^17 + P^21 + P^22 + 2*P^23 + P^24 + P^27 + P^28 + 
    P^29 + P^30 + P^31 + P^33 + P^34 + 2*P^35 + 2*P^36 + P^37 + P^40 + 2*P^41 + 2*P^42 + 2*P^43 + P^44 + P^46 + P^47 + 2*P^48 + 
    2*P^49 + 2*P^50 + P^51 + P^53 + 2*P^54 + 3*P^55 + 2*P^56 + 2*P^57 + P^58 + P^59 + P^60 + 2*P^61 + 3*P^62 + 2*P^63 + 2*P^64 + 
    P^65 + P^66 + 2*P^67 + 3*P^68 + 3*P^69 + 2*P^70 + 2*P^71 + 2*P^72 + P^73 + 2*P^74 + 3*P^75 + 3*P^76 + 2*P^77 + 2*P^78 + 
    2*P^79 + 2*P^80 + 3*P^81 + 3*P^82 + 3*P^83 + 2*P^84 + 2*P^85 + 2*P^86 + 2*P^87 + 3*P^88 + 3*P^89 + 3*P^90 + 3*P^91 + 
    2*P^92 + 2*P^93 + 3*P^94 + 3*P^95 + 3*P^96 + 2*P^97 + 3*P^98 + 3*P^99 + 3*P^100 + 3*P^101 + 2*P^102 + 2*P^103 + 3*P^104 + 
    3*P^105 + 3*P^106 + 2*P^107 + 3*P^108 + 2*P^109 + 2*P^110 + 3*P^111 + 3*P^112 + 3*P^113 + 2*P^114 + 2*P^115 + P^116 + 
    2*P^117 + 3*P^118 + 3*P^119 + 2*P^120 + 2*P^121 + 2*P^122 + 2*P^123 + 2*P^124 + 3*P^125 + 2*P^126 + 2*P^127 + P^128 + 
    P^129 + 2*P^130 + 3*P^131 + 3*P^132 + 2*P^133 + P^134 + P^135 + P^136 + 2*P^137 + 3*P^138 + 2*P^139 + 2*P^140 + P^141 + 
    P^142 + P^143 + 2*P^144 + 3*P^145 + 2*P^146 + P^147 + P^149 + P^150 + 2*P^151 + 2*P^152 + 2*P^153 + P^154 + P^156 + P^157 + 
    2*P^158 + 2*P^159 + P^160 + P^163 + P^164 + P^165 + 2*P^166 + P^167 + P^170 + P^171 + P^172 + P^173 + P^177 + P^178 + 
    P^179 + P^180 + P^185 + P^186 + P^190)/((1 - P^3)*(1 - P^93)*(1 - P^103))}, 
 {3, (P^4 + 2*P^11 + P^17 + 2*P^18 + 3*P^24 + 2*P^25 + P^30 + 3*P^31 + 2*P^32 + 3*P^37 + 3*P^38 + 2*P^39 + P^43 + 3*P^44 + 
    3*P^45 + P^46 + P^49 + 3*P^50 + 3*P^51 + 3*P^52 + 2*P^56 + 3*P^57 + 3*P^58 + 3*P^59 + P^62 + 3*P^63 + 3*P^64 + 3*P^65 + 
    2*P^66 + 3*P^69 + 3*P^70 + 3*P^71 + 3*P^72 + 2*P^73 + P^75 + 3*P^76 + 3*P^77 + 3*P^78 + 3*P^79 + 2*P^80 + 3*P^82 + 3*P^83 + 
    3*P^84 + 3*P^85 + 3*P^86 + 2*P^87 + P^88 + 3*P^89 + 3*P^90 + 3*P^91 + 3*P^92 + 3*P^93 + 2*P^94 + 3*P^95 + 3*P^96 + 2*P^97 + 
    3*P^98 + 3*P^99 + 3*P^100 + 2*P^101 + 3*P^102 + 3*P^103 + P^104 + 3*P^105 + 3*P^106 + 3*P^107 + 3*P^108 + 3*P^109 + 
    2*P^110 + P^111 + 3*P^112 + 3*P^113 + 3*P^114 + 3*P^115 + 3*P^116 + P^118 + 3*P^119 + 3*P^120 + 3*P^121 + 3*P^122 + 
    2*P^123 + P^125 + 3*P^126 + 3*P^127 + 3*P^128 + 3*P^129 + P^132 + 3*P^133 + 3*P^134 + 3*P^135 + 2*P^136 + 2*P^139 + 
    3*P^140 + 3*P^141 + 2*P^142 + 3*P^146 + 3*P^147 + 3*P^148 + P^149 + 3*P^153 + 3*P^154 + 2*P^155 + P^159 + 3*P^160 + 
    3*P^161 + P^166 + 3*P^167 + 2*P^168 + P^173 + 3*P^174 + P^180 + 2*P^181 + P^187 + P^194)/
   ((1 - P^3)*(1 - P^93)*(1 - P^103))}, {3, (P^6 + P^11 + P^13 + P^16 + P^18 + P^19 + P^20 + P^23 + P^24 + P^25 + P^26 + P^29 + 
    2*P^30 + P^31 + P^32 + P^33 + P^35 + P^36 + 2*P^37 + P^38 + P^39 + P^40 + P^42 + 2*P^43 + 2*P^44 + 2*P^45 + P^46 + P^47 + 
    P^48 + P^49 + 2*P^50 + 2*P^51 + 2*P^52 + P^53 + P^54 + P^55 + 2*P^56 + 2*P^57 + 2*P^58 + 2*P^59 + P^60 + 2*P^61 + P^62 + 
    2*P^63 + 3*P^64 + 2*P^65 + 2*P^66 + P^67 + 2*P^68 + 2*P^69 + 2*P^70 + 3*P^71 + 2*P^72 + 2*P^73 + 2*P^74 + 2*P^75 + 2*P^76 + 
    3*P^77 + 3*P^78 + 2*P^79 + 2*P^80 + 2*P^81 + 2*P^82 + 2*P^83 + 3*P^84 + 3*P^85 + 2*P^86 + 2*P^87 + 3*P^88 + 2*P^89 + 
    3*P^90 + 3*P^91 + 3*P^92 + 3*P^93 + 2*P^94 + 3*P^95 + 2*P^96 + 3*P^97 + 3*P^98 + 2*P^99 + 3*P^100 + 3*P^101 + 3*P^102 + 
    3*P^103 + 2*P^104 + 3*P^105 + 2*P^106 + 3*P^107 + 3*P^108 + 2*P^109 + 3*P^110 + 2*P^111 + 2*P^112 + 2*P^113 + 3*P^114 + 
    3*P^115 + 2*P^116 + 2*P^117 + 2*P^118 + 2*P^119 + 3*P^120 + 3*P^121 + 2*P^122 + P^123 + 2*P^124 + 2*P^125 + 2*P^126 + 
    3*P^127 + 2*P^128 + 2*P^129 + P^130 + 2*P^131 + 2*P^132 + 2*P^133 + 3*P^134 + 2*P^135 + P^136 + P^137 + P^138 + 2*P^139 + 
    2*P^140 + 2*P^141 + 2*P^142 + P^143 + P^144 + P^145 + 2*P^146 + 2*P^147 + 2*P^148 + P^149 + P^150 + P^151 + P^152 + 
    2*P^153 + P^154 + 2*P^155 + P^156 + P^158 + P^159 + 2*P^160 + P^161 + P^162 + P^163 + P^165 + P^166 + P^167 + P^168 + 
    P^169 + P^172 + P^173 + P^174 + P^175 + P^176 + P^179 + P^180 + P^182 + P^187 + P^189)/((1 - P^3)*(1 - P^93)*(1 - P^103))}, 
 {3, (P^4 + P^11 + P^12 + 2*P^17 + P^18 + P^19 + 2*P^24 + P^25 + P^26 + 2*P^30 + 3*P^31 + P^32 + P^36 + 2*P^37 + 3*P^38 + P^39 + 
    2*P^43 + 3*P^44 + 3*P^45 + P^46 + P^49 + 2*P^50 + 3*P^51 + 3*P^52 + P^53 + 2*P^56 + 3*P^57 + 3*P^58 + 2*P^59 + P^60 + 
    2*P^62 + 2*P^63 + 3*P^64 + 3*P^65 + 2*P^66 + P^67 + 2*P^69 + 3*P^70 + 3*P^71 + 3*P^72 + P^73 + P^74 + 2*P^75 + 3*P^76 + 
    3*P^77 + 3*P^78 + 3*P^79 + P^80 + P^81 + 2*P^82 + 3*P^83 + 3*P^84 + 3*P^85 + 3*P^86 + P^87 + 2*P^88 + 3*P^89 + 3*P^90 + 
    3*P^91 + 3*P^92 + 3*P^93 + 2*P^94 + 2*P^95 + 3*P^96 + 2*P^97 + 3*P^98 + 3*P^99 + 3*P^100 + 3*P^101 + 3*P^102 + 3*P^103 + 
    2*P^104 + 2*P^105 + 3*P^106 + 3*P^107 + 3*P^108 + 3*P^109 + P^110 + 2*P^111 + 2*P^112 + 3*P^113 + 3*P^114 + 3*P^115 + 
    3*P^116 + P^117 + 2*P^118 + 2*P^119 + 3*P^120 + 3*P^121 + 3*P^122 + P^123 + 2*P^125 + 3*P^126 + 3*P^127 + 3*P^128 + 
    2*P^129 + P^130 + 2*P^132 + 3*P^133 + 3*P^134 + 3*P^135 + P^136 + 2*P^139 + 3*P^140 + 3*P^141 + 2*P^142 + P^143 + 2*P^146 + 
    3*P^147 + 3*P^148 + P^149 + P^152 + 2*P^153 + 3*P^154 + P^155 + P^156 + P^159 + 2*P^160 + 3*P^161 + P^162 + 2*P^166 + 
    2*P^167 + P^168 + 2*P^173 + 2*P^174 + P^175 + 2*P^180 + P^181 + P^187 + P^188)/((1 - P^3)*(1 - P^93)*(1 - P^103))}, 
 {3, (P^4 + P^8 + P^14 + P^15 + P^17 + 2*P^21 + P^22 + P^24 + P^27 + 2*P^28 + P^29 + P^30 + P^31 + 2*P^34 + 2*P^35 + P^36 + 
    P^37 + P^38 + P^40 + 2*P^41 + 2*P^42 + P^43 + P^44 + P^45 + 2*P^47 + 2*P^48 + 3*P^49 + P^50 + P^51 + P^52 + P^53 + 2*P^54 + 
    2*P^55 + 3*P^56 + P^57 + P^58 + P^59 + 2*P^60 + 2*P^61 + 3*P^62 + 2*P^63 + P^64 + P^65 + 2*P^66 + 2*P^67 + 2*P^68 + 3*P^69 + 
    2*P^70 + P^71 + 2*P^72 + 2*P^73 + 2*P^74 + 3*P^75 + 3*P^76 + 2*P^77 + P^78 + 3*P^79 + 2*P^80 + 2*P^81 + 3*P^82 + 3*P^83 + 
    2*P^84 + 2*P^85 + 3*P^86 + 2*P^87 + 3*P^88 + 3*P^89 + 3*P^90 + P^91 + 3*P^92 + 3*P^93 + 3*P^94 + 3*P^95 + 3*P^96 + 2*P^97 + 
    2*P^98 + 3*P^99 + 3*P^100 + 2*P^101 + 3*P^102 + 3*P^103 + 3*P^104 + 3*P^105 + 3*P^106 + 2*P^107 + 2*P^108 + 3*P^109 + 
    2*P^110 + 3*P^111 + 3*P^112 + 3*P^113 + P^114 + 2*P^115 + 3*P^116 + 2*P^117 + 3*P^118 + 3*P^119 + 2*P^120 + P^121 + 
    2*P^122 + 2*P^123 + 2*P^124 + 3*P^125 + 3*P^126 + P^127 + P^128 + 2*P^129 + 2*P^130 + 2*P^131 + 3*P^132 + 2*P^133 + P^134 + 
    P^135 + 2*P^136 + 2*P^137 + 2*P^138 + 3*P^139 + P^140 + P^141 + 2*P^143 + 2*P^144 + 2*P^145 + 2*P^146 + P^147 + P^148 + 
    2*P^150 + 2*P^151 + 2*P^152 + P^153 + P^154 + P^156 + 2*P^157 + 2*P^158 + P^159 + P^160 + P^161 + P^163 + 2*P^164 + P^165 + 
    P^166 + P^167 + P^170 + 2*P^171 + P^173 + P^174 + P^177 + P^178 + P^180 + 2*P^184 + P^191)/
   ((1 - P^3)*(1 - P^93)*(1 - P^103))}, {3, (P^6 + P^10 + P^11 + P^16 + P^17 + P^18 + P^19 + P^23 + P^24 + P^25 + P^26 + P^29 + 
    2*P^30 + P^31 + P^32 + P^33 + P^36 + 2*P^37 + 2*P^38 + P^39 + P^40 + P^42 + 2*P^43 + 2*P^44 + 2*P^45 + P^46 + P^47 + P^49 + 
    2*P^50 + 3*P^51 + 2*P^52 + P^53 + P^54 + P^55 + 2*P^56 + 2*P^57 + 3*P^58 + 2*P^59 + P^60 + P^61 + P^62 + 2*P^63 + 3*P^64 + 
    3*P^65 + 2*P^66 + P^67 + P^68 + 2*P^69 + 2*P^70 + 3*P^71 + 2*P^72 + 2*P^73 + 2*P^74 + 2*P^75 + 2*P^76 + 3*P^77 + 3*P^78 + 
    2*P^79 + P^80 + 2*P^81 + 2*P^82 + 3*P^83 + 3*P^84 + 3*P^85 + 2*P^86 + 2*P^87 + 3*P^88 + 2*P^89 + 3*P^90 + 3*P^91 + 3*P^92 + 
    2*P^93 + 2*P^94 + 3*P^95 + 3*P^96 + 3*P^97 + 3*P^98 + 2*P^99 + 3*P^100 + 3*P^101 + 3*P^102 + 2*P^103 + 2*P^104 + 3*P^105 + 
    3*P^106 + 3*P^107 + 3*P^108 + 2*P^109 + 2*P^110 + 2*P^111 + 2*P^112 + 3*P^113 + 3*P^114 + 3*P^115 + 2*P^116 + 2*P^117 + 
    2*P^118 + 2*P^119 + 3*P^120 + 3*P^121 + 2*P^122 + P^123 + 2*P^124 + 2*P^125 + 2*P^126 + 3*P^127 + 3*P^128 + 2*P^129 + 
    P^130 + P^131 + 2*P^132 + 2*P^133 + 3*P^134 + 2*P^135 + P^136 + P^137 + P^138 + 2*P^139 + 2*P^140 + 3*P^141 + 2*P^142 + 
    P^143 + P^145 + 2*P^146 + 2*P^147 + 2*P^148 + P^149 + P^150 + P^152 + 2*P^153 + 2*P^154 + 2*P^155 + P^156 + P^159 + 
    2*P^160 + 2*P^161 + P^162 + P^163 + P^165 + P^166 + P^167 + P^168 + P^169 + P^172 + 2*P^173 + P^174 + P^175 + P^179 + 
    P^180 + P^182 + P^186 + P^187)/((1 - P^3)*(1 - P^93)*(1 - P^103))}, 
 {3, (P^6 + P^7 + P^13 + P^14 + P^19 + 2*P^20 + P^21 + 2*P^26 + 2*P^27 + P^28 + P^32 + 3*P^33 + 2*P^34 + P^38 + 2*P^39 + 
    3*P^40 + 2*P^41 + P^45 + 3*P^46 + 3*P^47 + 2*P^48 + P^51 + 2*P^52 + 3*P^53 + 3*P^54 + 2*P^55 + P^58 + 3*P^59 + 3*P^60 + 
    3*P^61 + P^62 + P^64 + 3*P^65 + 3*P^66 + 3*P^67 + 2*P^68 + P^69 + 2*P^71 + 3*P^72 + 3*P^73 + 3*P^74 + 2*P^75 + P^76 + P^77 + 
    3*P^78 + 3*P^79 + 3*P^80 + 3*P^81 + 2*P^82 + P^83 + 2*P^84 + 3*P^85 + 3*P^86 + 3*P^87 + 3*P^88 + 2*P^89 + P^90 + 3*P^91 + 
    3*P^92 + 3*P^93 + 3*P^94 + 3*P^95 + 3*P^96 + 2*P^97 + 3*P^98 + 2*P^99 + 2*P^100 + 3*P^101 + 3*P^102 + 3*P^103 + 3*P^104 + 
    3*P^105 + 2*P^106 + 2*P^107 + 3*P^108 + 3*P^109 + 3*P^110 + 3*P^111 + 2*P^112 + P^113 + 2*P^114 + 3*P^115 + 3*P^116 + 
    3*P^117 + 3*P^118 + P^119 + P^120 + 2*P^121 + 3*P^122 + 3*P^123 + 3*P^124 + 2*P^125 + P^127 + 3*P^128 + 3*P^129 + 3*P^130 + 
    2*P^131 + P^132 + P^134 + 3*P^135 + 3*P^136 + 3*P^137 + 2*P^138 + P^141 + 3*P^142 + 3*P^143 + 2*P^144 + P^145 + P^148 + 
    3*P^149 + 3*P^150 + 2*P^151 + 2*P^155 + 3*P^156 + 2*P^157 + P^161 + 2*P^162 + 3*P^163 + P^164 + P^168 + 2*P^169 + 2*P^170 + 
    P^175 + 2*P^176 + P^177 + P^182 + 2*P^183 + P^190)/((1 - P^3)*(1 - P^93)*(1 - P^103))}, 
 {3, (P^7 + P^8 + P^14 + P^15 + P^18 + P^20 + P^21 + P^22 + P^24 + P^25 + P^27 + P^28 + P^29 + P^31 + P^32 + P^33 + 2*P^34 + 
    P^35 + P^37 + P^38 + 2*P^39 + P^40 + 2*P^41 + P^42 + P^44 + P^45 + 2*P^46 + 2*P^47 + 2*P^48 + P^49 + P^50 + P^51 + 2*P^52 + 
    2*P^53 + 2*P^54 + 2*P^55 + P^56 + P^57 + P^58 + 2*P^59 + 2*P^60 + 2*P^61 + 2*P^62 + 2*P^63 + P^64 + 2*P^65 + 3*P^66 + 
    2*P^67 + 2*P^68 + 2*P^69 + 2*P^70 + P^71 + 2*P^72 + 3*P^73 + 2*P^74 + 2*P^75 + 2*P^76 + 2*P^77 + 2*P^78 + 3*P^79 + 3*P^80 + 
    2*P^81 + 3*P^82 + 2*P^83 + 2*P^84 + 2*P^85 + 3*P^86 + 3*P^87 + 2*P^88 + 3*P^89 + 2*P^90 + 2*P^91 + 3*P^92 + 3*P^93 + 
    3*P^94 + 3*P^95 + 3*P^96 + 3*P^97 + 2*P^98 + 3*P^99 + 2*P^100 + 2*P^101 + 3*P^102 + 3*P^103 + 3*P^104 + 3*P^105 + 3*P^106 + 
    2*P^107 + 2*P^108 + 3*P^109 + 3*P^110 + 2*P^111 + 3*P^112 + 2*P^113 + 2*P^114 + 2*P^115 + 3*P^116 + 2*P^117 + 2*P^118 + 
    3*P^119 + 2*P^120 + 2*P^121 + 2*P^122 + 3*P^123 + 2*P^124 + 2*P^125 + 2*P^126 + P^127 + 2*P^128 + 3*P^129 + 2*P^130 + 
    2*P^131 + P^132 + 2*P^133 + P^134 + 2*P^135 + 3*P^136 + 2*P^137 + 2*P^138 + P^139 + P^140 + P^141 + 2*P^142 + 2*P^143 + 
    2*P^144 + P^145 + P^146 + P^147 + P^148 + 2*P^149 + 2*P^150 + 2*P^151 + P^152 + P^153 + P^154 + P^155 + P^156 + 2*P^157 + 
    P^158 + P^160 + P^161 + P^162 + P^163 + 2*P^164 + P^165 + P^167 + P^168 + P^169 + P^170 + P^171 + P^174 + P^176 + P^177 + 
    P^178 + P^181 + P^183 + P^184 + P^191)/((1 - P^3)*(1 - P^93)*(1 - P^103))}, 
 {3, (P^2 + 2*P^12 + P^15 + 2*P^19 + P^22 + 2*P^25 + 2*P^26 + P^28 + P^29 + 2*P^32 + 2*P^33 + P^35 + P^36 + 2*P^38 + 2*P^39 + 
    2*P^40 + P^41 + P^42 + P^43 + 2*P^45 + 2*P^46 + 2*P^47 + P^48 + P^49 + P^50 + 2*P^51 + 2*P^52 + 2*P^53 + P^54 + P^55 + 
    P^56 + 2*P^57 + 2*P^58 + 2*P^59 + 3*P^60 + P^61 + P^62 + P^63 + 2*P^64 + 2*P^65 + 2*P^66 + 3*P^67 + P^68 + P^69 + 3*P^70 + 
    2*P^71 + 2*P^72 + 3*P^73 + 3*P^74 + P^75 + P^76 + 3*P^77 + 2*P^78 + 2*P^79 + 3*P^80 + 3*P^81 + P^82 + 3*P^83 + 3*P^84 + 
    2*P^85 + 3*P^86 + 3*P^87 + 3*P^88 + P^89 + 3*P^90 + 3*P^91 + 2*P^92 + 3*P^93 + 3*P^94 + 2*P^95 + 3*P^96 + 3*P^97 + 3*P^98 + 
    3*P^99 + 3*P^100 + 3*P^101 + 2*P^102 + 3*P^103 + 3*P^104 + P^105 + 3*P^106 + 3*P^107 + 2*P^108 + 3*P^109 + 3*P^110 + 
    3*P^111 + P^112 + 3*P^113 + 3*P^114 + 2*P^115 + 3*P^116 + 3*P^117 + P^118 + P^119 + 3*P^120 + 2*P^121 + 2*P^122 + 3*P^123 + 
    3*P^124 + P^125 + P^126 + 3*P^127 + 2*P^128 + 2*P^129 + 3*P^130 + P^131 + P^132 + P^133 + 2*P^134 + 2*P^135 + 2*P^136 + 
    3*P^137 + P^138 + P^139 + P^140 + 2*P^141 + 2*P^142 + 2*P^143 + P^144 + P^145 + P^146 + 2*P^147 + 2*P^148 + 2*P^149 + 
    P^150 + P^151 + P^152 + 2*P^154 + 2*P^155 + 2*P^156 + P^157 + P^158 + P^159 + 2*P^161 + 2*P^162 + P^164 + P^165 + 2*P^168 + 
    2*P^169 + P^171 + P^172 + 2*P^175 + P^178 + 2*P^182 + P^185 + P^195)/((1 - P^3)*(1 - P^93)*(1 - P^103))}, 
 {3, (P^8 + P^9 + P^10 + P^15 + P^16 + P^17 + P^21 + P^22 + P^23 + P^27 + 2*P^28 + 2*P^29 + P^30 + P^34 + 2*P^35 + 2*P^36 + 
    P^37 + P^40 + 2*P^41 + 3*P^42 + 2*P^43 + P^44 + P^47 + 2*P^48 + 3*P^49 + 2*P^50 + P^51 + P^53 + 2*P^54 + 3*P^55 + 3*P^56 + 
    2*P^57 + P^58 + P^60 + 2*P^61 + 3*P^62 + 3*P^63 + 2*P^64 + P^65 + P^66 + 2*P^67 + 3*P^68 + 3*P^69 + 2*P^70 + P^71 + P^72 + 
    2*P^73 + 3*P^74 + 3*P^75 + 3*P^76 + 2*P^77 + P^78 + P^79 + 2*P^80 + 3*P^81 + 3*P^82 + 3*P^83 + 2*P^84 + 2*P^85 + 2*P^86 + 
    3*P^87 + 3*P^88 + 3*P^89 + 3*P^90 + 2*P^91 + 2*P^92 + 2*P^93 + 3*P^94 + 3*P^95 + 3*P^96 + 3*P^97 + 3*P^98 + 3*P^99 + 
    3*P^100 + 2*P^101 + 2*P^102 + 2*P^103 + 3*P^104 + 3*P^105 + 3*P^106 + 3*P^107 + 2*P^108 + 2*P^109 + 2*P^110 + 3*P^111 + 
    3*P^112 + 3*P^113 + 2*P^114 + 2*P^115 + 2*P^116 + 3*P^117 + 3*P^118 + 3*P^119 + 2*P^120 + P^121 + P^122 + 2*P^123 + 
    3*P^124 + 3*P^125 + 3*P^126 + 2*P^127 + P^128 + P^129 + 2*P^130 + 3*P^131 + 3*P^132 + 2*P^133 + P^134 + P^136 + 2*P^137 + 
    3*P^138 + 3*P^139 + 2*P^140 + P^141 + P^143 + 2*P^144 + 3*P^145 + 2*P^146 + P^147 + P^150 + 2*P^151 + 3*P^152 + 2*P^153 + 
    P^154 + P^157 + 2*P^158 + 2*P^159 + P^160 + P^163 + 2*P^164 + 2*P^165 + P^166 + P^170 + 2*P^171 + 2*P^172 + P^173 + P^177 + 
    P^178 + P^179 + P^184 + P^185 + P^186)/((1 - P^3)*(1 - P^93)*(1 - P^103))}, 
 {3, (P^7 + P^9 + P^11 + P^16 + P^17 + P^18 + P^20 + P^22 + P^24 + P^26 + P^27 + P^28 + P^29 + P^30 + P^31 + P^33 + P^34 + 
    P^35 + P^36 + P^37 + P^38 + P^39 + P^40 + 2*P^41 + P^42 + 2*P^43 + P^44 + P^45 + P^46 + P^47 + 2*P^48 + P^49 + 2*P^50 + 
    P^51 + 2*P^52 + P^53 + 2*P^54 + 2*P^55 + 2*P^56 + 2*P^57 + P^58 + 2*P^59 + P^60 + 2*P^61 + 2*P^62 + 2*P^63 + 2*P^64 + 
    2*P^65 + 2*P^66 + 2*P^67 + 2*P^68 + 2*P^69 + 2*P^70 + 2*P^71 + 2*P^72 + 2*P^73 + 2*P^74 + 3*P^75 + 2*P^76 + 2*P^77 + 
    2*P^78 + 2*P^79 + 2*P^80 + 2*P^81 + 3*P^82 + 2*P^83 + 3*P^84 + 2*P^85 + 3*P^86 + 2*P^87 + 3*P^88 + 3*P^89 + 2*P^90 + 
    3*P^91 + 2*P^92 + 3*P^93 + 2*P^94 + 3*P^95 + 3*P^96 + 3*P^97 + 3*P^98 + 3*P^99 + 2*P^100 + 3*P^101 + 2*P^102 + 3*P^103 + 
    2*P^104 + 3*P^105 + 3*P^106 + 3*P^107 + 3*P^108 + 2*P^109 + 2*P^110 + 2*P^111 + 3*P^112 + 2*P^113 + 3*P^114 + 2*P^115 + 
    3*P^116 + 2*P^117 + 3*P^118 + 2*P^119 + 2*P^120 + 2*P^121 + 2*P^122 + 2*P^123 + 2*P^124 + 3*P^125 + 2*P^126 + 2*P^127 + 
    2*P^128 + 2*P^129 + 2*P^130 + 2*P^131 + 2*P^132 + 2*P^133 + P^134 + 2*P^135 + P^136 + 2*P^137 + 2*P^138 + 2*P^139 + 
    2*P^140 + P^141 + 2*P^142 + P^143 + 2*P^144 + P^145 + 2*P^146 + P^147 + P^148 + P^149 + P^150 + 2*P^151 + P^152 + 2*P^153 + 
    P^154 + P^155 + P^156 + P^157 + P^158 + P^159 + P^160 + P^161 + P^162 + P^163 + P^164 + P^165 + P^166 + P^167 + P^169 + 
    P^170 + P^171 + P^172 + P^173 + P^174 + P^176 + P^178 + P^180 + P^183 + P^185 + P^187)/((1 - P^3)*(1 - P^93)*(1 - P^103))}, 
 {3, (P^7 + P^8 + P^12 + P^14 + P^18 + P^19 + P^20 + P^21 + P^25 + P^26 + 2*P^27 + P^28 + P^31 + P^32 + P^33 + 2*P^34 + P^35 + 
    P^38 + 2*P^39 + 2*P^40 + 2*P^41 + P^42 + P^44 + P^45 + 2*P^46 + 2*P^47 + 2*P^48 + P^49 + P^51 + 2*P^52 + 3*P^53 + 2*P^54 + 
    2*P^55 + P^56 + P^57 + P^58 + 2*P^59 + 3*P^60 + 2*P^61 + 2*P^62 + P^63 + P^64 + 2*P^65 + 3*P^66 + 3*P^67 + 2*P^68 + P^69 + 
    P^70 + P^71 + 3*P^72 + 3*P^73 + 3*P^74 + 2*P^75 + 2*P^76 + P^77 + 2*P^78 + 3*P^79 + 3*P^80 + 2*P^81 + 2*P^82 + 2*P^83 + 
    2*P^84 + 3*P^85 + 3*P^86 + 3*P^87 + 2*P^88 + 3*P^89 + 2*P^90 + 2*P^91 + 3*P^92 + 3*P^93 + 3*P^94 + 2*P^95 + 3*P^96 + 
    3*P^97 + 3*P^98 + 3*P^99 + 2*P^100 + 2*P^101 + 3*P^102 + 3*P^103 + 3*P^104 + 2*P^105 + 3*P^106 + 2*P^107 + 3*P^108 + 
    3*P^109 + 3*P^110 + 2*P^111 + 2*P^112 + 2*P^113 + 2*P^114 + 3*P^115 + 3*P^116 + 3*P^117 + 2*P^118 + 2*P^119 + P^120 + 
    2*P^121 + 3*P^122 + 3*P^123 + 2*P^124 + 2*P^125 + 2*P^126 + P^127 + 2*P^128 + 3*P^129 + 3*P^130 + 2*P^131 + P^132 + P^133 + 
    P^134 + 2*P^135 + 3*P^136 + 2*P^137 + 2*P^138 + P^139 + P^140 + P^141 + 2*P^142 + 3*P^143 + 2*P^144 + P^145 + P^147 + 
    P^148 + 2*P^149 + 2*P^150 + 2*P^151 + P^152 + P^154 + P^155 + 2*P^156 + 2*P^157 + P^158 + P^161 + 2*P^162 + 2*P^163 + 
    2*P^164 + P^168 + P^169 + 2*P^170 + P^171 + P^174 + P^175 + P^176 + P^177 + P^181 + P^183 + P^184 + P^188)/
   ((1 - P^3)*(1 - P^93)*(1 - P^103))}, {3, (P^8 + P^10 + 2*P^15 + P^17 + P^21 + 2*P^22 + P^23 + P^24 + 2*P^28 + 2*P^29 + P^30 + 
    2*P^34 + 2*P^35 + 2*P^36 + P^37 + 2*P^41 + 3*P^42 + 2*P^43 + P^44 + 2*P^47 + 2*P^48 + 3*P^49 + P^50 + P^51 + P^53 + 2*P^54 + 
    3*P^55 + 3*P^56 + P^57 + P^58 + 2*P^60 + 2*P^61 + 3*P^62 + 3*P^63 + P^64 + P^65 + P^66 + 2*P^67 + 3*P^68 + 3*P^69 + 3*P^70 + 
    P^71 + P^72 + 2*P^73 + 2*P^74 + 3*P^75 + 3*P^76 + 3*P^77 + P^78 + 2*P^79 + 2*P^80 + 3*P^81 + 3*P^82 + 3*P^83 + 2*P^84 + 
    P^85 + 2*P^86 + 3*P^87 + 3*P^88 + 3*P^89 + 3*P^90 + 2*P^91 + 3*P^92 + 2*P^93 + 3*P^94 + 3*P^95 + 3*P^96 + 3*P^97 + 2*P^98 + 
    3*P^99 + 3*P^100 + 2*P^101 + 3*P^102 + 2*P^103 + 3*P^104 + 3*P^105 + 3*P^106 + 3*P^107 + P^108 + 3*P^109 + 2*P^110 + 
    3*P^111 + 3*P^112 + 3*P^113 + 2*P^114 + P^115 + 2*P^116 + 2*P^117 + 3*P^118 + 3*P^119 + 3*P^120 + P^121 + P^122 + 2*P^123 + 
    3*P^124 + 3*P^125 + 3*P^126 + P^127 + P^128 + P^129 + 2*P^130 + 3*P^131 + 3*P^132 + 3*P^133 + P^134 + P^136 + 2*P^137 + 
    3*P^138 + 3*P^139 + P^140 + P^141 + 2*P^143 + 2*P^144 + 3*P^145 + 2*P^146 + P^147 + 2*P^150 + 2*P^151 + 3*P^152 + P^153 + 
    P^154 + 2*P^157 + 2*P^158 + 2*P^159 + P^160 + 2*P^164 + 2*P^165 + P^166 + P^167 + 2*P^171 + P^172 + P^173 + P^177 + 
    2*P^178 + P^179 + P^184 + P^186 + P^191)/((1 - P^3)*(1 - P^93)*(1 - P^103))}, 
 {3, (P^7 + P^11 + P^14 + P^15 + P^18 + P^20 + P^21 + P^22 + P^24 + P^25 + P^27 + P^28 + P^29 + P^31 + P^32 + P^33 + 2*P^34 + 
    P^35 + P^36 + P^37 + P^38 + P^39 + P^40 + 2*P^41 + P^42 + P^43 + P^44 + P^45 + P^46 + 2*P^47 + 2*P^48 + P^49 + P^50 + P^51 + 
    2*P^52 + P^53 + 2*P^54 + 2*P^55 + 2*P^56 + P^57 + P^58 + 2*P^59 + 2*P^60 + 2*P^61 + 2*P^62 + 2*P^63 + P^64 + 2*P^65 + 
    2*P^66 + 2*P^67 + 2*P^68 + 3*P^69 + 2*P^70 + P^71 + 2*P^72 + 3*P^73 + 2*P^74 + 2*P^75 + 2*P^76 + 2*P^77 + 2*P^78 + 3*P^79 + 
    3*P^80 + 2*P^81 + 3*P^82 + 2*P^83 + 2*P^84 + 2*P^85 + 3*P^86 + 3*P^87 + 2*P^88 + 3*P^89 + 2*P^90 + 3*P^91 + 3*P^92 + 
    3*P^93 + 2*P^94 + 3*P^95 + 3*P^96 + 3*P^97 + 2*P^98 + 3*P^99 + 2*P^100 + 3*P^101 + 3*P^102 + 3*P^103 + 2*P^104 + 3*P^105 + 
    3*P^106 + 2*P^107 + 2*P^108 + 3*P^109 + 3*P^110 + 2*P^111 + 3*P^112 + 2*P^113 + 2*P^114 + 2*P^115 + 3*P^116 + 2*P^117 + 
    2*P^118 + 3*P^119 + 2*P^120 + 2*P^121 + 2*P^122 + 3*P^123 + 2*P^124 + 2*P^125 + 2*P^126 + P^127 + 2*P^128 + 2*P^129 + 
    2*P^130 + 2*P^131 + 2*P^132 + 2*P^133 + P^134 + 2*P^135 + 2*P^136 + 2*P^137 + 2*P^138 + 2*P^139 + P^140 + P^141 + 2*P^142 + 
    2*P^143 + 2*P^144 + P^145 + 2*P^146 + P^147 + P^148 + P^149 + 2*P^150 + 2*P^151 + P^152 + P^153 + P^154 + P^155 + P^156 + 
    2*P^157 + P^158 + P^159 + P^160 + P^161 + P^163 + 2*P^164 + P^165 + P^167 + P^168 + P^169 + P^170 + P^171 + P^174 + P^176 + 
    P^177 + P^178 + P^181 + P^183 + P^187 + P^191)/((1 - P^3)*(1 - P^93)*(1 - P^103))}, 
 {3, (P^8 + P^9 + P^15 + 2*P^16 + P^21 + 2*P^22 + 2*P^23 + P^28 + 2*P^29 + 2*P^30 + P^34 + 3*P^35 + 2*P^36 + P^37 + P^40 + 
    P^41 + 3*P^42 + 2*P^43 + P^44 + P^47 + 3*P^48 + 3*P^49 + 2*P^50 + P^53 + 2*P^54 + 3*P^55 + 3*P^56 + 2*P^57 + P^60 + 3*P^61 + 
    3*P^62 + 3*P^63 + 2*P^64 + P^66 + 2*P^67 + 3*P^68 + 3*P^69 + 3*P^70 + 2*P^71 + P^73 + 3*P^74 + 3*P^75 + 3*P^76 + 2*P^77 + 
    2*P^78 + P^79 + 3*P^80 + 3*P^81 + 3*P^82 + 3*P^83 + 2*P^84 + 2*P^85 + P^86 + 3*P^87 + 3*P^88 + 3*P^89 + 3*P^90 + 2*P^91 + 
    2*P^92 + 3*P^93 + 3*P^94 + 3*P^95 + 3*P^96 + 3*P^97 + 3*P^98 + 2*P^99 + 3*P^100 + 2*P^101 + 2*P^102 + 3*P^103 + 3*P^104 + 
    3*P^105 + 3*P^106 + 3*P^107 + 2*P^108 + P^109 + 3*P^110 + 3*P^111 + 3*P^112 + 3*P^113 + 2*P^114 + P^115 + P^116 + 3*P^117 + 
    3*P^118 + 3*P^119 + 3*P^120 + 2*P^121 + P^122 + P^123 + 3*P^124 + 3*P^125 + 3*P^126 + 2*P^127 + P^129 + 2*P^130 + 3*P^131 + 
    3*P^132 + 2*P^133 + 2*P^134 + P^136 + 2*P^137 + 3*P^138 + 3*P^139 + 2*P^140 + P^143 + 3*P^144 + 3*P^145 + 2*P^146 + P^147 + 
    P^150 + 3*P^151 + 3*P^152 + 2*P^153 + P^157 + 3*P^158 + 2*P^159 + P^160 + P^164 + 3*P^165 + 2*P^166 + P^170 + P^171 + 
    2*P^172 + P^177 + P^178 + 2*P^179 + P^184 + P^185 + P^192)/((1 - P^3)*(1 - P^93)*(1 - P^103))}, 
 {3, (P^5 + P^10 + P^12 + P^17 + 2*P^18 + P^19 + P^23 + P^24 + 2*P^25 + P^29 + P^30 + 2*P^31 + 2*P^32 + P^36 + 2*P^37 + 2*P^38 + 
    2*P^39 + P^42 + P^43 + 3*P^44 + 2*P^45 + 2*P^46 + P^49 + 2*P^50 + 3*P^51 + 2*P^52 + 2*P^53 + P^55 + P^56 + 3*P^57 + 3*P^58 + 
    2*P^59 + P^60 + P^62 + 3*P^63 + 3*P^64 + 3*P^65 + 2*P^66 + P^67 + P^68 + P^69 + 3*P^70 + 3*P^71 + 3*P^72 + 2*P^73 + P^74 + 
    P^75 + 3*P^76 + 3*P^77 + 3*P^78 + 2*P^79 + 2*P^80 + P^81 + 2*P^82 + 3*P^83 + 3*P^84 + 3*P^85 + 2*P^86 + 3*P^87 + P^88 + 
    3*P^89 + 3*P^90 + 3*P^91 + 3*P^92 + 2*P^93 + 3*P^94 + 2*P^95 + 3*P^96 + 3*P^97 + 2*P^98 + 3*P^99 + 3*P^100 + 3*P^101 + 
    3*P^102 + 2*P^103 + 3*P^104 + 2*P^105 + 3*P^106 + 3*P^107 + 3*P^108 + 3*P^109 + 2*P^110 + P^111 + 2*P^112 + 3*P^113 + 
    3*P^114 + 3*P^115 + 2*P^116 + 2*P^117 + P^118 + 3*P^119 + 3*P^120 + 3*P^121 + 2*P^122 + 2*P^123 + P^124 + P^125 + 3*P^126 + 
    3*P^127 + 3*P^128 + 2*P^129 + P^130 + P^131 + P^132 + 3*P^133 + 3*P^134 + 2*P^135 + 2*P^136 + P^138 + P^139 + 3*P^140 + 
    3*P^141 + 2*P^142 + P^143 + P^145 + P^146 + 3*P^147 + 2*P^148 + 2*P^149 + P^152 + 2*P^153 + 3*P^154 + 2*P^155 + P^159 + 
    2*P^160 + 2*P^161 + 2*P^162 + P^166 + 2*P^167 + 2*P^168 + P^172 + P^173 + 2*P^174 + P^175 + P^179 + 2*P^181 + P^186 + P^188)/
   ((1 - P^3)*(1 - P^93)*(1 - P^103))}, {3, (P^7 + P^12 + 2*P^14 + P^19 + P^20 + 2*P^21 + P^25 + P^26 + 2*P^27 + P^28 + P^31 + 
    P^32 + 2*P^33 + 2*P^34 + P^35 + P^38 + P^39 + 2*P^40 + 2*P^41 + P^42 + P^44 + P^45 + 3*P^46 + 2*P^47 + 2*P^48 + P^51 + 
    2*P^52 + 3*P^53 + 2*P^54 + 2*P^55 + P^57 + P^58 + 3*P^59 + 3*P^60 + 2*P^61 + 2*P^62 + P^64 + 2*P^65 + 3*P^66 + 3*P^67 + 
    2*P^68 + 2*P^69 + P^70 + P^71 + 3*P^72 + 3*P^73 + 3*P^74 + 2*P^75 + 2*P^76 + P^77 + 2*P^78 + 3*P^79 + 3*P^80 + 3*P^81 + 
    2*P^82 + 2*P^83 + P^84 + 3*P^85 + 3*P^86 + 3*P^87 + 2*P^88 + 3*P^89 + 2*P^90 + 3*P^91 + 3*P^92 + 3*P^93 + 3*P^94 + 2*P^95 + 
    3*P^96 + 2*P^97 + 3*P^98 + 3*P^99 + 2*P^100 + 3*P^101 + 3*P^102 + 3*P^103 + 3*P^104 + 2*P^105 + 3*P^106 + P^107 + 3*P^108 + 
    3*P^109 + 3*P^110 + 3*P^111 + 2*P^112 + 2*P^113 + P^114 + 3*P^115 + 3*P^116 + 3*P^117 + 2*P^118 + 2*P^119 + P^120 + 
    2*P^121 + 3*P^122 + 3*P^123 + 2*P^124 + 2*P^125 + P^126 + P^127 + 2*P^128 + 3*P^129 + 3*P^130 + 2*P^131 + 2*P^132 + P^133 + 
    P^134 + 2*P^135 + 3*P^136 + 2*P^137 + 2*P^138 + P^140 + P^141 + 3*P^142 + 3*P^143 + 2*P^144 + P^145 + P^147 + P^148 + 
    3*P^149 + 2*P^150 + 2*P^151 + P^154 + P^155 + 3*P^156 + 2*P^157 + P^158 + P^161 + P^162 + 2*P^163 + 2*P^164 + P^168 + 
    P^169 + 2*P^170 + P^171 + P^175 + P^176 + 2*P^177 + P^181 + P^183 + P^188 + P^190)/((1 - P^3)*(1 - P^93)*(1 - P^103))}, 
 {3, (P^5 + P^9 + P^12 + P^16 + P^18 + P^19 + P^22 + P^23 + 2*P^25 + P^26 + P^29 + P^30 + P^31 + 2*P^32 + P^33 + P^35 + P^36 + 
    P^37 + 2*P^38 + 2*P^39 + P^40 + P^42 + P^43 + P^44 + 2*P^45 + 2*P^46 + P^47 + P^48 + P^49 + 2*P^50 + 2*P^51 + 2*P^52 + 
    2*P^53 + P^54 + P^55 + P^56 + 2*P^57 + 2*P^58 + 2*P^59 + 2*P^60 + P^61 + P^62 + 2*P^63 + 3*P^64 + 2*P^65 + 2*P^66 + 2*P^67 + 
    P^68 + P^69 + 3*P^70 + 3*P^71 + 2*P^72 + 2*P^73 + 2*P^74 + P^75 + 2*P^76 + 3*P^77 + 3*P^78 + 2*P^79 + 3*P^80 + 2*P^81 + 
    P^82 + 3*P^83 + 3*P^84 + 3*P^85 + 2*P^86 + 3*P^87 + 2*P^88 + 2*P^89 + 3*P^90 + 3*P^91 + 2*P^92 + 3*P^93 + 3*P^94 + 3*P^95 + 
    3*P^96 + 3*P^97 + 2*P^98 + 2*P^99 + 3*P^100 + 3*P^101 + 2*P^102 + 3*P^103 + 3*P^104 + 2*P^105 + 3*P^106 + 3*P^107 + 
    3*P^108 + 2*P^109 + 3*P^110 + 2*P^111 + 2*P^112 + 3*P^113 + 3*P^114 + 2*P^115 + 2*P^116 + 3*P^117 + P^118 + 2*P^119 + 
    3*P^120 + 3*P^121 + 2*P^122 + 2*P^123 + 2*P^124 + P^125 + 2*P^126 + 3*P^127 + 2*P^128 + 2*P^129 + 2*P^130 + P^131 + P^132 + 
    2*P^133 + 3*P^134 + 2*P^135 + 2*P^136 + 2*P^137 + P^138 + P^139 + 2*P^140 + 2*P^141 + 2*P^142 + P^143 + P^144 + P^145 + 
    P^146 + 2*P^147 + 2*P^148 + 2*P^149 + P^150 + P^151 + P^152 + P^153 + 2*P^154 + 2*P^155 + P^156 + P^158 + P^159 + P^160 + 
    2*P^161 + 2*P^162 + P^165 + P^166 + P^167 + 2*P^168 + P^169 + P^172 + P^174 + 2*P^175 + P^179 + P^181 + P^182 + P^185 + 
    P^192)/((1 - P^3)*(1 - P^93)*(1 - P^103))}, 
 {3, (P^3 + P^10 + P^13 + P^16 + P^17 + P^20 + 2*P^23 + P^24 + P^26 + P^27 + P^29 + 2*P^30 + P^31 + P^33 + P^34 + 2*P^36 + 
    2*P^37 + P^38 + P^39 + P^40 + P^41 + P^42 + 2*P^43 + 2*P^44 + P^45 + P^46 + P^47 + P^48 + 2*P^49 + 2*P^50 + 2*P^51 + P^52 + 
    P^53 + P^54 + P^55 + 2*P^56 + 2*P^57 + 3*P^58 + P^59 + P^60 + 2*P^61 + 2*P^62 + 2*P^63 + 2*P^64 + 2*P^65 + P^66 + P^67 + 
    3*P^68 + 2*P^69 + 2*P^70 + 3*P^71 + 2*P^72 + P^73 + 2*P^74 + 3*P^75 + 2*P^76 + 2*P^77 + 3*P^78 + 2*P^79 + P^80 + 3*P^81 + 
    3*P^82 + 2*P^83 + 3*P^84 + 3*P^85 + 2*P^86 + 2*P^87 + 3*P^88 + 3*P^89 + 2*P^90 + 3*P^91 + 3*P^92 + 2*P^93 + 3*P^94 + 
    3*P^95 + 2*P^96 + 3*P^97 + 3*P^98 + 3*P^99 + 2*P^100 + 3*P^101 + 3*P^102 + 2*P^103 + 3*P^104 + 3*P^105 + 2*P^106 + 3*P^107 + 
    3*P^108 + 2*P^109 + 2*P^110 + 3*P^111 + 3*P^112 + 2*P^113 + 3*P^114 + 3*P^115 + P^116 + 2*P^117 + 3*P^118 + 2*P^119 + 
    2*P^120 + 3*P^121 + 2*P^122 + P^123 + 2*P^124 + 3*P^125 + 2*P^126 + 2*P^127 + 3*P^128 + P^129 + P^130 + 2*P^131 + 2*P^132 + 
    2*P^133 + 2*P^134 + 2*P^135 + P^136 + P^137 + 2*P^138 + 2*P^139 + 2*P^140 + 2*P^141 + P^142 + P^143 + P^144 + 2*P^145 + 
    2*P^146 + 2*P^147 + 2*P^148 + P^149 + P^150 + 2*P^152 + 2*P^153 + P^154 + P^155 + P^156 + P^157 + P^158 + 2*P^159 + 
    2*P^160 + P^162 + P^163 + P^165 + 2*P^166 + P^167 + P^169 + P^170 + P^172 + 2*P^173 + P^176 + P^179 + P^180 + P^183 + 
    P^186 + P^193)/((1 - P^3)*(1 - P^93)*(1 - P^103))}, 
 {3, (P^2 + P^9 + 2*P^15 + P^16 + 3*P^22 + P^23 + 2*P^28 + 3*P^29 + P^30 + 3*P^35 + 3*P^36 + P^37 + 2*P^41 + 3*P^42 + 3*P^43 + 
    P^47 + 3*P^48 + 3*P^49 + 3*P^50 + 2*P^54 + 3*P^55 + 3*P^56 + 2*P^57 + 2*P^60 + 3*P^61 + 3*P^62 + 3*P^63 + P^64 + 3*P^67 + 
    3*P^68 + 3*P^69 + 3*P^70 + P^71 + 2*P^73 + 3*P^74 + 3*P^75 + 3*P^76 + 3*P^77 + P^78 + 3*P^80 + 3*P^81 + 3*P^82 + 3*P^83 + 
    3*P^84 + P^85 + 2*P^86 + 3*P^87 + 3*P^88 + 3*P^89 + 3*P^90 + 3*P^91 + P^92 + 3*P^93 + 3*P^94 + 2*P^95 + 3*P^96 + 3*P^97 + 
    3*P^98 + 2*P^99 + 3*P^100 + 3*P^101 + 2*P^102 + 3*P^103 + 3*P^104 + 3*P^105 + 3*P^106 + 3*P^107 + P^108 + 2*P^109 + 
    3*P^110 + 3*P^111 + 3*P^112 + 3*P^113 + 3*P^114 + 2*P^116 + 3*P^117 + 3*P^118 + 3*P^119 + 3*P^120 + P^121 + 2*P^123 + 
    3*P^124 + 3*P^125 + 3*P^126 + 3*P^127 + 2*P^130 + 3*P^131 + 3*P^132 + 3*P^133 + P^134 + 3*P^137 + 3*P^138 + 3*P^139 + 
    2*P^140 + 3*P^144 + 3*P^145 + 3*P^146 + P^147 + P^150 + 3*P^151 + 3*P^152 + P^153 + 2*P^157 + 3*P^158 + 3*P^159 + 2*P^164 + 
    3*P^165 + P^166 + 2*P^171 + 3*P^172 + 2*P^178 + P^179 + 2*P^185 + P^192)/((1 - P^3)*(1 - P^93)*(1 - P^103))}, 
 {3, (P^5 + P^12 + P^13 + P^15 + P^18 + P^19 + P^20 + P^22 + P^25 + P^26 + P^27 + P^28 + P^29 + P^31 + 2*P^32 + P^33 + P^34 + 
    P^35 + P^36 + P^38 + 2*P^39 + P^40 + P^41 + P^42 + P^43 + P^44 + 2*P^45 + 2*P^46 + 2*P^47 + P^48 + P^49 + P^50 + P^51 + 
    2*P^52 + 2*P^53 + 2*P^54 + P^55 + P^56 + P^57 + 2*P^58 + 2*P^59 + 3*P^60 + 2*P^61 + P^62 + 2*P^63 + P^64 + 2*P^65 + 2*P^66 + 
    3*P^67 + 2*P^68 + P^69 + 2*P^70 + 2*P^71 + 2*P^72 + 3*P^73 + 2*P^74 + 2*P^75 + 2*P^76 + 3*P^77 + 2*P^78 + 2*P^79 + 3*P^80 + 
    2*P^81 + 2*P^82 + 2*P^83 + 3*P^84 + 2*P^85 + 3*P^86 + 3*P^87 + 2*P^88 + 2*P^89 + 3*P^90 + 3*P^91 + 3*P^92 + 3*P^93 + 
    3*P^94 + 2*P^95 + 2*P^96 + 3*P^97 + 2*P^98 + 3*P^99 + 3*P^100 + 3*P^101 + 3*P^102 + 3*P^103 + 3*P^104 + 2*P^105 + 2*P^106 + 
    3*P^107 + 2*P^108 + 3*P^109 + 3*P^110 + 2*P^111 + 2*P^112 + 2*P^113 + 3*P^114 + 2*P^115 + 3*P^116 + 3*P^117 + 2*P^118 + 
    2*P^119 + 2*P^120 + 2*P^121 + 2*P^122 + 3*P^123 + 2*P^124 + P^125 + 2*P^126 + 2*P^127 + 2*P^128 + 2*P^129 + 3*P^130 + 
    2*P^131 + P^132 + 2*P^133 + 2*P^134 + 2*P^135 + 2*P^136 + 2*P^137 + P^138 + P^139 + P^140 + 2*P^141 + 2*P^142 + 2*P^143 + 
    2*P^144 + P^145 + P^146 + P^147 + 2*P^148 + 2*P^149 + 2*P^150 + P^151 + P^152 + P^154 + 2*P^155 + P^156 + 2*P^157 + P^158 + 
    P^159 + P^161 + 2*P^162 + P^163 + P^164 + P^165 + P^167 + P^168 + P^169 + P^171 + P^172 + P^174 + P^175 + P^176 + P^178 + 
    P^181 + P^182 + P^188 + P^189)/((1 - P^3)*(1 - P^93)*(1 - P^103))}, 
 {3, (P^3 + P^10 + P^13 + P^16 + P^17 + P^20 + 2*P^23 + P^24 + P^26 + P^27 + P^29 + 2*P^30 + P^31 + P^33 + P^34 + 2*P^36 + 
    2*P^37 + P^38 + P^39 + P^40 + P^41 + P^42 + 2*P^43 + 2*P^44 + P^46 + P^47 + 2*P^48 + 2*P^49 + 2*P^50 + 2*P^51 + P^52 + 
    P^53 + P^54 + 2*P^55 + 2*P^56 + 2*P^57 + 2*P^58 + P^59 + P^60 + 2*P^61 + 2*P^62 + 2*P^63 + 2*P^64 + 2*P^65 + P^66 + P^67 + 
    3*P^68 + 2*P^69 + 2*P^70 + 3*P^71 + 2*P^72 + P^73 + 2*P^74 + 3*P^75 + 2*P^76 + 2*P^77 + 3*P^78 + 2*P^79 + P^80 + 3*P^81 + 
    3*P^82 + 2*P^83 + 3*P^84 + 3*P^85 + 2*P^86 + 2*P^87 + 3*P^88 + 3*P^89 + 2*P^90 + 3*P^91 + 3*P^92 + 2*P^93 + 3*P^94 + 
    3*P^95 + 2*P^96 + 3*P^97 + 3*P^98 + 3*P^99 + 2*P^100 + 3*P^101 + 3*P^102 + 2*P^103 + 3*P^104 + 3*P^105 + 2*P^106 + 3*P^107 + 
    3*P^108 + 2*P^109 + 2*P^110 + 3*P^111 + 3*P^112 + 2*P^113 + 3*P^114 + 3*P^115 + P^116 + 2*P^117 + 3*P^118 + 2*P^119 + 
    2*P^120 + 3*P^121 + 2*P^122 + P^123 + 2*P^124 + 3*P^125 + 2*P^126 + 2*P^127 + 3*P^128 + P^129 + P^130 + 2*P^131 + 2*P^132 + 
    2*P^133 + 2*P^134 + 2*P^135 + P^136 + P^137 + 3*P^138 + 2*P^139 + 2*P^140 + P^141 + P^142 + P^143 + P^144 + 2*P^145 + 
    2*P^146 + 2*P^147 + P^148 + P^149 + P^150 + P^151 + 2*P^152 + 2*P^153 + P^154 + P^155 + P^156 + P^157 + P^158 + 2*P^159 + 
    2*P^160 + P^162 + P^163 + P^165 + 2*P^166 + P^167 + P^169 + P^170 + P^172 + 2*P^173 + P^176 + P^179 + P^180 + P^183 + 
    P^186 + P^193)/((1 - P^3)*(1 - P^93)*(1 - P^103))}, 
 {3, (P^5 + P^9 + P^13 + P^15 + P^18 + P^19 + P^20 + P^22 + P^25 + P^26 + P^27 + P^28 + P^29 + P^31 + 2*P^32 + P^33 + P^35 + 
    P^36 + P^37 + P^38 + 2*P^39 + P^40 + P^41 + P^42 + P^43 + P^44 + 2*P^45 + 2*P^46 + P^47 + P^48 + P^49 + 2*P^50 + P^51 + 
    2*P^52 + 2*P^53 + 2*P^54 + P^55 + P^56 + 2*P^57 + 2*P^58 + 2*P^59 + 2*P^60 + 2*P^61 + P^62 + 2*P^63 + 2*P^64 + 2*P^65 + 
    2*P^66 + 2*P^67 + 2*P^68 + P^69 + 2*P^70 + 2*P^71 + 2*P^72 + 3*P^73 + 2*P^74 + 2*P^75 + 2*P^76 + 3*P^77 + 2*P^78 + 2*P^79 + 
    3*P^80 + 2*P^81 + 2*P^82 + 2*P^83 + 3*P^84 + 2*P^85 + 3*P^86 + 3*P^87 + 2*P^88 + 2*P^89 + 3*P^90 + 3*P^91 + 2*P^92 + 
    3*P^93 + 3*P^94 + 3*P^95 + 2*P^96 + 3*P^97 + 2*P^98 + 3*P^99 + 3*P^100 + 3*P^101 + 2*P^102 + 3*P^103 + 3*P^104 + 3*P^105 + 
    2*P^106 + 3*P^107 + 2*P^108 + 3*P^109 + 3*P^110 + 2*P^111 + 2*P^112 + 2*P^113 + 3*P^114 + 2*P^115 + 3*P^116 + 3*P^117 + 
    2*P^118 + 2*P^119 + 2*P^120 + 2*P^121 + 2*P^122 + 3*P^123 + 2*P^124 + P^125 + 2*P^126 + 3*P^127 + 2*P^128 + 2*P^129 + 
    2*P^130 + 2*P^131 + P^132 + 2*P^133 + 2*P^134 + 2*P^135 + 2*P^136 + 2*P^137 + P^138 + P^139 + 2*P^140 + 2*P^141 + 2*P^142 + 
    P^143 + 2*P^144 + P^145 + P^146 + P^147 + 2*P^148 + 2*P^149 + P^150 + P^151 + P^152 + P^153 + P^154 + 2*P^155 + P^156 + 
    P^157 + P^158 + P^159 + P^160 + P^161 + 2*P^162 + P^163 + P^164 + P^165 + P^167 + P^168 + P^169 + P^171 + P^172 + P^174 + 
    P^175 + P^176 + P^178 + P^181 + P^182 + P^185 + P^189)/((1 - P^3)*(1 - P^93)*(1 - P^103))}, 
 {3, (P^3 + P^10 + P^14 + 2*P^16 + P^20 + P^21 + 2*P^23 + P^27 + P^28 + 2*P^29 + 2*P^30 + P^33 + P^34 + P^35 + 2*P^36 + 2*P^37 + 
    P^40 + P^41 + 2*P^42 + 2*P^43 + 2*P^44 + P^46 + P^47 + 2*P^48 + 2*P^49 + 2*P^50 + 2*P^51 + P^53 + P^54 + 3*P^55 + 2*P^56 + 
    2*P^57 + P^58 + P^59 + P^60 + 3*P^61 + 3*P^62 + 2*P^63 + 2*P^64 + P^65 + P^66 + P^67 + 3*P^68 + 3*P^69 + 2*P^70 + 2*P^71 + 
    P^72 + P^73 + 3*P^74 + 3*P^75 + 3*P^76 + 2*P^77 + 3*P^78 + P^79 + P^80 + 3*P^81 + 3*P^82 + 3*P^83 + 2*P^84 + 3*P^85 + P^86 + 
    3*P^87 + 3*P^88 + 3*P^89 + 2*P^90 + 3*P^91 + 3*P^92 + 2*P^93 + 3*P^94 + 3*P^95 + 2*P^96 + 2*P^97 + 3*P^98 + 3*P^99 + 
    3*P^100 + 3*P^101 + 3*P^102 + 2*P^103 + 3*P^104 + 3*P^105 + 3*P^106 + 2*P^107 + 3*P^108 + P^109 + 3*P^110 + 3*P^111 + 
    3*P^112 + 2*P^113 + 2*P^114 + 3*P^115 + P^116 + 3*P^117 + 3*P^118 + 3*P^119 + 2*P^120 + 2*P^121 + P^122 + P^123 + 3*P^124 + 
    3*P^125 + 2*P^126 + 2*P^127 + 2*P^128 + P^129 + P^130 + 3*P^131 + 3*P^132 + 2*P^133 + 2*P^134 + P^135 + P^136 + P^137 + 
    3*P^138 + 2*P^139 + 2*P^140 + P^141 + P^142 + P^143 + P^144 + 3*P^145 + 2*P^146 + 2*P^147 + P^149 + P^150 + 2*P^151 + 
    2*P^152 + 2*P^153 + P^156 + P^157 + 2*P^158 + 2*P^159 + 2*P^160 + P^163 + P^164 + 2*P^165 + 2*P^166 + P^170 + 2*P^172 + 
    2*P^173 + P^177 + 2*P^179 + P^183 + P^186 + P^190)/((1 - P^3)*(1 - P^93)*(1 - P^103))}, 
 {3, (P^6 + P^8 + P^13 + P^15 + 2*P^19 + P^20 + P^21 + P^25 + 2*P^26 + P^27 + P^28 + 2*P^32 + 2*P^33 + P^34 + P^35 + P^38 + 
    2*P^39 + 3*P^40 + P^41 + P^42 + 2*P^45 + 2*P^46 + 3*P^47 + P^48 + P^49 + P^51 + 2*P^52 + 3*P^53 + 3*P^54 + P^55 + P^56 + 
    2*P^58 + 2*P^59 + 3*P^60 + 2*P^61 + P^62 + P^63 + 2*P^64 + 2*P^65 + 3*P^66 + 3*P^67 + 2*P^68 + P^69 + P^70 + 2*P^71 + 
    2*P^72 + 3*P^73 + 3*P^74 + 2*P^75 + P^76 + 2*P^77 + 2*P^78 + 3*P^79 + 3*P^80 + 3*P^81 + P^82 + 2*P^83 + 2*P^84 + 3*P^85 + 
    3*P^86 + 3*P^87 + 3*P^88 + P^89 + 3*P^90 + 2*P^91 + 3*P^92 + 3*P^93 + 3*P^94 + 3*P^95 + 2*P^96 + 3*P^97 + 3*P^98 + 2*P^99 + 
    3*P^100 + 2*P^101 + 3*P^102 + 3*P^103 + 3*P^104 + 3*P^105 + 2*P^106 + 3*P^107 + 2*P^108 + 3*P^109 + 3*P^110 + 3*P^111 + 
    P^112 + 2*P^113 + 2*P^114 + 3*P^115 + 3*P^116 + 3*P^117 + 2*P^118 + P^119 + 2*P^120 + 2*P^121 + 3*P^122 + 3*P^123 + 
    3*P^124 + P^125 + P^126 + 2*P^127 + 2*P^128 + 3*P^129 + 3*P^130 + 2*P^131 + P^132 + 2*P^134 + 2*P^135 + 3*P^136 + 3*P^137 + 
    P^138 + P^139 + 2*P^141 + 2*P^142 + 3*P^143 + 2*P^144 + P^145 + 2*P^148 + 2*P^149 + 3*P^150 + P^151 + P^152 + P^154 + 
    2*P^155 + 2*P^156 + P^157 + P^158 + P^161 + 2*P^162 + 2*P^163 + P^164 + P^165 + P^168 + 2*P^169 + P^170 + P^171 + 2*P^175 + 
    P^176 + P^177 + 2*P^182 + P^184 + P^189)/((1 - P^3)*(1 - P^93)*(1 - P^103))}, 
 {3, (P^8 + P^12 + P^13 + P^15 + P^19 + P^20 + P^21 + P^22 + P^25 + 2*P^26 + P^27 + P^28 + 2*P^32 + 2*P^33 + 2*P^34 + P^35 + 
    P^38 + 2*P^39 + 2*P^40 + P^41 + P^42 + P^44 + 2*P^45 + 2*P^46 + 2*P^47 + P^48 + P^49 + P^51 + 2*P^52 + 3*P^53 + 2*P^54 + 
    P^55 + P^56 + P^57 + 2*P^58 + 2*P^59 + 3*P^60 + 2*P^61 + P^62 + P^63 + P^64 + 2*P^65 + 3*P^66 + 3*P^67 + 2*P^68 + P^69 + 
    2*P^70 + 2*P^71 + 2*P^72 + 3*P^73 + 3*P^74 + 2*P^75 + P^76 + 2*P^77 + 2*P^78 + 3*P^79 + 3*P^80 + 3*P^81 + 2*P^82 + 2*P^83 + 
    2*P^84 + 2*P^85 + 3*P^86 + 3*P^87 + 3*P^88 + 2*P^89 + 3*P^90 + 2*P^91 + 3*P^92 + 3*P^93 + 3*P^94 + 2*P^95 + 2*P^96 + 
    3*P^97 + 3*P^98 + 3*P^99 + 3*P^100 + 2*P^101 + 3*P^102 + 3*P^103 + 3*P^104 + 2*P^105 + 2*P^106 + 3*P^107 + 2*P^108 + 
    3*P^109 + 3*P^110 + 3*P^111 + 2*P^112 + 2*P^113 + 2*P^114 + 2*P^115 + 3*P^116 + 3*P^117 + 2*P^118 + P^119 + 2*P^120 + 
    2*P^121 + 3*P^122 + 3*P^123 + 3*P^124 + P^125 + P^126 + P^127 + 2*P^128 + 3*P^129 + 3*P^130 + 2*P^131 + P^132 + P^133 + 
    2*P^134 + 2*P^135 + 3*P^136 + 2*P^137 + P^138 + P^139 + P^140 + 2*P^141 + 2*P^142 + 3*P^143 + 2*P^144 + P^145 + P^147 + 
    2*P^148 + 2*P^149 + 2*P^150 + P^151 + P^152 + P^154 + 2*P^155 + 2*P^156 + 2*P^157 + P^158 + P^161 + 2*P^162 + P^163 + 
    P^164 + P^165 + P^168 + 2*P^169 + P^170 + P^171 + P^175 + P^176 + P^177 + P^178 + P^182 + P^184 + P^188 + P^189)/
   ((1 - P^3)*(1 - P^93)*(1 - P^103))}};
Generating41=ToExpression[Import["./SUtreeData/Generating41.mml","MathML"]];
Generating42={{1, (1 + P^17 + P^19 + P^21 + P^32 + P^34 + P^36 + P^38 + P^40 + P^42 + P^47 + P^49 + P^51 + P^53 + P^55 + P^57 + P^59 + P^61 + 
    P^63 + P^64 + P^65 + P^66 + P^68 + P^70 + P^72 + P^74 + P^76 + P^78 + P^79 + P^80 + P^81 + P^82 + P^83 + P^84 + P^85 + 
    P^86 + P^87 + P^89 + P^93 + P^94 + P^95 + P^96 + P^97 + P^98 + P^99 + P^100 + P^101 + P^102 + P^103 + P^104 + P^105 + 
    P^106 + P^107 + P^111 + P^113 + P^114 + P^115 + P^116 + P^117 + P^118 + P^119 + P^120 + P^121 + P^122 + P^124 + P^126 + 
    P^128 + P^130 + P^132 + P^134 + P^135 + P^136 + P^137 + P^139 + P^141 + P^143 + P^145 + P^147 + P^149 + P^151 + P^153 + 
    P^158 + P^160 + P^162 + P^164 + P^166 + P^168 + P^179 + P^181 + P^183 + P^200)/((1 - P^3)*(1 - P^91)*(1 - P^109))}, 
 {1, (P^17 + P^19 + P^21 + P^32 + P^34 + P^36 + P^38 + P^40 + P^42 + P^47 + P^49 + P^51 + P^53 + P^55 + P^57 + P^59 + P^61 + 
    P^63 + P^64 + P^65 + P^66 + P^68 + P^70 + P^72 + P^74 + P^76 + P^78 + P^79 + P^80 + P^81 + P^82 + P^83 + P^84 + P^85 + 
    P^86 + P^87 + P^89 + P^91 + P^93 + P^94 + P^95 + P^96 + P^97 + P^98 + P^99 + P^100 + P^101 + P^102 + P^103 + P^104 + P^105 + 
    P^106 + P^107 + P^109 + P^111 + P^113 + P^114 + P^115 + P^116 + P^117 + P^118 + P^119 + P^120 + P^121 + P^122 + P^124 + 
    P^126 + P^128 + P^130 + P^132 + P^134 + P^135 + P^136 + P^137 + P^139 + P^141 + P^143 + P^145 + P^147 + P^149 + P^151 + 
    P^153 + P^158 + P^160 + P^162 + P^164 + P^166 + P^168 + P^179 + P^181 + P^183)/((1 - P^3)*(1 - P^91)*(1 - P^109))}, 
 {1, (P^17 + P^19 + P^21 + P^32 + P^34 + P^36 + P^38 + P^40 + P^42 + P^47 + P^49 + P^51 + P^53 + P^55 + P^57 + P^59 + P^61 + 
    P^63 + P^64 + P^65 + P^66 + P^68 + P^70 + P^72 + P^74 + P^76 + P^78 + P^79 + P^80 + P^81 + P^82 + P^83 + P^84 + P^85 + 
    P^86 + P^87 + P^89 + P^91 + P^93 + P^94 + P^95 + P^96 + P^97 + P^98 + P^99 + P^100 + P^101 + P^102 + P^103 + P^104 + P^105 + 
    P^106 + P^107 + P^109 + P^111 + P^113 + P^114 + P^115 + P^116 + P^117 + P^118 + P^119 + P^120 + P^121 + P^122 + P^124 + 
    P^126 + P^128 + P^130 + P^132 + P^134 + P^135 + P^136 + P^137 + P^139 + P^141 + P^143 + P^145 + P^147 + P^149 + P^151 + 
    P^153 + P^158 + P^160 + P^162 + P^164 + P^166 + P^168 + P^179 + P^181 + P^183)/((1 - P^3)*(1 - P^91)*(1 - P^109))}, 
 {3, (P + P^15 + P^17 + 2*P^18 + P^19 + 2*P^20 + 2*P^22 + P^30 + P^32 + 2*P^33 + P^34 + 2*P^35 + P^36 + 2*P^37 + P^38 + 2*P^39 + 
    P^40 + 2*P^41 + 2*P^43 + P^45 + P^47 + 2*P^48 + P^49 + 2*P^50 + P^51 + 2*P^52 + P^53 + 2*P^54 + P^55 + 2*P^56 + P^57 + 
    2*P^58 + P^59 + 2*P^60 + P^61 + 3*P^62 + P^63 + 3*P^64 + 2*P^65 + 3*P^66 + 2*P^67 + P^68 + 2*P^69 + P^70 + 2*P^71 + P^72 + 
    2*P^73 + P^74 + 2*P^75 + P^76 + 3*P^77 + P^78 + 3*P^79 + 3*P^80 + 3*P^81 + 3*P^82 + 3*P^83 + 3*P^84 + 3*P^85 + 2*P^86 + 
    3*P^87 + 2*P^88 + P^89 + 2*P^90 + P^91 + 2*P^92 + P^93 + 3*P^94 + 3*P^95 + 3*P^96 + 3*P^97 + 3*P^98 + 3*P^99 + 3*P^100 + 
    3*P^101 + 3*P^102 + 3*P^103 + 3*P^104 + 3*P^105 + 2*P^106 + 2*P^107 + 2*P^108 + P^109 + 2*P^110 + P^111 + 3*P^112 + P^113 + 
    3*P^114 + 3*P^115 + 3*P^116 + 3*P^117 + 3*P^118 + 3*P^119 + 3*P^120 + 2*P^121 + 3*P^122 + 2*P^123 + P^124 + 2*P^125 + 
    P^126 + 2*P^127 + P^128 + 2*P^129 + P^130 + 2*P^131 + P^132 + 3*P^133 + P^134 + 3*P^135 + 2*P^136 + 3*P^137 + 2*P^138 + 
    P^139 + 2*P^140 + P^141 + 2*P^142 + P^143 + 2*P^144 + P^145 + 2*P^146 + P^147 + 2*P^148 + P^149 + 2*P^150 + P^151 + 
    2*P^152 + 2*P^154 + P^156 + P^158 + 2*P^159 + P^160 + 2*P^161 + P^162 + 2*P^163 + P^164 + 2*P^165 + P^166 + 2*P^167 + 
    2*P^169 + P^177 + P^179 + 2*P^180 + P^181 + 2*P^182 + 2*P^184 + P^198)/((1 - P^3)*(1 - P^91)*(1 - P^109))}, 
 {3, (P^7 + P^8 + P^9 + P^19 + P^21 + 2*P^23 + P^24 + 2*P^25 + P^26 + P^27 + P^28 + P^29 + P^30 + P^34 + P^36 + 2*P^38 + P^39 + 
    2*P^40 + P^41 + 2*P^42 + P^43 + 2*P^44 + P^45 + 2*P^46 + P^47 + P^48 + P^49 + P^50 + 2*P^51 + P^52 + 2*P^53 + P^54 + 
    2*P^55 + P^56 + 2*P^57 + P^58 + 2*P^59 + P^60 + 2*P^61 + P^62 + 2*P^63 + P^64 + 2*P^65 + 2*P^66 + 2*P^67 + 2*P^68 + 2*P^69 + 
    3*P^70 + 2*P^71 + 3*P^72 + 2*P^73 + 3*P^74 + P^75 + 2*P^76 + P^77 + 2*P^78 + P^79 + 2*P^80 + 2*P^81 + 2*P^82 + 2*P^83 + 
    2*P^84 + 3*P^85 + 3*P^86 + 3*P^87 + 3*P^88 + 3*P^89 + 3*P^90 + 3*P^91 + 2*P^92 + 3*P^93 + 2*P^94 + 3*P^95 + 2*P^96 + 
    2*P^97 + P^98 + P^99 + 2*P^100 + 3*P^101 + 3*P^102 + 3*P^103 + 3*P^104 + 3*P^105 + 3*P^106 + 3*P^107 + 3*P^108 + 3*P^109 + 
    2*P^110 + 3*P^111 + 2*P^112 + 3*P^113 + P^114 + 2*P^115 + P^116 + 2*P^117 + 2*P^118 + 2*P^119 + 2*P^120 + 2*P^121 + 
    3*P^122 + 3*P^123 + 3*P^124 + 2*P^125 + 3*P^126 + 2*P^127 + 3*P^128 + P^129 + 2*P^130 + P^131 + 2*P^132 + P^133 + 2*P^134 + 
    P^135 + 2*P^136 + P^137 + 2*P^138 + 2*P^139 + 2*P^140 + 2*P^141 + P^142 + 2*P^143 + P^144 + 2*P^145 + P^146 + 2*P^147 + 
    P^148 + 2*P^149 + P^150 + 2*P^151 + P^152 + 2*P^153 + P^154 + 2*P^155 + P^156 + P^157 + P^158 + P^159 + P^160 + P^162 + 
    P^164 + 2*P^166 + P^167 + 2*P^168 + P^169 + 2*P^170 + P^171 + P^172 + P^173 + P^174 + P^175 + P^183 + P^185 + P^187 + 
    P^188 + P^189 + P^190)/((1 - P^3)*(1 - P^91)*(1 - P^109))}, 
 {3, (P^8 + 2*P^13 + 2*P^15 + P^17 + P^23 + P^25 + P^27 + P^28 + P^29 + 2*P^30 + P^31 + 2*P^32 + 2*P^34 + 2*P^36 + 2*P^38 + 
    P^40 + P^42 + P^43 + P^44 + 2*P^45 + P^46 + 2*P^47 + P^48 + 2*P^49 + P^50 + 2*P^51 + P^52 + 2*P^53 + 3*P^55 + 3*P^57 + 
    3*P^59 + 2*P^60 + 2*P^61 + 2*P^62 + P^63 + 2*P^64 + P^65 + 2*P^66 + P^67 + 2*P^68 + P^69 + 3*P^70 + P^71 + 3*P^72 + P^73 + 
    3*P^74 + 2*P^75 + 3*P^76 + 2*P^77 + 3*P^78 + 2*P^79 + 3*P^80 + 2*P^81 + 2*P^82 + 2*P^83 + P^84 + 3*P^85 + P^86 + 3*P^87 + 
    P^88 + 3*P^89 + 2*P^90 + 3*P^91 + 3*P^92 + 3*P^93 + 3*P^94 + 3*P^95 + 3*P^96 + 3*P^97 + 2*P^98 + 2*P^99 + 2*P^100 + 
    3*P^101 + 3*P^102 + 3*P^103 + P^104 + 2*P^105 + P^106 + 3*P^107 + 2*P^108 + 3*P^109 + 3*P^110 + 3*P^111 + 3*P^112 + 
    3*P^113 + 2*P^114 + 3*P^115 + 2*P^116 + 3*P^117 + 2*P^118 + 2*P^119 + 2*P^120 + P^121 + 2*P^122 + P^123 + 3*P^124 + P^125 + 
    3*P^126 + P^127 + 3*P^128 + P^129 + 3*P^130 + 2*P^131 + 3*P^132 + 2*P^133 + 2*P^134 + 2*P^135 + P^136 + 2*P^137 + P^138 + 
    2*P^139 + P^140 + 2*P^141 + P^142 + 2*P^143 + P^144 + 3*P^145 + 3*P^147 + 3*P^149 + P^151 + P^152 + P^153 + 2*P^154 + 
    P^155 + 2*P^156 + P^157 + 2*P^158 + P^159 + 2*P^160 + 2*P^162 + 2*P^164 + P^166 + P^168 + P^170 + P^172 + P^173 + P^174 + 
    2*P^175 + 2*P^177 + 2*P^179 + P^181 + P^189 + P^191 + P^196)/((1 - P^3)*(1 - P^91)*(1 - P^109))}, 
 {3, (P^10 + P^11 + P^12 + P^13 + P^15 + P^17 + P^25 + P^26 + P^27 + P^28 + P^29 + 2*P^30 + P^31 + 2*P^32 + P^33 + 2*P^34 + 
    P^36 + P^38 + P^40 + P^41 + P^42 + P^43 + P^44 + 2*P^45 + P^46 + 2*P^47 + P^48 + 2*P^49 + P^50 + 2*P^51 + P^52 + 2*P^53 + 
    P^54 + 2*P^55 + P^56 + 2*P^57 + P^58 + 2*P^59 + 2*P^60 + 2*P^61 + 2*P^62 + P^63 + 2*P^64 + P^65 + 2*P^66 + P^67 + 2*P^68 + 
    P^69 + 2*P^70 + P^71 + 3*P^72 + 2*P^73 + 3*P^74 + 2*P^75 + 3*P^76 + 3*P^77 + 3*P^78 + 2*P^79 + 2*P^80 + 2*P^81 + 2*P^82 + 
    2*P^83 + P^84 + 2*P^85 + P^86 + 3*P^87 + 2*P^88 + 3*P^89 + 2*P^90 + 3*P^91 + 3*P^92 + 3*P^93 + 3*P^94 + 3*P^95 + 3*P^96 + 
    3*P^97 + 3*P^98 + 3*P^99 + 2*P^100 + P^101 + P^102 + 2*P^103 + 2*P^104 + 3*P^105 + 2*P^106 + 3*P^107 + 2*P^108 + 3*P^109 + 
    3*P^110 + 3*P^111 + 3*P^112 + 3*P^113 + 3*P^114 + 3*P^115 + 2*P^116 + 2*P^117 + 2*P^118 + 2*P^119 + 2*P^120 + P^121 + 
    2*P^122 + P^123 + 2*P^124 + P^125 + 3*P^126 + 2*P^127 + 3*P^128 + 2*P^129 + 3*P^130 + 2*P^131 + 2*P^132 + 2*P^133 + 
    2*P^134 + 2*P^135 + P^136 + 2*P^137 + P^138 + 2*P^139 + P^140 + 2*P^141 + P^142 + 2*P^143 + P^144 + 2*P^145 + P^146 + 
    2*P^147 + P^148 + 2*P^149 + P^150 + P^151 + P^152 + P^153 + 2*P^154 + P^155 + 2*P^156 + P^157 + 2*P^158 + P^159 + 2*P^160 + 
    P^161 + 2*P^162 + P^164 + P^166 + P^170 + P^171 + P^172 + P^173 + P^174 + 2*P^175 + P^176 + 2*P^177 + P^179 + P^181 + 
    P^191 + P^192 + P^193)/((1 - P^3)*(1 - P^91)*(1 - P^109))}, 
 {3, (P^11 + P^12 + 2*P^13 + P^14 + P^15 + P^26 + P^27 + 2*P^28 + P^29 + 2*P^30 + P^31 + 2*P^32 + P^33 + 2*P^34 + P^35 + P^36 + 
    P^41 + P^42 + 2*P^43 + P^44 + 2*P^45 + P^46 + 2*P^47 + P^48 + 2*P^49 + P^50 + 2*P^51 + P^52 + 2*P^53 + P^54 + 2*P^55 + 
    P^56 + 2*P^57 + 2*P^58 + 2*P^59 + 2*P^60 + P^61 + 2*P^62 + P^63 + 2*P^64 + P^65 + 2*P^66 + P^67 + 2*P^68 + P^69 + 2*P^70 + 
    P^71 + 2*P^72 + 2*P^73 + 3*P^74 + 3*P^75 + 3*P^76 + 3*P^77 + 3*P^78 + 3*P^79 + 2*P^80 + 2*P^81 + P^82 + 2*P^83 + P^84 + 
    2*P^85 + P^86 + 2*P^87 + 2*P^88 + 3*P^89 + 3*P^90 + 3*P^91 + 3*P^92 + 3*P^93 + 3*P^94 + 3*P^95 + 3*P^96 + 3*P^97 + 3*P^98 + 
    3*P^99 + 3*P^100 + 2*P^101 + P^102 + P^103 + P^104 + 2*P^105 + 2*P^106 + 3*P^107 + 3*P^108 + 3*P^109 + 3*P^110 + 3*P^111 + 
    3*P^112 + 3*P^113 + 3*P^114 + 3*P^115 + 3*P^116 + 2*P^117 + 2*P^118 + P^119 + 2*P^120 + P^121 + 2*P^122 + P^123 + 2*P^124 + 
    P^125 + 2*P^126 + 2*P^127 + 3*P^128 + 3*P^129 + 3*P^130 + 3*P^131 + 2*P^132 + 2*P^133 + P^134 + 2*P^135 + P^136 + 2*P^137 + 
    P^138 + 2*P^139 + P^140 + 2*P^141 + P^142 + 2*P^143 + P^144 + 2*P^145 + P^146 + 2*P^147 + P^148 + P^149 + P^150 + P^151 + 
    2*P^152 + P^153 + 2*P^154 + P^155 + 2*P^156 + P^157 + 2*P^158 + P^159 + 2*P^160 + P^161 + 2*P^162 + P^163 + P^164 + P^171 + 
    P^172 + 2*P^173 + P^174 + 2*P^175 + P^176 + 2*P^177 + P^178 + P^179 + P^192 + P^193 + P^194)/
   ((1 - P^3)*(1 - P^91)*(1 - P^109))}, {3, (P^4 + 2*P^15 + 2*P^17 + 2*P^19 + P^21 + P^23 + P^25 + 2*P^30 + 2*P^32 + 2*P^34 + 
    3*P^36 + 3*P^38 + 3*P^40 + P^42 + P^44 + P^45 + P^46 + 2*P^47 + P^48 + 2*P^49 + 3*P^51 + 3*P^53 + 3*P^55 + 3*P^57 + 3*P^59 + 
    3*P^61 + 2*P^62 + 2*P^63 + 2*P^64 + P^65 + 3*P^66 + P^67 + 3*P^68 + P^69 + 3*P^70 + 3*P^72 + 3*P^74 + 3*P^76 + 2*P^77 + 
    3*P^78 + 2*P^79 + 3*P^80 + 2*P^81 + 3*P^82 + 3*P^83 + 3*P^84 + 3*P^85 + P^86 + 3*P^87 + P^88 + 3*P^89 + P^90 + 3*P^91 + 
    2*P^92 + 3*P^93 + 2*P^94 + 2*P^95 + 2*P^96 + 3*P^97 + 3*P^98 + 3*P^99 + 3*P^100 + 3*P^101 + 3*P^102 + 3*P^103 + 3*P^104 + 
    3*P^105 + P^106 + 2*P^107 + P^108 + 3*P^109 + P^110 + 3*P^111 + 2*P^112 + 3*P^113 + 2*P^114 + 3*P^115 + 2*P^116 + 3*P^117 + 
    3*P^118 + 3*P^119 + 3*P^120 + P^121 + 3*P^122 + P^123 + 3*P^124 + P^125 + 3*P^126 + 3*P^128 + 3*P^130 + 3*P^132 + 2*P^133 + 
    3*P^134 + 2*P^135 + 2*P^136 + 2*P^137 + P^138 + 2*P^139 + P^140 + 3*P^141 + 3*P^143 + 3*P^145 + 3*P^147 + 3*P^149 + 
    3*P^151 + P^153 + P^154 + P^155 + 2*P^156 + 2*P^158 + 2*P^160 + 3*P^162 + 3*P^164 + 3*P^166 + P^168 + P^170 + P^172 + 
    2*P^177 + 2*P^179 + 2*P^181 + P^183 + P^185 + P^187 + P^198)/((1 - P^3)*(1 - P^91)*(1 - P^109))}, 
 {3, (P^7 + P^9 + P^11 + P^16 + P^18 + P^20 + P^22 + P^24 + 2*P^26 + 2*P^28 + 2*P^30 + P^32 + P^33 + P^34 + P^35 + P^37 + 
    2*P^39 + 3*P^41 + 3*P^43 + 2*P^45 + 2*P^47 + P^48 + 2*P^49 + P^50 + 2*P^51 + P^52 + P^53 + 2*P^54 + P^55 + 3*P^56 + 3*P^58 + 
    3*P^60 + 3*P^62 + P^63 + 3*P^64 + P^65 + 2*P^66 + P^67 + 2*P^68 + 2*P^69 + 2*P^70 + 2*P^71 + 2*P^72 + 3*P^73 + 2*P^74 + 
    3*P^75 + P^76 + 3*P^77 + P^78 + 3*P^79 + P^80 + 3*P^81 + P^82 + 3*P^83 + P^84 + 3*P^85 + 2*P^86 + 3*P^87 + 3*P^88 + 2*P^89 + 
    3*P^90 + 2*P^91 + 3*P^92 + 2*P^93 + 3*P^94 + 3*P^95 + 3*P^96 + 2*P^97 + 2*P^98 + 2*P^99 + 2*P^100 + 2*P^101 + 2*P^102 + 
    3*P^103 + 3*P^104 + 3*P^105 + 3*P^106 + 2*P^107 + 3*P^108 + 2*P^109 + 3*P^110 + 2*P^111 + 3*P^112 + 2*P^113 + 3*P^114 + 
    2*P^115 + 3*P^116 + P^117 + 3*P^118 + P^119 + 3*P^120 + P^121 + 3*P^122 + 2*P^123 + 2*P^124 + 2*P^125 + 2*P^126 + 3*P^127 + 
    2*P^128 + 3*P^129 + P^130 + 3*P^131 + 3*P^133 + 3*P^135 + P^136 + 3*P^137 + P^138 + 2*P^139 + P^140 + 2*P^141 + P^142 + 
    2*P^143 + 2*P^144 + P^145 + 2*P^146 + 3*P^148 + 3*P^150 + 3*P^152 + 2*P^154 + 2*P^156 + P^157 + 2*P^158 + P^159 + P^160 + 
    P^161 + P^162 + P^163 + P^165 + 2*P^167 + 2*P^169 + 2*P^171 + 2*P^173 + 2*P^175 + P^177 + P^180 + P^182 + P^184 + P^188 + 
    P^190 + P^192)/((1 - P^3)*(1 - P^91)*(1 - P^109))}, 
 {3, (P^6 + 2*P^14 + 2*P^16 + P^18 + P^21 + P^23 + P^25 + P^27 + 2*P^29 + 2*P^31 + 2*P^33 + 2*P^35 + 2*P^37 + P^38 + 2*P^39 + 
    P^40 + P^42 + 2*P^44 + 3*P^46 + 3*P^48 + 3*P^50 + 2*P^52 + P^53 + 2*P^54 + P^55 + 2*P^56 + P^57 + 2*P^58 + P^59 + 2*P^60 + 
    3*P^61 + P^62 + 3*P^63 + 3*P^65 + 3*P^67 + P^68 + 3*P^69 + P^70 + 3*P^71 + P^72 + 2*P^73 + P^74 + 2*P^75 + 3*P^76 + 2*P^77 + 
    3*P^78 + 2*P^79 + 3*P^80 + 2*P^81 + 3*P^82 + 2*P^83 + 3*P^84 + P^85 + 3*P^86 + P^87 + 3*P^88 + P^89 + 3*P^90 + 2*P^91 + 
    3*P^92 + 3*P^93 + 3*P^94 + 3*P^95 + 2*P^96 + 2*P^97 + 2*P^98 + 3*P^99 + 3*P^100 + 3*P^101 + 3*P^102 + 3*P^103 + 3*P^104 + 
    P^105 + 2*P^106 + P^107 + 3*P^108 + 2*P^109 + 3*P^110 + 3*P^111 + 2*P^112 + 3*P^113 + 2*P^114 + 3*P^115 + 2*P^116 + 
    3*P^117 + 2*P^118 + 3*P^119 + P^120 + 3*P^121 + P^122 + 3*P^123 + P^124 + 3*P^125 + P^126 + 3*P^127 + P^128 + 2*P^129 + 
    P^130 + 2*P^131 + 3*P^132 + 2*P^133 + 3*P^134 + P^135 + 3*P^136 + 3*P^138 + 3*P^140 + 3*P^142 + P^143 + 2*P^144 + P^145 + 
    2*P^146 + P^147 + 2*P^148 + P^149 + 2*P^150 + P^151 + 2*P^153 + 3*P^155 + 3*P^157 + 2*P^159 + 2*P^161 + 2*P^163 + P^164 + 
    2*P^165 + P^166 + P^168 + P^170 + P^172 + P^174 + 2*P^176 + 2*P^178 + 2*P^180 + P^182 + P^187 + P^189 + P^197)/
   ((1 - P^3)*(1 - P^91)*(1 - P^109))}, {3, (P^5 + P^10 + P^12 + P^19 + P^20 + P^21 + P^22 + P^23 + P^24 + P^25 + P^26 + P^27 + 
    P^29 + P^31 + P^33 + P^34 + P^35 + P^36 + P^37 + P^38 + P^39 + P^40 + P^41 + 2*P^42 + P^43 + 2*P^44 + P^45 + 2*P^46 + P^47 + 
    P^48 + P^49 + P^50 + P^51 + 2*P^52 + P^53 + 2*P^54 + P^55 + 2*P^56 + 2*P^57 + P^58 + 2*P^59 + P^60 + 2*P^61 + P^62 + 
    2*P^63 + P^64 + 2*P^65 + 2*P^66 + 3*P^67 + 2*P^68 + 2*P^69 + 2*P^70 + 2*P^71 + 2*P^72 + 2*P^73 + 2*P^74 + 2*P^75 + 2*P^76 + 
    2*P^77 + 2*P^78 + P^79 + 2*P^80 + 2*P^81 + 3*P^82 + 2*P^83 + 3*P^84 + 2*P^85 + 3*P^86 + 2*P^87 + 3*P^88 + 3*P^89 + 3*P^90 + 
    3*P^91 + 2*P^92 + 2*P^93 + 2*P^94 + 2*P^95 + 2*P^96 + 2*P^97 + 3*P^98 + 3*P^99 + 3*P^100 + 2*P^101 + 2*P^102 + 2*P^103 + 
    3*P^104 + 3*P^105 + 3*P^106 + 3*P^107 + 3*P^108 + 3*P^109 + 2*P^110 + 2*P^111 + 2*P^112 + 2*P^113 + 2*P^114 + 2*P^115 + 
    2*P^116 + 2*P^117 + 2*P^118 + 3*P^119 + 2*P^120 + 3*P^121 + 2*P^122 + 3*P^123 + 2*P^124 + 2*P^125 + 2*P^126 + 2*P^127 + 
    2*P^128 + 2*P^129 + 2*P^130 + 2*P^131 + 2*P^132 + P^133 + 2*P^134 + P^135 + 2*P^136 + P^137 + 2*P^138 + 2*P^139 + 2*P^140 + 
    2*P^141 + 2*P^142 + P^143 + 2*P^144 + P^145 + 2*P^146 + P^147 + P^148 + 2*P^149 + P^150 + 2*P^151 + P^152 + 2*P^153 + 
    P^154 + 2*P^155 + P^156 + P^157 + P^159 + P^160 + P^161 + P^162 + P^163 + P^164 + P^165 + P^166 + P^167 + P^168 + P^169 + 
    2*P^170 + P^171 + P^172 + P^174 + P^176 + P^178 + P^183 + P^184 + P^185 + P^186 + P^188 + P^193)/
   ((1 - P^3)*(1 - P^91)*(1 - P^109))}, {3, (P^9 + P^10 + P^11 + P^15 + P^17 + P^19 + P^24 + P^25 + P^26 + P^27 + P^28 + P^29 + 
    P^30 + P^31 + 2*P^32 + P^33 + P^34 + P^36 + P^38 + 2*P^40 + P^41 + 2*P^42 + P^43 + P^44 + P^45 + P^46 + 2*P^47 + P^48 + 
    2*P^49 + P^50 + 2*P^51 + P^52 + 2*P^53 + P^54 + 2*P^55 + P^56 + 2*P^57 + P^58 + 2*P^59 + P^60 + 2*P^61 + 2*P^62 + 2*P^63 + 
    2*P^64 + P^65 + 2*P^66 + P^67 + 2*P^68 + P^69 + 2*P^70 + 2*P^71 + 3*P^72 + 2*P^73 + 3*P^74 + 2*P^75 + 3*P^76 + 2*P^77 + 
    2*P^78 + 2*P^79 + 2*P^80 + 2*P^81 + 2*P^82 + 2*P^83 + 2*P^84 + 2*P^85 + 2*P^86 + 3*P^87 + 2*P^88 + 3*P^89 + 2*P^90 + 
    3*P^91 + 2*P^92 + 3*P^93 + 3*P^94 + 3*P^95 + 3*P^96 + 3*P^97 + 3*P^98 + 2*P^99 + P^100 + P^101 + 2*P^102 + 3*P^103 + 
    3*P^104 + 3*P^105 + 2*P^106 + 3*P^107 + 2*P^108 + 3*P^109 + 2*P^110 + 3*P^111 + 3*P^112 + 3*P^113 + 3*P^114 + 2*P^115 + 
    2*P^116 + 2*P^117 + 2*P^118 + 2*P^119 + 2*P^120 + 2*P^121 + 2*P^122 + P^123 + 2*P^124 + 2*P^125 + 3*P^126 + 2*P^127 + 
    3*P^128 + 2*P^129 + 3*P^130 + P^131 + 2*P^132 + P^133 + 2*P^134 + 2*P^135 + 2*P^136 + 2*P^137 + P^138 + 2*P^139 + P^140 + 
    2*P^141 + P^142 + 2*P^143 + P^144 + 2*P^145 + P^146 + 2*P^147 + P^148 + 2*P^149 + P^150 + 2*P^151 + P^152 + P^153 + P^154 + 
    P^155 + 2*P^156 + P^157 + 2*P^158 + P^159 + 2*P^160 + P^161 + P^162 + P^164 + P^166 + P^168 + P^169 + P^170 + P^171 + 
    P^172 + P^173 + P^174 + P^175 + P^176 + P^177 + P^179 + P^181 + P^183 + P^190 + P^191 + P^192)/
   ((1 - P^3)*(1 - P^91)*(1 - P^109))}, {3, (P^4 + P^9 + P^11 + P^19 + 2*P^21 + 2*P^23 + 2*P^25 + P^26 + P^27 + P^28 + P^30 + 
    P^32 + P^34 + 2*P^36 + 2*P^38 + 2*P^40 + P^41 + 2*P^42 + P^43 + 2*P^44 + P^45 + 2*P^46 + P^47 + P^48 + P^49 + 3*P^51 + 
    3*P^53 + 3*P^55 + P^56 + 2*P^57 + P^58 + 2*P^59 + P^60 + 2*P^61 + P^62 + 2*P^63 + P^64 + 2*P^65 + 2*P^66 + 2*P^67 + 3*P^68 + 
    2*P^69 + 3*P^70 + P^71 + 3*P^72 + P^73 + 3*P^74 + P^75 + 3*P^76 + P^77 + 2*P^78 + P^79 + 2*P^80 + 2*P^81 + 2*P^82 + 3*P^83 + 
    2*P^84 + 3*P^85 + 2*P^86 + 3*P^87 + 3*P^88 + 3*P^89 + 3*P^90 + 3*P^91 + 2*P^92 + 3*P^93 + P^94 + 2*P^95 + P^96 + 3*P^97 + 
    3*P^98 + 3*P^99 + 2*P^100 + 2*P^101 + 2*P^102 + 3*P^103 + 3*P^104 + 3*P^105 + 3*P^106 + 3*P^107 + 3*P^108 + 3*P^109 + 
    2*P^110 + 3*P^111 + P^112 + 3*P^113 + P^114 + 3*P^115 + P^116 + 2*P^117 + 2*P^118 + 2*P^119 + 3*P^120 + 2*P^121 + 3*P^122 + 
    2*P^123 + 3*P^124 + 2*P^125 + 3*P^126 + P^127 + 3*P^128 + P^129 + 3*P^130 + P^131 + 2*P^132 + P^133 + 2*P^134 + P^135 + 
    2*P^136 + P^137 + 2*P^138 + 2*P^139 + 2*P^140 + 3*P^141 + 3*P^143 + 3*P^145 + 2*P^147 + P^148 + 2*P^149 + P^150 + 2*P^151 + 
    P^152 + 2*P^153 + P^154 + 2*P^155 + P^156 + P^157 + P^158 + P^160 + 2*P^162 + 2*P^164 + 2*P^166 + 2*P^168 + P^169 + 
    2*P^170 + P^171 + P^172 + P^173 + P^175 + P^177 + P^183 + 2*P^185 + 2*P^187 + P^192)/((1 - P^3)*(1 - P^91)*(1 - P^109))}, 
 {3, (P^8 + P^10 + P^12 + P^16 + P^18 + P^20 + P^23 + 2*P^25 + 2*P^27 + 2*P^29 + 2*P^31 + 2*P^33 + P^35 + P^37 + P^38 + P^39 + 
    P^40 + P^41 + 2*P^42 + P^43 + 2*P^44 + 2*P^46 + 3*P^48 + 3*P^50 + 3*P^52 + 2*P^54 + P^55 + 2*P^56 + 2*P^57 + P^58 + 2*P^59 + 
    P^60 + 2*P^61 + P^62 + 3*P^63 + P^64 + 3*P^65 + 3*P^67 + 3*P^69 + P^70 + 3*P^71 + 2*P^72 + 3*P^73 + 2*P^74 + 2*P^75 + 
    2*P^76 + 2*P^77 + 3*P^78 + P^79 + 3*P^80 + P^81 + 3*P^82 + P^83 + 3*P^84 + 2*P^85 + 3*P^86 + 2*P^87 + 3*P^88 + 2*P^89 + 
    3*P^90 + 2*P^91 + 3*P^92 + 2*P^93 + 3*P^94 + 3*P^95 + 3*P^96 + 3*P^97 + 2*P^98 + 2*P^99 + 2*P^100 + 2*P^101 + 2*P^102 + 
    2*P^103 + 3*P^104 + 3*P^105 + 3*P^106 + 2*P^107 + 3*P^108 + 2*P^109 + 3*P^110 + 2*P^111 + 3*P^112 + 3*P^113 + 2*P^114 + 
    3*P^115 + P^116 + 3*P^117 + P^118 + 3*P^119 + P^120 + 3*P^121 + P^122 + 3*P^123 + P^124 + 3*P^125 + 2*P^126 + 3*P^127 + 
    2*P^128 + 2*P^129 + 2*P^130 + 2*P^131 + 2*P^132 + P^133 + 2*P^134 + P^135 + 3*P^136 + P^137 + 3*P^138 + 3*P^140 + 3*P^142 + 
    3*P^144 + P^145 + 2*P^146 + P^147 + P^148 + 2*P^149 + P^150 + 2*P^151 + P^152 + 2*P^153 + 2*P^155 + 3*P^157 + 3*P^159 + 
    2*P^161 + P^163 + P^165 + P^166 + P^167 + P^168 + 2*P^170 + 2*P^172 + 2*P^174 + P^176 + P^178 + P^180 + P^182 + P^184 + 
    P^189 + P^191 + P^193)/((1 - P^3)*(1 - P^91)*(1 - P^109))}, 
 {3, (P^3 + P^14 + P^16 + P^17 + P^18 + P^19 + P^20 + P^21 + P^22 + P^24 + P^29 + P^31 + P^32 + P^33 + P^34 + 2*P^35 + P^36 + 
    2*P^37 + P^38 + 2*P^39 + P^40 + P^41 + P^42 + P^43 + P^44 + P^45 + P^46 + P^47 + P^48 + P^49 + 2*P^50 + P^51 + 2*P^52 + 
    P^53 + 2*P^54 + P^55 + 2*P^56 + P^57 + 2*P^58 + P^59 + 2*P^60 + 2*P^61 + P^62 + 2*P^63 + 2*P^64 + 3*P^65 + 2*P^66 + 2*P^67 + 
    2*P^68 + 2*P^69 + P^70 + 2*P^71 + P^72 + 2*P^73 + P^74 + 2*P^75 + 2*P^76 + 2*P^77 + 2*P^78 + 3*P^79 + 2*P^80 + 3*P^81 + 
    3*P^82 + 3*P^83 + 3*P^84 + 2*P^85 + 3*P^86 + 2*P^87 + 2*P^88 + 2*P^89 + 2*P^90 + 2*P^91 + 2*P^92 + 2*P^93 + 2*P^94 + 
    2*P^95 + 3*P^96 + 3*P^97 + 3*P^98 + 3*P^99 + 3*P^100 + 3*P^101 + 3*P^102 + 3*P^103 + 3*P^104 + 2*P^105 + 2*P^106 + 2*P^107 + 
    2*P^108 + 2*P^109 + 2*P^110 + 2*P^111 + 2*P^112 + 2*P^113 + 3*P^114 + 2*P^115 + 3*P^116 + 3*P^117 + 3*P^118 + 3*P^119 + 
    2*P^120 + 3*P^121 + 2*P^122 + 2*P^123 + 2*P^124 + 2*P^125 + P^126 + 2*P^127 + P^128 + 2*P^129 + P^130 + 2*P^131 + 2*P^132 + 
    2*P^133 + 2*P^134 + 2*P^135 + 2*P^136 + 2*P^137 + 2*P^138 + 2*P^139 + 2*P^140 + P^141 + 2*P^142 + P^143 + 2*P^144 + P^145 + 
    2*P^146 + P^147 + 2*P^148 + P^149 + 2*P^150 + P^151 + P^152 + 2*P^153 + P^154 + P^155 + P^157 + P^158 + P^159 + P^160 + 
    2*P^161 + P^162 + 2*P^163 + P^164 + 2*P^165 + P^166 + P^167 + P^168 + P^169 + P^171 + P^176 + P^178 + P^179 + P^180 + 
    P^181 + P^182 + P^183 + P^184 + P^186 + P^197)/((1 - P^3)*(1 - P^91)*(1 - P^109))}, 
 {3, (P^3 + P^14 + P^16 + P^17 + P^18 + P^19 + P^20 + P^21 + P^22 + P^24 + P^29 + P^31 + P^32 + P^33 + P^34 + 2*P^35 + P^36 + 
    2*P^37 + P^38 + 2*P^39 + P^40 + P^41 + P^42 + P^43 + P^45 + P^46 + 2*P^47 + P^48 + P^49 + 2*P^50 + P^51 + 2*P^52 + P^53 + 
    2*P^54 + P^55 + 2*P^56 + P^57 + 2*P^58 + P^59 + 2*P^60 + 2*P^61 + 2*P^62 + 2*P^63 + 2*P^64 + 2*P^65 + 2*P^66 + 2*P^67 + 
    2*P^68 + 2*P^69 + P^70 + 2*P^71 + P^72 + 2*P^73 + P^74 + 2*P^75 + 2*P^76 + 2*P^77 + 2*P^78 + 3*P^79 + 2*P^80 + 3*P^81 + 
    3*P^82 + 3*P^83 + 3*P^84 + 2*P^85 + 3*P^86 + 2*P^87 + 2*P^88 + 2*P^89 + 2*P^90 + 2*P^91 + 2*P^92 + 2*P^93 + 2*P^94 + 
    2*P^95 + 3*P^96 + 3*P^97 + 3*P^98 + 3*P^99 + 3*P^100 + 3*P^101 + 3*P^102 + 3*P^103 + 3*P^104 + 2*P^105 + 2*P^106 + 2*P^107 + 
    2*P^108 + 2*P^109 + 2*P^110 + 2*P^111 + 2*P^112 + 2*P^113 + 3*P^114 + 2*P^115 + 3*P^116 + 3*P^117 + 3*P^118 + 3*P^119 + 
    2*P^120 + 3*P^121 + 2*P^122 + 2*P^123 + 2*P^124 + 2*P^125 + P^126 + 2*P^127 + P^128 + 2*P^129 + P^130 + 2*P^131 + 2*P^132 + 
    2*P^133 + 2*P^134 + 3*P^135 + 2*P^136 + 2*P^137 + P^138 + 2*P^139 + 2*P^140 + P^141 + 2*P^142 + P^143 + 2*P^144 + P^145 + 
    2*P^146 + P^147 + 2*P^148 + P^149 + 2*P^150 + P^151 + P^152 + P^153 + P^154 + P^155 + P^156 + P^157 + P^158 + P^159 + 
    P^160 + 2*P^161 + P^162 + 2*P^163 + P^164 + 2*P^165 + P^166 + P^167 + P^168 + P^169 + P^171 + P^176 + P^178 + P^179 + 
    P^180 + P^181 + P^182 + P^183 + P^184 + P^186 + P^197)/((1 - P^3)*(1 - P^91)*(1 - P^109))}, 
 {3, (P^8 + P^9 + P^10 + P^17 + P^19 + P^21 + P^23 + P^24 + P^25 + P^26 + P^27 + P^28 + P^29 + P^30 + P^31 + P^32 + P^34 + 
    P^36 + P^38 + P^39 + 2*P^40 + P^41 + 2*P^42 + P^43 + 2*P^44 + P^45 + P^46 + P^47 + P^48 + 2*P^49 + P^50 + 2*P^51 + P^52 + 
    2*P^53 + P^54 + 2*P^55 + P^56 + 2*P^57 + P^58 + 2*P^59 + P^60 + 2*P^61 + P^62 + 2*P^63 + 2*P^64 + 2*P^65 + 2*P^66 + P^67 + 
    2*P^68 + P^69 + 3*P^70 + 2*P^71 + 3*P^72 + 2*P^73 + 3*P^74 + 2*P^75 + 2*P^76 + P^77 + 2*P^78 + 2*P^79 + 2*P^80 + 2*P^81 + 
    2*P^82 + 2*P^83 + 2*P^84 + 2*P^85 + 3*P^86 + 3*P^87 + 3*P^88 + 3*P^89 + 2*P^90 + 3*P^91 + 2*P^92 + 3*P^93 + 2*P^94 + 
    3*P^95 + 3*P^96 + 3*P^97 + 2*P^98 + P^99 + P^100 + 2*P^101 + 3*P^102 + 3*P^103 + 3*P^104 + 3*P^105 + 3*P^106 + 3*P^107 + 
    2*P^108 + 3*P^109 + 2*P^110 + 3*P^111 + 2*P^112 + 3*P^113 + 2*P^114 + 2*P^115 + 2*P^116 + 2*P^117 + 2*P^118 + 2*P^119 + 
    2*P^120 + 2*P^121 + 2*P^122 + 2*P^123 + 3*P^124 + 2*P^125 + 3*P^126 + 2*P^127 + 3*P^128 + 2*P^129 + 2*P^130 + P^131 + 
    2*P^132 + P^133 + 2*P^134 + P^135 + 2*P^136 + 2*P^137 + 2*P^138 + 2*P^139 + P^140 + 2*P^141 + P^142 + 2*P^143 + P^144 + 
    2*P^145 + P^146 + 2*P^147 + P^148 + 2*P^149 + P^150 + 2*P^151 + P^152 + 2*P^153 + P^154 + P^155 + P^156 + P^157 + 2*P^158 + 
    P^159 + 2*P^160 + P^162 + P^164 + P^166 + P^167 + 2*P^168 + P^169 + P^170 + P^171 + P^172 + P^173 + P^174 + P^175 + P^176 + 
    P^181 + P^183 + P^185 + P^189 + P^190 + P^191)/((1 - P^3)*(1 - P^91)*(1 - P^109))}, 
 {3, (P^7 + P^12 + P^14 + P^15 + P^17 + P^19 + P^22 + P^24 + P^26 + P^27 + P^28 + P^29 + P^30 + P^31 + P^32 + P^33 + P^34 + 
    P^35 + P^36 + P^37 + P^38 + P^39 + P^40 + P^41 + P^42 + P^43 + P^44 + P^45 + P^46 + 2*P^47 + P^48 + 2*P^49 + P^50 + 2*P^51 + 
    P^52 + P^53 + 2*P^54 + P^55 + 2*P^56 + P^57 + 2*P^58 + 2*P^59 + P^60 + 2*P^61 + 2*P^62 + 2*P^63 + 2*P^64 + P^65 + 2*P^66 + 
    P^67 + 2*P^68 + 2*P^69 + 2*P^70 + 2*P^71 + 2*P^72 + 2*P^73 + 2*P^74 + 2*P^75 + 2*P^76 + 3*P^77 + 2*P^78 + 3*P^79 + 2*P^80 + 
    2*P^81 + 2*P^82 + 2*P^83 + 3*P^84 + 2*P^85 + 2*P^86 + 2*P^87 + 2*P^88 + 3*P^89 + 2*P^90 + 3*P^91 + 2*P^92 + 3*P^93 + 
    3*P^94 + 3*P^95 + 3*P^96 + 2*P^97 + 2*P^98 + 2*P^99 + 3*P^100 + 3*P^101 + 3*P^102 + 2*P^103 + 2*P^104 + 2*P^105 + 2*P^106 + 
    3*P^107 + 2*P^108 + 3*P^109 + 2*P^110 + 3*P^111 + 3*P^112 + 2*P^113 + 3*P^114 + 2*P^115 + 3*P^116 + 2*P^117 + 2*P^118 + 
    2*P^119 + 2*P^120 + 2*P^121 + 2*P^122 + 2*P^123 + 2*P^124 + 2*P^125 + 2*P^126 + 2*P^127 + 2*P^128 + 2*P^129 + 2*P^130 + 
    2*P^131 + 2*P^132 + 2*P^133 + 2*P^134 + 2*P^135 + 2*P^136 + 2*P^137 + P^138 + 2*P^139 + P^140 + 2*P^141 + P^142 + 2*P^143 + 
    2*P^144 + P^145 + 2*P^146 + P^147 + 2*P^148 + P^149 + P^150 + 2*P^151 + P^152 + P^153 + P^154 + P^155 + 2*P^156 + P^157 + 
    2*P^158 + P^159 + P^160 + P^161 + P^162 + P^163 + P^164 + P^165 + P^166 + P^167 + P^169 + P^171 + P^172 + P^173 + P^174 + 
    P^176 + P^177 + P^178 + P^179 + P^181 + P^183 + P^188 + P^190 + P^195)/((1 - P^3)*(1 - P^91)*(1 - P^109))}, 
 {3, (P^6 + P^7 + P^8 + P^21 + P^22 + 2*P^23 + P^24 + 2*P^25 + P^26 + 2*P^27 + P^28 + P^29 + P^36 + P^37 + 2*P^38 + P^39 + 
    2*P^40 + P^41 + 2*P^42 + P^43 + 2*P^44 + P^45 + 2*P^46 + P^47 + 2*P^48 + P^49 + P^50 + P^51 + P^52 + 2*P^53 + P^54 + 
    2*P^55 + P^56 + 2*P^57 + P^58 + 2*P^59 + P^60 + 2*P^61 + P^62 + 2*P^63 + P^64 + 2*P^65 + P^66 + 2*P^67 + 2*P^68 + 3*P^69 + 
    3*P^70 + 3*P^71 + 3*P^72 + 2*P^73 + 2*P^74 + P^75 + 2*P^76 + P^77 + 2*P^78 + P^79 + 2*P^80 + P^81 + 2*P^82 + 2*P^83 + 
    3*P^84 + 3*P^85 + 3*P^86 + 3*P^87 + 3*P^88 + 3*P^89 + 3*P^90 + 3*P^91 + 3*P^92 + 3*P^93 + 2*P^94 + 2*P^95 + P^96 + P^97 + 
    P^98 + 2*P^99 + 3*P^100 + 3*P^101 + 3*P^102 + 3*P^103 + 3*P^104 + 3*P^105 + 3*P^106 + 3*P^107 + 3*P^108 + 3*P^109 + 
    3*P^110 + 3*P^111 + 2*P^112 + 2*P^113 + P^114 + 2*P^115 + P^116 + 2*P^117 + P^118 + 2*P^119 + 2*P^120 + 3*P^121 + 3*P^122 + 
    3*P^123 + 3*P^124 + 3*P^125 + 3*P^126 + 2*P^127 + 2*P^128 + P^129 + 2*P^130 + P^131 + 2*P^132 + P^133 + 2*P^134 + P^135 + 
    2*P^136 + P^137 + 2*P^138 + P^139 + 2*P^140 + 2*P^141 + 2*P^142 + 2*P^143 + P^144 + 2*P^145 + P^146 + 2*P^147 + P^148 + 
    2*P^149 + P^150 + 2*P^151 + P^152 + 2*P^153 + P^154 + 2*P^155 + P^156 + 2*P^157 + P^158 + P^159 + P^164 + P^165 + 2*P^166 + 
    P^167 + 2*P^168 + P^169 + 2*P^170 + P^171 + 2*P^172 + P^173 + P^174 + P^185 + P^186 + 2*P^187 + P^188 + P^189)/
   ((1 - P^3)*(1 - P^91)*(1 - P^109))}, {3, (P^6 + P^11 + P^13 + P^15 + P^17 + P^19 + P^21 + P^23 + P^25 + P^27 + P^28 + P^29 + 
    P^30 + 2*P^32 + 2*P^34 + 2*P^36 + 2*P^38 + 2*P^40 + 2*P^42 + P^43 + P^44 + P^45 + P^46 + 2*P^47 + P^48 + 2*P^49 + P^50 + 
    2*P^51 + 3*P^53 + 3*P^55 + 3*P^57 + P^58 + 2*P^59 + P^60 + 2*P^61 + 2*P^62 + 2*P^63 + 2*P^64 + P^65 + 2*P^66 + P^67 + 
    3*P^68 + P^69 + 3*P^70 + P^71 + 3*P^72 + P^73 + 3*P^74 + P^75 + 3*P^76 + P^77 + 3*P^78 + 2*P^79 + 3*P^80 + 2*P^81 + 2*P^82 + 
    2*P^83 + 2*P^84 + 3*P^85 + 2*P^86 + 3*P^87 + P^88 + 3*P^89 + 2*P^90 + 3*P^91 + 2*P^92 + 3*P^93 + 3*P^94 + 3*P^95 + 2*P^96 + 
    2*P^97 + 2*P^98 + 3*P^99 + 3*P^100 + 3*P^101 + 2*P^102 + 2*P^103 + 2*P^104 + 3*P^105 + 2*P^106 + 3*P^107 + 2*P^108 + 
    3*P^109 + 2*P^110 + 3*P^111 + 2*P^112 + 3*P^113 + 2*P^114 + 3*P^115 + 2*P^116 + 3*P^117 + 2*P^118 + 2*P^119 + 2*P^120 + 
    2*P^121 + 3*P^122 + P^123 + 3*P^124 + P^125 + 3*P^126 + P^127 + 3*P^128 + P^129 + 3*P^130 + P^131 + 3*P^132 + P^133 + 
    2*P^134 + 2*P^135 + 2*P^136 + 2*P^137 + P^138 + 2*P^139 + P^140 + 2*P^141 + P^142 + 3*P^143 + 3*P^145 + 3*P^147 + 2*P^149 + 
    P^150 + 2*P^151 + P^152 + P^153 + P^154 + P^155 + 2*P^156 + P^157 + 2*P^158 + 2*P^160 + 2*P^162 + 2*P^164 + 2*P^166 + 
    2*P^168 + P^170 + P^172 + P^173 + P^174 + P^175 + P^177 + 2*P^179 + P^181 + P^183 + P^187 + P^189 + P^194)/
   ((1 - P^3)*(1 - P^91)*(1 - P^109))}, {3, (P^7 + P^12 + P^14 + P^15 + P^16 + P^17 + P^22 + P^24 + P^26 + P^28 + P^29 + 
    2*P^30 + P^31 + P^32 + P^33 + P^34 + P^35 + P^36 + P^37 + P^38 + P^39 + P^40 + P^41 + P^43 + P^44 + 2*P^45 + P^46 + 2*P^47 + 
    P^48 + 2*P^49 + P^50 + 2*P^51 + P^52 + P^53 + 2*P^54 + P^55 + 2*P^56 + P^57 + 2*P^58 + 2*P^59 + 2*P^60 + 2*P^61 + 2*P^62 + 
    P^63 + 2*P^64 + P^65 + 2*P^66 + P^67 + 2*P^68 + 2*P^69 + 2*P^70 + 2*P^71 + 2*P^72 + 2*P^73 + 2*P^74 + 2*P^75 + 2*P^76 + 
    3*P^77 + 2*P^78 + 3*P^79 + 2*P^80 + 3*P^81 + 2*P^82 + 2*P^83 + 2*P^84 + 2*P^85 + 2*P^86 + 2*P^87 + 2*P^88 + 2*P^89 + 
    2*P^90 + 3*P^91 + 3*P^92 + 3*P^93 + 3*P^94 + 3*P^95 + 3*P^96 + 2*P^97 + 2*P^98 + 2*P^99 + 3*P^100 + 3*P^101 + 3*P^102 + 
    2*P^103 + 2*P^104 + 2*P^105 + 2*P^106 + 2*P^107 + 2*P^108 + 3*P^109 + 3*P^110 + 3*P^111 + 3*P^112 + 2*P^113 + 3*P^114 + 
    2*P^115 + 3*P^116 + 2*P^117 + 3*P^118 + 2*P^119 + 2*P^120 + P^121 + 2*P^122 + 2*P^123 + 2*P^124 + 2*P^125 + 2*P^126 + 
    2*P^127 + 2*P^128 + 2*P^129 + 2*P^130 + 2*P^131 + 2*P^132 + 3*P^133 + 2*P^134 + 2*P^135 + P^136 + 2*P^137 + P^138 + 
    2*P^139 + P^140 + 2*P^141 + P^142 + 2*P^143 + 2*P^144 + P^145 + 2*P^146 + P^147 + 2*P^148 + P^149 + P^150 + P^151 + P^152 + 
    P^153 + 2*P^154 + P^155 + 2*P^156 + P^157 + 2*P^158 + P^159 + P^160 + P^161 + P^162 + P^163 + P^164 + P^165 + P^166 + 
    P^167 + P^169 + P^171 + P^173 + P^174 + P^175 + P^176 + P^177 + P^178 + P^179 + P^180 + P^181 + P^188 + P^190 + P^195)/
   ((1 - P^3)*(1 - P^91)*(1 - P^109))}, {3, (P^7 + P^9 + P^11 + P^18 + P^20 + 2*P^22 + 2*P^24 + 2*P^26 + 2*P^28 + P^30 + P^32 + 
    P^33 + P^35 + 2*P^37 + 2*P^39 + 3*P^41 + 3*P^43 + 3*P^45 + 2*P^47 + 2*P^49 + P^50 + 2*P^51 + P^52 + P^53 + 2*P^54 + P^55 + 
    3*P^56 + 3*P^58 + 3*P^60 + 3*P^62 + 3*P^64 + P^65 + 3*P^66 + P^67 + 2*P^68 + 2*P^69 + 2*P^70 + 3*P^71 + 2*P^72 + 3*P^73 + 
    P^74 + 3*P^75 + P^76 + 3*P^77 + 3*P^79 + P^80 + 3*P^81 + P^82 + 3*P^83 + 2*P^84 + 3*P^85 + 2*P^86 + 3*P^87 + 3*P^88 + 
    3*P^89 + 3*P^90 + 2*P^91 + 3*P^92 + 2*P^93 + 3*P^94 + 2*P^95 + 3*P^96 + 2*P^97 + 2*P^98 + 2*P^99 + 2*P^100 + 2*P^101 + 
    2*P^102 + 3*P^103 + 3*P^104 + 3*P^105 + 3*P^106 + 3*P^107 + 3*P^108 + 2*P^109 + 3*P^110 + 2*P^111 + 3*P^112 + P^113 + 
    3*P^114 + P^115 + 3*P^116 + P^117 + 3*P^118 + P^119 + 3*P^120 + 2*P^121 + 3*P^122 + 2*P^123 + 2*P^124 + 3*P^125 + 2*P^126 + 
    3*P^127 + P^128 + 3*P^129 + P^130 + 3*P^131 + 3*P^133 + 3*P^135 + 3*P^137 + P^138 + 3*P^139 + P^140 + 2*P^141 + P^142 + 
    2*P^143 + 2*P^144 + P^145 + 2*P^146 + 3*P^148 + 3*P^150 + 3*P^152 + 3*P^154 + 2*P^156 + 2*P^158 + P^159 + P^160 + P^161 + 
    P^163 + 2*P^165 + 2*P^167 + 3*P^169 + 2*P^171 + 2*P^173 + P^175 + P^177 + P^182 + P^184 + P^186 + P^188 + P^190 + P^192)/
   ((1 - P^3)*(1 - P^91)*(1 - P^109))}, {3, (P^4 + P^12 + P^14 + P^18 + P^19 + P^20 + P^21 + P^22 + P^23 + P^25 + P^27 + P^29 + 
    P^31 + 2*P^33 + 2*P^35 + P^36 + 2*P^37 + P^38 + P^39 + P^40 + P^41 + P^42 + P^43 + 2*P^44 + P^45 + 2*P^46 + 2*P^48 + 
    2*P^50 + P^51 + 2*P^52 + P^53 + 2*P^54 + P^55 + 2*P^56 + P^57 + 2*P^58 + 2*P^59 + P^60 + 2*P^61 + P^62 + 2*P^63 + P^64 + 
    3*P^65 + 2*P^66 + 3*P^67 + P^68 + 3*P^69 + P^70 + 2*P^71 + P^72 + 2*P^73 + 2*P^74 + 2*P^75 + 2*P^76 + 2*P^77 + 2*P^78 + 
    2*P^79 + 3*P^80 + 2*P^81 + 3*P^82 + 2*P^83 + 3*P^84 + 2*P^85 + 3*P^86 + 2*P^87 + 3*P^88 + 2*P^89 + 3*P^90 + 2*P^91 + 
    2*P^92 + 2*P^93 + 2*P^94 + 2*P^95 + 2*P^96 + 3*P^97 + 3*P^98 + 3*P^99 + 3*P^100 + 3*P^101 + 3*P^102 + 2*P^103 + 2*P^104 + 
    2*P^105 + 3*P^106 + 3*P^107 + 3*P^108 + 2*P^109 + 2*P^110 + 2*P^111 + 2*P^112 + 2*P^113 + 2*P^114 + 3*P^115 + 2*P^116 + 
    3*P^117 + 2*P^118 + 3*P^119 + 2*P^120 + 3*P^121 + 2*P^122 + 3*P^123 + P^124 + 3*P^125 + P^126 + 2*P^127 + P^128 + 2*P^129 + 
    2*P^130 + 2*P^131 + 2*P^132 + 2*P^133 + 2*P^134 + P^135 + 2*P^136 + P^137 + 3*P^138 + P^139 + 3*P^140 + P^141 + 2*P^142 + 
    P^143 + 2*P^144 + P^145 + 2*P^146 + P^147 + 2*P^148 + P^149 + P^150 + 2*P^151 + P^152 + 2*P^153 + P^154 + 2*P^155 + P^157 + 
    2*P^159 + 2*P^161 + P^162 + 2*P^163 + P^164 + P^165 + P^166 + P^167 + P^168 + P^169 + P^170 + P^172 + P^174 + P^176 + 
    P^178 + P^180 + P^182 + P^183 + P^184 + P^185 + P^187 + P^195)/((1 - P^3)*(1 - P^91)*(1 - P^109))}, 
 {3, (P^9 + P^11 + P^13 + P^14 + P^16 + P^18 + P^24 + 2*P^26 + 2*P^28 + 2*P^30 + P^31 + 2*P^32 + P^33 + P^34 + P^35 + P^37 + 
    2*P^39 + 2*P^41 + 2*P^43 + 2*P^45 + P^46 + 2*P^47 + P^48 + 2*P^49 + P^50 + 2*P^51 + P^52 + 2*P^53 + P^54 + P^55 + 2*P^56 + 
    P^57 + 3*P^58 + 3*P^60 + P^61 + 3*P^62 + P^63 + 2*P^64 + P^65 + 2*P^66 + P^67 + 2*P^68 + P^69 + 2*P^70 + 2*P^71 + 2*P^72 + 
    3*P^73 + 2*P^74 + 3*P^75 + 2*P^76 + 3*P^77 + 2*P^78 + 3*P^79 + P^80 + 3*P^81 + P^82 + 3*P^83 + P^84 + 2*P^85 + 2*P^86 + 
    2*P^87 + 3*P^88 + 2*P^89 + 3*P^90 + 2*P^91 + 3*P^92 + 3*P^93 + 3*P^94 + 3*P^95 + 3*P^96 + 3*P^97 + 3*P^98 + 2*P^99 + 
    2*P^100 + 2*P^101 + 2*P^102 + 2*P^103 + 2*P^104 + 2*P^105 + 3*P^106 + 2*P^107 + 3*P^108 + 2*P^109 + 3*P^110 + 3*P^111 + 
    3*P^112 + 3*P^113 + 3*P^114 + 2*P^115 + 3*P^116 + P^117 + 3*P^118 + P^119 + 3*P^120 + P^121 + 2*P^122 + P^123 + 2*P^124 + 
    2*P^125 + 2*P^126 + 3*P^127 + 2*P^128 + 3*P^129 + P^130 + 3*P^131 + P^132 + 3*P^133 + P^134 + 3*P^135 + P^136 + 2*P^137 + 
    P^138 + 2*P^139 + P^140 + 2*P^141 + P^142 + 2*P^143 + P^144 + 2*P^145 + 2*P^146 + P^147 + 2*P^148 + 3*P^150 + 2*P^152 + 
    2*P^154 + P^155 + 2*P^156 + P^157 + 2*P^158 + P^159 + 2*P^160 + P^161 + P^162 + P^163 + P^165 + P^167 + P^169 + 2*P^171 + 
    2*P^173 + 2*P^175 + P^176 + P^177 + P^178 + P^180 + P^182 + P^190 + P^192 + P^194)/((1 - P^3)*(1 - P^91)*(1 - P^109))}, 
 {3, (P^8 + P^10 + P^12 + P^14 + P^16 + P^18 + P^23 + P^25 + 2*P^27 + 2*P^29 + 3*P^31 + 2*P^33 + 2*P^35 + P^37 + P^39 + P^40 + 
    P^41 + 2*P^42 + 2*P^44 + 3*P^46 + 3*P^48 + 3*P^50 + 3*P^52 + 2*P^54 + P^55 + 2*P^56 + 2*P^57 + P^58 + 2*P^59 + P^60 + 
    3*P^61 + P^62 + 3*P^63 + 3*P^65 + 3*P^67 + 3*P^69 + P^70 + 3*P^71 + P^72 + 3*P^73 + 2*P^74 + 3*P^75 + 2*P^76 + 2*P^77 + 
    3*P^78 + 2*P^79 + 3*P^80 + P^81 + 3*P^82 + P^83 + 3*P^84 + P^85 + 3*P^86 + P^87 + 3*P^88 + 2*P^89 + 3*P^90 + 2*P^91 + 
    3*P^92 + 3*P^93 + 3*P^94 + 3*P^95 + 3*P^96 + 3*P^97 + 2*P^98 + 2*P^99 + 2*P^100 + 2*P^101 + 2*P^102 + 2*P^103 + 3*P^104 + 
    2*P^105 + 3*P^106 + 2*P^107 + 3*P^108 + 2*P^109 + 3*P^110 + 3*P^111 + 3*P^112 + 3*P^113 + 2*P^114 + 3*P^115 + 2*P^116 + 
    3*P^117 + P^118 + 3*P^119 + P^120 + 3*P^121 + 3*P^123 + P^124 + 3*P^125 + P^126 + 3*P^127 + 2*P^128 + 3*P^129 + 2*P^130 + 
    2*P^131 + 2*P^132 + P^133 + 3*P^134 + P^135 + 3*P^136 + 3*P^138 + 3*P^140 + 3*P^142 + 3*P^144 + P^145 + 2*P^146 + P^147 + 
    P^148 + 2*P^149 + P^150 + 2*P^151 + 2*P^153 + 3*P^155 + 3*P^157 + 3*P^159 + 2*P^161 + 2*P^163 + P^165 + P^167 + P^168 + 
    P^170 + 2*P^172 + 2*P^174 + 2*P^176 + 2*P^178 + P^180 + P^182 + P^189 + P^191 + P^193)/((1 - P^3)*(1 - P^91)*(1 - P^109))}, 
 {3, (P^2 + P^13 + P^15 + P^17 + 2*P^19 + 2*P^21 + 2*P^23 + P^28 + P^30 + P^32 + 3*P^34 + 3*P^36 + 3*P^38 + 2*P^40 + 2*P^42 + 
    2*P^44 + P^45 + P^46 + P^47 + 3*P^49 + 3*P^51 + 3*P^53 + 3*P^55 + 3*P^57 + 3*P^59 + P^60 + 2*P^61 + P^62 + 2*P^63 + 2*P^64 + 
    2*P^65 + 3*P^66 + 2*P^67 + 3*P^68 + 3*P^70 + 3*P^72 + 3*P^74 + P^75 + 3*P^76 + P^77 + 3*P^78 + P^79 + 3*P^80 + 3*P^81 + 
    3*P^82 + 3*P^83 + 2*P^84 + 3*P^85 + 2*P^86 + 3*P^87 + 2*P^88 + 3*P^89 + P^90 + 3*P^91 + P^92 + 2*P^93 + P^94 + 3*P^95 + 
    3*P^96 + 3*P^97 + 3*P^98 + 3*P^99 + 3*P^100 + 3*P^101 + 3*P^102 + 3*P^103 + 2*P^104 + 2*P^105 + 2*P^106 + 3*P^107 + 
    2*P^108 + 3*P^109 + P^110 + 3*P^111 + P^112 + 3*P^113 + P^114 + 3*P^115 + 3*P^116 + 3*P^117 + 3*P^118 + 2*P^119 + 3*P^120 + 
    2*P^121 + 3*P^122 + 2*P^123 + 3*P^124 + 3*P^126 + 3*P^128 + 3*P^130 + P^131 + 3*P^132 + P^133 + 3*P^134 + P^135 + 2*P^136 + 
    2*P^137 + 2*P^138 + 3*P^139 + 3*P^141 + 3*P^143 + 3*P^145 + 3*P^147 + 3*P^149 + 2*P^151 + P^152 + 2*P^153 + P^154 + P^155 + 
    P^156 + P^158 + 3*P^160 + 3*P^162 + 3*P^164 + 2*P^166 + 2*P^168 + 2*P^170 + P^175 + P^177 + P^179 + 2*P^181 + 2*P^183 + 
    2*P^185 + P^196)/((1 - P^3)*(1 - P^91)*(1 - P^109))}, 
 {3, (P^6 + P^11 + P^13 + P^17 + P^19 + 2*P^21 + P^23 + P^25 + P^26 + P^27 + P^28 + P^30 + 2*P^32 + 2*P^34 + 2*P^36 + 2*P^38 + 
    2*P^40 + 2*P^42 + P^43 + 2*P^44 + P^45 + P^46 + P^47 + P^48 + 2*P^49 + P^50 + 2*P^51 + 3*P^53 + 3*P^55 + 3*P^57 + P^58 + 
    2*P^59 + P^60 + 2*P^61 + P^62 + 2*P^63 + 2*P^64 + 2*P^65 + 2*P^66 + P^67 + 3*P^68 + P^69 + 3*P^70 + P^71 + 3*P^72 + P^73 + 
    3*P^74 + P^75 + 3*P^76 + P^77 + 3*P^78 + 2*P^79 + 2*P^80 + 2*P^81 + 2*P^82 + 3*P^83 + 2*P^84 + 3*P^85 + 2*P^86 + 3*P^87 + 
    2*P^88 + 3*P^89 + 2*P^90 + 3*P^91 + 2*P^92 + 3*P^93 + 2*P^94 + 3*P^95 + 2*P^96 + 2*P^97 + 2*P^98 + 3*P^99 + 3*P^100 + 
    3*P^101 + 2*P^102 + 2*P^103 + 2*P^104 + 3*P^105 + 3*P^106 + 3*P^107 + 2*P^108 + 3*P^109 + 2*P^110 + 3*P^111 + P^112 + 
    3*P^113 + 2*P^114 + 3*P^115 + 2*P^116 + 2*P^117 + 2*P^118 + 2*P^119 + 3*P^120 + 2*P^121 + 3*P^122 + P^123 + 3*P^124 + 
    P^125 + 3*P^126 + P^127 + 3*P^128 + P^129 + 3*P^130 + P^131 + 3*P^132 + P^133 + 2*P^134 + P^135 + 2*P^136 + 2*P^137 + 
    2*P^138 + 2*P^139 + P^140 + 2*P^141 + P^142 + 3*P^143 + 3*P^145 + 3*P^147 + 2*P^149 + P^150 + 2*P^151 + P^152 + 2*P^153 + 
    P^154 + P^155 + P^156 + P^157 + 2*P^158 + 2*P^160 + 2*P^162 + 2*P^164 + 2*P^166 + 2*P^168 + P^170 + P^171 + P^172 + P^173 + 
    P^175 + P^177 + P^179 + P^181 + P^183 + P^185 + P^187 + P^189 + P^194)/((1 - P^3)*(1 - P^91)*(1 - P^109))}, 
 {3, (P^9 + P^11 + P^13 + P^14 + P^15 + P^16 + P^24 + P^26 + 2*P^28 + P^29 + 2*P^30 + P^31 + 2*P^32 + P^33 + P^34 + P^35 + 
    P^36 + P^37 + P^39 + P^41 + 2*P^43 + P^44 + 2*P^45 + P^46 + 2*P^47 + P^48 + 2*P^49 + P^50 + 2*P^51 + P^52 + 2*P^53 + P^54 + 
    P^55 + 2*P^56 + P^57 + 3*P^58 + P^59 + 3*P^60 + P^61 + 2*P^62 + P^63 + 2*P^64 + P^65 + 2*P^66 + P^67 + 2*P^68 + P^69 + 
    2*P^70 + 2*P^71 + 2*P^72 + 2*P^73 + 2*P^74 + 3*P^75 + 3*P^76 + 3*P^77 + 2*P^78 + 3*P^79 + 2*P^80 + 3*P^81 + P^82 + 2*P^83 + 
    P^84 + 2*P^85 + 2*P^86 + 2*P^87 + 2*P^88 + 2*P^89 + 3*P^90 + 3*P^91 + 3*P^92 + 3*P^93 + 3*P^94 + 3*P^95 + 3*P^96 + 3*P^97 + 
    3*P^98 + 2*P^99 + 2*P^100 + 2*P^101 + 2*P^102 + 2*P^103 + 2*P^104 + 2*P^105 + 2*P^106 + 2*P^107 + 3*P^108 + 3*P^109 + 
    3*P^110 + 3*P^111 + 3*P^112 + 3*P^113 + 3*P^114 + 2*P^115 + 3*P^116 + 2*P^117 + 3*P^118 + P^119 + 2*P^120 + P^121 + 
    2*P^122 + P^123 + 2*P^124 + 2*P^125 + 2*P^126 + 2*P^127 + 2*P^128 + 3*P^129 + 2*P^130 + 3*P^131 + 2*P^132 + 3*P^133 + 
    P^134 + 2*P^135 + P^136 + 2*P^137 + P^138 + 2*P^139 + P^140 + 2*P^141 + P^142 + 2*P^143 + P^144 + 2*P^145 + 2*P^146 + 
    P^147 + 2*P^148 + 2*P^150 + 2*P^152 + P^153 + 2*P^154 + P^155 + 2*P^156 + P^157 + 2*P^158 + P^159 + 2*P^160 + P^161 + 
    P^162 + P^163 + P^164 + P^165 + P^169 + P^171 + 2*P^173 + P^174 + 2*P^175 + P^176 + P^177 + P^178 + P^179 + P^180 + P^190 + 
    P^192 + P^194)/((1 - P^3)*(1 - P^91)*(1 - P^109))}, 
 {3, (P^6 + P^8 + P^10 + P^18 + P^20 + P^22 + P^23 + P^24 + 2*P^25 + 2*P^27 + 2*P^29 + P^31 + P^33 + P^35 + P^37 + P^38 + P^39 + 
    2*P^40 + P^41 + 2*P^42 + P^43 + 2*P^44 + P^45 + 2*P^46 + 2*P^48 + 3*P^50 + 2*P^52 + P^53 + 2*P^54 + 2*P^55 + P^56 + 2*P^57 + 
    P^58 + 2*P^59 + P^60 + 2*P^61 + P^62 + 2*P^63 + P^64 + 3*P^65 + P^66 + 3*P^67 + P^68 + 3*P^69 + P^70 + 3*P^71 + 2*P^72 + 
    3*P^73 + 2*P^74 + 2*P^75 + 2*P^76 + P^77 + 2*P^78 + P^79 + 3*P^80 + P^81 + 3*P^82 + P^83 + 3*P^84 + 2*P^85 + 3*P^86 + 
    3*P^87 + 3*P^88 + 3*P^89 + 3*P^90 + 2*P^91 + 3*P^92 + 2*P^93 + 3*P^94 + 2*P^95 + 2*P^96 + 2*P^97 + 2*P^98 + 2*P^99 + 
    2*P^100 + 2*P^101 + 3*P^102 + 3*P^103 + 3*P^104 + 3*P^105 + 3*P^106 + 3*P^107 + 3*P^108 + 2*P^109 + 3*P^110 + 2*P^111 + 
    3*P^112 + 2*P^113 + 2*P^114 + 2*P^115 + P^116 + 3*P^117 + P^118 + 3*P^119 + P^120 + 3*P^121 + 2*P^122 + 3*P^123 + 2*P^124 + 
    3*P^125 + 2*P^126 + 3*P^127 + 2*P^128 + 2*P^129 + 2*P^130 + P^131 + 2*P^132 + P^133 + 2*P^134 + P^135 + 2*P^136 + P^137 + 
    3*P^138 + P^139 + 3*P^140 + 3*P^142 + P^143 + 2*P^144 + P^145 + P^146 + 2*P^147 + P^148 + 2*P^149 + P^150 + 2*P^151 + 
    P^152 + 2*P^153 + P^154 + 2*P^155 + 2*P^157 + 2*P^159 + 2*P^161 + P^163 + P^165 + P^166 + P^167 + 2*P^168 + P^169 + 
    2*P^170 + 2*P^172 + 2*P^174 + P^176 + P^182 + P^184 + P^186 + P^187 + P^189 + P^191)/((1 - P^3)*(1 - P^91)*(1 - P^109))}, 
 {3, (P^10 + 2*P^12 + 2*P^14 + P^16 + P^25 + 2*P^27 + 3*P^29 + 3*P^31 + 3*P^33 + 2*P^35 + P^37 + P^40 + 2*P^42 + 3*P^44 + 
    3*P^46 + 3*P^48 + 3*P^50 + 3*P^52 + 3*P^54 + 2*P^56 + P^57 + 2*P^58 + 3*P^59 + P^60 + 3*P^61 + 3*P^63 + 3*P^65 + 3*P^67 + 
    3*P^69 + 3*P^71 + P^72 + 3*P^73 + 2*P^74 + 3*P^75 + 3*P^76 + 3*P^77 + 3*P^78 + 2*P^79 + 3*P^80 + P^81 + 3*P^82 + 3*P^84 + 
    3*P^86 + P^87 + 3*P^88 + 2*P^89 + 3*P^90 + 3*P^91 + 3*P^92 + 3*P^93 + 3*P^94 + 3*P^95 + 3*P^96 + 3*P^97 + 3*P^98 + 3*P^99 + 
    2*P^100 + 2*P^101 + 2*P^102 + P^103 + 2*P^104 + P^105 + 3*P^106 + 2*P^107 + 3*P^108 + 3*P^109 + 3*P^110 + 3*P^111 + 
    3*P^112 + 3*P^113 + 3*P^114 + 3*P^115 + 2*P^116 + 3*P^117 + P^118 + 3*P^119 + 3*P^121 + 3*P^123 + 3*P^125 + P^126 + 
    3*P^127 + 2*P^128 + 3*P^129 + 3*P^130 + 2*P^131 + 3*P^132 + P^133 + 3*P^134 + 3*P^136 + 3*P^138 + 3*P^140 + 3*P^142 + 
    3*P^144 + 3*P^146 + P^147 + 2*P^148 + P^149 + 2*P^151 + 3*P^153 + 3*P^155 + 3*P^157 + 3*P^159 + 3*P^161 + 2*P^163 + P^165 + 
    P^170 + 2*P^172 + 3*P^174 + 3*P^176 + 2*P^178 + P^180 + P^191 + P^193 + P^195)/((1 - P^3)*(1 - P^91)*(1 - P^109))}, 
 {3, (P^5 + P^13 + P^15 + P^16 + P^17 + P^18 + P^20 + P^22 + P^24 + P^26 + P^28 + P^30 + P^31 + P^32 + P^33 + P^34 + P^35 + 
    P^36 + 2*P^37 + P^38 + 2*P^39 + 2*P^41 + P^43 + 2*P^45 + P^46 + 2*P^47 + P^48 + 2*P^49 + P^50 + P^51 + 2*P^52 + P^53 + 
    2*P^54 + P^55 + 2*P^56 + P^57 + 2*P^58 + P^59 + 3*P^60 + P^61 + 3*P^62 + P^63 + 2*P^64 + P^65 + 2*P^66 + 2*P^67 + 2*P^68 + 
    2*P^69 + 2*P^70 + 2*P^71 + P^72 + 2*P^73 + P^74 + 3*P^75 + P^76 + 3*P^77 + 2*P^78 + 3*P^79 + 2*P^80 + 3*P^81 + 2*P^82 + 
    3*P^83 + 2*P^84 + 3*P^85 + 2*P^86 + 2*P^87 + 2*P^88 + 2*P^89 + 2*P^90 + 2*P^91 + 3*P^92 + 3*P^93 + 3*P^94 + 2*P^95 + 
    2*P^96 + 2*P^97 + 3*P^98 + 3*P^99 + 3*P^100 + 3*P^101 + 3*P^102 + 3*P^103 + 2*P^104 + 2*P^105 + 2*P^106 + 2*P^107 + 
    2*P^108 + 2*P^109 + 3*P^110 + 2*P^111 + 3*P^112 + 2*P^113 + 3*P^114 + 2*P^115 + 3*P^116 + 2*P^117 + 3*P^118 + 2*P^119 + 
    3*P^120 + 2*P^121 + 2*P^122 + 2*P^123 + 2*P^124 + 2*P^125 + 2*P^126 + 2*P^127 + P^128 + 2*P^129 + P^130 + 3*P^131 + P^132 + 
    3*P^133 + 2*P^134 + 3*P^135 + P^136 + 2*P^137 + P^138 + 2*P^139 + P^140 + 2*P^141 + 2*P^142 + P^143 + 2*P^144 + P^145 + 
    2*P^146 + P^147 + 2*P^148 + P^149 + 2*P^150 + 2*P^152 + 2*P^154 + P^155 + 2*P^156 + P^157 + P^158 + P^159 + P^160 + P^161 + 
    P^162 + 2*P^163 + P^164 + 2*P^165 + 2*P^167 + P^169 + P^171 + P^173 + P^175 + P^177 + P^178 + P^179 + P^180 + P^181 + 
    P^182 + P^186 + P^188 + P^196)/((1 - P^3)*(1 - P^91)*(1 - P^109))}, 
 {3, (P^5 + P^10 + P^12 + P^17 + P^19 + P^21 + P^22 + P^23 + P^24 + P^26 + P^27 + P^28 + P^29 + P^31 + P^33 + P^34 + P^35 + 
    P^36 + P^37 + P^38 + P^39 + P^40 + P^41 + 2*P^42 + P^43 + 2*P^44 + P^45 + P^46 + P^47 + P^48 + 2*P^49 + P^50 + P^51 + 
    2*P^52 + P^53 + 2*P^54 + P^55 + 2*P^56 + 2*P^57 + P^58 + 2*P^59 + P^60 + 2*P^61 + P^62 + 2*P^63 + 2*P^64 + 2*P^65 + 2*P^66 + 
    2*P^67 + 2*P^68 + 2*P^69 + 2*P^70 + 2*P^71 + 2*P^72 + 2*P^73 + 2*P^74 + 2*P^75 + 2*P^76 + 2*P^77 + 2*P^78 + 2*P^79 + 
    2*P^80 + 2*P^81 + 2*P^82 + 2*P^83 + 3*P^84 + 2*P^85 + 3*P^86 + 2*P^87 + 3*P^88 + 3*P^89 + 2*P^90 + 3*P^91 + 2*P^92 + 
    3*P^93 + 2*P^94 + 2*P^95 + 2*P^96 + 2*P^97 + 3*P^98 + 3*P^99 + 3*P^100 + 2*P^101 + 2*P^102 + 2*P^103 + 3*P^104 + 3*P^105 + 
    3*P^106 + 3*P^107 + 2*P^108 + 3*P^109 + 2*P^110 + 3*P^111 + 2*P^112 + 2*P^113 + 2*P^114 + 2*P^115 + 3*P^116 + 2*P^117 + 
    2*P^118 + 2*P^119 + 2*P^120 + 3*P^121 + 2*P^122 + 3*P^123 + 2*P^124 + 2*P^125 + 2*P^126 + 2*P^127 + 2*P^128 + 2*P^129 + 
    2*P^130 + 2*P^131 + 2*P^132 + P^133 + 2*P^134 + P^135 + 2*P^136 + 2*P^137 + 2*P^138 + 2*P^139 + P^140 + 2*P^141 + 2*P^142 + 
    P^143 + 2*P^144 + P^145 + 2*P^146 + P^147 + P^148 + 2*P^149 + P^150 + 2*P^151 + P^152 + 2*P^153 + P^154 + P^155 + P^156 + 
    P^157 + P^158 + P^159 + P^160 + P^161 + P^162 + P^163 + P^164 + P^165 + P^166 + P^167 + P^168 + P^169 + P^170 + P^171 + 
    P^172 + P^173 + P^174 + P^176 + P^178 + P^181 + P^183 + P^185 + P^186 + P^188 + P^193)/((1 - P^3)*(1 - P^91)*(1 - P^109))}, 
 {3, (P^2 + 2*P^16 + 2*P^18 + P^19 + 2*P^20 + P^21 + P^23 + 2*P^31 + 2*P^33 + P^34 + 2*P^35 + P^36 + 2*P^37 + P^38 + 2*P^39 + 
    P^40 + 2*P^41 + P^42 + P^44 + 2*P^46 + 2*P^48 + P^49 + 2*P^50 + P^51 + 2*P^52 + P^53 + 2*P^54 + P^55 + 2*P^56 + P^57 + 
    2*P^58 + P^59 + 2*P^60 + P^61 + 2*P^62 + 3*P^63 + 2*P^64 + 3*P^65 + P^66 + 3*P^67 + P^68 + 2*P^69 + P^70 + 2*P^71 + P^72 + 
    2*P^73 + P^74 + 2*P^75 + P^76 + 2*P^77 + 3*P^78 + 2*P^79 + 3*P^80 + 3*P^81 + 3*P^82 + 3*P^83 + 3*P^84 + 3*P^85 + 3*P^86 + 
    P^87 + 3*P^88 + P^89 + 2*P^90 + P^91 + 2*P^92 + 2*P^93 + 2*P^94 + 3*P^95 + 3*P^96 + 3*P^97 + 3*P^98 + 3*P^99 + 3*P^100 + 
    3*P^101 + 3*P^102 + 3*P^103 + 3*P^104 + 3*P^105 + 3*P^106 + P^107 + 2*P^108 + P^109 + 2*P^110 + P^111 + 2*P^112 + 3*P^113 + 
    2*P^114 + 3*P^115 + 3*P^116 + 3*P^117 + 3*P^118 + 3*P^119 + 3*P^120 + 3*P^121 + P^122 + 3*P^123 + P^124 + 2*P^125 + P^126 + 
    2*P^127 + P^128 + 2*P^129 + P^130 + 2*P^131 + P^132 + 2*P^133 + 3*P^134 + 2*P^135 + 3*P^136 + P^137 + 3*P^138 + P^139 + 
    2*P^140 + P^141 + 2*P^142 + P^143 + 2*P^144 + P^145 + 2*P^146 + P^147 + 2*P^148 + P^149 + 2*P^150 + P^151 + 2*P^152 + 
    P^153 + P^155 + 2*P^157 + 2*P^159 + P^160 + 2*P^161 + P^162 + 2*P^163 + P^164 + 2*P^165 + P^166 + 2*P^167 + P^168 + P^170 + 
    2*P^178 + 2*P^180 + P^181 + 2*P^182 + P^183 + P^185 + P^199)/((1 - P^3)*(1 - P^91)*(1 - P^109))}, 
 {3, (P^3 + P^11 + P^13 + P^18 + 2*P^20 + 2*P^22 + 2*P^24 + P^26 + P^28 + P^30 + P^32 + P^34 + 2*P^35 + P^36 + 2*P^37 + 2*P^39 + 
    2*P^41 + 3*P^43 + 3*P^45 + 2*P^47 + P^49 + 2*P^50 + P^51 + 2*P^52 + P^53 + 2*P^54 + P^55 + 2*P^56 + P^57 + 3*P^58 + 3*P^60 + 
    3*P^62 + 3*P^64 + P^65 + 3*P^66 + 2*P^67 + 3*P^68 + 2*P^69 + P^70 + 2*P^71 + P^72 + 3*P^73 + P^74 + 3*P^75 + P^76 + 3*P^77 + 
    P^78 + 3*P^79 + P^80 + 3*P^81 + 2*P^82 + 3*P^83 + 2*P^84 + 3*P^85 + 2*P^86 + 3*P^87 + 2*P^88 + 3*P^89 + 3*P^90 + 2*P^91 + 
    3*P^92 + P^93 + 2*P^94 + P^95 + 3*P^96 + 3*P^97 + 3*P^98 + 3*P^99 + 3*P^100 + 3*P^101 + 2*P^102 + 2*P^103 + 2*P^104 + 
    3*P^105 + 3*P^106 + 3*P^107 + 3*P^108 + 2*P^109 + 3*P^110 + P^111 + 3*P^112 + P^113 + 3*P^114 + P^115 + 3*P^116 + 2*P^117 + 
    3*P^118 + 2*P^119 + 3*P^120 + 2*P^121 + 3*P^122 + 2*P^123 + 3*P^124 + 2*P^125 + P^126 + 2*P^127 + P^128 + 3*P^129 + P^130 + 
    3*P^131 + P^132 + 3*P^133 + 3*P^135 + 3*P^137 + P^138 + 3*P^139 + 2*P^140 + P^141 + 2*P^142 + P^143 + 2*P^144 + P^145 + 
    2*P^146 + P^147 + 2*P^148 + 3*P^150 + 3*P^152 + 3*P^154 + 2*P^156 + P^158 + P^160 + 2*P^161 + P^162 + 2*P^163 + 2*P^165 + 
    2*P^167 + 2*P^169 + 2*P^171 + P^173 + P^175 + P^177 + P^179 + P^182 + 2*P^184 + 2*P^186 + P^194)/
   ((1 - P^3)*(1 - P^91)*(1 - P^109))}, {3, (P^5 + P^13 + P^15 + P^16 + P^18 + 2*P^20 + P^22 + P^24 + P^26 + P^28 + P^30 + 
    P^31 + P^32 + P^33 + P^34 + P^35 + P^36 + 2*P^37 + P^38 + 2*P^39 + 2*P^41 + 2*P^43 + 2*P^45 + 2*P^47 + P^48 + 2*P^49 + 
    P^50 + P^51 + 2*P^52 + P^53 + 2*P^54 + P^55 + 2*P^56 + P^57 + 2*P^58 + P^59 + 3*P^60 + 3*P^62 + P^63 + 3*P^64 + P^65 + 
    2*P^66 + 2*P^67 + 2*P^68 + 2*P^69 + 2*P^70 + 2*P^71 + P^72 + 2*P^73 + P^74 + 3*P^75 + P^76 + 3*P^77 + 2*P^78 + 3*P^79 + 
    2*P^80 + 3*P^81 + 2*P^82 + 3*P^83 + 2*P^84 + 3*P^85 + 2*P^86 + 2*P^87 + 2*P^88 + 2*P^89 + 3*P^90 + 2*P^91 + 3*P^92 + 
    2*P^93 + 3*P^94 + 2*P^95 + 2*P^96 + 2*P^97 + 3*P^98 + 3*P^99 + 3*P^100 + 3*P^101 + 3*P^102 + 3*P^103 + 2*P^104 + 2*P^105 + 
    2*P^106 + 2*P^107 + 3*P^108 + 2*P^109 + 3*P^110 + P^111 + 3*P^112 + 2*P^113 + 3*P^114 + 2*P^115 + 3*P^116 + 2*P^117 + 
    3*P^118 + 2*P^119 + 3*P^120 + 2*P^121 + 2*P^122 + 2*P^123 + 2*P^124 + 2*P^125 + 2*P^126 + 2*P^127 + P^128 + 2*P^129 + 
    P^130 + 3*P^131 + P^132 + 3*P^133 + P^134 + 3*P^135 + P^136 + 3*P^137 + P^138 + 2*P^139 + P^140 + 2*P^141 + 2*P^142 + 
    P^143 + 2*P^144 + P^145 + 2*P^146 + P^147 + 2*P^148 + P^149 + 2*P^150 + 3*P^152 + 2*P^154 + 2*P^156 + P^157 + P^158 + 
    P^159 + P^160 + P^161 + P^162 + 2*P^163 + P^164 + 2*P^165 + 2*P^167 + P^169 + P^171 + P^173 + P^175 + P^177 + P^178 + 
    P^179 + P^180 + P^182 + P^184 + P^186 + P^188 + P^196)/((1 - P^3)*(1 - P^91)*(1 - P^109))}, 
 {3, (P^6 + P^8 + P^10 + P^20 + P^21 + P^22 + P^23 + P^24 + 2*P^25 + P^26 + 2*P^27 + P^29 + P^31 + P^35 + P^36 + P^37 + P^38 + 
    P^39 + 2*P^40 + P^41 + 2*P^42 + P^43 + 2*P^44 + P^45 + 2*P^46 + P^47 + 2*P^48 + 2*P^50 + 2*P^52 + P^53 + 2*P^54 + 2*P^55 + 
    P^56 + 2*P^57 + P^58 + 2*P^59 + P^60 + 2*P^61 + P^62 + 2*P^63 + P^64 + 2*P^65 + P^66 + 3*P^67 + 2*P^68 + 3*P^69 + 2*P^70 + 
    3*P^71 + 2*P^72 + 2*P^73 + 2*P^74 + 2*P^75 + 2*P^76 + P^77 + 2*P^78 + P^79 + 2*P^80 + P^81 + 3*P^82 + 2*P^83 + 3*P^84 + 
    2*P^85 + 3*P^86 + 3*P^87 + 3*P^88 + 3*P^89 + 3*P^90 + 3*P^91 + 3*P^92 + 2*P^93 + 2*P^94 + 2*P^95 + 2*P^96 + 2*P^97 + 
    2*P^98 + 2*P^99 + 2*P^100 + 2*P^101 + 3*P^102 + 3*P^103 + 3*P^104 + 3*P^105 + 3*P^106 + 3*P^107 + 3*P^108 + 3*P^109 + 
    3*P^110 + 2*P^111 + 2*P^112 + 2*P^113 + 2*P^114 + 2*P^115 + P^116 + 2*P^117 + P^118 + 3*P^119 + 2*P^120 + 3*P^121 + 
    2*P^122 + 3*P^123 + 3*P^124 + 3*P^125 + 2*P^126 + 2*P^127 + 2*P^128 + 2*P^129 + 2*P^130 + P^131 + 2*P^132 + P^133 + 
    2*P^134 + P^135 + 2*P^136 + P^137 + 2*P^138 + P^139 + 3*P^140 + P^141 + 3*P^142 + P^143 + 2*P^144 + P^145 + P^146 + 
    2*P^147 + P^148 + 2*P^149 + P^150 + 2*P^151 + P^152 + 2*P^153 + P^154 + 2*P^155 + P^156 + 2*P^157 + P^159 + P^161 + P^163 + 
    P^164 + P^165 + P^166 + P^167 + 2*P^168 + P^169 + 2*P^170 + P^171 + 2*P^172 + P^174 + P^176 + P^184 + P^185 + P^186 + 
    P^187 + P^189 + P^191)/((1 - P^3)*(1 - P^91)*(1 - P^109))}, 
 {3, (P^5 + P^7 + P^9 + P^20 + 2*P^22 + 3*P^24 + 3*P^26 + 2*P^28 + P^30 + P^35 + 2*P^37 + 3*P^39 + 3*P^41 + 3*P^43 + 3*P^45 + 
    3*P^47 + 2*P^49 + P^51 + 2*P^52 + P^53 + 3*P^54 + 3*P^56 + 3*P^58 + 3*P^60 + 3*P^62 + 3*P^64 + 3*P^66 + P^67 + 3*P^68 + 
    2*P^69 + 3*P^70 + 3*P^71 + 2*P^72 + 3*P^73 + P^74 + 3*P^75 + 3*P^77 + 3*P^79 + 3*P^81 + P^82 + 3*P^83 + 2*P^84 + 3*P^85 + 
    3*P^86 + 3*P^87 + 3*P^88 + 3*P^89 + 3*P^90 + 3*P^91 + 3*P^92 + 2*P^93 + 3*P^94 + P^95 + 2*P^96 + P^97 + 2*P^98 + 2*P^99 + 
    2*P^100 + 3*P^101 + 3*P^102 + 3*P^103 + 3*P^104 + 3*P^105 + 3*P^106 + 3*P^107 + 3*P^108 + 3*P^109 + 3*P^110 + 2*P^111 + 
    3*P^112 + P^113 + 3*P^114 + 3*P^116 + 3*P^118 + P^119 + 3*P^120 + 2*P^121 + 3*P^122 + 3*P^123 + 3*P^124 + 3*P^125 + 
    2*P^126 + 3*P^127 + P^128 + 3*P^129 + 3*P^131 + 3*P^133 + 3*P^135 + 3*P^137 + 3*P^139 + P^140 + 3*P^141 + 2*P^142 + P^143 + 
    2*P^144 + 3*P^146 + 3*P^148 + 3*P^150 + 3*P^152 + 3*P^154 + 3*P^156 + 2*P^158 + P^160 + P^163 + 2*P^165 + 3*P^167 + 
    3*P^169 + 3*P^171 + 2*P^173 + P^175 + P^184 + 2*P^186 + 2*P^188 + P^190)/((1 - P^3)*(1 - P^91)*(1 - P^109))}, 
 {3, (P^4 + P^12 + P^14 + P^16 + P^18 + P^20 + P^21 + P^22 + P^23 + P^25 + P^27 + P^29 + P^31 + 2*P^33 + 2*P^35 + P^36 + 
    2*P^37 + P^38 + P^39 + P^40 + P^41 + P^42 + P^43 + 2*P^44 + 2*P^46 + 3*P^48 + 2*P^50 + P^51 + 2*P^52 + P^53 + 2*P^54 + 
    P^55 + 2*P^56 + P^57 + 2*P^58 + 2*P^59 + P^60 + 2*P^61 + P^62 + 3*P^63 + P^64 + 3*P^65 + P^66 + 3*P^67 + P^68 + 3*P^69 + 
    P^70 + 2*P^71 + P^72 + 2*P^73 + 2*P^74 + 2*P^75 + 2*P^76 + 2*P^77 + 2*P^78 + 2*P^79 + 3*P^80 + 2*P^81 + 3*P^82 + 2*P^83 + 
    3*P^84 + 2*P^85 + 3*P^86 + 2*P^87 + 3*P^88 + P^89 + 3*P^90 + 2*P^91 + 3*P^92 + 2*P^93 + 2*P^94 + 2*P^95 + 2*P^96 + 3*P^97 + 
    3*P^98 + 3*P^99 + 3*P^100 + 3*P^101 + 3*P^102 + 2*P^103 + 2*P^104 + 2*P^105 + 3*P^106 + 2*P^107 + 3*P^108 + 2*P^109 + 
    3*P^110 + 2*P^111 + 2*P^112 + 2*P^113 + 2*P^114 + 3*P^115 + 2*P^116 + 3*P^117 + 2*P^118 + 3*P^119 + 2*P^120 + 3*P^121 + 
    2*P^122 + 3*P^123 + P^124 + 3*P^125 + P^126 + 2*P^127 + P^128 + 2*P^129 + 2*P^130 + 2*P^131 + 2*P^132 + 2*P^133 + 2*P^134 + 
    P^135 + 3*P^136 + P^137 + 3*P^138 + 3*P^140 + P^141 + 2*P^142 + P^143 + 2*P^144 + P^145 + 2*P^146 + P^147 + 2*P^148 + 
    P^149 + P^150 + 2*P^151 + P^152 + 2*P^153 + 2*P^155 + 2*P^157 + 2*P^159 + 2*P^161 + P^162 + 2*P^163 + P^164 + P^165 + 
    P^166 + P^167 + P^168 + P^169 + P^170 + P^172 + P^174 + P^176 + P^178 + 2*P^180 + P^182 + P^184 + P^185 + P^187 + P^195)/
   ((1 - P^3)*(1 - P^91)*(1 - P^109))}};
Generating43=ToExpression[Import["./SUtreeData/Generating43.mml","MathML"]];
Generating44=ToExpression[Import["./SUtreeData/Generating44.mml","MathML"]];
Generating45=ToExpression[Import["./SUtreeData/Generating45.mml","MathML"]];
Generating46=ToExpression[Import["./SUtreeData/Generating46.mml","MathML"]];
Generating47=ToExpression[Import["./SUtreeData/Generating47.mml","MathML"]];
Generating48=ToExpression[Import["./SUtreeData/Generating48.mml","MathML"]];
Generating49=ToExpression[Import["./SUtreeData/Generating49.mml","MathML"]];
Generating50={{1, (1 + P^17 + P^22 + P^27 + P^32 + P^34 + P^39 + P^44 + P^46 + P^49 + P^51 + P^54 + P^56 + P^59 + P^63 + P^64 + P^66 + 
    P^68 + P^71 + P^73 + P^75 + P^76 + P^80 + P^81 + P^85 + P^86 + P^90 + P^91 + P^92 + P^96 + P^97 + P^98 + P^102 + P^103 + 
    P^104 + P^108 + P^109 + P^113 + P^114 + P^118 + P^119 + P^121 + P^123 + P^126 + P^128 + P^130 + P^131 + P^135 + P^138 + 
    P^140 + P^143 + P^145 + P^148 + P^150 + P^155 + P^160 + P^162 + P^167 + P^172 + P^177 + P^194)/
   ((1 - P^3)*(1 - P^61)*(1 - P^133))}, {1, (P^17 + P^22 + P^27 + P^32 + P^34 + P^39 + P^44 + P^46 + P^49 + P^51 + P^54 + 
    P^56 + P^59 + P^61 + P^63 + P^64 + P^66 + P^68 + P^71 + P^73 + P^75 + P^76 + P^80 + P^81 + P^85 + P^86 + P^90 + P^91 + 
    P^92 + P^96 + P^97 + P^98 + P^102 + P^103 + P^104 + P^108 + P^109 + P^113 + P^114 + P^118 + P^119 + P^121 + P^123 + P^126 + 
    P^128 + P^130 + P^131 + P^133 + P^135 + P^138 + P^140 + P^143 + P^145 + P^148 + P^150 + P^155 + P^160 + P^162 + P^167 + 
    P^172 + P^177)/((1 - P^3)*(1 - P^61)*(1 - P^133))}, 
 {1, (P^17 + P^22 + P^27 + P^32 + P^34 + P^39 + P^44 + P^46 + P^49 + P^51 + P^54 + P^56 + P^59 + P^61 + P^63 + P^64 + P^66 + 
    P^68 + P^71 + P^73 + P^75 + P^76 + P^80 + P^81 + P^85 + P^86 + P^90 + P^91 + P^92 + P^96 + P^97 + P^98 + P^102 + P^103 + 
    P^104 + P^108 + P^109 + P^113 + P^114 + P^118 + P^119 + P^121 + P^123 + P^126 + P^128 + P^130 + P^131 + P^133 + P^135 + 
    P^138 + P^140 + P^143 + P^145 + P^148 + P^150 + P^155 + P^160 + P^162 + P^167 + P^172 + P^177)/
   ((1 - P^3)*(1 - P^61)*(1 - P^133))}, {3, (P^8 + P^13 + P^15 + P^16 + P^20 + P^21 + P^25 + P^26 + P^27 + P^28 + P^30 + P^32 + 
    P^33 + P^35 + 2*P^37 + P^38 + P^40 + 2*P^42 + P^43 + P^44 + 2*P^45 + 2*P^47 + P^48 + P^49 + P^50 + 2*P^52 + P^53 + 2*P^54 + 
    P^55 + P^56 + 2*P^57 + P^58 + 2*P^59 + P^60 + P^61 + 2*P^62 + 2*P^64 + P^65 + 2*P^66 + 2*P^67 + P^69 + P^70 + 2*P^71 + 
    2*P^72 + P^73 + 2*P^74 + P^75 + P^76 + P^77 + P^78 + 3*P^79 + P^80 + P^81 + 2*P^83 + 3*P^84 + 2*P^85 + P^86 + P^88 + 
    2*P^89 + 2*P^90 + 2*P^91 + P^92 + P^93 + P^94 + 2*P^95 + 2*P^96 + P^97 + P^99 + 2*P^100 + 2*P^101 + 2*P^102 + P^103 + 
    P^104 + P^105 + P^106 + 2*P^107 + P^108 + P^109 + P^110 + 2*P^111 + 3*P^112 + P^113 + P^114 + 2*P^116 + 2*P^117 + P^118 + 
    P^119 + P^120 + 2*P^121 + 2*P^122 + P^123 + 2*P^124 + P^125 + P^126 + P^127 + P^128 + 3*P^129 + P^130 + 2*P^131 + P^132 + 
    P^133 + 2*P^134 + 2*P^136 + P^137 + P^138 + 2*P^139 + 2*P^141 + P^142 + 2*P^143 + P^144 + P^146 + P^147 + 2*P^148 + P^149 + 
    P^151 + 2*P^153 + P^154 + P^155 + P^156 + 2*P^158 + P^159 + P^160 + P^161 + P^163 + P^165 + P^166 + P^168 + P^170 + P^171 + 
    P^175 + P^176 + P^180 + P^185 + P^187)/((1 - P^3)*(1 - P^61)*(1 - P^133))}, 
 {3, (P^7 + P^9 + P^14 + P^18 + P^19 + P^23 + P^24 + P^26 + P^28 + P^29 + P^31 + P^33 + P^34 + P^35 + 2*P^36 + P^38 + P^39 + 
    P^40 + 2*P^41 + P^43 + P^45 + 2*P^46 + P^47 + P^48 + P^50 + 2*P^51 + P^52 + 2*P^53 + 2*P^55 + P^56 + P^57 + 2*P^58 + 
    2*P^60 + P^61 + P^62 + 2*P^63 + P^64 + 3*P^65 + P^66 + P^67 + P^68 + P^69 + 2*P^70 + P^71 + 2*P^72 + 2*P^73 + P^74 + P^75 + 
    P^76 + 2*P^77 + 2*P^78 + P^80 + P^81 + 3*P^82 + 2*P^83 + P^84 + P^85 + P^86 + 2*P^87 + P^88 + P^89 + P^90 + P^91 + 2*P^92 + 
    2*P^93 + 2*P^94 + P^95 + P^97 + 2*P^98 + 2*P^99 + P^100 + P^101 + P^102 + 2*P^103 + 2*P^104 + 2*P^105 + P^106 + P^108 + 
    2*P^109 + 3*P^110 + 2*P^111 + P^113 + P^114 + 3*P^115 + P^116 + P^117 + P^118 + P^119 + 2*P^120 + P^121 + 2*P^122 + 
    2*P^123 + P^124 + P^125 + 2*P^127 + 2*P^128 + P^129 + 2*P^130 + 2*P^132 + P^133 + P^134 + 2*P^135 + P^136 + 2*P^137 + 
    P^138 + P^139 + 2*P^140 + P^141 + 2*P^142 + P^144 + P^145 + P^146 + 2*P^147 + 2*P^149 + P^150 + P^151 + 2*P^152 + P^154 + 
    P^156 + 2*P^157 + P^159 + P^161 + P^162 + P^164 + P^166 + P^167 + P^168 + P^169 + P^173 + P^174 + P^178 + P^179 + P^181 + 
    P^186)/((1 - P^3)*(1 - P^61)*(1 - P^133))}, 
 {3, (P^6 + P^11 + P^13 + P^18 + P^20 + P^23 + 2*P^25 + P^28 + 2*P^30 + P^32 + P^33 + 2*P^35 + P^37 + P^38 + 2*P^40 + 2*P^42 + 
    P^43 + 2*P^45 + 2*P^47 + P^49 + 2*P^50 + 3*P^52 + 2*P^54 + P^55 + 3*P^57 + 2*P^59 + P^60 + P^61 + 3*P^62 + 2*P^64 + P^65 + 
    P^66 + 2*P^67 + 3*P^69 + P^70 + 2*P^71 + P^72 + 2*P^74 + P^75 + 2*P^76 + 2*P^77 + P^78 + 2*P^79 + 2*P^81 + 2*P^82 + 
    2*P^83 + 2*P^84 + P^86 + P^87 + 2*P^88 + 2*P^89 + P^90 + P^91 + P^92 + P^93 + 2*P^94 + P^95 + P^96 + P^97 + 2*P^98 + 
    2*P^99 + 2*P^100 + P^101 + P^102 + P^103 + P^104 + 2*P^105 + P^106 + 2*P^107 + P^108 + 2*P^109 + 2*P^110 + P^111 + 
    2*P^112 + 2*P^114 + P^115 + 2*P^116 + 2*P^117 + 2*P^119 + P^120 + 2*P^121 + P^122 + 2*P^124 + P^125 + 2*P^126 + 2*P^127 + 
    3*P^129 + 2*P^131 + P^132 + P^133 + 3*P^134 + 2*P^136 + P^137 + P^138 + 2*P^139 + 3*P^141 + P^143 + P^144 + 3*P^146 + 
    2*P^148 + P^149 + 2*P^151 + 2*P^153 + P^154 + 2*P^156 + 2*P^158 + P^161 + 2*P^163 + P^165 + P^166 + P^168 + P^170 + P^173 + 
    P^175 + P^178 + P^180 + P^183 + P^185)/((1 - P^3)*(1 - P^61)*(1 - P^133))}, 
 {3, (P^4 + P^12 + P^17 + P^18 + P^21 + P^22 + P^23 + P^26 + P^28 + P^29 + P^31 + 2*P^33 + P^34 + P^35 + P^36 + P^38 + P^39 + 
    P^40 + P^41 + P^43 + P^44 + P^45 + P^46 + P^47 + P^48 + P^49 + 2*P^50 + P^51 + P^52 + P^53 + P^54 + 2*P^55 + P^56 + P^57 + 
    2*P^58 + 2*P^60 + P^61 + 2*P^62 + 2*P^63 + P^64 + P^65 + P^66 + 2*P^67 + 2*P^68 + P^69 + 2*P^70 + P^71 + 2*P^72 + P^74 + 
    2*P^75 + 2*P^76 + 2*P^77 + P^79 + 2*P^80 + 2*P^81 + P^82 + P^84 + 2*P^85 + 2*P^86 + 2*P^87 + P^88 + P^89 + P^90 + 2*P^91 + 
    2*P^92 + 2*P^93 + P^95 + P^96 + 2*P^97 + 2*P^98 + P^99 + P^100 + P^101 + 2*P^102 + 2*P^103 + 2*P^104 + P^105 + P^106 + 
    P^107 + 2*P^108 + 2*P^109 + P^110 + P^112 + 2*P^113 + 2*P^114 + P^115 + P^116 + P^117 + 2*P^118 + P^119 + 2*P^120 + P^121 + 
    2*P^122 + P^123 + P^124 + 2*P^125 + P^126 + 2*P^127 + P^129 + 2*P^130 + P^131 + 2*P^132 + P^133 + 2*P^134 + 2*P^135 + 
    P^136 + P^137 + P^138 + 2*P^139 + P^140 + P^141 + P^142 + P^143 + 2*P^144 + P^145 + P^146 + P^147 + 2*P^149 + P^150 + 
    P^151 + P^152 + P^154 + P^155 + P^156 + P^157 + P^159 + P^160 + P^161 + P^162 + P^164 + P^166 + P^167 + P^168 + P^171 + 
    P^172 + P^173 + P^176 + P^178 + P^181 + P^189)/((1 - P^3)*(1 - P^61)*(1 - P^133))}, 
 {3, (P^10 + P^14 + 2*P^15 + P^19 + P^20 + P^25 + P^26 + 2*P^27 + P^31 + 2*P^32 + P^36 + 2*P^37 + P^39 + P^41 + 2*P^42 + P^43 + 
    2*P^44 + P^46 + 2*P^47 + P^48 + 2*P^49 + P^51 + P^52 + P^53 + 2*P^54 + P^55 + 2*P^56 + P^57 + P^58 + 2*P^59 + P^60 + 
    2*P^61 + P^63 + 2*P^64 + P^65 + 2*P^66 + 2*P^68 + 2*P^69 + P^70 + P^71 + P^72 + 3*P^73 + 2*P^74 + P^77 + 3*P^78 + 2*P^79 + 
    P^81 + P^82 + 3*P^83 + 2*P^84 + 2*P^85 + P^86 + P^88 + 2*P^89 + 3*P^90 + 2*P^91 + P^94 + 3*P^95 + 2*P^96 + P^97 + P^99 + 
    2*P^100 + 3*P^101 + 2*P^102 + P^105 + 3*P^106 + 2*P^107 + P^110 + 3*P^111 + 2*P^112 + P^113 + P^114 + P^115 + 2*P^116 + 
    P^117 + 2*P^118 + 2*P^119 + P^120 + P^121 + P^122 + 3*P^123 + 2*P^124 + P^126 + P^127 + 3*P^128 + P^129 + P^130 + 2*P^131 + 
    P^132 + 2*P^133 + P^135 + 2*P^136 + P^137 + 2*P^138 + P^140 + 2*P^141 + P^142 + 2*P^143 + P^145 + P^146 + P^147 + 2*P^148 + 
    P^150 + P^152 + 2*P^153 + P^154 + 2*P^155 + P^157 + P^158 + P^159 + 2*P^160 + P^164 + 2*P^165 + P^169 + 2*P^170 + P^174 + 
    P^175 + P^182 + P^186 + P^187)/((1 - P^3)*(1 - P^61)*(1 - P^133))}, 
 {3, (P^9 + P^11 + P^14 + P^16 + P^19 + P^21 + P^24 + P^26 + P^28 + P^29 + 2*P^31 + P^33 + 2*P^36 + 2*P^38 + P^40 + 2*P^41 + 
    2*P^43 + P^45 + 2*P^46 + 3*P^48 + P^50 + P^51 + 3*P^53 + 2*P^55 + P^56 + P^57 + 2*P^58 + 3*P^60 + P^61 + P^62 + 2*P^63 + 
    3*P^65 + 2*P^67 + 2*P^68 + P^69 + 2*P^70 + P^72 + 2*P^73 + P^74 + 2*P^75 + 2*P^77 + 2*P^78 + P^79 + 2*P^80 + 2*P^82 + 
    P^83 + 2*P^84 + 2*P^85 + P^86 + 2*P^87 + P^88 + 2*P^89 + P^90 + P^91 + P^92 + P^93 + 2*P^94 + 2*P^95 + 2*P^96 + P^97 + 
    P^98 + P^99 + 2*P^100 + P^101 + P^102 + P^103 + P^104 + 2*P^105 + 2*P^106 + P^107 + P^108 + 2*P^110 + 2*P^111 + 2*P^112 + 
    2*P^113 + 2*P^115 + P^116 + 2*P^117 + 2*P^118 + P^119 + 2*P^120 + P^122 + 2*P^123 + P^124 + 3*P^125 + 2*P^127 + P^128 + 
    P^129 + 2*P^130 + 3*P^132 + P^133 + P^134 + 2*P^135 + 3*P^137 + P^139 + 2*P^140 + 3*P^142 + 2*P^144 + P^145 + 2*P^147 + 
    2*P^149 + P^151 + 2*P^152 + 2*P^154 + P^156 + P^157 + 2*P^159 + P^161 + P^162 + 2*P^164 + P^166 + 2*P^169 + P^171 + P^174 + 
    P^176 + P^181 + P^183 + P^188)/((1 - P^3)*(1 - P^61)*(1 - P^133))}, 
 {3, (P^7 + P^8 + P^12 + P^19 + P^20 + 2*P^24 + P^25 + 2*P^29 + P^30 + 2*P^34 + P^35 + P^36 + P^37 + 2*P^39 + P^40 + 2*P^41 + 
    P^42 + P^44 + 2*P^46 + P^47 + P^48 + P^49 + 2*P^51 + P^52 + 2*P^53 + P^54 + 2*P^56 + P^57 + 2*P^58 + P^59 + 2*P^61 + P^62 + 
    2*P^63 + P^64 + P^65 + 3*P^66 + P^67 + P^68 + 2*P^70 + 3*P^71 + P^72 + P^73 + P^74 + 2*P^75 + 2*P^76 + P^77 + 2*P^78 + 
    P^79 + P^80 + P^81 + 2*P^82 + 3*P^83 + P^84 + 2*P^87 + 3*P^88 + P^89 + 2*P^92 + 3*P^93 + 2*P^94 + P^95 + P^97 + 2*P^98 + 
    3*P^99 + P^100 + 2*P^103 + 3*P^104 + 2*P^105 + P^106 + P^108 + 2*P^109 + 2*P^110 + 3*P^111 + P^112 + P^113 + 2*P^115 + 
    3*P^116 + P^117 + 2*P^120 + 3*P^121 + P^122 + P^123 + P^124 + 2*P^125 + 2*P^126 + 2*P^128 + P^129 + 2*P^130 + P^131 + 
    2*P^133 + P^134 + 2*P^135 + P^136 + P^137 + 2*P^138 + P^139 + 2*P^140 + P^141 + P^142 + P^143 + 2*P^145 + P^146 + 2*P^147 + 
    P^148 + 2*P^150 + P^151 + 2*P^152 + P^153 + P^155 + 2*P^157 + P^158 + 2*P^162 + P^163 + 2*P^167 + P^168 + P^169 + P^174 + 
    P^175 + 2*P^179 + P^180 + P^184)/((1 - P^3)*(1 - P^61)*(1 - P^133))}, 
 {3, (P^5 + P^13 + P^16 + P^18 + P^21 + P^22 + P^23 + P^26 + P^27 + P^28 + P^30 + P^32 + P^33 + P^34 + P^35 + P^37 + P^38 + 
    P^39 + P^40 + P^42 + P^43 + P^44 + 2*P^45 + P^47 + P^48 + P^49 + 2*P^50 + P^51 + P^52 + P^53 + P^54 + 2*P^55 + P^56 + 
    P^57 + P^58 + 2*P^59 + 2*P^60 + P^61 + 2*P^62 + P^63 + 2*P^64 + P^65 + 2*P^67 + P^68 + 2*P^69 + P^70 + P^71 + 2*P^72 + 
    P^73 + 2*P^74 + P^75 + 2*P^76 + P^77 + P^78 + P^79 + 2*P^80 + 2*P^81 + P^82 + P^84 + 2*P^85 + 2*P^86 + P^87 + P^88 + P^89 + 
    2*P^90 + 2*P^91 + 2*P^92 + P^93 + P^94 + P^95 + 2*P^96 + 2*P^97 + P^98 + P^99 + 2*P^101 + 2*P^102 + 2*P^103 + P^104 + 
    P^105 + P^106 + 2*P^107 + 2*P^108 + 2*P^109 + P^110 + P^112 + 2*P^113 + 2*P^114 + P^115 + 2*P^117 + 2*P^118 + 2*P^119 + 
    P^120 + 2*P^122 + P^123 + 2*P^124 + P^125 + 2*P^126 + 2*P^127 + P^128 + P^129 + P^130 + 2*P^131 + 2*P^132 + P^133 + 
    2*P^134 + 2*P^136 + P^137 + P^138 + 2*P^139 + P^140 + P^141 + P^142 + P^143 + 2*P^144 + P^145 + P^146 + P^147 + P^148 + 
    P^149 + P^150 + P^151 + P^153 + P^154 + P^155 + P^156 + P^158 + P^159 + P^160 + 2*P^161 + P^163 + P^165 + P^166 + P^168 + 
    P^171 + P^172 + P^173 + P^176 + P^177 + P^182 + P^190)/((1 - P^3)*(1 - P^61)*(1 - P^133))}, 
 {3, (P^6 + 2*P^14 + 2*P^19 + P^23 + 2*P^24 + P^28 + P^29 + 2*P^31 + P^33 + P^35 + 2*P^36 + P^38 + P^40 + 2*P^41 + 2*P^43 + 
    P^45 + 2*P^46 + 2*P^48 + P^50 + 2*P^51 + P^52 + 2*P^53 + P^55 + 2*P^56 + P^57 + 2*P^58 + 3*P^60 + P^61 + P^62 + 2*P^63 + 
    P^64 + 3*P^65 + 2*P^68 + P^69 + 3*P^70 + 2*P^72 + 2*P^73 + P^74 + P^75 + 3*P^77 + 2*P^78 + P^79 + P^81 + 3*P^82 + 2*P^83 + 
    P^86 + 3*P^87 + 2*P^88 + 2*P^89 + P^90 + P^91 + P^92 + 2*P^93 + 2*P^94 + 2*P^95 + P^97 + P^98 + 2*P^99 + 2*P^100 + P^101 + 
    P^102 + P^103 + P^104 + 2*P^105 + 2*P^106 + P^107 + P^108 + P^109 + 3*P^110 + 2*P^111 + P^114 + 3*P^115 + 2*P^116 + 
    2*P^118 + P^119 + 3*P^120 + P^122 + 2*P^123 + P^124 + 2*P^125 + 3*P^127 + 2*P^128 + P^129 + P^130 + 3*P^132 + P^133 + 
    P^134 + 2*P^135 + 3*P^137 + P^139 + 2*P^140 + P^141 + 2*P^142 + P^144 + 2*P^145 + P^146 + 2*P^147 + P^149 + P^151 + 
    2*P^152 + P^154 + P^156 + 2*P^157 + 2*P^159 + P^161 + P^162 + 2*P^164 + P^166 + 2*P^169 + P^173 + 2*P^174 + P^178 + P^183 + 
    P^191)/((1 - P^3)*(1 - P^61)*(1 - P^133))}, 
 {3, (P^7 + P^11 + P^12 + P^16 + P^21 + P^23 + P^24 + P^26 + P^28 + P^29 + P^31 + 2*P^33 + P^34 + P^36 + 2*P^38 + P^39 + P^40 + 
    P^41 + 2*P^43 + P^44 + P^45 + P^46 + 2*P^48 + 2*P^50 + P^51 + P^52 + 2*P^53 + 2*P^55 + P^56 + P^57 + 2*P^58 + 2*P^60 + 
    P^61 + 2*P^62 + 2*P^63 + 2*P^65 + P^66 + 2*P^67 + P^68 + P^69 + 3*P^70 + P^71 + P^72 + P^74 + 3*P^75 + P^76 + P^77 + P^78 + 
    2*P^79 + 3*P^80 + P^81 + 2*P^82 + P^83 + P^84 + P^85 + P^86 + 2*P^87 + P^88 + P^89 + P^90 + 2*P^91 + 2*P^92 + P^93 + P^95 + 
    2*P^96 + 2*P^97 + 2*P^98 + P^99 + P^100 + P^101 + 2*P^102 + 2*P^103 + P^104 + P^106 + 2*P^107 + 3*P^108 + P^109 + P^110 + 
    P^111 + 2*P^112 + 2*P^113 + P^114 + 2*P^115 + P^116 + P^117 + P^118 + P^119 + 3*P^120 + P^121 + P^122 + P^124 + 3*P^125 + 
    P^126 + 2*P^127 + P^128 + P^129 + 2*P^130 + 2*P^132 + P^133 + 2*P^134 + 2*P^135 + 2*P^137 + P^138 + 2*P^139 + P^140 + 
    2*P^142 + 2*P^144 + P^145 + P^146 + 2*P^147 + 2*P^149 + P^150 + P^151 + P^152 + 2*P^154 + P^155 + P^156 + P^157 + P^159 + 
    P^161 + P^162 + P^164 + 2*P^166 + P^167 + 2*P^171 + P^176 + P^178 + P^179 + P^183 + P^184)/
   ((1 - P^3)*(1 - P^61)*(1 - P^133))}, {3, (P^5 + P^13 + P^16 + P^18 + P^21 + P^22 + P^23 + P^26 + P^27 + P^30 + P^31 + P^32 + 
    P^33 + P^34 + P^35 + P^37 + P^38 + P^39 + P^40 + P^42 + P^43 + P^44 + 2*P^45 + P^47 + P^48 + P^49 + 2*P^50 + P^51 + P^52 + 
    P^53 + P^54 + 2*P^55 + P^56 + P^57 + P^58 + 2*P^59 + P^60 + P^61 + 2*P^62 + 2*P^63 + 2*P^64 + P^65 + 2*P^67 + P^68 + 
    2*P^69 + P^70 + 2*P^71 + 2*P^72 + P^73 + P^74 + P^75 + 2*P^76 + P^77 + P^78 + P^79 + 2*P^80 + 2*P^81 + P^82 + P^84 + 
    2*P^85 + 2*P^86 + P^87 + P^88 + 2*P^89 + 2*P^90 + 2*P^91 + P^92 + P^93 + P^94 + P^95 + 2*P^96 + 2*P^97 + P^98 + P^99 + 
    P^100 + 2*P^101 + 2*P^102 + P^103 + P^104 + P^105 + P^106 + 2*P^107 + 2*P^108 + 2*P^109 + P^110 + P^112 + 2*P^113 + 
    2*P^114 + P^115 + 2*P^117 + 2*P^118 + 2*P^119 + P^120 + P^121 + 2*P^122 + P^123 + P^124 + P^125 + 2*P^126 + 2*P^127 + 
    P^128 + P^129 + P^130 + 2*P^131 + P^132 + P^133 + 2*P^134 + P^135 + 2*P^136 + P^137 + P^138 + 2*P^139 + P^140 + P^141 + 
    P^142 + P^143 + 2*P^144 + P^145 + P^146 + P^147 + P^148 + P^149 + P^150 + P^151 + P^153 + P^154 + P^155 + P^156 + P^158 + 
    P^159 + P^160 + P^161 + P^163 + P^164 + P^165 + P^166 + P^168 + P^171 + P^172 + P^173 + P^176 + P^177 + P^182 + P^190)/
   ((1 - P^3)*(1 - P^61)*(1 - P^133))}, {3, (P^3 + P^14 + P^17 + P^19 + P^20 + P^22 + P^24 + P^25 + P^27 + P^29 + P^30 + P^31 + 
    P^32 + P^34 + P^35 + P^36 + P^37 + P^39 + P^41 + P^42 + P^43 + P^44 + 2*P^46 + P^47 + P^48 + 2*P^49 + 2*P^51 + P^52 + 
    P^53 + 2*P^54 + 2*P^56 + P^57 + P^58 + 2*P^59 + P^60 + 2*P^61 + P^62 + 2*P^63 + P^64 + P^65 + 2*P^66 + P^67 + 2*P^68 + 
    P^69 + P^70 + 2*P^71 + P^72 + 2*P^73 + P^74 + P^75 + 2*P^76 + P^77 + 2*P^78 + P^79 + P^80 + P^81 + P^82 + 2*P^83 + P^84 + 
    P^85 + P^86 + P^87 + 2*P^88 + 2*P^89 + P^90 + P^91 + P^92 + 2*P^93 + 2*P^94 + 2*P^95 + P^96 + P^97 + P^98 + 2*P^99 + 
    2*P^100 + P^101 + P^102 + P^103 + 2*P^104 + 2*P^105 + 2*P^106 + P^107 + P^108 + P^109 + P^110 + 2*P^111 + P^112 + P^113 + 
    P^114 + P^115 + 2*P^116 + P^117 + 2*P^118 + P^119 + P^120 + 2*P^121 + P^122 + 2*P^123 + P^124 + P^125 + 2*P^126 + P^127 + 
    2*P^128 + P^129 + P^130 + 2*P^131 + P^132 + 2*P^133 + P^134 + 2*P^135 + P^136 + P^137 + 2*P^138 + 2*P^140 + P^141 + P^142 + 
    2*P^143 + 2*P^145 + P^146 + P^147 + 2*P^148 + P^150 + P^151 + P^152 + P^153 + P^155 + P^157 + P^158 + P^159 + P^160 + 
    2*P^162 + P^163 + P^164 + P^167 + P^169 + P^170 + P^172 + P^174 + P^175 + P^177 + P^180 + P^191)/
   ((1 - P^3)*(1 - P^61)*(1 - P^133))}, {3, (P^11 + P^12 + 2*P^16 + P^17 + P^21 + P^24 + P^26 + 2*P^28 + P^29 + 2*P^33 + P^34 + 
    2*P^38 + P^39 + P^40 + P^41 + 2*P^43 + P^44 + 2*P^45 + P^46 + 2*P^48 + P^49 + 2*P^50 + P^51 + 2*P^53 + 2*P^55 + P^56 + 
    2*P^57 + 2*P^58 + 2*P^60 + P^61 + 2*P^62 + P^63 + 2*P^65 + P^66 + 2*P^67 + P^68 + P^69 + 3*P^70 + P^71 + P^72 + 2*P^74 + 
    3*P^75 + P^76 + 2*P^79 + 3*P^80 + P^81 + P^82 + P^83 + 2*P^84 + 2*P^85 + 2*P^86 + 2*P^87 + P^88 + P^90 + 2*P^91 + 3*P^92 + 
    P^93 + 2*P^96 + 3*P^97 + 2*P^98 + P^99 + P^101 + 2*P^102 + 3*P^103 + P^104 + 2*P^107 + 3*P^108 + P^109 + 2*P^112 + 
    3*P^113 + P^114 + 2*P^115 + P^116 + 2*P^117 + P^118 + P^119 + 3*P^120 + P^121 + P^122 + 2*P^124 + 3*P^125 + P^126 + P^127 + 
    P^128 + 2*P^129 + 2*P^130 + 2*P^132 + P^133 + 2*P^134 + P^135 + 2*P^137 + P^138 + 2*P^139 + P^140 + 2*P^142 + P^143 + 
    2*P^144 + P^145 + P^147 + 2*P^149 + P^150 + P^151 + P^152 + 2*P^154 + P^155 + 2*P^156 + P^157 + P^159 + 2*P^161 + P^162 + 
    2*P^166 + P^167 + 2*P^171 + P^172 + P^176 + P^183 + P^184 + P^188)/((1 - P^3)*(1 - P^61)*(1 - P^133))}, 
 {3, (P^9 + P^10 + P^14 + P^15 + P^20 + P^22 + P^25 + P^26 + P^27 + P^30 + P^31 + 2*P^32 + P^36 + 2*P^37 + P^38 + P^39 + P^41 + 
    2*P^42 + P^43 + P^44 + P^46 + 2*P^47 + P^48 + 2*P^49 + P^51 + P^52 + P^53 + 2*P^54 + P^55 + P^56 + P^57 + P^58 + 2*P^59 + 
    P^60 + 2*P^61 + P^62 + P^63 + 2*P^64 + P^65 + 2*P^66 + P^67 + 2*P^68 + 2*P^69 + P^71 + P^72 + 2*P^73 + 2*P^74 + P^76 + 
    P^77 + 3*P^78 + 2*P^79 + P^80 + P^81 + P^82 + 2*P^83 + 2*P^84 + 2*P^85 + P^86 + P^88 + 2*P^89 + 3*P^90 + P^91 + 2*P^94 + 
    3*P^95 + 2*P^96 + P^97 + P^99 + 2*P^100 + 3*P^101 + P^102 + 2*P^105 + 3*P^106 + 2*P^107 + P^110 + 3*P^111 + 2*P^112 + 
    2*P^113 + P^114 + P^115 + P^116 + 2*P^117 + 2*P^118 + 2*P^119 + P^121 + P^122 + 2*P^123 + 2*P^124 + 2*P^126 + P^127 + 
    2*P^128 + P^129 + P^130 + 2*P^131 + P^132 + 2*P^133 + P^134 + P^135 + 2*P^136 + P^137 + 2*P^138 + P^140 + 2*P^141 + P^142 + 
    2*P^143 + P^145 + P^146 + P^147 + 2*P^148 + P^149 + P^150 + P^152 + 2*P^153 + P^154 + P^155 + P^157 + P^158 + P^159 + 
    P^160 + P^163 + P^164 + 2*P^165 + P^169 + 2*P^170 + P^175 + P^177 + P^181 + P^182 + P^186)/
   ((1 - P^3)*(1 - P^61)*(1 - P^133))}, {3, (P^7 + P^12 + P^14 + P^18 + P^19 + P^23 + P^24 + P^26 + P^28 + P^29 + P^30 + P^31 + 
    P^34 + P^35 + 2*P^36 + P^39 + P^40 + 2*P^41 + P^43 + P^44 + P^45 + 2*P^46 + P^47 + P^48 + P^50 + 2*P^51 + P^52 + 2*P^53 + 
    2*P^55 + P^56 + P^57 + 2*P^58 + P^59 + 2*P^60 + P^61 + P^62 + 2*P^63 + P^64 + 2*P^65 + P^66 + P^67 + P^68 + P^69 + 2*P^70 + 
    P^71 + 2*P^72 + P^73 + P^74 + P^75 + 2*P^76 + 2*P^77 + 2*P^78 + P^80 + P^81 + 3*P^82 + 2*P^83 + P^84 + P^85 + P^86 + 
    2*P^87 + 2*P^88 + P^89 + P^90 + 2*P^92 + 2*P^93 + 2*P^94 + P^95 + P^97 + 2*P^98 + 3*P^99 + P^100 + P^101 + 2*P^103 + 
    2*P^104 + 2*P^105 + P^106 + P^108 + 2*P^109 + 3*P^110 + 2*P^111 + P^113 + P^114 + 3*P^115 + P^116 + P^117 + P^118 + P^119 + 
    2*P^120 + P^121 + 2*P^122 + P^123 + P^124 + P^125 + P^126 + 2*P^127 + 2*P^128 + P^129 + 2*P^130 + P^131 + 2*P^132 + P^133 + 
    P^134 + 2*P^135 + P^136 + P^137 + P^138 + P^139 + 2*P^140 + P^141 + 2*P^142 + P^144 + P^145 + P^146 + 2*P^147 + P^149 + 
    P^150 + P^151 + 2*P^152 + P^154 + P^155 + P^156 + 2*P^157 + P^159 + P^161 + P^162 + P^163 + P^164 + P^167 + P^168 + P^169 + 
    P^173 + P^174 + P^178 + P^179 + P^184 + P^186)/((1 - P^3)*(1 - P^61)*(1 - P^133))}, 
 {3, (P^6 + P^8 + P^13 + P^18 + P^20 + P^23 + 2*P^25 + P^28 + 2*P^30 + P^33 + 3*P^35 + P^37 + P^38 + 3*P^40 + 2*P^42 + 2*P^45 + 
    2*P^47 + P^49 + 2*P^50 + 3*P^52 + 2*P^54 + P^55 + 3*P^57 + 2*P^59 + P^60 + 3*P^62 + 3*P^64 + P^65 + P^66 + 2*P^67 + 
    2*P^69 + P^70 + 2*P^71 + 3*P^72 + 2*P^74 + 2*P^76 + 2*P^77 + P^78 + 2*P^79 + 2*P^81 + 2*P^82 + 2*P^83 + 2*P^84 + P^86 + 
    P^87 + 2*P^88 + 2*P^89 + P^91 + P^92 + 3*P^93 + 2*P^94 + P^95 + P^97 + 2*P^98 + 2*P^99 + 2*P^100 + P^102 + P^103 + 
    3*P^104 + 2*P^105 + P^106 + P^107 + P^108 + 2*P^109 + 2*P^110 + P^111 + 2*P^112 + 2*P^114 + P^115 + 2*P^116 + 2*P^117 + 
    P^119 + P^120 + 2*P^121 + 3*P^122 + 2*P^124 + 2*P^126 + 2*P^127 + 3*P^129 + 2*P^131 + P^132 + 3*P^134 + 3*P^136 + P^137 + 
    P^138 + 2*P^139 + 3*P^141 + P^143 + P^144 + 3*P^146 + 2*P^148 + P^149 + 3*P^151 + 2*P^153 + 2*P^156 + 2*P^158 + P^161 + 
    2*P^163 + P^166 + 2*P^168 + P^170 + P^173 + P^175 + P^178 + 2*P^180 + P^185)/((1 - P^3)*(1 - P^61)*(1 - P^133))}, 
 {3, (P^8 + P^9 + P^13 + P^17 + P^21 + P^22 + P^25 + P^26 + P^27 + P^30 + P^31 + P^32 + P^34 + P^35 + P^36 + P^37 + P^38 + 
    P^39 + P^40 + P^41 + P^42 + P^43 + P^44 + P^45 + P^46 + P^47 + P^48 + P^49 + P^50 + P^51 + P^52 + P^53 + 2*P^54 + P^55 + 
    P^56 + P^57 + P^58 + 2*P^59 + P^60 + P^61 + P^62 + 2*P^63 + 2*P^64 + P^65 + P^66 + 2*P^67 + 2*P^68 + P^69 + 2*P^71 + 
    2*P^72 + 2*P^73 + P^75 + 2*P^76 + 2*P^77 + P^78 + P^79 + 2*P^80 + 2*P^81 + P^82 + P^83 + 2*P^84 + 2*P^85 + P^86 + P^88 + 
    2*P^89 + 2*P^90 + P^91 + P^92 + P^93 + 2*P^94 + P^95 + 2*P^96 + P^97 + P^98 + P^99 + 2*P^100 + 2*P^101 + P^102 + P^103 + 
    P^104 + 2*P^105 + P^106 + P^107 + P^108 + 2*P^109 + 2*P^110 + P^111 + 2*P^112 + 2*P^113 + 2*P^114 + P^116 + 2*P^117 + 
    2*P^118 + P^119 + 2*P^121 + 2*P^122 + 2*P^123 + P^125 + 2*P^126 + 2*P^127 + P^128 + P^129 + P^130 + 2*P^131 + P^132 + 
    P^133 + P^134 + 2*P^135 + 2*P^136 + P^137 + P^138 + P^139 + 2*P^140 + P^141 + P^142 + P^143 + P^144 + P^145 + P^146 + 
    P^147 + 2*P^148 + P^149 + P^150 + P^151 + P^152 + P^153 + P^154 + P^155 + P^156 + P^158 + P^159 + P^160 + P^163 + P^164 + 
    P^165 + P^167 + P^168 + P^169 + P^172 + P^176 + P^177 + P^180 + P^181 + P^185)/((1 - P^3)*(1 - P^61)*(1 - P^133))}, 
 {3, (P^10 + P^12 + P^15 + 2*P^17 + 2*P^22 + 2*P^27 + 2*P^29 + P^32 + 2*P^34 + P^37 + 3*P^39 + P^41 + P^42 + 3*P^44 + 2*P^46 + 
    P^47 + 3*P^49 + 2*P^51 + 3*P^54 + 3*P^56 + 2*P^58 + 2*P^59 + 3*P^61 + 2*P^63 + P^64 + 3*P^66 + 3*P^68 + P^69 + P^70 + 
    2*P^71 + 2*P^73 + P^74 + 2*P^75 + 2*P^76 + P^78 + P^79 + 2*P^80 + 3*P^81 + P^83 + 3*P^85 + 3*P^86 + 2*P^87 + P^88 + P^90 + 
    2*P^91 + 2*P^92 + 2*P^93 + P^95 + P^96 + 3*P^97 + 2*P^98 + P^99 + P^101 + 2*P^102 + 2*P^103 + 2*P^104 + P^106 + P^107 + 
    2*P^108 + 2*P^109 + P^111 + P^112 + 3*P^113 + 3*P^114 + 2*P^116 + 3*P^118 + P^119 + P^120 + 2*P^121 + 2*P^123 + P^124 + 
    2*P^125 + 3*P^126 + 2*P^128 + 2*P^130 + 2*P^131 + 3*P^133 + 2*P^135 + P^136 + 3*P^138 + 2*P^140 + P^141 + 3*P^143 + 
    3*P^145 + P^148 + 3*P^150 + P^152 + P^153 + 3*P^155 + 2*P^157 + 2*P^160 + 2*P^162 + P^165 + 2*P^167 + P^170 + 2*P^172 + 
    P^177 + P^182 + P^184 + P^189)/((1 - P^3)*(1 - P^61)*(1 - P^133))}, 
 {3, (P^8 + P^9 + P^10 + P^20 + P^21 + P^22 + P^25 + P^26 + P^27 + P^30 + P^31 + P^32 + P^35 + P^36 + 2*P^37 + P^38 + P^39 + 
    P^40 + P^41 + 2*P^42 + P^43 + P^44 + P^47 + P^48 + 2*P^49 + P^50 + P^51 + P^52 + P^53 + 2*P^54 + P^55 + P^56 + P^57 + 
    P^58 + 2*P^59 + P^60 + P^61 + P^62 + P^63 + 2*P^64 + P^65 + 2*P^66 + 2*P^67 + 2*P^68 + P^69 + P^71 + 2*P^72 + 2*P^73 + 
    2*P^74 + P^75 + 2*P^76 + P^77 + 2*P^78 + 2*P^79 + 2*P^80 + P^81 + P^83 + 2*P^84 + 2*P^85 + P^86 + P^88 + 2*P^89 + 2*P^90 + 
    P^91 + P^93 + 2*P^94 + 3*P^95 + 2*P^96 + P^97 + P^99 + 2*P^100 + 2*P^101 + P^102 + P^104 + 2*P^105 + 3*P^106 + 2*P^107 + 
    P^108 + P^109 + P^110 + 2*P^111 + 2*P^112 + 2*P^113 + P^114 + P^116 + 2*P^117 + 2*P^118 + P^119 + P^121 + 2*P^122 + 
    2*P^123 + 2*P^124 + P^125 + 2*P^126 + P^127 + P^128 + P^129 + P^130 + 2*P^131 + P^132 + P^133 + P^134 + P^135 + 2*P^136 + 
    P^137 + 2*P^138 + P^139 + P^140 + P^141 + P^142 + 2*P^143 + P^144 + P^145 + P^146 + P^147 + 2*P^148 + P^149 + P^150 + 
    P^151 + P^152 + 2*P^153 + P^154 + P^155 + P^158 + P^159 + P^160 + P^163 + P^164 + P^165 + P^168 + P^169 + P^170 + P^175 + 
    P^176 + P^177 + P^180 + P^181 + P^182)/((1 - P^3)*(1 - P^61)*(1 - P^133))}, 
 {3, (P^2 + P^13 + P^18 + 2*P^19 + P^23 + 2*P^24 + 2*P^29 + P^30 + P^31 + 2*P^34 + P^35 + 2*P^36 + P^40 + 2*P^41 + P^42 + 
    P^45 + 2*P^46 + P^47 + 2*P^48 + P^50 + 2*P^51 + P^52 + 2*P^53 + P^55 + 2*P^56 + P^57 + 2*P^58 + P^59 + P^60 + 2*P^61 + 
    P^62 + P^63 + P^64 + 2*P^65 + 2*P^66 + P^67 + 2*P^68 + P^69 + 2*P^70 + P^71 + P^72 + 2*P^73 + 2*P^75 + P^76 + 3*P^77 + 
    2*P^78 + P^81 + 3*P^82 + 2*P^83 + P^86 + 3*P^87 + 3*P^88 + P^89 + 2*P^92 + 3*P^93 + 3*P^94 + 3*P^98 + 3*P^99 + 2*P^100 + 
    P^103 + 3*P^104 + 3*P^105 + 2*P^106 + P^109 + 3*P^110 + 2*P^111 + P^114 + 3*P^115 + 2*P^116 + P^117 + P^119 + 2*P^120 + 
    2*P^121 + P^122 + 2*P^123 + P^124 + 2*P^125 + P^126 + P^127 + 2*P^128 + 2*P^130 + P^131 + 2*P^132 + 2*P^133 + P^134 + 
    2*P^135 + P^136 + 2*P^137 + P^139 + 2*P^140 + P^141 + 2*P^142 + P^144 + 2*P^145 + P^146 + 2*P^147 + 2*P^150 + P^151 + 
    2*P^152 + P^156 + 2*P^157 + P^158 + P^161 + 2*P^162 + P^163 + P^164 + P^168 + 2*P^169 + P^173 + 2*P^174 + 2*P^179 + P^190)/
   ((1 - P^3)*(1 - P^61)*(1 - P^133))}, {3, (P + P^15 + 2*P^18 + P^20 + 2*P^23 + P^25 + 2*P^28 + P^30 + P^32 + 2*P^33 + 
    2*P^35 + P^37 + 2*P^40 + P^42 + P^44 + 2*P^45 + 3*P^47 + P^49 + 2*P^50 + 3*P^52 + P^54 + 2*P^55 + 3*P^57 + P^59 + 2*P^60 + 
    P^61 + 2*P^62 + 3*P^64 + 2*P^65 + P^66 + 2*P^67 + 3*P^69 + P^71 + 2*P^72 + P^73 + 3*P^74 + 2*P^76 + 2*P^77 + P^78 + P^79 + 
    2*P^81 + 2*P^82 + P^83 + P^84 + 2*P^86 + 2*P^87 + P^88 + P^89 + P^90 + 2*P^91 + 2*P^92 + 2*P^93 + P^94 + P^95 + P^96 + 
    2*P^97 + 2*P^98 + 2*P^99 + P^100 + P^101 + P^102 + 2*P^103 + 2*P^104 + 2*P^105 + P^106 + P^107 + 2*P^109 + 2*P^110 + 
    P^111 + P^112 + 2*P^114 + 2*P^115 + P^116 + P^117 + 3*P^119 + 2*P^120 + P^121 + 2*P^122 + 3*P^124 + P^126 + 2*P^127 + 
    P^128 + 3*P^129 + 2*P^131 + 2*P^132 + P^133 + 2*P^134 + 3*P^136 + P^138 + 2*P^139 + 3*P^141 + P^143 + 2*P^144 + 3*P^146 + 
    P^148 + 2*P^149 + 2*P^151 + P^153 + 2*P^156 + P^158 + P^160 + 2*P^161 + 2*P^163 + P^165 + 2*P^168 + P^170 + 2*P^173 + 
    P^175 + 2*P^178 + P^192)/((1 - P^3)*(1 - P^61)*(1 - P^133))}, 
 {3, (P^6 + P^11 + P^16 + P^17 + P^21 + P^22 + P^23 + P^27 + 2*P^28 + P^29 + 2*P^33 + P^34 + P^35 + 2*P^38 + P^39 + P^40 + 
    2*P^43 + P^44 + 2*P^45 + P^46 + P^48 + P^49 + 2*P^50 + P^51 + P^52 + P^53 + P^54 + 2*P^55 + P^56 + 2*P^57 + P^58 + P^59 + 
    2*P^60 + P^61 + 2*P^62 + P^63 + P^64 + 2*P^65 + P^66 + P^67 + P^68 + P^69 + 2*P^70 + P^71 + P^72 + P^73 + 2*P^74 + 3*P^75 + 
    P^76 + P^77 + 2*P^79 + 2*P^80 + 2*P^81 + P^82 + P^84 + 2*P^85 + 3*P^86 + 2*P^87 + P^90 + 3*P^91 + 3*P^92 + P^93 + 2*P^96 + 
    3*P^97 + 2*P^98 + P^101 + 3*P^102 + 3*P^103 + P^104 + 2*P^107 + 3*P^108 + 2*P^109 + P^110 + P^112 + 2*P^113 + 2*P^114 + 
    2*P^115 + P^117 + P^118 + 2*P^119 + 2*P^120 + P^121 + P^122 + P^123 + 2*P^124 + 2*P^125 + P^126 + P^127 + P^128 + 2*P^129 + 
    2*P^130 + P^131 + 2*P^132 + P^133 + 2*P^134 + P^135 + 2*P^137 + P^138 + 2*P^139 + P^140 + P^141 + P^142 + P^143 + 2*P^144 + 
    P^145 + P^146 + P^148 + 2*P^149 + P^150 + P^151 + 2*P^154 + P^155 + 2*P^156 + P^159 + P^160 + 2*P^161 + P^162 + 2*P^166 + 
    P^167 + P^171 + P^172 + P^173 + P^177 + P^178 + P^183 + P^188)/((1 - P^3)*(1 - P^61)*(1 - P^133))}, 
 {3, (P^5 + P^10 + P^15 + P^19 + P^20 + P^22 + P^24 + 2*P^27 + P^29 + 2*P^32 + 2*P^34 + P^36 + 2*P^37 + 2*P^39 + P^41 + P^42 + 
    2*P^44 + P^46 + P^47 + P^48 + 2*P^49 + 2*P^51 + P^52 + P^53 + 2*P^54 + 3*P^56 + P^58 + 2*P^59 + 3*P^61 + 2*P^63 + 2*P^64 + 
    P^65 + 2*P^66 + 2*P^68 + 2*P^69 + P^70 + 2*P^71 + 3*P^73 + P^74 + P^75 + P^76 + P^77 + 3*P^78 + P^79 + P^80 + P^81 + P^82 + 
    2*P^83 + P^84 + 2*P^85 + 2*P^86 + P^87 + P^88 + 2*P^90 + 2*P^91 + 2*P^92 + P^93 + P^94 + P^95 + 2*P^96 + P^97 + P^98 + 
    P^99 + P^100 + 2*P^101 + 2*P^102 + 2*P^103 + P^104 + P^105 + 2*P^106 + 2*P^107 + P^108 + P^109 + P^110 + 2*P^111 + P^112 + 
    P^113 + 2*P^114 + P^115 + 2*P^116 + 2*P^118 + 2*P^119 + P^120 + 2*P^121 + 3*P^123 + P^124 + P^125 + P^126 + 3*P^128 + 
    P^129 + P^130 + 2*P^131 + 3*P^133 + 2*P^135 + 2*P^136 + P^137 + 2*P^138 + 2*P^140 + P^141 + P^142 + 2*P^143 + 2*P^145 + 
    P^147 + 2*P^148 + 3*P^150 + P^152 + P^153 + 2*P^155 + P^157 + P^158 + 2*P^160 + P^162 + 2*P^165 + P^167 + P^169 + P^170 + 
    P^172 + P^174 + P^177 + P^179 + P^182 + P^187)/((1 - P^3)*(1 - P^61)*(1 - P^133))}, 
 {3, (P^7 + P^12 + P^15 + P^17 + P^20 + P^22 + P^24 + P^25 + 2*P^29 + P^30 + P^32 + 2*P^34 + P^36 + P^37 + 2*P^39 + 2*P^41 + 
    P^42 + 2*P^44 + 2*P^46 + P^47 + 2*P^49 + 2*P^51 + P^52 + P^53 + 2*P^54 + 2*P^56 + P^57 + 2*P^58 + P^59 + 3*P^61 + P^62 + 
    2*P^63 + P^64 + P^65 + 3*P^66 + P^68 + P^69 + 2*P^70 + 3*P^71 + P^73 + P^74 + 2*P^75 + 2*P^76 + 2*P^78 + P^79 + 2*P^80 + 
    P^81 + P^82 + 2*P^83 + P^84 + P^85 + P^86 + 2*P^87 + 3*P^88 + P^89 + P^90 + 2*P^92 + 2*P^93 + 2*P^94 + P^95 + P^96 + P^97 + 
    2*P^98 + 2*P^99 + P^100 + P^101 + 2*P^103 + 2*P^104 + P^105 + P^106 + P^107 + 2*P^108 + 2*P^109 + P^110 + 2*P^111 + P^112 + 
    P^113 + P^114 + P^115 + 3*P^116 + P^117 + P^118 + P^119 + 2*P^120 + 3*P^121 + P^123 + P^124 + 2*P^125 + 2*P^126 + 2*P^128 + 
    P^129 + 2*P^130 + P^131 + 3*P^133 + P^134 + 2*P^135 + P^136 + 3*P^138 + 2*P^140 + P^141 + P^142 + 2*P^143 + 2*P^145 + 
    P^146 + P^147 + P^148 + 2*P^150 + 2*P^152 + P^153 + P^155 + 2*P^157 + P^158 + P^160 + 2*P^162 + P^163 + P^165 + 2*P^167 + 
    P^170 + P^172 + P^174 + P^175 + P^179 + P^184 + P^189)/((1 - P^3)*(1 - P^61)*(1 - P^133))}, 
 {3, (P^4 + P^9 + P^14 + P^19 + 2*P^21 + 3*P^26 + 3*P^31 + P^33 + 3*P^36 + 2*P^38 + 2*P^41 + 3*P^43 + P^46 + 3*P^48 + 2*P^50 + 
    P^51 + 3*P^53 + 3*P^55 + 3*P^58 + 3*P^60 + P^62 + 3*P^63 + 2*P^65 + 2*P^67 + 3*P^68 + 2*P^70 + 3*P^72 + 2*P^73 + 2*P^75 + 
    3*P^77 + P^78 + 2*P^79 + 2*P^80 + P^82 + P^83 + 3*P^84 + 3*P^85 + 3*P^89 + 3*P^90 + P^91 + 2*P^94 + 3*P^95 + 2*P^96 + 
    P^99 + 3*P^100 + 3*P^101 + P^102 + 2*P^105 + 3*P^106 + 2*P^107 + 2*P^108 + P^110 + P^111 + 2*P^112 + 3*P^113 + P^115 + 
    3*P^117 + 3*P^118 + P^120 + 3*P^122 + 2*P^123 + 2*P^125 + 3*P^127 + P^128 + 3*P^130 + 3*P^132 + P^134 + 3*P^135 + 3*P^137 + 
    2*P^139 + P^140 + 3*P^142 + 2*P^144 + 3*P^147 + 3*P^149 + 2*P^152 + 3*P^154 + P^157 + 3*P^159 + 3*P^164 + P^166 + P^169 + 
    2*P^171 + 2*P^176 + 2*P^181 + P^186)/((1 - P^3)*(1 - P^61)*(1 - P^133))}, 
 {3, (P^11 + P^13 + P^15 + P^16 + P^18 + P^20 + P^23 + P^25 + P^27 + P^28 + P^30 + P^32 + P^33 + P^35 + P^37 + P^38 + 2*P^40 + 
    2*P^42 + P^43 + P^44 + 2*P^45 + 2*P^47 + P^48 + P^49 + 2*P^50 + 2*P^52 + P^54 + 2*P^55 + P^56 + 3*P^57 + 2*P^59 + P^60 + 
    P^61 + 2*P^62 + 2*P^64 + P^65 + P^66 + 2*P^67 + 3*P^69 + P^70 + 2*P^71 + P^72 + P^73 + 2*P^74 + P^75 + P^76 + P^77 + P^78 + 
    2*P^79 + P^80 + P^81 + 2*P^82 + P^83 + 2*P^84 + P^85 + 2*P^86 + 2*P^87 + P^88 + 2*P^89 + P^90 + 2*P^91 + P^92 + P^93 + 
    P^94 + P^95 + 2*P^96 + P^97 + 2*P^98 + P^99 + 2*P^100 + P^101 + 2*P^102 + P^103 + P^104 + P^105 + P^106 + 2*P^107 + P^108 + 
    P^109 + P^110 + P^111 + 2*P^112 + P^113 + 2*P^114 + 2*P^115 + P^116 + 2*P^117 + 3*P^119 + P^120 + 2*P^121 + P^122 + P^123 + 
    2*P^124 + P^125 + P^126 + 2*P^127 + P^128 + 3*P^129 + 2*P^131 + P^132 + P^133 + 2*P^134 + 2*P^136 + P^137 + P^138 + 
    2*P^139 + 2*P^141 + P^142 + P^143 + 2*P^144 + 2*P^146 + P^148 + P^149 + 2*P^151 + 2*P^153 + P^154 + P^155 + 2*P^156 + 
    2*P^158 + P^160 + P^161 + P^163 + P^165 + P^166 + P^168 + P^170 + P^171 + P^173 + P^175 + P^183 + P^185 + P^187)/
   ((1 - P^3)*(1 - P^61)*(1 - P^133))}, {3, (P^5 + P^10 + P^12 + P^17 + 2*P^22 + P^24 + 2*P^27 + P^29 + 2*P^32 + 2*P^34 + 
    2*P^37 + 3*P^39 + P^41 + P^42 + 3*P^44 + P^46 + 3*P^49 + 3*P^51 + P^53 + 2*P^54 + 3*P^56 + P^58 + 2*P^59 + 3*P^61 + 
    2*P^63 + 2*P^64 + 2*P^66 + 3*P^68 + 2*P^69 + P^70 + 2*P^71 + 2*P^73 + P^74 + P^75 + 3*P^76 + 2*P^78 + 3*P^80 + 3*P^81 + 
    P^82 + P^83 + 2*P^85 + 2*P^86 + P^87 + P^88 + 2*P^90 + 2*P^91 + 2*P^92 + P^93 + P^95 + 2*P^96 + 3*P^97 + P^98 + P^99 + 
    2*P^101 + 2*P^102 + 2*P^103 + P^104 + P^106 + 2*P^107 + 3*P^108 + 3*P^109 + P^111 + 3*P^113 + 2*P^114 + P^115 + P^116 + 
    2*P^118 + 2*P^119 + P^120 + 2*P^121 + 2*P^123 + P^124 + P^125 + 3*P^126 + 3*P^128 + P^130 + 2*P^131 + 3*P^133 + 2*P^135 + 
    2*P^136 + 3*P^138 + 3*P^140 + 2*P^143 + 3*P^145 + P^147 + 2*P^148 + 3*P^150 + P^152 + P^153 + 3*P^155 + P^157 + 2*P^160 + 
    P^162 + 2*P^165 + 2*P^167 + 2*P^172 + 2*P^177 + P^179 + P^182 + P^184)/((1 - P^3)*(1 - P^61)*(1 - P^133))}, 
 {3, (P^12 + P^13 + P^14 + P^17 + P^18 + P^19 + P^24 + P^25 + P^26 + P^29 + P^30 + P^31 + P^34 + P^35 + P^36 + P^39 + P^40 + 
    2*P^41 + P^42 + P^43 + P^44 + P^45 + 2*P^46 + P^47 + P^48 + P^49 + P^50 + 2*P^51 + P^52 + P^53 + P^54 + P^55 + 2*P^56 + 
    P^57 + 2*P^58 + P^59 + P^60 + P^61 + P^62 + 2*P^63 + P^64 + P^65 + P^66 + P^67 + 2*P^68 + P^69 + 2*P^70 + 2*P^71 + 2*P^72 + 
    P^73 + P^75 + 2*P^76 + 2*P^77 + P^78 + P^80 + 2*P^81 + 2*P^82 + 2*P^83 + P^84 + P^85 + P^86 + 2*P^87 + 3*P^88 + 2*P^89 + 
    P^90 + P^92 + 2*P^93 + 2*P^94 + P^95 + P^97 + 2*P^98 + 3*P^99 + 2*P^100 + P^101 + P^103 + 2*P^104 + 2*P^105 + P^106 + 
    P^108 + 2*P^109 + 2*P^110 + P^111 + P^113 + 2*P^114 + 2*P^115 + 2*P^116 + P^117 + 2*P^118 + P^119 + 2*P^120 + 2*P^121 + 
    2*P^122 + P^123 + P^125 + 2*P^126 + 2*P^127 + 2*P^128 + P^129 + 2*P^130 + P^131 + P^132 + P^133 + P^134 + 2*P^135 + P^136 + 
    P^137 + P^138 + P^139 + 2*P^140 + P^141 + P^142 + P^143 + P^144 + 2*P^145 + P^146 + P^147 + P^150 + P^151 + 2*P^152 + 
    P^153 + P^154 + P^155 + P^156 + 2*P^157 + P^158 + P^159 + P^162 + P^163 + P^164 + P^167 + P^168 + P^169 + P^172 + P^173 + 
    P^174 + P^184 + P^185 + P^186)/((1 - P^3)*(1 - P^61)*(1 - P^133))}, 
 {3, (P^4 + 2*P^15 + 2*P^20 + P^21 + 2*P^25 + P^26 + P^30 + P^31 + 2*P^32 + P^33 + P^36 + 2*P^37 + P^38 + 2*P^42 + P^43 + 
    2*P^44 + 2*P^47 + P^48 + 2*P^49 + P^50 + 2*P^52 + P^53 + 2*P^54 + P^55 + 2*P^57 + P^58 + 2*P^59 + P^60 + 2*P^61 + 2*P^62 + 
    P^63 + 2*P^64 + 2*P^66 + P^67 + P^68 + 2*P^69 + P^70 + 2*P^71 + P^72 + 2*P^73 + 2*P^74 + P^75 + P^77 + 2*P^78 + 3*P^79 + 
    P^80 + 2*P^83 + 3*P^84 + P^85 + 2*P^88 + 3*P^89 + 3*P^90 + P^91 + 2*P^94 + 3*P^95 + 3*P^96 + 3*P^100 + 3*P^101 + 2*P^102 + 
    P^105 + 3*P^106 + 3*P^107 + P^108 + 2*P^111 + 3*P^112 + P^113 + 2*P^116 + 3*P^117 + P^118 + 2*P^119 + 2*P^121 + P^122 + 
    P^123 + 2*P^124 + P^125 + 2*P^126 + P^127 + 2*P^128 + 2*P^129 + P^130 + P^131 + P^132 + 2*P^133 + P^134 + P^135 + 2*P^136 + 
    P^137 + 2*P^138 + P^139 + 2*P^141 + P^142 + 2*P^143 + P^144 + 2*P^146 + P^147 + 2*P^148 + P^149 + P^152 + 2*P^153 + P^154 + 
    2*P^158 + P^159 + 2*P^160 + P^163 + P^164 + 2*P^165 + 2*P^170 + P^171 + 2*P^175 + P^176 + P^181 + P^192)/
   ((1 - P^3)*(1 - P^61)*(1 - P^133))}, {3, (P^5 + P^10 + P^15 + P^19 + P^20 + P^22 + P^24 + 2*P^27 + P^29 + P^31 + 2*P^32 + 
    P^34 + P^36 + 2*P^37 + P^39 + P^41 + 2*P^42 + 2*P^44 + P^46 + P^47 + P^48 + 2*P^49 + 2*P^51 + P^52 + P^53 + 2*P^54 + 
    3*P^56 + P^58 + 2*P^59 + P^60 + 3*P^61 + P^63 + 2*P^64 + P^65 + 2*P^66 + 2*P^68 + 2*P^69 + P^70 + P^71 + 3*P^73 + 2*P^74 + 
    P^75 + P^76 + P^77 + 3*P^78 + P^79 + P^80 + P^81 + P^82 + 2*P^83 + P^84 + 2*P^85 + 2*P^86 + P^87 + P^88 + P^89 + 2*P^90 + 
    2*P^91 + P^93 + P^94 + 2*P^95 + 2*P^96 + P^97 + P^98 + P^99 + 2*P^100 + 2*P^101 + 2*P^102 + P^104 + P^105 + 3*P^106 + 
    2*P^107 + P^108 + P^109 + P^110 + 2*P^111 + P^112 + P^113 + 2*P^114 + P^115 + 2*P^116 + 2*P^118 + 2*P^119 + P^120 + P^121 + 
    3*P^123 + 2*P^124 + P^125 + P^126 + 3*P^128 + P^129 + P^130 + 2*P^131 + P^132 + 3*P^133 + P^135 + 2*P^136 + P^137 + 
    2*P^138 + 2*P^140 + P^141 + P^142 + 2*P^143 + 2*P^145 + P^147 + 2*P^148 + 2*P^150 + P^152 + 2*P^153 + 2*P^155 + P^157 + 
    P^158 + 2*P^160 + P^162 + P^164 + 2*P^165 + P^169 + P^170 + P^172 + P^174 + P^177 + P^179 + P^182 + P^187)/
   ((1 - P^3)*(1 - P^61)*(1 - P^133))}, {3, (P^7 + P^9 + P^11 + P^19 + P^21 + P^23 + P^24 + P^26 + P^28 + P^29 + P^31 + P^33 + 
    P^34 + 2*P^36 + 2*P^38 + P^39 + P^40 + 2*P^41 + 2*P^43 + P^45 + P^46 + 2*P^48 + 2*P^50 + P^51 + P^52 + 2*P^53 + 2*P^55 + 
    P^56 + P^57 + 2*P^58 + 2*P^60 + P^61 + P^62 + 2*P^63 + 3*P^65 + P^66 + 2*P^67 + P^68 + P^69 + 2*P^70 + P^71 + P^72 + 
    2*P^73 + P^74 + 3*P^75 + 2*P^77 + P^78 + 2*P^79 + 2*P^80 + P^81 + 2*P^82 + P^83 + P^84 + P^85 + P^86 + 2*P^87 + P^88 + 
    P^89 + P^90 + P^91 + 2*P^92 + P^93 + 2*P^94 + P^95 + 2*P^96 + P^97 + 2*P^98 + P^99 + P^100 + P^101 + P^102 + 2*P^103 + 
    P^104 + 2*P^105 + P^106 + 2*P^107 + 2*P^108 + P^109 + 2*P^110 + P^111 + 2*P^112 + P^113 + P^114 + 2*P^115 + P^116 + P^117 + 
    P^118 + P^119 + 2*P^120 + P^121 + P^122 + 2*P^123 + P^124 + 3*P^125 + 2*P^127 + P^128 + P^129 + 2*P^130 + 2*P^132 + P^133 + 
    P^134 + 2*P^135 + 3*P^137 + P^138 + 2*P^139 + P^140 + 2*P^142 + 2*P^144 + P^145 + P^146 + 2*P^147 + 2*P^149 + P^150 + 
    P^151 + 2*P^152 + 2*P^154 + P^156 + P^157 + P^159 + P^161 + P^162 + P^164 + P^166 + P^167 + P^169 + P^171 + P^174 + P^176 + 
    P^178 + P^179 + P^181 + P^183)/((1 - P^3)*(1 - P^61)*(1 - P^133))}, 
 {3, (P^8 + 2*P^13 + 2*P^18 + 2*P^23 + P^25 + P^28 + 3*P^30 + 3*P^35 + P^37 + 3*P^40 + 2*P^42 + 3*P^45 + 3*P^47 + 2*P^50 + 
    3*P^52 + P^54 + 2*P^55 + 3*P^57 + 3*P^59 + P^60 + 3*P^62 + 3*P^64 + P^66 + 3*P^67 + 2*P^69 + 2*P^71 + 3*P^72 + P^74 + 
    3*P^76 + 3*P^77 + P^79 + 3*P^81 + 2*P^82 + P^83 + P^84 + 2*P^86 + 2*P^87 + 3*P^88 + 2*P^89 + P^92 + 3*P^93 + 3*P^94 + 
    P^95 + 2*P^98 + 3*P^99 + 2*P^100 + P^103 + 3*P^104 + 3*P^105 + 3*P^109 + 3*P^110 + P^111 + P^112 + 2*P^114 + 2*P^115 + 
    P^116 + 3*P^117 + 2*P^119 + 2*P^121 + 3*P^122 + 2*P^124 + 3*P^126 + 2*P^127 + 2*P^129 + 3*P^131 + P^132 + 3*P^134 + 
    3*P^136 + 3*P^139 + 3*P^141 + P^143 + 2*P^144 + 3*P^146 + P^148 + 3*P^151 + 2*P^153 + 2*P^156 + 3*P^158 + P^161 + 3*P^163 + 
    3*P^168 + 2*P^173 + P^175 + P^180 + P^185 + P^190)/((1 - P^3)*(1 - P^61)*(1 - P^133))}, 
 {3, (P^7 + P^12 + P^15 + P^17 + P^20 + P^22 + P^24 + P^25 + P^27 + 2*P^29 + P^32 + 2*P^34 + P^36 + P^37 + 2*P^39 + P^41 + 
    P^42 + 3*P^44 + 2*P^46 + P^47 + 2*P^49 + 2*P^51 + P^52 + P^53 + 2*P^54 + 2*P^56 + P^57 + 2*P^58 + 2*P^59 + 3*P^61 + 
    2*P^63 + P^64 + P^65 + 3*P^66 + P^68 + P^69 + P^70 + 3*P^71 + 2*P^73 + P^74 + 2*P^75 + 2*P^76 + 2*P^78 + P^79 + 2*P^80 + 
    P^81 + P^82 + 2*P^83 + P^84 + P^85 + P^86 + 2*P^87 + 2*P^88 + P^89 + P^90 + 2*P^91 + 2*P^92 + 2*P^93 + P^94 + P^95 + P^96 + 
    P^97 + 2*P^98 + P^99 + P^100 + P^101 + 2*P^102 + 2*P^103 + 2*P^104 + P^106 + P^107 + 2*P^108 + 2*P^109 + P^110 + 2*P^111 + 
    P^112 + P^113 + P^114 + P^115 + 3*P^116 + P^117 + P^118 + P^119 + P^120 + 3*P^121 + 2*P^123 + P^124 + 2*P^125 + 2*P^126 + 
    2*P^128 + P^129 + 2*P^130 + 2*P^131 + 3*P^133 + 2*P^135 + P^136 + 3*P^138 + 2*P^140 + P^141 + P^142 + 2*P^143 + 2*P^145 + 
    P^146 + P^147 + P^148 + 2*P^150 + P^152 + P^153 + 2*P^155 + 2*P^157 + P^158 + 2*P^160 + 2*P^162 + P^165 + 2*P^167 + P^170 + 
    P^172 + P^174 + P^175 + P^179 + P^184 + P^189)/((1 - P^3)*(1 - P^61)*(1 - P^133))}, 
 {3, (P^2 + 2*P^16 + P^19 + 2*P^21 + P^24 + 2*P^26 + P^29 + 2*P^31 + 2*P^33 + P^34 + P^36 + 2*P^38 + P^41 + 2*P^43 + 2*P^45 + 
    P^46 + 3*P^48 + 2*P^50 + P^51 + 3*P^53 + 2*P^55 + P^56 + 3*P^58 + 2*P^60 + P^61 + 2*P^62 + 2*P^63 + 3*P^65 + P^66 + 
    2*P^67 + P^68 + 3*P^70 + 2*P^72 + P^73 + 2*P^74 + 3*P^75 + P^77 + P^78 + 2*P^79 + 2*P^80 + P^82 + P^83 + 2*P^84 + 2*P^85 + 
    P^87 + P^88 + 2*P^89 + 2*P^90 + 2*P^91 + P^92 + P^93 + P^94 + 2*P^95 + 2*P^96 + 2*P^97 + P^98 + P^99 + P^100 + 2*P^101 + 
    2*P^102 + 2*P^103 + P^104 + P^105 + P^106 + 2*P^107 + 2*P^108 + P^110 + P^111 + 2*P^112 + 2*P^113 + P^115 + P^116 + 
    2*P^117 + 2*P^118 + 3*P^120 + P^121 + 2*P^122 + P^123 + 3*P^125 + 2*P^127 + P^128 + 2*P^129 + 3*P^130 + 2*P^132 + P^133 + 
    2*P^134 + P^135 + 3*P^137 + 2*P^139 + P^140 + 3*P^142 + 2*P^144 + P^145 + 3*P^147 + 2*P^149 + P^150 + P^152 + 2*P^154 + 
    P^157 + 2*P^159 + 2*P^161 + P^162 + P^164 + 2*P^166 + P^169 + 2*P^171 + P^174 + 2*P^176 + P^179 + P^193)/
   ((1 - P^3)*(1 - P^61)*(1 - P^133))}, {3, (P^6 + P^11 + P^16 + P^17 + P^21 + P^22 + P^23 + P^27 + 2*P^28 + P^32 + 2*P^33 + 
    P^34 + P^35 + 2*P^38 + P^39 + 2*P^40 + P^43 + P^44 + 2*P^45 + P^46 + P^48 + P^49 + 2*P^50 + P^51 + P^52 + P^53 + P^54 + 
    2*P^55 + P^56 + 2*P^57 + P^59 + 2*P^60 + P^61 + 2*P^62 + P^63 + 2*P^64 + 2*P^65 + P^66 + P^67 + P^68 + 2*P^69 + 2*P^70 + 
    P^71 + P^72 + P^73 + 2*P^74 + 2*P^75 + P^76 + P^77 + 2*P^79 + 2*P^80 + 2*P^81 + P^82 + P^84 + 2*P^85 + 3*P^86 + 2*P^87 + 
    P^90 + 3*P^91 + 3*P^92 + P^93 + 2*P^96 + 3*P^97 + 2*P^98 + P^101 + 3*P^102 + 3*P^103 + P^104 + 2*P^107 + 3*P^108 + 
    2*P^109 + P^110 + P^112 + 2*P^113 + 2*P^114 + 2*P^115 + P^117 + P^118 + 3*P^119 + 2*P^120 + P^121 + P^122 + P^123 + 
    2*P^124 + P^125 + P^126 + P^127 + P^128 + 2*P^129 + P^130 + P^131 + 2*P^132 + P^133 + 2*P^134 + P^135 + P^136 + 2*P^137 + 
    P^138 + 2*P^139 + P^140 + P^141 + P^142 + P^143 + 2*P^144 + P^145 + P^146 + P^148 + 2*P^149 + P^150 + 2*P^151 + P^154 + 
    P^155 + 2*P^156 + P^159 + P^160 + 2*P^161 + P^165 + 2*P^166 + P^167 + P^171 + P^172 + P^173 + P^177 + P^178 + P^183 + 
    P^188)/((1 - P^3)*(1 - P^61)*(1 - P^133))}, 
 {3, (P^4 + P^12 + P^17 + P^18 + P^21 + P^22 + P^23 + P^26 + P^28 + P^29 + P^30 + P^31 + P^33 + P^34 + P^35 + P^36 + P^38 + 
    P^39 + P^40 + P^41 + P^43 + P^44 + P^45 + P^46 + P^47 + P^48 + P^49 + 2*P^50 + P^51 + P^52 + P^53 + P^54 + 2*P^55 + P^56 + 
    P^57 + 2*P^58 + P^59 + 2*P^60 + P^61 + P^62 + 2*P^63 + P^64 + P^65 + P^66 + 2*P^67 + 2*P^68 + P^69 + P^70 + P^71 + 2*P^72 + 
    P^73 + P^74 + 2*P^75 + 2*P^76 + 2*P^77 + P^79 + 2*P^80 + 2*P^81 + P^82 + P^84 + 2*P^85 + 2*P^86 + 2*P^87 + P^88 + P^89 + 
    P^90 + P^91 + 2*P^92 + 2*P^93 + P^94 + P^95 + P^96 + 2*P^97 + 2*P^98 + P^99 + P^100 + P^101 + P^102 + 2*P^103 + 2*P^104 + 
    2*P^105 + P^106 + P^107 + 2*P^108 + 2*P^109 + P^110 + P^112 + 2*P^113 + 2*P^114 + P^115 + P^116 + P^117 + 2*P^118 + P^119 + 
    P^120 + P^121 + 2*P^122 + 2*P^123 + P^124 + 2*P^125 + P^126 + 2*P^127 + P^129 + 2*P^130 + 2*P^131 + 2*P^132 + P^133 + 
    P^134 + 2*P^135 + P^136 + P^137 + P^138 + 2*P^139 + P^140 + P^141 + P^142 + P^143 + 2*P^144 + P^145 + P^146 + P^147 + 
    2*P^149 + P^150 + P^151 + P^152 + P^154 + P^155 + P^156 + P^157 + P^159 + P^160 + P^161 + P^162 + P^163 + P^164 + P^167 + 
    P^168 + P^171 + P^172 + P^173 + P^176 + P^178 + P^181 + P^189)/((1 - P^3)*(1 - P^61)*(1 - P^133))}, 
 {3, (P^10 + P^11 + P^15 + P^16 + P^18 + 2*P^23 + P^27 + 2*P^28 + P^30 + P^32 + P^33 + P^35 + P^37 + P^38 + P^39 + 2*P^40 + 
    P^42 + P^43 + P^44 + 2*P^45 + 2*P^47 + P^48 + P^49 + 2*P^50 + 2*P^52 + P^54 + 2*P^55 + P^56 + 2*P^57 + 2*P^59 + 2*P^60 + 
    P^61 + 2*P^62 + 2*P^64 + P^65 + P^66 + 2*P^67 + P^68 + 3*P^69 + P^70 + P^72 + P^73 + 3*P^74 + P^75 + P^76 + P^77 + P^78 + 
    2*P^79 + P^80 + 2*P^81 + 2*P^82 + P^83 + P^84 + P^85 + 3*P^86 + 2*P^87 + P^88 + P^90 + 2*P^91 + 2*P^92 + P^93 + P^94 + 
    P^95 + 2*P^96 + 2*P^97 + 2*P^98 + P^99 + P^101 + 2*P^102 + 2*P^103 + P^104 + P^105 + P^106 + 2*P^107 + P^108 + P^109 + 
    P^110 + P^111 + 2*P^112 + P^113 + 3*P^114 + 2*P^115 + P^116 + P^117 + P^118 + 3*P^119 + P^120 + P^122 + P^123 + 3*P^124 + 
    P^125 + P^126 + 2*P^127 + P^128 + 2*P^129 + 2*P^131 + 2*P^132 + P^133 + 2*P^134 + 2*P^136 + P^137 + P^138 + 2*P^139 + 
    2*P^141 + P^142 + P^143 + 2*P^144 + 2*P^146 + P^148 + P^149 + P^150 + 2*P^151 + P^153 + P^154 + P^155 + 2*P^156 + P^158 + 
    P^160 + 2*P^161 + P^163 + P^165 + P^166 + P^168 + P^170 + P^171 + P^173 + P^178 + P^182 + P^183 + P^187)/
   ((1 - P^3)*(1 - P^61)*(1 - P^133))}, {3, (P^3 + P^11 + P^16 + 2*P^20 + P^21 + 2*P^25 + P^28 + 2*P^30 + P^32 + P^33 + 
    2*P^35 + 2*P^37 + P^38 + P^40 + 2*P^42 + P^43 + P^45 + 2*P^47 + P^48 + 2*P^49 + P^50 + 2*P^52 + P^53 + 2*P^54 + P^55 + 
    3*P^57 + 2*P^59 + P^60 + P^61 + 3*P^62 + P^64 + P^65 + 2*P^66 + 3*P^67 + 2*P^69 + P^70 + 2*P^71 + P^72 + 3*P^74 + P^75 + 
    2*P^76 + 2*P^78 + 3*P^79 + P^80 + 2*P^83 + 3*P^84 + P^85 + P^86 + P^87 + 2*P^88 + 2*P^89 + P^90 + P^91 + P^92 + P^93 + 
    2*P^94 + 2*P^95 + P^96 + P^97 + 2*P^99 + 2*P^100 + 2*P^101 + P^102 + P^103 + P^104 + 2*P^105 + 2*P^106 + 3*P^107 + P^108 + 
    2*P^111 + 3*P^112 + P^113 + P^115 + 2*P^116 + 3*P^117 + P^119 + P^120 + 2*P^121 + 2*P^122 + 3*P^124 + P^125 + 2*P^126 + 
    3*P^129 + P^130 + 2*P^131 + P^132 + P^133 + 3*P^134 + 2*P^136 + P^137 + 2*P^138 + P^139 + 2*P^141 + P^142 + 2*P^143 + 
    P^144 + 2*P^146 + 2*P^148 + P^149 + 2*P^151 + 2*P^153 + P^154 + P^156 + 2*P^158 + P^159 + P^161 + 2*P^163 + P^165 + P^166 + 
    2*P^170 + P^171 + 2*P^175 + 2*P^180 + P^188)/((1 - P^3)*(1 - P^61)*(1 - P^133))}, 
 {3, (P^9 + P^13 + P^14 + P^17 + P^18 + P^22 + P^25 + P^26 + P^27 + P^29 + P^30 + P^31 + P^34 + P^35 + P^36 + P^38 + P^39 + 
    P^40 + P^41 + P^42 + P^43 + P^44 + P^45 + 2*P^46 + P^47 + P^48 + P^49 + P^50 + P^51 + P^52 + P^53 + 2*P^54 + P^55 + P^56 + 
    P^57 + 2*P^58 + 2*P^59 + P^60 + P^61 + P^62 + 2*P^63 + P^64 + P^65 + P^66 + 2*P^67 + 2*P^68 + P^69 + 2*P^71 + 2*P^72 + 
    2*P^73 + P^75 + 2*P^76 + 2*P^77 + P^78 + 2*P^80 + 2*P^81 + 2*P^82 + P^83 + 2*P^84 + 2*P^85 + P^86 + P^87 + P^88 + 2*P^89 + 
    P^90 + P^91 + P^92 + 2*P^93 + 2*P^94 + P^95 + P^96 + P^97 + 2*P^98 + P^99 + 2*P^100 + P^101 + P^102 + P^103 + 2*P^104 + 
    2*P^105 + P^106 + P^108 + 2*P^109 + 2*P^110 + P^111 + P^112 + 2*P^113 + 2*P^114 + P^115 + P^116 + 2*P^117 + 2*P^118 + 
    P^119 + 2*P^121 + 2*P^122 + 2*P^123 + P^125 + 2*P^126 + 2*P^127 + P^128 + P^129 + 2*P^130 + 2*P^131 + P^132 + P^133 + 
    P^134 + 2*P^135 + P^136 + P^137 + P^138 + P^139 + 2*P^140 + P^141 + P^142 + P^143 + P^144 + P^145 + P^146 + P^147 + P^148 + 
    P^149 + P^150 + P^151 + P^152 + P^153 + P^154 + P^155 + P^156 + P^157 + P^158 + P^159 + P^160 + P^162 + P^163 + P^164 + 
    P^167 + P^168 + P^169 + P^172 + P^173 + P^177 + P^181 + P^185 + P^186)/((1 - P^3)*(1 - P^61)*(1 - P^133))}, 
 {3, (P^8 + P^10 + P^15 + P^16 + P^20 + P^21 + P^25 + P^26 + P^27 + P^30 + P^31 + P^32 + P^33 + P^35 + 2*P^37 + P^38 + P^39 + 
    P^40 + 2*P^42 + P^43 + P^44 + P^45 + 2*P^47 + P^48 + P^49 + P^50 + 2*P^52 + P^53 + 2*P^54 + P^55 + P^56 + P^57 + P^58 + 
    2*P^59 + P^60 + P^61 + 2*P^62 + P^63 + 2*P^64 + P^65 + 2*P^66 + 2*P^67 + P^68 + P^69 + P^70 + P^71 + 2*P^72 + P^73 + 
    2*P^74 + P^75 + P^76 + P^77 + P^78 + 3*P^79 + P^80 + P^81 + 2*P^83 + 3*P^84 + 2*P^85 + P^86 + P^88 + 2*P^89 + 2*P^90 + 
    2*P^91 + P^93 + P^94 + 3*P^95 + 2*P^96 + P^97 + P^99 + 2*P^100 + 2*P^101 + 2*P^102 + P^104 + P^105 + 2*P^106 + 2*P^107 + 
    P^108 + P^109 + P^110 + 2*P^111 + 3*P^112 + P^113 + P^114 + 2*P^116 + 2*P^117 + 2*P^118 + P^119 + P^120 + P^121 + 2*P^122 + 
    P^123 + 2*P^124 + P^125 + P^126 + P^127 + P^128 + 2*P^129 + P^130 + 2*P^131 + P^132 + P^133 + 2*P^134 + P^135 + 2*P^136 + 
    P^137 + P^138 + 2*P^139 + 2*P^141 + P^142 + 2*P^143 + P^144 + P^146 + P^147 + 2*P^148 + P^149 + P^150 + P^151 + 2*P^153 + 
    P^154 + P^155 + 2*P^158 + P^159 + P^160 + P^163 + P^164 + P^165 + P^166 + P^168 + P^170 + P^171 + P^175 + P^176 + P^180 + 
    P^182 + P^187)/((1 - P^3)*(1 - P^61)*(1 - P^133))}, 
 {3, (P^9 + 2*P^14 + P^16 + P^19 + P^21 + P^24 + 2*P^26 + P^28 + 2*P^31 + P^33 + 2*P^36 + 2*P^38 + 2*P^41 + 3*P^43 + P^45 + 
    2*P^46 + 3*P^48 + P^50 + P^51 + 3*P^53 + 2*P^55 + P^56 + P^57 + 3*P^58 + 3*P^60 + P^62 + 2*P^63 + 3*P^65 + 2*P^67 + 
    2*P^68 + 2*P^70 + 3*P^72 + 2*P^73 + P^74 + P^75 + 2*P^77 + 2*P^78 + P^79 + 2*P^80 + 2*P^82 + P^83 + 2*P^84 + 2*P^85 + 
    P^86 + P^87 + P^88 + 2*P^89 + 3*P^90 + P^91 + P^92 + 2*P^94 + 2*P^95 + 2*P^96 + P^97 + P^99 + 2*P^100 + 3*P^101 + P^102 + 
    P^103 + 2*P^105 + 2*P^106 + P^107 + P^108 + 2*P^110 + 2*P^111 + 2*P^112 + 2*P^113 + 2*P^115 + P^116 + 2*P^117 + 2*P^118 + 
    2*P^120 + 3*P^122 + 2*P^123 + P^124 + 2*P^125 + 2*P^127 + P^128 + P^129 + 3*P^130 + 3*P^132 + P^134 + 2*P^135 + 3*P^137 + 
    P^139 + 2*P^140 + 3*P^142 + 2*P^144 + P^145 + 2*P^147 + 2*P^149 + 2*P^152 + 3*P^154 + P^156 + P^157 + 3*P^159 + P^161 + 
    2*P^164 + P^166 + 2*P^169 + P^171 + P^174 + P^176 + P^181 + P^186 + P^188)/((1 - P^3)*(1 - P^61)*(1 - P^133))}, 
 {3, (P^6 + P^10 + P^11 + P^18 + P^22 + 2*P^23 + P^27 + 2*P^28 + P^32 + 2*P^33 + P^35 + P^37 + 2*P^38 + P^39 + 2*P^40 + P^42 + 
    P^43 + P^44 + 2*P^45 + P^47 + P^49 + 2*P^50 + P^51 + 2*P^52 + P^54 + 2*P^55 + P^56 + 2*P^57 + P^59 + 2*P^60 + P^61 + 
    2*P^62 + 2*P^64 + 2*P^65 + P^66 + P^67 + P^68 + 3*P^69 + 2*P^70 + P^72 + P^73 + 3*P^74 + P^75 + P^76 + 2*P^77 + P^78 + 
    2*P^79 + P^80 + 3*P^81 + 2*P^82 + P^85 + 3*P^86 + 2*P^87 + P^90 + 3*P^91 + 2*P^92 + P^93 + P^95 + 2*P^96 + 3*P^97 + 
    2*P^98 + P^101 + 3*P^102 + 2*P^103 + P^104 + P^106 + 2*P^107 + 2*P^108 + 2*P^109 + 2*P^110 + P^111 + P^112 + P^113 + 
    3*P^114 + 2*P^115 + P^118 + 3*P^119 + 2*P^120 + P^122 + P^123 + 3*P^124 + P^125 + P^126 + 2*P^127 + P^128 + 2*P^129 + 
    P^131 + 2*P^132 + P^133 + 2*P^134 + 2*P^136 + 2*P^137 + P^138 + 2*P^139 + 2*P^141 + P^143 + 2*P^144 + P^145 + 2*P^146 + 
    P^148 + 2*P^149 + P^150 + 2*P^151 + P^153 + P^154 + P^155 + 2*P^156 + P^160 + 2*P^161 + P^165 + 2*P^166 + P^168 + P^170 + 
    P^173 + P^177 + 2*P^178 + P^182 + P^183)/((1 - P^3)*(1 - P^61)*(1 - P^133))}, 
 {3, (P^3 + P^14 + P^17 + P^19 + P^20 + P^22 + P^24 + P^25 + P^27 + P^30 + P^31 + 2*P^32 + P^34 + P^35 + P^36 + P^37 + P^39 + 
    P^41 + P^42 + P^43 + P^44 + 2*P^46 + P^47 + P^48 + 2*P^49 + 2*P^51 + P^52 + P^53 + 2*P^54 + 2*P^56 + P^57 + P^58 + 2*P^59 + 
    P^60 + 2*P^61 + P^62 + 2*P^63 + P^64 + P^65 + 2*P^66 + P^67 + 2*P^68 + P^69 + P^70 + 2*P^71 + P^72 + 2*P^73 + P^74 + P^75 + 
    2*P^76 + P^77 + 2*P^78 + P^79 + P^80 + P^81 + P^82 + 2*P^83 + P^84 + P^85 + P^86 + P^87 + 2*P^88 + 2*P^89 + 2*P^90 + P^91 + 
    P^92 + P^93 + 2*P^94 + 2*P^95 + P^96 + P^97 + P^98 + 2*P^99 + 2*P^100 + 2*P^101 + P^102 + P^103 + P^104 + 2*P^105 + 
    2*P^106 + P^107 + P^108 + P^109 + P^110 + 2*P^111 + P^112 + P^113 + P^114 + P^115 + 2*P^116 + P^117 + 2*P^118 + P^119 + 
    P^120 + 2*P^121 + P^122 + 2*P^123 + P^124 + P^125 + 2*P^126 + P^127 + 2*P^128 + P^129 + P^130 + 2*P^131 + P^132 + 2*P^133 + 
    P^134 + 2*P^135 + P^136 + P^137 + 2*P^138 + 2*P^140 + P^141 + P^142 + 2*P^143 + 2*P^145 + P^146 + P^147 + 2*P^148 + P^150 + 
    P^151 + P^152 + P^153 + P^155 + P^157 + P^158 + P^159 + P^160 + P^162 + P^163 + P^164 + P^165 + P^167 + P^169 + P^170 + 
    P^172 + P^174 + P^175 + P^177 + P^180 + P^191)/((1 - P^3)*(1 - P^61)*(1 - P^133))}, 
 {3, (P^8 + P^12 + P^13 + P^17 + P^19 + 2*P^24 + P^25 + 2*P^29 + P^30 + P^31 + P^34 + P^35 + P^36 + P^37 + P^39 + P^40 + 
    2*P^41 + P^42 + P^44 + P^45 + 2*P^46 + P^47 + P^48 + P^49 + 2*P^51 + P^52 + 2*P^53 + P^54 + 2*P^56 + P^57 + 2*P^58 + P^59 + 
    P^60 + 2*P^61 + P^62 + 2*P^63 + P^64 + P^65 + 2*P^66 + P^67 + 2*P^68 + 2*P^70 + 2*P^71 + P^72 + P^73 + 2*P^75 + 2*P^76 + 
    2*P^77 + P^78 + P^79 + P^80 + 2*P^81 + 2*P^82 + 3*P^83 + P^84 + 2*P^87 + 3*P^88 + 2*P^89 + P^92 + 3*P^93 + 2*P^94 + P^95 + 
    P^97 + 2*P^98 + 3*P^99 + 2*P^100 + P^103 + 3*P^104 + 2*P^105 + P^106 + P^108 + 2*P^109 + 2*P^110 + 2*P^111 + P^112 + 
    P^113 + P^114 + 2*P^115 + 3*P^116 + P^117 + P^118 + 2*P^120 + 2*P^121 + P^122 + P^123 + 2*P^125 + 2*P^126 + P^127 + 
    2*P^128 + P^129 + 2*P^130 + P^131 + P^132 + 2*P^133 + P^134 + 2*P^135 + P^136 + P^137 + P^138 + P^139 + 2*P^140 + P^141 + 
    P^142 + P^143 + 2*P^145 + P^146 + 2*P^147 + P^148 + P^150 + P^151 + 2*P^152 + P^153 + P^155 + P^156 + 2*P^157 + P^158 + 
    2*P^162 + P^163 + P^164 + P^167 + P^168 + P^169 + P^172 + P^174 + P^179 + P^180 + P^184 + P^185)/
   ((1 - P^3)*(1 - P^61)*(1 - P^133))}};
Generating51={{1, (1 + P^16 + P^23 + P^30 + P^32 + P^37 + P^39 + P^44 + P^46 + P^48 + P^53 + P^55 + P^57 + P^60 + P^62 + P^64 + P^67 + 
    P^69 + P^71 + P^73 + P^74 + P^76 + P^78 + P^80 + P^81 + P^83 + P^87 + P^88 + P^89 + P^90 + P^92 + P^94 + P^96 + P^97 + 
    P^98 + P^99 + P^103 + P^104 + P^105 + P^106 + P^110 + P^111 + P^112 + P^113 + P^114 + P^118 + P^119 + P^120 + P^121 + 
    P^125 + P^126 + P^127 + P^128 + P^130 + P^132 + P^134 + P^135 + P^136 + P^137 + P^141 + P^143 + P^144 + P^146 + P^148 + 
    P^150 + P^151 + P^153 + P^155 + P^157 + P^160 + P^162 + P^164 + P^167 + P^169 + P^171 + P^176 + P^178 + P^180 + P^185 + 
    P^187 + P^192 + P^194 + P^201 + P^208 + P^224)/((1 - P^3)*(1 - P^85)*(1 - P^139))}, 
 {1, (P^16 + P^23 + P^30 + P^32 + P^37 + P^39 + P^44 + P^46 + P^48 + P^53 + P^55 + P^57 + P^60 + P^62 + P^64 + P^67 + P^69 + 
    P^71 + P^73 + P^74 + P^76 + P^78 + P^80 + P^81 + P^83 + P^85 + P^87 + P^88 + P^89 + P^90 + P^92 + P^94 + P^96 + P^97 + 
    P^98 + P^99 + P^103 + P^104 + P^105 + P^106 + P^110 + P^111 + P^112 + P^113 + P^114 + P^118 + P^119 + P^120 + P^121 + 
    P^125 + P^126 + P^127 + P^128 + P^130 + P^132 + P^134 + P^135 + P^136 + P^137 + P^139 + P^141 + P^143 + P^144 + P^146 + 
    P^148 + P^150 + P^151 + P^153 + P^155 + P^157 + P^160 + P^162 + P^164 + P^167 + P^169 + P^171 + P^176 + P^178 + P^180 + 
    P^185 + P^187 + P^192 + P^194 + P^201 + P^208)/((1 - P^3)*(1 - P^85)*(1 - P^139))}, 
 {1, (P^16 + P^23 + P^30 + P^32 + P^37 + P^39 + P^44 + P^46 + P^48 + P^53 + P^55 + P^57 + P^60 + P^62 + P^64 + P^67 + P^69 + 
    P^71 + P^73 + P^74 + P^76 + P^78 + P^80 + P^81 + P^83 + P^85 + P^87 + P^88 + P^89 + P^90 + P^92 + P^94 + P^96 + P^97 + 
    P^98 + P^99 + P^103 + P^104 + P^105 + P^106 + P^110 + P^111 + P^112 + P^113 + P^114 + P^118 + P^119 + P^120 + P^121 + 
    P^125 + P^126 + P^127 + P^128 + P^130 + P^132 + P^134 + P^135 + P^136 + P^137 + P^139 + P^141 + P^143 + P^144 + P^146 + 
    P^148 + P^150 + P^151 + P^153 + P^155 + P^157 + P^160 + P^162 + P^164 + P^167 + P^169 + P^171 + P^176 + P^178 + P^180 + 
    P^185 + P^187 + P^192 + P^194 + P^201 + P^208)/((1 - P^3)*(1 - P^85)*(1 - P^139))}, 
 {3, (P^5 + P^12 + P^15 + P^19 + P^21 + P^22 + P^26 + 2*P^28 + P^29 + P^31 + P^33 + 2*P^35 + P^36 + P^37 + P^38 + 2*P^42 + 
    P^43 + 2*P^44 + P^45 + P^46 + P^47 + 2*P^49 + 2*P^51 + P^52 + 2*P^53 + P^54 + 2*P^56 + 2*P^58 + P^59 + 2*P^60 + P^61 + 
    P^62 + 2*P^63 + 2*P^65 + P^66 + 2*P^67 + P^68 + 2*P^69 + 2*P^70 + 3*P^72 + P^73 + 2*P^74 + P^75 + 2*P^76 + 2*P^77 + P^78 + 
    3*P^79 + P^80 + 2*P^81 + P^82 + 2*P^83 + P^84 + 2*P^85 + 3*P^86 + 2*P^87 + 3*P^88 + P^89 + P^90 + P^91 + 2*P^92 + 3*P^93 + 
    2*P^94 + 3*P^95 + P^96 + P^97 + P^98 + 2*P^99 + 2*P^100 + 2*P^101 + 3*P^102 + 2*P^103 + 2*P^104 + P^105 + P^106 + P^107 + 
    2*P^108 + 3*P^109 + 3*P^110 + 2*P^111 + P^112 + P^113 + P^114 + 2*P^115 + 2*P^116 + 3*P^117 + 2*P^118 + 2*P^119 + P^120 + 
    P^121 + P^122 + 2*P^123 + 3*P^124 + 3*P^125 + 3*P^126 + P^127 + P^128 + P^129 + 2*P^130 + 2*P^131 + 2*P^132 + 3*P^133 + 
    P^134 + 2*P^135 + P^136 + 2*P^137 + P^138 + 2*P^139 + 3*P^140 + P^141 + 3*P^142 + P^143 + 2*P^144 + P^145 + 2*P^146 + 
    2*P^147 + P^148 + 3*P^149 + P^150 + 2*P^151 + P^152 + 2*P^153 + P^154 + P^155 + 3*P^156 + 2*P^158 + P^159 + 2*P^160 + 
    P^161 + P^162 + 2*P^163 + 2*P^165 + P^166 + 2*P^167 + P^168 + 2*P^169 + P^170 + P^172 + 2*P^174 + P^175 + 2*P^176 + P^177 + 
    P^179 + 2*P^181 + P^182 + 2*P^183 + P^184 + P^186 + P^188 + 2*P^190 + P^191 + P^192 + P^193 + 2*P^197 + P^199 + P^200 + 
    P^204 + P^206 + P^207 + P^213 + P^220)/((1 - P^3)*(1 - P^85)*(1 - P^139))}, 
 {3, (P^5 + P^12 + P^13 + P^20 + 2*P^21 + P^22 + 2*P^28 + P^29 + P^30 + 2*P^35 + P^36 + 2*P^37 + P^38 + 2*P^42 + P^43 + 
    2*P^44 + P^45 + P^46 + 2*P^49 + P^50 + 2*P^51 + P^52 + 2*P^53 + P^54 + P^56 + P^57 + 2*P^58 + P^59 + 2*P^60 + P^61 + 
    2*P^62 + P^63 + P^64 + 2*P^65 + P^66 + 2*P^67 + P^68 + 2*P^69 + P^70 + P^71 + 2*P^72 + P^73 + 2*P^74 + P^75 + 2*P^76 + 
    P^77 + 2*P^78 + 3*P^79 + P^80 + 2*P^81 + P^82 + 2*P^83 + P^84 + 2*P^85 + 3*P^86 + 2*P^87 + 2*P^88 + P^89 + P^90 + P^91 + 
    2*P^92 + 3*P^93 + 3*P^94 + 3*P^95 + P^96 + P^97 + 2*P^99 + 2*P^100 + 3*P^101 + 3*P^102 + 3*P^103 + 2*P^104 + P^107 + 
    3*P^108 + 3*P^109 + 3*P^110 + 3*P^111 + P^112 + 2*P^115 + 3*P^116 + 3*P^117 + 3*P^118 + 3*P^119 + P^120 + 2*P^123 + 
    3*P^124 + 3*P^125 + 3*P^126 + P^127 + P^128 + 2*P^130 + 2*P^131 + 3*P^132 + 3*P^133 + P^134 + 2*P^135 + P^136 + 2*P^137 + 
    P^138 + 2*P^139 + 3*P^140 + 2*P^141 + 2*P^142 + P^143 + 2*P^144 + P^145 + 2*P^146 + P^147 + 2*P^148 + 2*P^149 + P^150 + 
    2*P^151 + P^152 + 2*P^153 + P^154 + 2*P^155 + 2*P^156 + P^157 + 2*P^158 + P^159 + 2*P^160 + P^161 + 2*P^162 + P^163 + 
    2*P^165 + P^166 + 2*P^167 + P^168 + 2*P^169 + P^170 + P^172 + P^173 + 2*P^174 + P^175 + 2*P^176 + P^177 + 2*P^181 + P^182 + 
    2*P^183 + P^184 + P^185 + P^189 + 2*P^190 + P^191 + P^192 + 2*P^197 + P^198 + 2*P^199 + 2*P^206 + P^207 + P^213 + P^214)/
   ((1 - P^3)*(1 - P^85)*(1 - P^139))}, {3, (P^6 + 2*P^13 + 2*P^20 + P^22 + 2*P^27 + 3*P^29 + 2*P^34 + 3*P^36 + P^38 + P^41 + 
    3*P^43 + 3*P^45 + P^47 + 3*P^50 + 3*P^52 + 2*P^54 + 3*P^57 + 3*P^59 + 3*P^61 + P^63 + 2*P^64 + 3*P^66 + 3*P^68 + 3*P^70 + 
    2*P^71 + 3*P^73 + 3*P^75 + 3*P^77 + 2*P^78 + P^79 + 3*P^80 + 3*P^82 + 3*P^84 + P^85 + 3*P^86 + 3*P^87 + P^88 + 3*P^89 + 
    2*P^91 + 3*P^93 + 3*P^94 + 2*P^95 + 3*P^96 + P^98 + 3*P^100 + 3*P^101 + 3*P^102 + 3*P^103 + P^104 + P^105 + 2*P^107 + 
    2*P^108 + 3*P^109 + 3*P^110 + 3*P^111 + P^112 + 2*P^115 + 3*P^116 + 3*P^117 + 3*P^118 + P^119 + P^120 + 2*P^122 + 2*P^123 + 
    3*P^124 + 3*P^125 + 2*P^126 + 3*P^127 + 2*P^129 + 3*P^131 + 2*P^132 + 3*P^133 + 3*P^134 + 2*P^136 + 3*P^138 + P^139 + 
    3*P^140 + 3*P^141 + 3*P^143 + 3*P^145 + 3*P^147 + 2*P^148 + P^149 + 3*P^150 + 3*P^152 + 3*P^154 + P^156 + 3*P^157 + 
    3*P^159 + 3*P^161 + P^163 + 2*P^164 + 3*P^166 + 3*P^168 + 2*P^170 + 2*P^173 + 3*P^175 + 3*P^177 + P^180 + 3*P^182 + 
    3*P^184 + 2*P^189 + 3*P^191 + P^193 + 3*P^198 + P^200 + 2*P^205 + P^207 + P^214 + P^221)/
   ((1 - P^3)*(1 - P^85)*(1 - P^139))}, {3, (P^2 + 2*P^15 + P^18 + 2*P^22 + P^25 + 2*P^29 + 2*P^31 + P^32 + P^34 + 2*P^36 + 
    2*P^38 + P^39 + P^41 + 2*P^43 + 2*P^45 + P^46 + 2*P^47 + P^48 + P^50 + 2*P^52 + 2*P^54 + P^55 + 2*P^56 + P^57 + 3*P^59 + 
    2*P^61 + P^62 + 2*P^63 + P^64 + 3*P^66 + 2*P^68 + P^69 + 2*P^70 + P^71 + 2*P^72 + 3*P^73 + 3*P^75 + P^76 + 2*P^77 + P^78 + 
    2*P^79 + 3*P^80 + 3*P^82 + P^83 + 2*P^84 + P^85 + 2*P^86 + 2*P^87 + 2*P^88 + 3*P^89 + P^90 + 3*P^91 + P^92 + 2*P^93 + 
    P^94 + 2*P^95 + 3*P^96 + 2*P^97 + 3*P^98 + P^99 + P^100 + P^101 + 2*P^102 + 2*P^103 + 2*P^104 + 3*P^105 + P^106 + P^107 + 
    P^108 + 2*P^109 + 2*P^110 + 2*P^111 + 3*P^112 + 3*P^113 + P^114 + P^115 + P^116 + 2*P^117 + 2*P^118 + 2*P^119 + 3*P^120 + 
    P^121 + P^122 + P^123 + 2*P^124 + 2*P^125 + 2*P^126 + 3*P^127 + P^128 + 3*P^129 + P^130 + 2*P^131 + P^132 + 2*P^133 + 
    3*P^134 + 2*P^135 + 3*P^136 + P^137 + 2*P^138 + P^139 + 2*P^140 + P^141 + 2*P^142 + 3*P^143 + 3*P^145 + P^146 + 2*P^147 + 
    P^148 + 2*P^149 + 3*P^150 + 3*P^152 + P^153 + 2*P^154 + P^155 + 2*P^156 + P^157 + 3*P^159 + 2*P^161 + P^162 + 2*P^163 + 
    P^164 + 3*P^166 + 2*P^168 + P^169 + 2*P^170 + P^171 + P^173 + 2*P^175 + 2*P^177 + P^178 + 2*P^179 + P^180 + P^182 + 
    2*P^184 + 2*P^186 + P^187 + P^189 + 2*P^191 + 2*P^193 + P^194 + P^196 + 2*P^200 + P^203 + 2*P^207 + P^210 + P^223)/
   ((1 - P^3)*(1 - P^85)*(1 - P^139))}, {3, (P^4 + 2*P^14 + P^20 + 2*P^21 + P^27 + 2*P^28 + 2*P^30 + P^34 + 2*P^35 + P^36 + 
    2*P^37 + P^41 + P^42 + P^43 + 2*P^44 + P^45 + 2*P^46 + P^48 + P^50 + 2*P^51 + P^52 + 2*P^53 + 2*P^55 + P^57 + 2*P^58 + 
    P^59 + 2*P^60 + P^61 + 2*P^62 + P^64 + 2*P^65 + P^66 + 2*P^67 + P^68 + 2*P^69 + 3*P^71 + 2*P^72 + P^73 + 2*P^74 + P^75 + 
    2*P^76 + P^77 + 3*P^78 + 2*P^79 + P^80 + 2*P^81 + P^82 + 2*P^83 + P^84 + 3*P^85 + 2*P^86 + 3*P^87 + 2*P^88 + 2*P^90 + 
    P^91 + 3*P^92 + P^93 + 3*P^94 + 2*P^95 + 2*P^96 + 2*P^97 + P^98 + P^99 + P^100 + 3*P^101 + 3*P^102 + 3*P^103 + 2*P^104 + 
    P^107 + 3*P^108 + 3*P^109 + 3*P^110 + 2*P^111 + 2*P^112 + P^114 + P^115 + 3*P^116 + 3*P^117 + 3*P^118 + 2*P^119 + P^122 + 
    3*P^123 + 3*P^124 + 3*P^125 + 2*P^126 + P^127 + 2*P^128 + P^129 + 2*P^130 + P^131 + 3*P^132 + 2*P^133 + 3*P^134 + 2*P^135 + 
    P^136 + P^137 + P^138 + 3*P^139 + P^140 + 3*P^141 + 2*P^142 + P^143 + 2*P^144 + P^145 + 2*P^146 + P^147 + 3*P^148 + 
    2*P^149 + P^150 + 2*P^151 + P^152 + 2*P^153 + P^154 + 3*P^155 + P^157 + 2*P^158 + P^159 + 2*P^160 + P^161 + 2*P^162 + 
    P^164 + 2*P^165 + P^166 + 2*P^167 + P^168 + 2*P^169 + P^171 + P^173 + 2*P^174 + P^175 + 2*P^176 + 2*P^178 + P^180 + P^181 + 
    P^182 + 2*P^183 + 2*P^185 + P^189 + 2*P^190 + P^191 + 2*P^192 + P^196 + P^198 + 2*P^199 + P^205 + 2*P^206 + P^212 + P^222)/
   ((1 - P^3)*(1 - P^85)*(1 - P^139))}, {3, (P^9 + P^11 + P^16 + P^18 + P^19 + P^23 + P^25 + P^26 + P^27 + P^28 + P^32 + P^33 + 
    P^34 + P^35 + P^36 + P^39 + P^40 + 2*P^41 + P^42 + P^43 + P^44 + P^46 + 2*P^48 + P^49 + 2*P^50 + P^51 + P^52 + P^53 + 
    2*P^55 + P^56 + 2*P^57 + P^58 + P^59 + 2*P^60 + 2*P^62 + P^63 + 2*P^64 + P^65 + 2*P^66 + 2*P^67 + P^68 + 2*P^69 + P^70 + 
    2*P^71 + P^72 + 2*P^73 + P^74 + P^75 + 2*P^76 + 2*P^77 + 2*P^78 + P^79 + 2*P^80 + P^81 + 2*P^82 + 2*P^83 + 2*P^84 + 
    3*P^85 + P^86 + 2*P^87 + P^88 + 2*P^89 + 2*P^90 + 2*P^91 + 3*P^92 + 2*P^93 + P^94 + P^95 + P^96 + 2*P^97 + 2*P^98 + 
    3*P^99 + 2*P^100 + 2*P^101 + P^102 + P^103 + P^104 + 2*P^105 + 3*P^106 + 3*P^107 + 2*P^108 + 2*P^109 + P^110 + P^111 + 
    P^112 + 2*P^113 + 3*P^114 + 3*P^115 + 2*P^116 + 2*P^117 + P^118 + P^119 + P^120 + 2*P^121 + 3*P^122 + 3*P^123 + 2*P^124 + 
    P^125 + P^126 + P^127 + 2*P^128 + 2*P^129 + 3*P^130 + 2*P^131 + 2*P^132 + P^133 + 2*P^134 + P^135 + 2*P^136 + 2*P^137 + 
    2*P^138 + 3*P^139 + P^140 + 2*P^141 + P^142 + 2*P^143 + 2*P^144 + P^145 + 3*P^146 + P^147 + 2*P^148 + P^149 + 2*P^150 + 
    P^151 + P^152 + 2*P^153 + P^154 + 2*P^155 + P^156 + 2*P^157 + P^158 + 2*P^159 + 2*P^160 + P^161 + P^162 + P^163 + 2*P^164 + 
    P^165 + 2*P^166 + P^167 + P^168 + P^169 + 2*P^171 + P^172 + 2*P^173 + P^174 + P^175 + P^176 + P^178 + P^179 + 2*P^180 + 
    P^181 + P^182 + P^183 + P^185 + 2*P^187 + P^188 + P^189 + P^190 + P^194 + P^195 + P^196 + P^197 + P^201 + P^203 + P^204 + 
    P^205 + P^210 + P^212 + P^217)/((1 - P^3)*(1 - P^85)*(1 - P^139))}, 
 {3, (P^9 + P^14 + 2*P^16 + P^21 + 2*P^23 + P^25 + P^28 + 2*P^30 + 2*P^32 + 2*P^37 + 3*P^39 + 2*P^41 + P^44 + 3*P^46 + 2*P^48 + 
    P^50 + P^51 + 3*P^53 + 3*P^55 + 2*P^57 + P^58 + 3*P^60 + 3*P^62 + 2*P^64 + P^65 + P^66 + 3*P^67 + 3*P^69 + 3*P^71 + P^72 + 
    2*P^73 + 2*P^74 + 3*P^76 + 3*P^78 + 3*P^80 + 2*P^81 + 2*P^82 + 3*P^83 + 3*P^85 + 3*P^87 + P^88 + 2*P^89 + 3*P^90 + P^91 + 
    3*P^92 + 2*P^94 + P^95 + 3*P^96 + 3*P^97 + 2*P^98 + 2*P^99 + P^101 + P^102 + 3*P^103 + 3*P^104 + 2*P^105 + 2*P^106 + 
    P^107 + P^108 + P^109 + 2*P^110 + 3*P^111 + 3*P^112 + 2*P^113 + 2*P^114 + P^115 + P^116 + P^117 + 2*P^118 + 3*P^119 + 
    3*P^120 + 3*P^121 + P^122 + 2*P^123 + 2*P^125 + P^126 + 3*P^127 + 3*P^128 + 2*P^129 + 2*P^130 + 2*P^132 + P^133 + 3*P^134 + 
    2*P^135 + 2*P^136 + 3*P^137 + 3*P^139 + 3*P^141 + P^142 + 2*P^143 + 3*P^144 + 3*P^146 + 3*P^148 + P^149 + 2*P^150 + 
    2*P^151 + 3*P^153 + 3*P^155 + 2*P^157 + P^158 + P^159 + 3*P^160 + 3*P^162 + 3*P^164 + P^166 + P^167 + 3*P^169 + 3*P^171 + 
    2*P^173 + P^174 + 2*P^176 + 3*P^178 + 2*P^180 + P^183 + 3*P^185 + 2*P^187 + P^190 + 2*P^192 + 2*P^194 + P^199 + 2*P^201 + 
    P^203 + P^208 + P^210 + P^215 + P^217)/((1 - P^3)*(1 - P^85)*(1 - P^139))}, 
 {3, (P^9 + P^10 + P^11 + P^18 + P^19 + P^20 + P^25 + P^26 + P^27 + P^32 + P^33 + 2*P^34 + P^35 + P^36 + P^39 + P^40 + 2*P^41 + 
    P^42 + P^43 + P^46 + P^47 + 2*P^48 + P^49 + 2*P^50 + P^51 + P^52 + P^53 + P^54 + 2*P^55 + P^56 + 2*P^57 + P^58 + P^59 + 
    P^60 + P^61 + 2*P^62 + P^63 + 2*P^64 + P^65 + 2*P^66 + P^67 + P^68 + P^69 + P^70 + 2*P^71 + P^72 + 2*P^73 + P^74 + 2*P^75 + 
    2*P^76 + 2*P^77 + 2*P^78 + P^79 + 2*P^80 + P^81 + 2*P^82 + 2*P^83 + 2*P^84 + 2*P^85 + P^86 + 2*P^87 + P^88 + 2*P^89 + 
    2*P^90 + 3*P^91 + 3*P^92 + 2*P^93 + P^94 + P^96 + 2*P^97 + 3*P^98 + 3*P^99 + 2*P^100 + 2*P^101 + P^102 + P^103 + P^104 + 
    2*P^105 + 3*P^106 + 3*P^107 + 3*P^108 + 2*P^109 + P^110 + P^112 + 2*P^113 + 3*P^114 + 3*P^115 + 3*P^116 + 2*P^117 + P^118 + 
    P^120 + 2*P^121 + 3*P^122 + 3*P^123 + 2*P^124 + P^125 + P^127 + 2*P^128 + 3*P^129 + 3*P^130 + 2*P^131 + 2*P^132 + P^133 + 
    2*P^134 + P^135 + 2*P^136 + 2*P^137 + 2*P^138 + 2*P^139 + P^140 + 2*P^141 + P^142 + 2*P^143 + 2*P^144 + 2*P^145 + 2*P^146 + 
    P^147 + 2*P^148 + P^149 + 2*P^150 + P^151 + 2*P^152 + 2*P^153 + 2*P^154 + 2*P^155 + P^156 + 2*P^157 + P^158 + 2*P^159 + 
    P^160 + P^161 + P^162 + P^163 + 2*P^164 + P^165 + 2*P^166 + P^167 + P^168 + P^169 + P^170 + 2*P^171 + P^172 + 2*P^173 + 
    P^174 + P^175 + P^178 + P^179 + 2*P^180 + P^181 + P^182 + P^185 + P^186 + 2*P^187 + P^188 + P^189 + P^194 + P^195 + 
    2*P^196 + P^197 + P^198 + P^203 + P^204 + P^205 + P^210 + P^211 + P^212)/((1 - P^3)*(1 - P^85)*(1 - P^139))}, 
 {3, (P^8 + P^9 + P^15 + P^16 + P^22 + P^23 + P^24 + P^25 + P^29 + 2*P^31 + P^32 + P^33 + P^36 + 2*P^38 + P^39 + P^40 + P^41 + 
    P^43 + 2*P^45 + P^46 + 2*P^47 + P^48 + P^49 + P^50 + 2*P^52 + P^53 + 2*P^54 + P^55 + P^56 + P^57 + 2*P^59 + P^60 + 2*P^61 + 
    P^62 + 2*P^63 + P^64 + P^65 + 2*P^66 + P^67 + 2*P^68 + P^69 + 2*P^70 + P^71 + 2*P^72 + 2*P^73 + P^74 + 2*P^75 + P^76 + 
    2*P^77 + P^78 + 2*P^79 + 2*P^80 + P^81 + 3*P^82 + P^83 + 2*P^84 + P^85 + 2*P^86 + 2*P^87 + 2*P^88 + 3*P^89 + 2*P^90 + 
    2*P^91 + P^92 + P^93 + P^94 + 2*P^95 + 3*P^96 + 2*P^97 + 3*P^98 + P^99 + P^100 + 2*P^102 + 3*P^103 + 3*P^104 + 3*P^105 + 
    2*P^106 + 2*P^107 + P^109 + P^110 + 3*P^111 + 3*P^112 + 3*P^113 + 2*P^114 + P^115 + P^117 + 2*P^118 + 3*P^119 + 3*P^120 + 
    2*P^121 + 2*P^122 + P^123 + P^124 + P^125 + 2*P^126 + 3*P^127 + 2*P^128 + 3*P^129 + P^130 + 2*P^131 + 2*P^133 + 2*P^134 + 
    2*P^135 + 3*P^136 + P^137 + 2*P^138 + P^139 + 2*P^140 + 2*P^141 + 2*P^142 + 3*P^143 + P^144 + 2*P^145 + P^146 + 2*P^147 + 
    P^148 + 2*P^149 + 2*P^150 + P^151 + 2*P^152 + P^153 + 2*P^154 + P^155 + 2*P^156 + P^157 + P^158 + 2*P^159 + P^160 + 
    2*P^161 + P^162 + 2*P^163 + P^164 + P^165 + 2*P^166 + 2*P^168 + P^169 + 2*P^170 + P^171 + P^172 + P^173 + P^175 + P^176 + 
    2*P^177 + P^178 + P^179 + P^180 + P^182 + 2*P^184 + P^185 + 2*P^186 + P^187 + P^191 + 2*P^193 + P^194 + P^195 + 2*P^200 + 
    P^201 + P^202 + P^207 + P^209 + P^210 + P^217)/((1 - P^3)*(1 - P^85)*(1 - P^139))}, 
 {3, (P^11 + P^13 + P^15 + P^18 + P^20 + P^22 + P^25 + 2*P^27 + 2*P^29 + P^31 + P^34 + 2*P^36 + 2*P^38 + P^40 + P^41 + 2*P^43 + 
    2*P^45 + P^47 + P^48 + 2*P^50 + 3*P^52 + 2*P^54 + P^55 + P^56 + 2*P^57 + 3*P^59 + 2*P^61 + P^62 + P^63 + 2*P^64 + 3*P^66 + 
    3*P^68 + P^69 + 2*P^70 + 2*P^71 + P^72 + 3*P^73 + 3*P^75 + 2*P^77 + P^78 + 2*P^79 + 3*P^80 + P^81 + 3*P^82 + 3*P^84 + 
    P^85 + 2*P^86 + 2*P^87 + P^88 + 3*P^89 + 3*P^91 + P^92 + 3*P^93 + 2*P^94 + 2*P^95 + 2*P^96 + P^97 + 2*P^98 + P^99 + 
    2*P^100 + 2*P^101 + 2*P^102 + 2*P^103 + P^104 + 2*P^105 + P^106 + 2*P^107 + 2*P^108 + 3*P^109 + 2*P^110 + 2*P^111 + P^112 + 
    2*P^113 + P^114 + 2*P^115 + 2*P^116 + 3*P^117 + 2*P^118 + 2*P^119 + 2*P^120 + P^121 + 2*P^122 + P^123 + 3*P^124 + 2*P^125 + 
    2*P^126 + 2*P^127 + P^128 + 2*P^129 + P^130 + 2*P^131 + 2*P^132 + 2*P^133 + 3*P^134 + P^135 + 3*P^136 + 3*P^138 + P^139 + 
    2*P^140 + 2*P^141 + P^142 + 3*P^143 + 3*P^145 + P^146 + 2*P^147 + 2*P^148 + P^149 + 3*P^150 + 3*P^152 + 2*P^154 + P^155 + 
    P^156 + 2*P^157 + 3*P^159 + 3*P^161 + P^162 + 2*P^163 + P^164 + 2*P^166 + 3*P^168 + 2*P^170 + P^171 + P^172 + 2*P^173 + 
    3*P^175 + 2*P^177 + P^179 + P^180 + 2*P^182 + 2*P^184 + P^186 + P^187 + 2*P^189 + 2*P^191 + P^193 + P^196 + P^198 + P^200 + 
    P^203 + P^205 + P^207 + P^212 + P^214 + P^216)/((1 - P^3)*(1 - P^85)*(1 - P^139))}, 
 {3, (P^10 + P^14 + P^15 + P^17 + P^21 + P^22 + P^24 + P^26 + P^28 + P^29 + P^30 + P^31 + P^33 + P^35 + P^37 + P^38 + P^39 + 
    2*P^40 + P^42 + P^44 + P^45 + P^46 + 2*P^47 + P^49 + 2*P^51 + P^52 + P^53 + 2*P^54 + P^55 + 2*P^56 + 2*P^58 + P^59 + P^60 + 
    2*P^61 + P^62 + 2*P^63 + 2*P^65 + P^66 + 2*P^67 + 2*P^68 + P^69 + 2*P^70 + P^71 + 3*P^72 + P^73 + 2*P^74 + P^75 + P^76 + 
    2*P^77 + P^78 + 3*P^79 + P^80 + 3*P^81 + P^82 + 2*P^83 + 2*P^84 + P^85 + 2*P^86 + P^87 + 3*P^88 + P^89 + 2*P^90 + 2*P^91 + 
    2*P^92 + 2*P^93 + P^94 + 2*P^95 + 2*P^96 + 3*P^97 + 2*P^98 + P^99 + P^100 + P^101 + 2*P^102 + 2*P^103 + 3*P^104 + 2*P^105 + 
    P^106 + P^107 + 2*P^108 + 2*P^109 + 2*P^110 + 2*P^111 + 3*P^112 + 2*P^113 + P^114 + P^115 + 2*P^116 + 2*P^117 + 2*P^118 + 
    2*P^119 + 2*P^120 + 2*P^121 + 2*P^122 + 2*P^123 + 2*P^124 + P^125 + 2*P^126 + 2*P^127 + 3*P^128 + 2*P^129 + P^130 + P^131 + 
    P^132 + 3*P^133 + 2*P^134 + 3*P^135 + P^136 + 2*P^137 + 2*P^138 + P^139 + 2*P^140 + P^141 + 3*P^142 + P^143 + 2*P^144 + 
    2*P^145 + P^146 + 2*P^147 + P^148 + 3*P^149 + P^150 + 2*P^151 + P^152 + P^153 + 2*P^154 + P^155 + 2*P^156 + 2*P^158 + 
    P^159 + 2*P^160 + 2*P^161 + P^162 + 2*P^163 + 2*P^165 + 2*P^167 + P^168 + P^169 + 2*P^170 + P^171 + 2*P^172 + 2*P^174 + 
    P^175 + P^176 + P^177 + P^178 + 2*P^179 + P^181 + P^183 + P^184 + P^185 + 2*P^186 + P^188 + P^190 + P^191 + P^192 + P^193 + 
    P^195 + P^199 + P^200 + P^202 + P^204 + P^206 + P^211 + P^215 + P^216)/((1 - P^3)*(1 - P^85)*(1 - P^139))}, 
 {3, (P^3 + P^13 + P^16 + P^19 + P^20 + P^23 + P^26 + P^27 + P^29 + P^30 + P^32 + P^33 + P^34 + P^35 + P^36 + P^37 + P^39 + 
    P^40 + P^41 + P^42 + P^43 + P^44 + P^45 + P^46 + P^47 + P^48 + P^49 + P^50 + P^51 + P^52 + P^53 + P^54 + P^55 + P^56 + 
    2*P^57 + P^58 + P^59 + 2*P^60 + P^61 + P^62 + P^63 + 2*P^64 + P^65 + P^66 + 2*P^67 + P^68 + P^69 + 2*P^70 + 2*P^71 + P^72 + 
    2*P^73 + 2*P^74 + P^75 + 2*P^76 + 2*P^77 + 2*P^78 + P^79 + 2*P^80 + 2*P^81 + P^82 + 2*P^83 + 2*P^84 + 2*P^85 + 2*P^86 + 
    2*P^87 + P^88 + 2*P^89 + 2*P^90 + 2*P^91 + 2*P^92 + 2*P^93 + 2*P^94 + P^95 + 2*P^96 + 2*P^97 + 2*P^98 + 2*P^99 + 2*P^100 + 
    2*P^101 + 2*P^102 + 2*P^103 + P^104 + P^105 + 2*P^106 + 2*P^107 + 2*P^108 + 2*P^109 + 2*P^110 + 2*P^111 + P^112 + 2*P^113 + 
    2*P^114 + 2*P^115 + 2*P^116 + 2*P^117 + 2*P^118 + P^119 + P^120 + 2*P^121 + 2*P^122 + 2*P^123 + 2*P^124 + 2*P^125 + P^126 + 
    2*P^127 + 2*P^128 + 2*P^129 + 2*P^130 + 2*P^131 + 2*P^132 + 2*P^133 + 2*P^134 + 2*P^135 + P^136 + 2*P^137 + 2*P^138 + 
    2*P^139 + 2*P^140 + 2*P^141 + P^142 + 2*P^143 + 2*P^144 + P^145 + 2*P^146 + 2*P^147 + 2*P^148 + P^149 + 2*P^150 + 2*P^151 + 
    P^152 + 2*P^153 + 2*P^154 + P^155 + P^156 + 2*P^157 + P^158 + P^159 + 2*P^160 + P^161 + P^162 + P^163 + 2*P^164 + P^165 + 
    P^166 + 2*P^167 + P^168 + P^169 + P^170 + P^171 + P^172 + P^173 + P^174 + P^175 + P^176 + P^177 + P^178 + P^179 + 2*P^180 + 
    P^181 + P^182 + P^184 + P^185 + P^187 + P^188 + P^189 + P^190 + P^191 + P^192 + P^194 + P^195 + P^197 + P^198 + P^201 + 
    P^204 + P^205 + P^208 + P^211 + P^221)/((1 - P^3)*(1 - P^85)*(1 - P^139))}, 
 {3, (P^4 + P^11 + P^17 + P^18 + P^20 + P^24 + P^25 + 2*P^27 + P^31 + P^32 + P^33 + 2*P^34 + P^36 + P^38 + P^40 + 2*P^41 + 
    2*P^43 + 2*P^45 + P^47 + 2*P^48 + P^49 + 2*P^50 + 2*P^52 + P^54 + P^55 + P^56 + 2*P^57 + P^58 + 2*P^59 + 2*P^61 + P^62 + 
    P^63 + 2*P^64 + P^65 + 2*P^66 + 3*P^68 + P^69 + P^70 + 2*P^71 + P^72 + 2*P^73 + P^74 + 3*P^75 + P^76 + 2*P^77 + 2*P^78 + 
    P^79 + 2*P^80 + P^81 + 3*P^82 + 3*P^84 + 2*P^85 + 2*P^86 + 2*P^87 + P^88 + 2*P^89 + P^90 + 3*P^91 + 2*P^92 + 2*P^93 + 
    2*P^94 + P^95 + 2*P^96 + P^97 + 3*P^98 + 2*P^99 + 3*P^100 + 2*P^101 + P^102 + P^103 + P^104 + 2*P^105 + 2*P^106 + 3*P^107 + 
    2*P^108 + 2*P^109 + P^110 + P^111 + P^112 + 2*P^113 + 3*P^114 + 3*P^115 + 2*P^116 + P^117 + P^118 + P^119 + 2*P^120 + 
    2*P^121 + 3*P^122 + 2*P^123 + 2*P^124 + 2*P^125 + P^126 + 2*P^127 + P^128 + 3*P^129 + P^130 + 3*P^131 + 2*P^132 + P^133 + 
    P^134 + P^135 + 3*P^136 + P^137 + 3*P^138 + 2*P^139 + 2*P^140 + 2*P^141 + P^142 + 2*P^143 + P^144 + 3*P^145 + P^146 + 
    2*P^147 + 2*P^148 + P^149 + 2*P^150 + P^151 + 3*P^152 + 2*P^154 + 2*P^155 + P^156 + 2*P^157 + P^158 + 2*P^159 + 2*P^161 + 
    P^162 + P^163 + 2*P^164 + P^165 + 2*P^166 + 3*P^168 + P^170 + P^171 + P^172 + 2*P^173 + 2*P^175 + P^177 + P^178 + P^179 + 
    2*P^180 + 2*P^182 + P^184 + P^186 + P^187 + P^188 + 2*P^189 + P^191 + P^193 + P^195 + 2*P^196 + P^198 + P^202 + P^203 + 
    P^205 + P^209 + P^212 + P^219)/((1 - P^3)*(1 - P^85)*(1 - P^139))}, 
 {3, (P^3 + P^13 + P^16 + P^19 + P^20 + P^23 + P^26 + P^27 + P^29 + P^30 + P^32 + P^33 + P^34 + P^35 + P^36 + P^37 + P^39 + 
    P^40 + P^42 + P^43 + 2*P^44 + P^45 + P^46 + P^47 + P^48 + P^49 + P^50 + P^51 + P^52 + P^53 + P^54 + P^55 + P^56 + 2*P^57 + 
    P^58 + P^59 + 2*P^60 + P^61 + P^62 + P^63 + 2*P^64 + P^65 + P^66 + 2*P^67 + P^68 + P^69 + 2*P^70 + 2*P^71 + P^72 + 2*P^73 + 
    2*P^74 + P^75 + 2*P^76 + 2*P^77 + 2*P^78 + P^79 + 2*P^80 + 2*P^81 + P^82 + 2*P^83 + 2*P^84 + 2*P^85 + 2*P^86 + 2*P^87 + 
    P^88 + 2*P^89 + 2*P^90 + 2*P^91 + 2*P^92 + 2*P^93 + 2*P^94 + 2*P^95 + 2*P^96 + 2*P^97 + P^98 + 2*P^99 + 2*P^100 + 2*P^101 + 
    2*P^102 + 2*P^103 + P^104 + P^105 + 2*P^106 + 2*P^107 + 2*P^108 + 2*P^109 + 2*P^110 + 2*P^111 + P^112 + 2*P^113 + 2*P^114 + 
    2*P^115 + 2*P^116 + 2*P^117 + 2*P^118 + P^119 + P^120 + 2*P^121 + 2*P^122 + 2*P^123 + 2*P^124 + 2*P^125 + 2*P^126 + 
    2*P^127 + 2*P^128 + P^129 + 2*P^130 + 2*P^131 + 2*P^132 + 2*P^133 + 2*P^134 + 2*P^135 + P^136 + 2*P^137 + 2*P^138 + 
    2*P^139 + 2*P^140 + 2*P^141 + P^142 + 2*P^143 + 2*P^144 + P^145 + 2*P^146 + 2*P^147 + 2*P^148 + P^149 + 2*P^150 + 2*P^151 + 
    P^152 + 2*P^153 + 2*P^154 + P^155 + P^156 + 2*P^157 + P^158 + P^159 + 2*P^160 + P^161 + P^162 + P^163 + 2*P^164 + P^165 + 
    P^166 + 2*P^167 + P^168 + P^169 + P^170 + P^171 + P^172 + P^173 + P^174 + P^175 + P^176 + P^177 + P^178 + P^179 + P^180 + 
    P^181 + P^182 + P^183 + P^184 + P^185 + P^187 + P^188 + P^189 + P^190 + P^191 + P^192 + P^194 + P^195 + P^197 + P^198 + 
    P^201 + P^204 + P^205 + P^208 + P^211 + P^221)/((1 - P^3)*(1 - P^85)*(1 - P^139))}, 
 {3, (P^8 + P^10 + P^12 + P^17 + P^19 + P^21 + P^24 + P^26 + P^28 + P^31 + 2*P^33 + 2*P^35 + P^37 + P^38 + 2*P^40 + 2*P^42 + 
    P^44 + P^45 + 2*P^47 + 3*P^49 + 2*P^51 + P^52 + P^53 + 2*P^54 + 3*P^56 + 2*P^58 + P^60 + 2*P^61 + P^62 + 3*P^63 + 3*P^65 + 
    2*P^67 + P^68 + P^69 + 2*P^70 + 3*P^72 + 3*P^74 + P^75 + 2*P^76 + 2*P^77 + P^78 + 3*P^79 + 3*P^81 + P^82 + 2*P^83 + 
    2*P^84 + P^85 + 3*P^86 + 3*P^88 + P^89 + 3*P^90 + 2*P^91 + 2*P^92 + 2*P^93 + P^94 + 2*P^95 + P^96 + 2*P^97 + 2*P^98 + 
    2*P^99 + 3*P^100 + P^101 + 2*P^102 + P^103 + 2*P^104 + 2*P^105 + 2*P^106 + 3*P^107 + 2*P^108 + 2*P^109 + P^110 + 2*P^111 + 
    P^112 + 2*P^113 + 2*P^114 + 3*P^115 + 2*P^116 + 2*P^117 + P^118 + 2*P^119 + P^120 + 2*P^121 + 2*P^122 + 2*P^123 + 2*P^124 + 
    P^125 + 2*P^126 + P^127 + 2*P^128 + 2*P^129 + 2*P^130 + 3*P^131 + P^132 + 3*P^133 + 3*P^135 + P^136 + 2*P^137 + 2*P^138 + 
    P^139 + 3*P^140 + 3*P^142 + P^143 + 3*P^144 + 2*P^145 + P^146 + 2*P^147 + 3*P^149 + 3*P^151 + P^152 + 2*P^153 + 2*P^154 + 
    P^155 + 3*P^156 + 3*P^158 + 2*P^160 + P^161 + P^162 + 2*P^163 + 3*P^165 + 2*P^167 + P^168 + P^169 + 2*P^170 + 3*P^172 + 
    2*P^174 + P^176 + P^177 + 2*P^179 + 2*P^181 + P^183 + P^184 + 2*P^186 + 2*P^188 + P^190 + P^193 + 2*P^195 + 2*P^197 + 
    P^199 + P^202 + P^204 + P^206 + P^209 + P^211 + P^213)/((1 - P^3)*(1 - P^85)*(1 - P^139))}, 
 {3, (P^4 + P^11 + P^15 + 2*P^20 + P^22 + P^24 + 2*P^27 + P^29 + P^31 + 2*P^34 + 2*P^36 + P^38 + P^40 + 2*P^41 + 2*P^43 + 
    2*P^45 + P^47 + 2*P^48 + 2*P^50 + 3*P^52 + P^54 + P^55 + P^56 + 2*P^57 + 3*P^59 + 3*P^61 + P^63 + 2*P^64 + P^65 + 3*P^66 + 
    3*P^68 + P^70 + 2*P^71 + P^72 + 3*P^73 + 3*P^75 + 3*P^77 + 2*P^78 + P^79 + 2*P^80 + P^81 + 3*P^82 + 3*P^84 + 2*P^85 + 
    2*P^86 + 2*P^87 + P^88 + 2*P^89 + 3*P^91 + 2*P^92 + 3*P^93 + 2*P^94 + P^95 + 2*P^96 + P^97 + 3*P^98 + P^99 + 2*P^100 + 
    2*P^101 + 3*P^102 + 3*P^103 + P^104 + P^105 + P^106 + 2*P^107 + 2*P^108 + 2*P^109 + 3*P^110 + P^111 + P^112 + P^113 + 
    2*P^114 + 2*P^115 + 2*P^116 + 3*P^117 + 3*P^118 + P^119 + P^120 + P^121 + 3*P^122 + 2*P^123 + 2*P^124 + 2*P^125 + P^126 + 
    2*P^127 + P^128 + 3*P^129 + P^130 + 2*P^131 + 2*P^132 + P^133 + 3*P^134 + P^135 + 3*P^136 + 3*P^138 + 2*P^139 + 2*P^140 + 
    2*P^141 + P^142 + 3*P^143 + 3*P^145 + 3*P^147 + 2*P^148 + P^149 + 2*P^150 + 3*P^152 + 3*P^154 + 2*P^155 + P^156 + 2*P^157 + 
    3*P^159 + 3*P^161 + P^163 + 2*P^164 + P^165 + 2*P^166 + 3*P^168 + P^170 + P^171 + P^172 + 2*P^173 + 3*P^175 + P^177 + 
    P^179 + 2*P^180 + 2*P^182 + 2*P^184 + P^186 + 2*P^189 + 2*P^191 + P^193 + 2*P^196 + 2*P^198 + P^200 + 2*P^205 + P^209 + 
    P^212 + P^216)/((1 - P^3)*(1 - P^85)*(1 - P^139))}, 
 {3, (P^11 + P^12 + P^16 + P^18 + P^19 + P^23 + P^25 + P^26 + P^27 + P^28 + P^30 + P^32 + P^34 + P^35 + P^36 + P^37 + P^39 + 
    2*P^41 + P^42 + P^43 + P^44 + P^46 + 2*P^48 + P^49 + P^50 + P^51 + P^52 + 2*P^53 + 2*P^55 + P^56 + 2*P^57 + P^58 + P^59 + 
    2*P^60 + 2*P^62 + P^63 + 2*P^64 + P^65 + P^66 + 2*P^67 + P^68 + 3*P^69 + P^70 + 2*P^71 + P^72 + 2*P^73 + 2*P^74 + P^75 + 
    2*P^76 + P^77 + 2*P^78 + P^79 + 2*P^80 + 2*P^81 + 2*P^82 + 2*P^83 + P^84 + 3*P^85 + P^86 + 2*P^87 + P^88 + 2*P^89 + 
    2*P^90 + P^91 + 3*P^92 + 2*P^93 + 3*P^94 + P^95 + P^96 + P^97 + 2*P^98 + 3*P^99 + 2*P^100 + 2*P^101 + P^102 + P^103 + 
    P^104 + 2*P^105 + 3*P^106 + 2*P^107 + 2*P^108 + 2*P^109 + 2*P^110 + P^111 + P^112 + 2*P^113 + 3*P^114 + 2*P^115 + 2*P^116 + 
    2*P^117 + 2*P^118 + P^119 + P^120 + 2*P^121 + 2*P^122 + 3*P^123 + 2*P^124 + 3*P^125 + P^126 + P^127 + P^128 + 2*P^129 + 
    3*P^130 + 2*P^131 + 2*P^132 + P^133 + 2*P^134 + 2*P^135 + 2*P^136 + 2*P^137 + P^138 + 3*P^139 + P^140 + 2*P^141 + P^142 + 
    2*P^143 + 2*P^144 + P^145 + 3*P^146 + P^147 + 2*P^148 + P^149 + 2*P^150 + 2*P^151 + P^152 + 2*P^153 + 2*P^155 + P^156 + 
    2*P^157 + P^158 + P^159 + 2*P^160 + P^161 + 2*P^162 + P^163 + 2*P^164 + P^165 + P^166 + P^167 + P^168 + 2*P^169 + 2*P^171 + 
    P^172 + 2*P^173 + P^174 + P^175 + 2*P^176 + P^178 + 2*P^180 + P^181 + P^182 + P^183 + P^185 + 2*P^187 + P^188 + P^189 + 
    P^190 + P^192 + P^194 + P^196 + P^197 + P^201 + P^203 + P^204 + P^205 + P^212 + P^213 + P^217)/
   ((1 - P^3)*(1 - P^85)*(1 - P^139))}, {3, (P^4 + P^11 + P^17 + P^18 + P^20 + P^24 + P^25 + 2*P^27 + P^31 + P^32 + P^33 + 
    2*P^34 + P^36 + P^38 + P^40 + 2*P^41 + P^42 + 2*P^43 + P^45 + P^47 + 2*P^48 + P^49 + 2*P^50 + P^52 + P^54 + 2*P^55 + P^56 + 
    2*P^57 + P^58 + 2*P^59 + 2*P^61 + P^62 + P^63 + 2*P^64 + P^65 + 2*P^66 + 3*P^68 + P^69 + P^70 + 2*P^71 + P^72 + 2*P^73 + 
    P^74 + 3*P^75 + P^76 + 2*P^77 + 2*P^78 + P^79 + 2*P^80 + P^81 + 3*P^82 + P^83 + 3*P^84 + 2*P^85 + P^86 + 2*P^87 + P^88 + 
    2*P^89 + P^90 + 3*P^91 + 2*P^92 + 2*P^93 + 2*P^94 + P^95 + P^96 + P^97 + 3*P^98 + 3*P^99 + 3*P^100 + 2*P^101 + P^102 + 
    P^103 + P^104 + 2*P^105 + 2*P^106 + 3*P^107 + 2*P^108 + 2*P^109 + P^110 + P^111 + P^112 + 2*P^113 + 3*P^114 + 3*P^115 + 
    2*P^116 + P^117 + P^118 + P^119 + 2*P^120 + 2*P^121 + 3*P^122 + 2*P^123 + 2*P^124 + 2*P^125 + P^126 + P^127 + P^128 + 
    3*P^129 + 2*P^130 + 3*P^131 + 2*P^132 + P^133 + P^134 + P^135 + 3*P^136 + 2*P^137 + 3*P^138 + 2*P^139 + P^140 + 2*P^141 + 
    P^142 + 2*P^143 + P^144 + 3*P^145 + P^146 + 2*P^147 + 2*P^148 + P^149 + 2*P^150 + P^151 + 3*P^152 + 2*P^154 + 2*P^155 + 
    P^156 + 2*P^157 + P^158 + 2*P^159 + 2*P^161 + P^162 + P^163 + 2*P^164 + P^165 + 2*P^166 + 2*P^168 + P^170 + 2*P^171 + 
    P^172 + 2*P^173 + 2*P^175 + P^177 + P^178 + P^179 + 2*P^180 + P^181 + 2*P^182 + P^186 + P^187 + P^188 + 2*P^189 + P^191 + 
    P^193 + P^195 + 2*P^196 + P^198 + P^202 + P^203 + P^205 + P^209 + P^212 + P^219)/((1 - P^3)*(1 - P^85)*(1 - P^139))}, 
 {3, (P^8 + P^12 + P^15 + 2*P^19 + P^24 + 2*P^26 + 2*P^28 + P^31 + 2*P^33 + 2*P^35 + P^38 + 2*P^40 + 2*P^42 + 2*P^44 + P^45 + 
    P^47 + 3*P^49 + 2*P^51 + P^52 + P^53 + P^54 + 3*P^56 + 2*P^58 + P^59 + 2*P^60 + P^61 + 3*P^63 + 3*P^65 + 2*P^67 + P^68 + 
    2*P^69 + 3*P^70 + 3*P^72 + 2*P^74 + P^75 + 2*P^76 + 3*P^77 + 3*P^79 + 3*P^81 + P^82 + 2*P^83 + 2*P^84 + 2*P^85 + 3*P^86 + 
    3*P^88 + P^89 + 3*P^90 + P^91 + 2*P^92 + 2*P^93 + P^94 + 3*P^95 + P^96 + 2*P^97 + P^98 + 2*P^99 + 2*P^100 + 2*P^101 + 
    3*P^102 + P^103 + P^104 + P^105 + 3*P^106 + 3*P^107 + 2*P^108 + 2*P^109 + 2*P^110 + P^111 + P^112 + P^113 + 3*P^114 + 
    2*P^115 + 2*P^116 + 2*P^117 + P^118 + P^119 + P^120 + 3*P^121 + 3*P^122 + 2*P^123 + 2*P^124 + P^125 + 3*P^126 + P^127 + 
    2*P^128 + P^129 + 2*P^130 + 3*P^131 + 2*P^132 + 3*P^133 + 2*P^135 + P^136 + 2*P^137 + 2*P^138 + 2*P^139 + 3*P^140 + 
    3*P^142 + P^143 + 2*P^144 + P^145 + 2*P^146 + 3*P^147 + 3*P^149 + 3*P^151 + P^152 + 2*P^153 + P^154 + 3*P^156 + 3*P^158 + 
    P^159 + 2*P^160 + P^161 + 3*P^163 + 3*P^165 + 2*P^167 + P^168 + P^169 + P^170 + 3*P^172 + 2*P^174 + 2*P^176 + P^177 + 
    2*P^179 + 2*P^181 + 2*P^183 + P^184 + P^186 + 2*P^188 + 2*P^190 + P^193 + P^195 + 2*P^197 + P^200 + P^202 + 2*P^204 + 
    P^209 + P^213 + P^220)/((1 - P^3)*(1 - P^85)*(1 - P^139))}, 
 {3, (P^8 + P^9 + P^13 + P^18 + P^20 + P^22 + P^24 + P^25 + P^29 + P^31 + P^32 + P^33 + P^34 + P^36 + 2*P^38 + P^39 + P^40 + 
    P^41 + P^43 + 2*P^45 + P^46 + P^47 + P^48 + P^49 + 2*P^50 + 2*P^52 + P^53 + 2*P^54 + P^55 + P^56 + 2*P^57 + 2*P^59 + 
    2*P^61 + P^62 + 2*P^63 + 2*P^64 + P^65 + 2*P^66 + 2*P^68 + P^69 + 2*P^70 + P^71 + P^72 + 2*P^73 + P^74 + 3*P^75 + P^76 + 
    2*P^77 + P^78 + 2*P^79 + 2*P^80 + P^81 + 3*P^82 + P^83 + 2*P^84 + P^85 + 2*P^86 + 2*P^87 + P^88 + 3*P^89 + 2*P^90 + 
    3*P^91 + P^92 + P^93 + P^94 + 2*P^95 + 3*P^96 + 2*P^97 + 2*P^98 + P^99 + 2*P^100 + 2*P^101 + 2*P^102 + 2*P^103 + 2*P^104 + 
    2*P^105 + 2*P^106 + 2*P^107 + 2*P^108 + P^109 + P^110 + 2*P^111 + 3*P^112 + 2*P^113 + 2*P^114 + 2*P^115 + 2*P^116 + P^117 + 
    P^118 + 2*P^119 + 3*P^120 + 2*P^121 + 2*P^122 + P^123 + P^124 + P^125 + 2*P^126 + 3*P^127 + 2*P^128 + 2*P^129 + P^130 + 
    2*P^131 + 2*P^132 + 2*P^133 + 2*P^134 + P^135 + 3*P^136 + P^137 + 2*P^138 + P^139 + 2*P^140 + 2*P^141 + P^142 + 3*P^143 + 
    P^144 + 3*P^145 + P^146 + 2*P^147 + P^148 + P^149 + 2*P^150 + P^151 + 3*P^152 + P^153 + 2*P^154 + P^155 + 2*P^156 + 
    2*P^157 + P^158 + 2*P^159 + 2*P^161 + P^162 + 2*P^163 + P^164 + P^165 + 2*P^166 + 2*P^168 + P^169 + 2*P^170 + P^171 + 
    P^172 + 2*P^173 + P^175 + 2*P^177 + P^178 + P^179 + P^180 + P^182 + 2*P^184 + P^185 + P^186 + P^187 + P^189 + P^191 + 
    P^193 + P^194 + P^195 + P^196 + P^198 + P^200 + P^202 + P^203 + P^207 + P^209 + P^210 + P^214)/
   ((1 - P^3)*(1 - P^85)*(1 - P^139))}, {3, (P + P^14 + 2*P^17 + P^21 + 2*P^24 + P^28 + P^30 + 2*P^31 + 2*P^33 + P^35 + P^37 + 
    2*P^38 + 2*P^40 + P^42 + P^44 + 2*P^45 + P^46 + 2*P^47 + 2*P^49 + P^51 + P^53 + 2*P^54 + P^55 + 2*P^56 + 3*P^58 + P^60 + 
    2*P^61 + P^62 + 2*P^63 + 3*P^65 + P^67 + 2*P^68 + P^69 + 2*P^70 + P^71 + 3*P^72 + 3*P^74 + 2*P^75 + P^76 + 2*P^77 + P^78 + 
    3*P^79 + 3*P^81 + 2*P^82 + P^83 + 2*P^84 + P^85 + 2*P^86 + P^87 + 3*P^88 + 2*P^89 + 3*P^90 + 2*P^91 + P^92 + 2*P^93 + 
    P^94 + 3*P^95 + P^96 + 3*P^97 + 2*P^98 + 2*P^99 + 2*P^100 + P^101 + P^102 + P^103 + 3*P^104 + 2*P^105 + 2*P^106 + 2*P^107 + 
    P^108 + P^109 + P^110 + 3*P^111 + 3*P^112 + 2*P^113 + 2*P^114 + 2*P^115 + P^116 + P^117 + P^118 + 3*P^119 + 2*P^120 + 
    2*P^121 + 2*P^122 + P^123 + P^124 + P^125 + 3*P^126 + 2*P^127 + 3*P^128 + 2*P^129 + P^130 + 2*P^131 + P^132 + 3*P^133 + 
    P^134 + 3*P^135 + 2*P^136 + 2*P^137 + 2*P^138 + P^139 + 2*P^140 + P^141 + 3*P^142 + 3*P^144 + 2*P^145 + P^146 + 2*P^147 + 
    P^148 + 3*P^149 + 3*P^151 + 2*P^152 + P^153 + 2*P^154 + P^155 + 2*P^156 + 3*P^158 + P^160 + 2*P^161 + P^162 + 2*P^163 + 
    3*P^165 + P^167 + 2*P^168 + P^169 + 2*P^170 + 2*P^172 + P^174 + P^176 + 2*P^177 + P^178 + 2*P^179 + 2*P^181 + P^183 + 
    P^185 + 2*P^186 + 2*P^188 + P^190 + P^192 + 2*P^193 + 2*P^195 + P^199 + 2*P^202 + P^206 + 2*P^209 + P^222)/
   ((1 - P^3)*(1 - P^85)*(1 - P^139))}, {3, (P^7 + P^14 + P^15 + P^17 + P^22 + P^23 + 2*P^24 + P^29 + P^30 + 2*P^31 + P^33 + 
    P^37 + 2*P^38 + P^39 + 2*P^40 + P^42 + P^44 + P^45 + P^46 + 2*P^47 + P^48 + P^49 + P^51 + P^52 + P^53 + 2*P^54 + P^55 + 
    2*P^56 + 2*P^58 + P^59 + P^60 + 2*P^61 + P^62 + 2*P^63 + P^64 + 2*P^65 + P^66 + P^67 + 2*P^68 + P^69 + 2*P^70 + P^71 + 
    2*P^72 + P^73 + 2*P^74 + 2*P^75 + P^76 + 2*P^77 + P^78 + 2*P^79 + P^80 + 3*P^81 + 2*P^82 + 2*P^83 + 2*P^84 + P^85 + 
    2*P^86 + P^87 + 3*P^88 + 2*P^89 + 2*P^90 + 2*P^91 + 2*P^93 + P^94 + 3*P^95 + 2*P^96 + 3*P^97 + 2*P^98 + P^99 + P^100 + 
    P^101 + 2*P^102 + 2*P^103 + 3*P^104 + 3*P^105 + 2*P^106 + P^107 + P^109 + 2*P^110 + 3*P^111 + 3*P^112 + 3*P^113 + P^114 + 
    P^115 + 2*P^117 + 2*P^118 + 3*P^119 + 3*P^120 + 3*P^121 + 2*P^122 + P^124 + P^125 + 3*P^126 + 2*P^127 + 3*P^128 + 2*P^129 + 
    P^130 + P^131 + P^132 + 2*P^133 + 2*P^134 + 3*P^135 + 2*P^136 + 2*P^137 + 2*P^138 + P^139 + 2*P^140 + P^141 + 3*P^142 + 
    P^143 + 2*P^144 + 2*P^145 + P^146 + 2*P^147 + P^148 + 2*P^149 + P^150 + 2*P^151 + 2*P^152 + P^153 + 2*P^154 + P^155 + 
    2*P^156 + P^157 + 2*P^158 + P^159 + P^160 + 2*P^161 + P^162 + 2*P^163 + P^164 + 2*P^165 + P^167 + P^168 + P^169 + 2*P^170 + 
    P^171 + 2*P^172 + P^174 + P^175 + P^176 + 2*P^177 + P^178 + 2*P^179 + P^181 + P^183 + P^184 + P^185 + 2*P^186 + P^188 + 
    P^191 + P^192 + 2*P^193 + P^195 + P^199 + P^200 + P^201 + P^202 + P^208 + P^209 + P^215 + P^216)/
   ((1 - P^3)*(1 - P^85)*(1 - P^139))}, {3, (P^7 + P^11 + P^12 + P^19 + P^20 + P^21 + P^23 + P^27 + P^28 + P^30 + P^32 + P^34 + 
    P^35 + P^36 + 2*P^37 + P^39 + P^41 + P^42 + P^43 + 2*P^44 + P^46 + 2*P^48 + P^49 + P^50 + 2*P^51 + P^52 + 2*P^53 + 2*P^55 + 
    P^56 + P^57 + P^58 + P^59 + 2*P^60 + P^61 + 2*P^62 + P^63 + 2*P^64 + P^65 + P^66 + 2*P^67 + P^68 + 2*P^69 + 2*P^71 + P^72 + 
    2*P^73 + 2*P^74 + P^75 + 2*P^76 + P^77 + 3*P^78 + P^79 + 2*P^80 + 2*P^81 + P^82 + 2*P^83 + P^84 + 3*P^85 + P^86 + 2*P^87 + 
    2*P^88 + 2*P^89 + 2*P^90 + P^91 + 2*P^92 + 2*P^93 + 3*P^94 + 2*P^95 + P^96 + P^97 + P^98 + 3*P^99 + 2*P^100 + 3*P^101 + 
    2*P^102 + 2*P^103 + P^104 + P^105 + 2*P^106 + 2*P^107 + 2*P^108 + 2*P^109 + 3*P^110 + 2*P^111 + P^112 + P^113 + 2*P^114 + 
    2*P^115 + 2*P^116 + 2*P^117 + 3*P^118 + 2*P^119 + P^120 + P^121 + P^122 + 2*P^123 + 2*P^124 + 3*P^125 + 2*P^126 + P^127 + 
    P^128 + P^129 + 3*P^130 + 2*P^131 + 3*P^132 + P^133 + 2*P^134 + 2*P^135 + P^136 + 2*P^137 + P^138 + 3*P^139 + P^140 + 
    2*P^141 + 2*P^142 + 2*P^143 + 2*P^144 + P^145 + 2*P^146 + P^147 + 2*P^148 + P^149 + 2*P^150 + 2*P^151 + P^152 + 2*P^153 + 
    P^154 + 3*P^155 + P^156 + 2*P^157 + P^158 + P^159 + 2*P^160 + P^161 + 2*P^162 + 2*P^164 + P^165 + P^166 + 2*P^167 + P^168 + 
    2*P^169 + 2*P^171 + P^172 + P^173 + P^174 + P^175 + 2*P^176 + P^178 + P^180 + P^181 + P^182 + 2*P^183 + P^185 + P^187 + 
    P^188 + P^189 + P^190 + P^192 + P^194 + P^196 + P^197 + P^198 + P^199 + P^201 + P^205 + P^206 + P^208 + P^212 + P^213)/
   ((1 - P^3)*(1 - P^85)*(1 - P^139))}, {3, (P^10 + P^11 + P^17 + 2*P^18 + 2*P^25 + P^26 + 2*P^27 + P^32 + P^33 + 2*P^34 + 
    P^35 + P^39 + P^40 + 2*P^41 + P^42 + 2*P^43 + P^47 + 2*P^48 + P^49 + 2*P^50 + P^51 + P^52 + P^54 + 2*P^55 + P^56 + 2*P^57 + 
    P^58 + 2*P^59 + P^61 + 2*P^62 + P^63 + 2*P^64 + P^65 + 2*P^66 + P^67 + 2*P^68 + 2*P^69 + P^70 + 2*P^71 + P^72 + 2*P^73 + 
    P^74 + 2*P^75 + 2*P^76 + P^77 + 2*P^78 + P^79 + 2*P^80 + P^81 + 2*P^82 + 2*P^83 + 3*P^84 + 2*P^85 + P^86 + 2*P^87 + P^88 + 
    2*P^89 + P^90 + 3*P^91 + 3*P^92 + 2*P^93 + 2*P^94 + P^96 + P^97 + 3*P^98 + 3*P^99 + 3*P^100 + 2*P^101 + P^104 + 3*P^105 + 
    3*P^106 + 3*P^107 + 3*P^108 + 2*P^109 + P^112 + 3*P^113 + 3*P^114 + 3*P^115 + 3*P^116 + P^117 + 2*P^120 + 3*P^121 + 
    3*P^122 + 3*P^123 + 2*P^124 + 2*P^125 + P^127 + P^128 + 3*P^129 + 3*P^130 + 3*P^131 + 2*P^132 + P^133 + P^134 + P^135 + 
    2*P^136 + 2*P^137 + 3*P^138 + 2*P^139 + P^140 + 2*P^141 + P^142 + 2*P^143 + P^144 + 3*P^145 + 2*P^146 + P^147 + 2*P^148 + 
    P^149 + 2*P^150 + P^151 + 2*P^152 + P^153 + P^154 + 2*P^155 + P^156 + 2*P^157 + P^158 + 2*P^159 + P^160 + P^161 + 2*P^162 + 
    P^163 + 2*P^164 + P^165 + 2*P^166 + P^167 + P^168 + P^170 + 2*P^171 + P^172 + 2*P^173 + P^174 + 2*P^175 + P^178 + P^179 + 
    2*P^180 + P^181 + 2*P^182 + P^186 + 2*P^187 + P^188 + 2*P^189 + P^194 + P^195 + 2*P^196 + P^202 + 2*P^203 + P^204 + P^211 + 
    P^212 + P^219)/((1 - P^3)*(1 - P^85)*(1 - P^139))}, 
 {3, (P^9 + P^10 + P^16 + P^17 + P^20 + P^24 + P^25 + P^26 + P^27 + P^29 + P^32 + P^33 + 2*P^34 + P^36 + P^39 + P^40 + 2*P^41 + 
    P^42 + P^43 + P^45 + P^46 + P^47 + P^48 + P^49 + 2*P^50 + P^51 + P^52 + P^53 + P^54 + P^55 + P^56 + 2*P^57 + P^58 + P^59 + 
    P^60 + 2*P^61 + P^62 + P^63 + 2*P^64 + P^65 + 2*P^66 + P^67 + 2*P^68 + P^69 + 2*P^70 + 2*P^71 + P^72 + 2*P^73 + P^74 + 
    2*P^75 + P^76 + 2*P^77 + 2*P^78 + P^79 + 2*P^80 + P^81 + 2*P^82 + 2*P^83 + 2*P^84 + 2*P^85 + 2*P^86 + 2*P^87 + P^88 + 
    2*P^89 + 2*P^90 + 3*P^91 + 2*P^92 + 2*P^93 + P^94 + 2*P^96 + 2*P^97 + 3*P^98 + 2*P^99 + 2*P^100 + P^101 + P^102 + 2*P^103 + 
    2*P^104 + 2*P^105 + 2*P^106 + 3*P^107 + 3*P^108 + P^109 + P^110 + P^111 + 2*P^112 + 2*P^113 + 2*P^114 + 3*P^115 + 2*P^116 + 
    P^117 + P^118 + P^119 + 2*P^120 + 2*P^121 + 3*P^122 + 3*P^123 + 2*P^124 + P^125 + 2*P^127 + 2*P^128 + 3*P^129 + 2*P^130 + 
    2*P^131 + 2*P^132 + P^133 + 2*P^134 + P^135 + 2*P^136 + 2*P^137 + 2*P^138 + 2*P^139 + 2*P^140 + 2*P^141 + P^142 + 2*P^143 + 
    2*P^144 + 2*P^145 + P^146 + 2*P^147 + 2*P^148 + P^149 + 2*P^150 + P^151 + 2*P^152 + P^153 + 2*P^154 + P^155 + P^156 + 
    2*P^157 + P^158 + 2*P^159 + P^160 + 2*P^161 + P^162 + P^163 + 2*P^164 + P^165 + 2*P^166 + P^167 + P^168 + P^169 + P^170 + 
    P^171 + P^172 + 2*P^173 + P^174 + P^175 + P^177 + P^178 + P^179 + 2*P^180 + P^181 + P^182 + P^184 + P^185 + P^186 + P^187 + 
    P^188 + P^189 + P^191 + P^194 + P^195 + P^196 + P^198 + P^201 + P^202 + P^203 + P^205 + P^210 + P^211 + P^218)/
   ((1 - P^3)*(1 - P^85)*(1 - P^139))}, {3, (P^8 + 2*P^15 + P^16 + P^22 + P^23 + P^24 + P^25 + P^29 + P^30 + 2*P^31 + P^32 + 
    P^36 + 2*P^38 + P^39 + 2*P^40 + P^41 + 2*P^45 + P^46 + 2*P^47 + P^48 + P^49 + 2*P^52 + P^53 + 2*P^54 + P^55 + 2*P^56 + 
    P^57 + 2*P^59 + P^60 + 2*P^61 + P^62 + 2*P^63 + P^64 + P^65 + 2*P^66 + P^67 + 2*P^68 + P^69 + 2*P^70 + P^71 + 2*P^72 + 
    2*P^73 + P^74 + 2*P^75 + P^76 + 2*P^77 + P^78 + 2*P^79 + 2*P^80 + 2*P^81 + 3*P^82 + P^83 + 2*P^84 + P^85 + 2*P^86 + P^87 + 
    2*P^88 + 3*P^89 + 2*P^90 + 2*P^91 + P^92 + P^93 + P^94 + 2*P^95 + 3*P^96 + 3*P^97 + 3*P^98 + P^99 + 2*P^102 + 3*P^103 + 
    3*P^104 + 3*P^105 + 2*P^106 + P^107 + P^109 + 2*P^110 + 3*P^111 + 3*P^112 + 3*P^113 + 2*P^114 + P^117 + 3*P^118 + 3*P^119 + 
    3*P^120 + 2*P^121 + 2*P^122 + P^123 + P^124 + P^125 + 2*P^126 + 3*P^127 + 3*P^128 + 3*P^129 + P^130 + P^131 + 2*P^133 + 
    2*P^134 + 3*P^135 + 3*P^136 + P^137 + 2*P^138 + P^139 + 2*P^140 + P^141 + 2*P^142 + 3*P^143 + P^144 + 2*P^145 + P^146 + 
    2*P^147 + P^148 + 2*P^149 + 2*P^150 + P^151 + 2*P^152 + P^153 + 2*P^154 + P^155 + 2*P^156 + P^157 + P^158 + 2*P^159 + 
    P^160 + 2*P^161 + P^162 + 2*P^163 + P^164 + P^165 + P^166 + 2*P^168 + P^169 + 2*P^170 + P^171 + 2*P^172 + P^173 + P^175 + 
    P^176 + 2*P^177 + P^178 + 2*P^179 + P^180 + 2*P^184 + P^185 + 2*P^186 + P^187 + P^191 + P^192 + 2*P^193 + P^194 + 2*P^200 + 
    P^201 + P^202 + P^207 + P^209 + P^216 + P^217)/((1 - P^3)*(1 - P^85)*(1 - P^139))}, 
 {3, (P^3 + P^10 + P^17 + 2*P^19 + P^24 + 3*P^26 + P^31 + 3*P^33 + 2*P^35 + 3*P^40 + 3*P^42 + P^44 + 3*P^47 + 3*P^49 + 2*P^51 + 
    2*P^54 + 3*P^56 + 3*P^58 + 2*P^60 + P^61 + 3*P^63 + 3*P^65 + 3*P^67 + P^68 + 3*P^70 + 3*P^72 + 3*P^74 + P^75 + 2*P^76 + 
    3*P^77 + 3*P^79 + 3*P^81 + 3*P^83 + 3*P^84 + P^85 + 3*P^86 + 2*P^88 + 3*P^90 + 3*P^91 + 2*P^92 + 3*P^93 + 2*P^95 + 3*P^97 + 
    2*P^98 + 3*P^99 + 3*P^100 + 2*P^101 + 2*P^102 + P^104 + P^105 + 3*P^106 + 3*P^107 + 3*P^108 + 2*P^109 + P^112 + 3*P^113 + 
    3*P^114 + 3*P^115 + 2*P^116 + 2*P^117 + P^119 + P^120 + 3*P^121 + 3*P^122 + 3*P^123 + 3*P^124 + P^126 + 3*P^128 + 2*P^129 + 
    3*P^130 + 3*P^131 + 2*P^133 + 3*P^135 + P^136 + 3*P^137 + 3*P^138 + P^139 + 3*P^140 + 3*P^142 + 3*P^144 + P^145 + 2*P^146 + 
    3*P^147 + 3*P^149 + 3*P^151 + 2*P^153 + 3*P^154 + 3*P^156 + 3*P^158 + 2*P^160 + P^161 + 3*P^163 + 3*P^165 + 3*P^167 + 
    2*P^170 + 3*P^172 + 3*P^174 + P^177 + 3*P^179 + 3*P^181 + P^183 + P^186 + 3*P^188 + 2*P^190 + 3*P^195 + 2*P^197 + P^202 + 
    2*P^204 + 2*P^211 + P^218)/((1 - P^3)*(1 - P^85)*(1 - P^139))}, 
 {3, (P^7 + P^8 + P^15 + P^17 + P^22 + P^23 + 2*P^24 + P^30 + 2*P^31 + P^32 + P^33 + P^37 + 2*P^38 + P^39 + 2*P^40 + P^44 + 
    2*P^45 + P^46 + 2*P^47 + P^48 + P^49 + P^51 + 2*P^52 + P^53 + 2*P^54 + P^55 + 2*P^56 + P^58 + P^59 + P^60 + 2*P^61 + P^62 + 
    2*P^63 + P^64 + 2*P^65 + P^66 + P^67 + 2*P^68 + P^69 + 2*P^70 + P^71 + 2*P^72 + P^73 + 2*P^74 + 2*P^75 + P^76 + 2*P^77 + 
    P^78 + 2*P^79 + P^80 + 3*P^81 + 2*P^82 + P^83 + 2*P^84 + P^85 + 2*P^86 + P^87 + 3*P^88 + 3*P^89 + 2*P^90 + 2*P^91 + P^93 + 
    P^94 + 3*P^95 + 3*P^96 + 3*P^97 + 2*P^98 + P^99 + P^100 + P^101 + 2*P^102 + 2*P^103 + 3*P^104 + 3*P^105 + 3*P^106 + P^107 + 
    2*P^110 + 3*P^111 + 3*P^112 + 3*P^113 + 2*P^114 + P^115 + P^117 + 2*P^118 + 3*P^119 + 3*P^120 + 3*P^121 + 2*P^122 + P^125 + 
    3*P^126 + 3*P^127 + 3*P^128 + 2*P^129 + P^130 + P^131 + P^132 + 2*P^133 + 2*P^134 + 3*P^135 + 2*P^136 + P^137 + 2*P^138 + 
    P^139 + 2*P^140 + P^141 + 3*P^142 + 2*P^143 + 2*P^144 + 2*P^145 + P^146 + 2*P^147 + P^148 + 2*P^149 + P^150 + 2*P^151 + 
    2*P^152 + P^153 + 2*P^154 + P^155 + 2*P^156 + P^157 + 2*P^158 + P^159 + P^160 + 2*P^161 + P^162 + 2*P^163 + P^164 + 
    2*P^165 + P^167 + 2*P^168 + P^169 + 2*P^170 + P^171 + 2*P^172 + P^175 + P^176 + 2*P^177 + P^178 + 2*P^179 + P^183 + 
    2*P^184 + P^185 + 2*P^186 + P^188 + P^192 + 2*P^193 + P^194 + P^195 + P^199 + P^200 + P^201 + P^202 + P^208 + 2*P^209 + 
    P^216)/((1 - P^3)*(1 - P^85)*(1 - P^139))}, 
 {3, (P^10 + P^12 + 2*P^17 + P^19 + 2*P^24 + 2*P^26 + P^28 + P^31 + 2*P^33 + P^35 + P^37 + P^38 + 2*P^40 + 3*P^42 + P^44 + 
    2*P^47 + 3*P^49 + 2*P^51 + P^53 + 2*P^54 + 3*P^56 + 3*P^58 + P^60 + 2*P^61 + 3*P^63 + 3*P^65 + 2*P^67 + 2*P^68 + P^69 + 
    3*P^70 + 3*P^72 + 3*P^74 + P^75 + P^76 + 2*P^77 + P^78 + 3*P^79 + 3*P^81 + P^82 + 3*P^83 + 2*P^84 + P^85 + 3*P^86 + 
    3*P^88 + 3*P^90 + 2*P^91 + 2*P^92 + 3*P^93 + P^94 + 2*P^95 + 2*P^97 + 2*P^98 + 3*P^99 + 3*P^100 + P^101 + P^102 + 2*P^104 + 
    2*P^105 + 3*P^106 + 3*P^107 + 2*P^108 + P^109 + P^110 + P^111 + 2*P^112 + 2*P^113 + 3*P^114 + 3*P^115 + 2*P^116 + P^117 + 
    P^118 + 2*P^119 + 2*P^120 + 2*P^121 + 2*P^122 + 2*P^123 + 3*P^124 + P^125 + 2*P^126 + 2*P^128 + 2*P^129 + 3*P^130 + 
    3*P^131 + P^132 + 2*P^133 + 3*P^135 + P^136 + 3*P^137 + 2*P^138 + P^139 + 3*P^140 + 3*P^142 + 3*P^144 + 2*P^145 + P^146 + 
    3*P^147 + 3*P^149 + 3*P^151 + P^152 + P^153 + 2*P^154 + 3*P^156 + 3*P^158 + 2*P^160 + 2*P^161 + P^162 + 2*P^163 + 3*P^165 + 
    2*P^167 + P^169 + 2*P^170 + 3*P^172 + 3*P^174 + P^176 + P^177 + 2*P^179 + 3*P^181 + P^183 + 2*P^186 + 3*P^188 + P^190 + 
    P^193 + 2*P^195 + P^197 + 2*P^202 + P^204 + P^206 + P^211 + P^213 + P^218)/((1 - P^3)*(1 - P^85)*(1 - P^139))}, 
 {3, (P^8 + P^10 + P^15 + P^17 + P^21 + P^22 + P^24 + P^26 + P^28 + P^30 + P^31 + P^33 + 2*P^35 + P^37 + P^38 + 2*P^40 + 
    2*P^42 + P^44 + P^45 + P^46 + 2*P^47 + 2*P^49 + 2*P^51 + P^52 + P^53 + 2*P^54 + 2*P^56 + 2*P^58 + P^59 + P^60 + 2*P^61 + 
    P^62 + 2*P^63 + 3*P^65 + P^66 + 2*P^67 + P^68 + P^69 + 2*P^70 + P^71 + 3*P^72 + 2*P^74 + P^75 + 2*P^76 + 2*P^77 + P^78 + 
    3*P^79 + 3*P^81 + P^82 + 2*P^83 + 2*P^84 + P^85 + 3*P^86 + P^87 + 3*P^88 + P^89 + 2*P^90 + 2*P^91 + 2*P^92 + 2*P^93 + 
    P^94 + 2*P^95 + P^96 + 3*P^97 + 2*P^98 + 2*P^99 + P^100 + P^101 + 2*P^102 + 2*P^103 + 3*P^104 + 2*P^105 + 2*P^106 + P^107 + 
    2*P^108 + 2*P^109 + 2*P^110 + 2*P^111 + 2*P^112 + 2*P^113 + 2*P^114 + P^115 + 2*P^116 + 2*P^117 + 2*P^118 + 2*P^119 + 
    P^120 + 2*P^121 + 2*P^122 + 2*P^123 + 2*P^124 + P^125 + 2*P^126 + P^127 + 3*P^128 + 2*P^129 + 2*P^130 + P^131 + P^132 + 
    3*P^133 + P^134 + 3*P^135 + P^136 + 2*P^137 + 2*P^138 + P^139 + 3*P^140 + P^141 + 3*P^142 + P^143 + 2*P^144 + 2*P^145 + 
    P^146 + 2*P^147 + P^148 + 3*P^149 + 2*P^151 + P^152 + 2*P^153 + 2*P^154 + P^155 + 2*P^156 + 3*P^158 + P^159 + 2*P^160 + 
    P^161 + P^162 + 2*P^163 + 3*P^165 + 2*P^167 + P^168 + P^169 + 2*P^170 + 2*P^172 + 2*P^174 + P^175 + P^176 + P^177 + 
    2*P^179 + 2*P^181 + P^183 + P^184 + P^185 + 2*P^186 + P^188 + P^190 + P^192 + P^193 + P^195 + P^197 + P^199 + P^200 + 
    P^202 + P^204 + P^206 + P^209 + P^211 + P^216)/((1 - P^3)*(1 - P^85)*(1 - P^139))}, 
 {3, (P^8 + P^13 + P^15 + P^18 + P^20 + P^22 + P^24 + P^25 + P^27 + P^29 + P^31 + P^32 + P^34 + P^36 + 2*P^38 + P^39 + P^40 + 
    P^41 + 2*P^43 + 2*P^45 + P^47 + P^48 + P^49 + 2*P^50 + 2*P^52 + 2*P^54 + P^55 + P^56 + 2*P^57 + 3*P^59 + 2*P^61 + P^62 + 
    P^63 + 2*P^64 + P^65 + 3*P^66 + 2*P^68 + P^69 + 2*P^70 + 2*P^71 + P^72 + 2*P^73 + 3*P^75 + P^76 + 2*P^77 + P^78 + 2*P^79 + 
    2*P^80 + P^81 + 3*P^82 + P^83 + 3*P^84 + P^85 + 2*P^86 + 2*P^87 + P^88 + 3*P^89 + P^90 + 3*P^91 + P^92 + P^93 + 2*P^94 + 
    2*P^95 + 3*P^96 + P^97 + 2*P^98 + P^99 + 2*P^100 + 2*P^101 + 2*P^102 + 2*P^103 + P^104 + 2*P^105 + 2*P^106 + 2*P^107 + 
    2*P^108 + P^109 + 2*P^110 + 2*P^111 + 2*P^112 + 2*P^113 + 2*P^114 + 2*P^115 + 2*P^116 + P^117 + 2*P^118 + 2*P^119 + 
    3*P^120 + 2*P^121 + 2*P^122 + P^123 + P^124 + 2*P^125 + 2*P^126 + 3*P^127 + P^128 + 2*P^129 + P^130 + 2*P^131 + 2*P^132 + 
    2*P^133 + 2*P^134 + P^135 + 3*P^136 + P^137 + 3*P^138 + P^139 + 2*P^140 + 2*P^141 + P^142 + 3*P^143 + 3*P^145 + P^146 + 
    2*P^147 + 2*P^148 + P^149 + 2*P^150 + 3*P^152 + P^153 + 2*P^154 + P^155 + P^156 + 2*P^157 + P^158 + 3*P^159 + 2*P^161 + 
    P^162 + 2*P^163 + P^164 + P^165 + 2*P^166 + 2*P^168 + 2*P^170 + P^171 + P^172 + 2*P^173 + 2*P^175 + 2*P^177 + P^178 + 
    P^179 + P^180 + 2*P^182 + 2*P^184 + P^186 + P^187 + 2*P^189 + P^191 + P^193 + P^194 + P^196 + P^198 + P^200 + P^202 + 
    P^203 + P^207 + P^209 + P^214 + P^216)/((1 - P^3)*(1 - P^85)*(1 - P^139))}, 
 {3, (P^2 + P^12 + 2*P^18 + P^19 + 2*P^25 + P^26 + P^28 + 2*P^32 + P^33 + 2*P^34 + P^35 + 2*P^39 + 2*P^41 + P^42 + P^43 + 
    P^44 + 2*P^46 + 2*P^48 + P^49 + 2*P^50 + P^51 + P^53 + 2*P^55 + P^56 + 2*P^57 + P^58 + 2*P^59 + P^60 + 2*P^62 + P^63 + 
    2*P^64 + P^65 + 2*P^66 + P^67 + 3*P^69 + P^70 + 2*P^71 + P^72 + 2*P^73 + P^74 + 2*P^75 + 3*P^76 + P^77 + 2*P^78 + P^79 + 
    2*P^80 + P^81 + 2*P^82 + 3*P^83 + P^84 + 3*P^85 + P^86 + P^87 + P^88 + 2*P^89 + 3*P^90 + 2*P^91 + 3*P^92 + P^93 + 2*P^94 + 
    P^95 + 2*P^96 + P^97 + 2*P^98 + 3*P^99 + 3*P^100 + 3*P^101 + P^102 + 2*P^105 + 3*P^106 + 3*P^107 + 3*P^108 + P^109 + 
    P^110 + 2*P^112 + 2*P^113 + 3*P^114 + 3*P^115 + 3*P^116 + P^117 + 2*P^120 + 3*P^121 + 3*P^122 + 3*P^123 + P^124 + P^125 + 
    P^126 + 2*P^127 + 2*P^128 + 2*P^129 + 3*P^130 + P^131 + 3*P^132 + P^133 + 2*P^134 + 2*P^136 + 3*P^137 + 2*P^138 + 3*P^139 + 
    P^140 + 2*P^141 + P^142 + 2*P^143 + P^144 + 2*P^145 + 3*P^146 + P^147 + 2*P^148 + P^149 + 2*P^150 + P^151 + 2*P^152 + 
    3*P^153 + 2*P^155 + P^156 + 2*P^157 + P^158 + 2*P^159 + P^160 + 2*P^162 + P^163 + 2*P^164 + P^165 + 2*P^166 + P^167 + 
    2*P^169 + 2*P^171 + P^172 + 2*P^173 + P^174 + P^176 + 2*P^178 + P^179 + 2*P^180 + P^181 + P^182 + P^183 + 2*P^187 + P^188 + 
    2*P^189 + P^190 + 2*P^194 + 2*P^196 + P^197 + 2*P^203 + P^204 + 2*P^210 + P^220)/((1 - P^3)*(1 - P^85)*(1 - P^139))}, 
 {3, (P^6 + P^11 + P^13 + P^18 + P^20 + 2*P^22 + P^27 + 2*P^29 + P^31 + P^34 + 3*P^36 + 2*P^38 + P^41 + 3*P^43 + 2*P^45 + 
    P^47 + P^48 + 3*P^50 + 3*P^52 + 2*P^54 + P^55 + 2*P^57 + 3*P^59 + 2*P^61 + P^62 + 2*P^63 + 2*P^64 + 3*P^66 + 3*P^68 + 
    2*P^70 + P^71 + P^72 + 3*P^73 + 3*P^75 + 3*P^77 + P^78 + 2*P^79 + 3*P^80 + 3*P^82 + 3*P^84 + P^85 + 2*P^86 + 3*P^87 + 
    P^88 + 3*P^89 + 2*P^91 + P^92 + 3*P^93 + 3*P^94 + 2*P^95 + 2*P^96 + 2*P^98 + P^99 + 3*P^100 + 2*P^101 + 2*P^102 + 2*P^103 + 
    2*P^104 + 2*P^105 + P^106 + P^107 + 2*P^108 + 3*P^109 + 3*P^110 + 2*P^111 + 2*P^112 + P^113 + P^114 + P^115 + 2*P^116 + 
    3*P^117 + 3*P^118 + 2*P^119 + 2*P^120 + P^122 + P^123 + 3*P^124 + 3*P^125 + 2*P^126 + 2*P^127 + 2*P^129 + P^130 + 3*P^131 + 
    2*P^132 + 2*P^133 + 3*P^134 + 3*P^136 + 3*P^138 + P^139 + 2*P^140 + 3*P^141 + P^142 + 3*P^143 + 3*P^145 + P^146 + 2*P^147 + 
    P^148 + P^149 + 3*P^150 + 3*P^152 + 3*P^154 + P^155 + 2*P^156 + 2*P^157 + 3*P^159 + 3*P^161 + 2*P^163 + P^164 + 3*P^166 + 
    3*P^168 + 2*P^170 + P^171 + 2*P^173 + 3*P^175 + 2*P^177 + P^180 + 3*P^182 + 2*P^184 + P^186 + P^187 + P^189 + 2*P^191 + 
    P^193 + P^196 + 2*P^198 + 2*P^200 + P^205 + 2*P^207 + P^212 + P^214)/((1 - P^3)*(1 - P^85)*(1 - P^139))}, 
 {3, (P^6 + P^13 + P^14 + P^19 + P^21 + P^22 + P^23 + P^26 + P^28 + P^29 + P^30 + P^33 + P^35 + P^36 + P^37 + P^38 + P^39 + 
    P^40 + P^42 + P^43 + 2*P^44 + P^45 + P^46 + P^47 + P^49 + P^50 + 2*P^51 + P^52 + P^53 + P^54 + P^55 + P^56 + P^57 + 
    2*P^58 + P^59 + 2*P^60 + P^61 + P^62 + 2*P^63 + P^64 + 2*P^65 + P^66 + 2*P^67 + P^68 + P^69 + 2*P^70 + P^71 + 2*P^72 + 
    P^73 + 2*P^74 + P^75 + 2*P^76 + 2*P^77 + P^78 + 2*P^79 + 2*P^80 + 2*P^81 + P^82 + 2*P^83 + 2*P^84 + 2*P^85 + 2*P^86 + 
    2*P^87 + 2*P^88 + P^89 + 2*P^90 + P^91 + 2*P^92 + 2*P^93 + 2*P^94 + 3*P^95 + 2*P^96 + 2*P^97 + P^99 + 2*P^100 + 3*P^101 + 
    3*P^102 + 2*P^103 + 2*P^104 + P^105 + P^106 + P^107 + 2*P^108 + 3*P^109 + 2*P^110 + 2*P^111 + 2*P^112 + P^113 + P^114 + 
    P^115 + 3*P^116 + 3*P^117 + 2*P^118 + 2*P^119 + 2*P^120 + 2*P^121 + P^122 + P^123 + 2*P^124 + 2*P^125 + 3*P^126 + 2*P^127 + 
    2*P^128 + P^130 + 2*P^131 + 2*P^132 + 3*P^133 + 2*P^134 + 2*P^135 + P^136 + 2*P^137 + 2*P^138 + 2*P^139 + 2*P^140 + 
    2*P^141 + 2*P^142 + P^143 + 2*P^144 + P^145 + 2*P^146 + 2*P^147 + P^148 + 2*P^149 + P^150 + 2*P^151 + P^152 + 2*P^153 + 
    2*P^154 + P^155 + 2*P^156 + P^157 + 2*P^158 + P^159 + 2*P^160 + P^161 + P^162 + 2*P^163 + P^164 + P^165 + P^166 + 2*P^167 + 
    P^168 + P^169 + P^170 + P^171 + P^172 + P^173 + 2*P^174 + P^175 + P^176 + P^177 + P^178 + P^179 + P^181 + P^182 + 2*P^183 + 
    P^184 + P^185 + P^188 + 2*P^190 + P^191 + P^192 + P^195 + P^197 + P^198 + P^199 + P^200 + P^204 + P^207 + P^208 + P^214 + 
    P^215)/((1 - P^3)*(1 - P^85)*(1 - P^139))}, 
 {3, (P^7 + 2*P^14 + P^18 + P^21 + P^23 + P^25 + P^27 + P^28 + 2*P^30 + P^32 + P^34 + P^35 + 2*P^37 + 2*P^39 + P^41 + P^43 + 
    2*P^44 + 2*P^46 + 2*P^48 + P^50 + 2*P^51 + 2*P^53 + 3*P^55 + P^57 + 2*P^58 + P^59 + 2*P^60 + 3*P^62 + 2*P^64 + P^65 + 
    P^66 + 2*P^67 + P^68 + 3*P^69 + 3*P^71 + P^72 + P^73 + 2*P^74 + P^75 + 3*P^76 + 3*P^78 + P^79 + 2*P^80 + 2*P^81 + P^82 + 
    3*P^83 + P^84 + 3*P^85 + 3*P^87 + 2*P^88 + 2*P^89 + 2*P^90 + P^91 + 2*P^92 + 3*P^94 + 2*P^95 + 3*P^96 + 2*P^97 + P^98 + 
    P^99 + P^100 + 3*P^101 + 2*P^102 + 2*P^103 + 2*P^104 + 2*P^105 + 2*P^106 + P^107 + 2*P^108 + 2*P^109 + 2*P^110 + 2*P^111 + 
    2*P^112 + 2*P^113 + P^114 + P^115 + 2*P^116 + 2*P^117 + 2*P^118 + 2*P^119 + 2*P^120 + 2*P^121 + P^122 + 2*P^123 + P^124 + 
    3*P^125 + 2*P^126 + 3*P^127 + 2*P^128 + P^129 + 2*P^130 + P^131 + 3*P^132 + P^133 + 2*P^134 + 2*P^135 + P^136 + 3*P^137 + 
    P^138 + 3*P^139 + 3*P^141 + 2*P^142 + P^143 + 2*P^144 + P^145 + 3*P^146 + 3*P^148 + P^149 + 2*P^150 + 2*P^151 + P^152 + 
    2*P^153 + 3*P^155 + 2*P^157 + 2*P^158 + P^159 + 2*P^160 + 3*P^162 + 2*P^164 + P^165 + P^166 + 2*P^167 + 2*P^169 + 3*P^171 + 
    P^173 + P^174 + P^175 + 2*P^176 + 3*P^178 + P^180 + P^182 + 2*P^183 + 2*P^185 + P^187 + P^189 + P^190 + 2*P^192 + P^194 + 
    P^196 + 2*P^199 + P^201 + P^203 + P^206 + P^208 + P^215 + P^219)/((1 - P^3)*(1 - P^85)*(1 - P^139))}, 
 {3, (P^5 + P^12 + P^15 + P^19 + P^21 + P^22 + P^26 + 2*P^28 + P^29 + P^31 + P^33 + 2*P^35 + P^36 + P^37 + P^38 + P^40 + 
    2*P^42 + 2*P^44 + P^45 + P^46 + P^47 + 2*P^49 + 2*P^51 + P^52 + P^53 + P^54 + 3*P^56 + 2*P^58 + P^59 + 2*P^60 + P^61 + 
    P^62 + 2*P^63 + 2*P^65 + P^66 + 2*P^67 + P^68 + 2*P^69 + 2*P^70 + 3*P^72 + P^73 + 2*P^74 + P^75 + 2*P^76 + 2*P^77 + P^78 + 
    3*P^79 + P^80 + 2*P^81 + P^82 + 2*P^83 + 2*P^84 + 2*P^85 + 3*P^86 + P^87 + 3*P^88 + P^89 + P^90 + P^91 + 2*P^92 + 3*P^93 + 
    P^94 + 3*P^95 + P^96 + 2*P^97 + P^98 + 2*P^99 + 2*P^100 + 2*P^101 + 3*P^102 + 2*P^103 + 2*P^104 + P^105 + P^106 + P^107 + 
    2*P^108 + 3*P^109 + 3*P^110 + 2*P^111 + P^112 + P^113 + P^114 + 2*P^115 + 2*P^116 + 3*P^117 + 2*P^118 + 2*P^119 + P^120 + 
    P^121 + P^122 + 2*P^123 + 3*P^124 + 2*P^125 + 3*P^126 + P^127 + 2*P^128 + P^129 + 2*P^130 + 2*P^131 + 2*P^132 + 3*P^133 + 
    P^134 + 2*P^135 + P^136 + 2*P^137 + 2*P^138 + 2*P^139 + 3*P^140 + 3*P^142 + P^143 + 2*P^144 + P^145 + 2*P^146 + 2*P^147 + 
    P^148 + 3*P^149 + P^150 + 2*P^151 + P^152 + 2*P^153 + P^154 + P^155 + 3*P^156 + 2*P^158 + P^159 + 2*P^160 + P^161 + P^162 + 
    2*P^163 + 2*P^165 + P^166 + 2*P^167 + P^168 + P^169 + P^170 + 2*P^172 + 2*P^174 + P^175 + 2*P^176 + P^177 + 2*P^179 + 
    2*P^181 + 2*P^183 + P^184 + P^186 + P^188 + 2*P^190 + P^191 + P^192 + P^193 + 2*P^197 + P^199 + P^200 + P^204 + P^206 + 
    P^207 + P^213 + P^220)/((1 - P^3)*(1 - P^85)*(1 - P^139))}, 
 {3, (P^7 + P^11 + P^14 + P^18 + P^21 + P^23 + P^25 + P^27 + P^28 + 2*P^30 + P^32 + P^34 + P^35 + 2*P^37 + P^39 + P^41 + P^42 + 
    P^43 + 2*P^44 + 2*P^46 + 2*P^48 + P^50 + 2*P^51 + P^52 + 2*P^53 + 2*P^55 + P^57 + 2*P^58 + P^59 + 2*P^60 + 3*P^62 + 
    2*P^64 + P^65 + P^66 + 2*P^67 + P^68 + 3*P^69 + 3*P^71 + P^72 + P^73 + 2*P^74 + P^75 + 3*P^76 + 3*P^78 + P^79 + 2*P^80 + 
    2*P^81 + P^82 + 2*P^83 + P^84 + 3*P^85 + P^86 + 3*P^87 + 2*P^88 + 2*P^89 + 2*P^90 + P^91 + 2*P^92 + P^93 + 3*P^94 + 
    2*P^95 + P^96 + 2*P^97 + P^98 + 2*P^99 + P^100 + 3*P^101 + 2*P^102 + 2*P^103 + 2*P^104 + 2*P^105 + 2*P^106 + P^107 + 
    2*P^108 + 2*P^109 + 2*P^110 + 2*P^111 + 2*P^112 + 2*P^113 + P^114 + P^115 + 2*P^116 + 2*P^117 + 2*P^118 + 2*P^119 + 
    2*P^120 + 2*P^121 + P^122 + 2*P^123 + 2*P^124 + 3*P^125 + 2*P^126 + P^127 + 2*P^128 + P^129 + 3*P^130 + P^131 + 3*P^132 + 
    P^133 + 2*P^134 + 2*P^135 + P^136 + 2*P^137 + P^138 + 3*P^139 + P^140 + 3*P^141 + 2*P^142 + P^143 + 2*P^144 + P^145 + 
    3*P^146 + 3*P^148 + P^149 + 2*P^150 + 2*P^151 + P^152 + 2*P^153 + 3*P^155 + 2*P^157 + 2*P^158 + P^159 + 2*P^160 + 3*P^162 + 
    2*P^164 + P^165 + P^166 + 2*P^167 + P^168 + 2*P^169 + 2*P^171 + P^173 + P^174 + P^175 + 2*P^176 + 2*P^178 + P^180 + P^181 + 
    P^182 + 2*P^183 + 2*P^185 + P^187 + P^189 + P^190 + 2*P^192 + P^194 + P^196 + 2*P^199 + P^201 + P^203 + P^206 + P^208 + 
    P^212 + P^219)/((1 - P^3)*(1 - P^85)*(1 - P^139))}, 
 {3, (P^6 + P^10 + P^16 + P^17 + P^22 + P^23 + P^24 + P^26 + P^29 + P^30 + P^31 + P^32 + P^33 + P^36 + P^37 + P^38 + P^39 + 
    P^40 + P^42 + P^43 + P^44 + P^45 + P^46 + 2*P^47 + P^48 + P^49 + P^50 + P^51 + P^52 + P^53 + 2*P^54 + P^55 + P^56 + P^57 + 
    P^58 + P^59 + P^60 + 2*P^61 + P^62 + 2*P^63 + P^64 + P^65 + P^66 + 2*P^67 + 2*P^68 + P^69 + 2*P^70 + P^71 + P^72 + 2*P^73 + 
    2*P^74 + 2*P^75 + P^76 + 2*P^77 + P^78 + 2*P^79 + 2*P^80 + 2*P^81 + P^82 + 2*P^83 + 2*P^84 + P^85 + 2*P^86 + 2*P^87 + 
    3*P^88 + 2*P^89 + 2*P^90 + P^91 + P^92 + 2*P^93 + 2*P^94 + 2*P^95 + 2*P^96 + 2*P^97 + 2*P^98 + 2*P^99 + 2*P^100 + P^101 + 
    P^102 + 2*P^103 + 3*P^104 + 3*P^105 + 2*P^106 + P^107 + P^108 + P^109 + 2*P^110 + 2*P^111 + 3*P^112 + 2*P^113 + 2*P^114 + 
    P^115 + P^116 + P^117 + 2*P^118 + 3*P^119 + 3*P^120 + 2*P^121 + P^122 + P^123 + 2*P^124 + 2*P^125 + 2*P^126 + 2*P^127 + 
    2*P^128 + 2*P^129 + 2*P^130 + 2*P^131 + P^132 + P^133 + 2*P^134 + 2*P^135 + 2*P^136 + 2*P^137 + 2*P^138 + P^139 + 2*P^140 + 
    2*P^141 + 2*P^142 + 2*P^143 + 2*P^144 + 2*P^145 + P^146 + 2*P^147 + P^148 + 2*P^149 + 2*P^150 + 2*P^151 + P^152 + P^153 + 
    2*P^154 + P^155 + 2*P^156 + 2*P^157 + P^158 + P^159 + P^160 + 2*P^161 + P^162 + 2*P^163 + P^164 + P^165 + P^166 + 2*P^167 + 
    P^168 + P^169 + 2*P^170 + P^171 + P^172 + P^174 + P^175 + P^176 + 2*P^177 + P^178 + P^179 + P^181 + P^182 + P^183 + P^184 + 
    P^185 + P^186 + P^187 + P^188 + P^191 + P^192 + P^193 + P^194 + P^195 + P^198 + P^200 + P^201 + P^202 + P^207 + P^208 + 
    P^211 + P^218)/((1 - P^3)*(1 - P^85)*(1 - P^139))}, 
 {3, (P^6 + P^13 + P^16 + P^17 + P^22 + P^23 + P^24 + P^26 + P^29 + P^30 + P^31 + P^32 + P^33 + P^36 + P^37 + P^38 + P^39 + 
    P^40 + P^41 + P^42 + P^43 + P^45 + P^46 + 2*P^47 + P^48 + P^49 + P^50 + P^52 + P^53 + 2*P^54 + P^55 + P^56 + 2*P^57 + 
    P^58 + P^59 + P^60 + 2*P^61 + P^62 + 2*P^63 + P^64 + P^65 + P^66 + 2*P^67 + 2*P^68 + P^69 + 2*P^70 + P^71 + P^72 + 2*P^73 + 
    2*P^74 + 2*P^75 + P^76 + 2*P^77 + P^78 + 2*P^79 + 2*P^80 + 2*P^81 + 2*P^82 + 2*P^83 + 2*P^84 + P^85 + 2*P^86 + 2*P^87 + 
    2*P^88 + 2*P^89 + 2*P^90 + P^91 + P^92 + 2*P^93 + 2*P^94 + 2*P^95 + 2*P^96 + 2*P^97 + 2*P^98 + 2*P^99 + 2*P^100 + P^101 + 
    P^102 + 2*P^103 + 3*P^104 + 3*P^105 + 2*P^106 + P^107 + P^108 + P^109 + 2*P^110 + 2*P^111 + 3*P^112 + 2*P^113 + 2*P^114 + 
    P^115 + P^116 + P^117 + 2*P^118 + 3*P^119 + 3*P^120 + 2*P^121 + P^122 + P^123 + 2*P^124 + 2*P^125 + 2*P^126 + 2*P^127 + 
    2*P^128 + 2*P^129 + 2*P^130 + 2*P^131 + P^132 + P^133 + 2*P^134 + 2*P^135 + 3*P^136 + 2*P^137 + 2*P^138 + P^139 + 2*P^140 + 
    2*P^141 + P^142 + 2*P^143 + 2*P^144 + 2*P^145 + P^146 + 2*P^147 + P^148 + 2*P^149 + 2*P^150 + 2*P^151 + P^152 + P^153 + 
    2*P^154 + P^155 + 2*P^156 + 2*P^157 + P^158 + P^159 + P^160 + 2*P^161 + P^162 + 2*P^163 + P^164 + P^165 + P^166 + P^167 + 
    P^168 + P^169 + 2*P^170 + P^171 + P^172 + P^173 + P^174 + P^175 + P^176 + 2*P^177 + P^178 + P^179 + P^180 + P^181 + P^182 + 
    P^184 + P^185 + P^186 + P^187 + P^188 + P^191 + P^192 + P^193 + P^194 + P^195 + P^198 + P^200 + P^201 + P^202 + P^207 + 
    P^208 + P^214 + P^218)/((1 - P^3)*(1 - P^85)*(1 - P^139))}, 
 {3, (P^5 + P^9 + P^16 + P^18 + P^21 + P^23 + 2*P^25 + P^28 + P^30 + 2*P^32 + P^34 + P^35 + P^37 + 2*P^39 + 2*P^41 + P^42 + 
    P^44 + 3*P^46 + 2*P^48 + P^49 + P^50 + P^51 + 3*P^53 + 2*P^55 + 2*P^57 + P^58 + P^59 + 2*P^60 + 3*P^62 + 2*P^64 + P^65 + 
    2*P^66 + 2*P^67 + 3*P^69 + 2*P^71 + P^72 + 2*P^73 + 2*P^74 + P^75 + 3*P^76 + 3*P^78 + P^79 + 2*P^80 + P^81 + 2*P^82 + 
    3*P^83 + 3*P^85 + P^86 + 3*P^87 + P^88 + 2*P^89 + 2*P^90 + P^91 + 3*P^92 + P^93 + 2*P^94 + P^95 + 2*P^96 + 3*P^97 + 
    2*P^98 + 3*P^99 + P^100 + 2*P^101 + P^102 + 2*P^103 + 2*P^104 + 2*P^105 + 2*P^106 + 2*P^107 + 2*P^108 + P^109 + P^110 + 
    2*P^111 + 2*P^112 + 2*P^113 + 2*P^114 + 2*P^115 + 2*P^116 + P^117 + 2*P^118 + 2*P^119 + 2*P^120 + 2*P^121 + 2*P^122 + 
    3*P^123 + P^124 + P^125 + P^126 + 2*P^127 + 3*P^128 + 2*P^129 + 3*P^130 + 2*P^132 + P^133 + 2*P^134 + 2*P^135 + 2*P^136 + 
    3*P^137 + 3*P^139 + P^140 + 3*P^141 + P^142 + 2*P^143 + 2*P^144 + P^145 + 3*P^146 + 3*P^148 + P^149 + 2*P^150 + P^151 + 
    P^152 + 3*P^153 + 3*P^155 + P^156 + 2*P^157 + P^158 + P^159 + 2*P^160 + 3*P^162 + 2*P^164 + P^165 + 2*P^166 + P^167 + 
    3*P^169 + 2*P^171 + 2*P^173 + P^174 + 2*P^176 + 2*P^178 + 2*P^180 + P^181 + P^183 + 2*P^185 + 2*P^187 + P^189 + P^190 + 
    P^192 + 2*P^194 + P^196 + P^197 + P^199 + P^201 + P^203 + P^206 + 2*P^210 + P^217)/((1 - P^3)*(1 - P^85)*(1 - P^139))}, 
 {3, (P^7 + P^12 + P^14 + P^19 + P^20 + P^21 + P^23 + P^27 + P^28 + P^29 + P^30 + P^34 + P^35 + P^36 + 2*P^37 + P^39 + P^41 + 
    P^42 + P^43 + 2*P^44 + P^45 + P^46 + P^48 + P^49 + P^50 + 2*P^51 + P^52 + 2*P^53 + P^55 + P^56 + P^57 + 2*P^58 + P^59 + 
    2*P^60 + P^61 + P^62 + P^63 + 2*P^64 + 2*P^65 + P^66 + 2*P^67 + P^68 + 2*P^69 + P^70 + 2*P^71 + P^72 + P^73 + 2*P^74 + 
    P^75 + 2*P^76 + P^77 + 3*P^78 + P^79 + 2*P^80 + 2*P^81 + P^82 + 2*P^83 + P^84 + 3*P^85 + 2*P^86 + 2*P^87 + 2*P^88 + P^89 + 
    2*P^90 + P^91 + 2*P^92 + 2*P^93 + 3*P^94 + 2*P^95 + 2*P^96 + P^97 + P^98 + P^99 + 2*P^100 + 3*P^101 + 3*P^102 + 2*P^103 + 
    P^104 + P^105 + P^106 + 2*P^107 + 2*P^108 + 3*P^109 + 3*P^110 + 2*P^111 + P^112 + P^113 + P^114 + 2*P^115 + 2*P^116 + 
    3*P^117 + 3*P^118 + 2*P^119 + P^120 + P^121 + P^122 + 2*P^123 + 2*P^124 + 3*P^125 + 2*P^126 + 2*P^127 + P^128 + P^129 + 
    P^130 + 2*P^131 + 3*P^132 + 2*P^133 + 2*P^134 + 2*P^135 + P^136 + 2*P^137 + P^138 + 3*P^139 + 2*P^140 + 2*P^141 + 2*P^142 + 
    P^143 + 2*P^144 + P^145 + 2*P^146 + 2*P^147 + 2*P^148 + P^149 + P^150 + 2*P^151 + P^152 + 2*P^153 + P^154 + 2*P^155 + 
    P^156 + 2*P^157 + 2*P^158 + P^159 + 2*P^160 + P^161 + 2*P^162 + 2*P^164 + P^165 + P^166 + 2*P^167 + P^168 + 2*P^169 + 
    P^171 + P^172 + P^173 + 2*P^174 + P^175 + 2*P^176 + P^178 + P^180 + P^181 + P^182 + 2*P^183 + P^184 + P^185 + P^188 + 
    P^189 + P^190 + P^191 + P^192 + P^196 + P^197 + P^198 + P^199 + P^201 + P^205 + P^206 + P^208 + P^213 + P^215)/
   ((1 - P^3)*(1 - P^85)*(1 - P^139))}, {3, (P^9 + P^13 + P^16 + P^17 + P^20 + P^24 + P^25 + P^26 + P^27 + P^29 + P^31 + P^32 + 
    P^33 + P^34 + P^36 + P^38 + P^39 + P^40 + P^41 + P^42 + P^43 + P^45 + P^46 + P^47 + P^48 + P^49 + 2*P^50 + P^52 + P^53 + 
    2*P^54 + P^55 + P^56 + 2*P^57 + P^58 + P^59 + P^60 + 2*P^61 + P^62 + P^63 + 2*P^64 + P^65 + 2*P^66 + P^67 + 2*P^68 + P^69 + 
    2*P^70 + 2*P^71 + P^72 + 2*P^73 + P^74 + 2*P^75 + P^76 + 2*P^77 + 2*P^78 + P^79 + 2*P^80 + P^81 + 3*P^82 + 2*P^83 + 
    2*P^84 + P^85 + 2*P^86 + 2*P^87 + P^88 + 2*P^89 + 2*P^90 + 3*P^91 + P^92 + 2*P^93 + P^94 + 2*P^95 + 2*P^96 + 2*P^97 + 
    2*P^98 + 2*P^99 + 2*P^100 + P^101 + P^102 + 2*P^103 + 2*P^104 + 2*P^105 + 2*P^106 + 3*P^107 + 2*P^108 + P^109 + P^110 + 
    2*P^111 + 2*P^112 + 2*P^113 + 2*P^114 + 3*P^115 + P^116 + P^117 + P^118 + 2*P^119 + 2*P^120 + 2*P^121 + 3*P^122 + 2*P^123 + 
    2*P^124 + P^125 + 2*P^126 + 2*P^127 + 2*P^128 + 2*P^129 + 2*P^130 + 2*P^131 + 2*P^132 + P^133 + 2*P^134 + P^135 + 3*P^136 + 
    2*P^137 + 2*P^138 + P^139 + 2*P^140 + 2*P^141 + P^142 + 2*P^143 + 2*P^144 + 2*P^145 + P^146 + 2*P^147 + 2*P^148 + P^149 + 
    2*P^150 + P^151 + 2*P^152 + P^153 + 2*P^154 + P^155 + P^156 + 2*P^157 + P^158 + 2*P^159 + P^160 + 2*P^161 + P^162 + P^163 + 
    2*P^164 + P^165 + 2*P^166 + P^168 + P^169 + 2*P^170 + P^171 + P^172 + 2*P^173 + P^174 + P^175 + 2*P^177 + P^178 + P^179 + 
    P^180 + P^181 + P^182 + P^184 + P^185 + P^186 + P^187 + P^188 + P^189 + P^191 + P^193 + P^194 + P^195 + P^198 + P^201 + 
    P^202 + P^203 + P^205 + P^210 + P^214 + P^218)/((1 - P^3)*(1 - P^85)*(1 - P^139))}, 
 {3, (P^6 + P^10 + P^14 + P^19 + P^21 + P^22 + P^23 + P^26 + P^29 + P^30 + P^31 + P^33 + P^35 + P^36 + P^37 + P^38 + P^39 + 
    P^40 + P^42 + P^43 + P^44 + P^45 + P^46 + 2*P^47 + P^49 + P^50 + 2*P^51 + P^52 + P^53 + 2*P^54 + P^55 + P^56 + 2*P^58 + 
    P^59 + 2*P^60 + P^61 + P^62 + 2*P^63 + P^64 + 2*P^65 + P^66 + 2*P^67 + P^68 + P^69 + 2*P^70 + P^71 + 2*P^72 + P^73 + 
    2*P^74 + P^75 + 2*P^76 + 2*P^77 + P^78 + 2*P^79 + 2*P^80 + 2*P^81 + P^82 + 2*P^83 + 2*P^84 + P^85 + 2*P^86 + 2*P^87 + 
    3*P^88 + P^89 + 2*P^90 + P^91 + 2*P^92 + 2*P^93 + 2*P^94 + 2*P^95 + 2*P^96 + 2*P^97 + 2*P^98 + P^99 + 2*P^100 + 2*P^101 + 
    3*P^102 + 2*P^103 + 2*P^104 + 2*P^105 + P^106 + P^107 + P^108 + 3*P^109 + 2*P^110 + 2*P^111 + 2*P^112 + 2*P^113 + P^114 + 
    P^115 + 2*P^116 + 3*P^117 + 2*P^118 + 2*P^119 + 2*P^120 + 2*P^121 + P^122 + P^123 + 2*P^124 + 2*P^125 + 2*P^126 + 2*P^127 + 
    2*P^128 + 2*P^129 + P^130 + 2*P^131 + P^132 + 3*P^133 + 2*P^134 + 2*P^135 + P^136 + 2*P^137 + 2*P^138 + P^139 + 2*P^140 + 
    2*P^141 + 3*P^142 + P^143 + 2*P^144 + P^145 + 2*P^146 + 2*P^147 + P^148 + 2*P^149 + P^150 + 2*P^151 + P^152 + 2*P^153 + 
    2*P^154 + P^155 + 2*P^156 + P^157 + 2*P^158 + P^159 + 2*P^160 + P^161 + P^162 + 2*P^163 + P^164 + P^165 + P^166 + 2*P^167 + 
    P^168 + P^169 + 2*P^170 + P^171 + P^172 + 2*P^174 + P^175 + P^176 + P^177 + P^178 + P^179 + P^181 + P^182 + P^183 + P^184 + 
    P^185 + P^186 + P^188 + P^190 + P^191 + P^192 + P^193 + P^195 + P^197 + P^198 + P^199 + P^200 + P^204 + P^207 + P^208 + 
    P^211 + P^215)/((1 - P^3)*(1 - P^85)*(1 - P^139))}, 
 {3, (P^12 + P^13 + P^14 + P^19 + P^20 + P^21 + P^26 + P^27 + 2*P^28 + P^29 + P^30 + P^35 + P^36 + 2*P^37 + P^38 + P^39 + 
    P^42 + P^43 + 2*P^44 + P^45 + P^46 + P^49 + P^50 + 2*P^51 + P^52 + 2*P^53 + P^54 + P^55 + P^56 + P^57 + 2*P^58 + P^59 + 
    2*P^60 + P^61 + P^62 + P^63 + P^64 + 2*P^65 + P^66 + 2*P^67 + P^68 + 2*P^69 + 2*P^70 + 2*P^71 + 2*P^72 + P^73 + 2*P^74 + 
    P^75 + 2*P^76 + P^77 + 2*P^78 + 2*P^79 + 2*P^80 + 2*P^81 + P^82 + 2*P^83 + P^84 + 2*P^85 + 2*P^86 + 2*P^87 + 2*P^88 + 
    P^89 + 2*P^90 + P^91 + 2*P^92 + 2*P^93 + 3*P^94 + 3*P^95 + 2*P^96 + P^97 + P^99 + 2*P^100 + 3*P^101 + 3*P^102 + 2*P^103 + 
    P^104 + P^106 + 2*P^107 + 3*P^108 + 3*P^109 + 3*P^110 + 2*P^111 + P^112 + P^114 + 2*P^115 + 3*P^116 + 3*P^117 + 3*P^118 + 
    2*P^119 + P^120 + P^121 + P^122 + 2*P^123 + 2*P^124 + 3*P^125 + 3*P^126 + 2*P^127 + P^128 + P^130 + 2*P^131 + 3*P^132 + 
    3*P^133 + 2*P^134 + 2*P^135 + P^136 + 2*P^137 + P^138 + 2*P^139 + 2*P^140 + 2*P^141 + 2*P^142 + P^143 + 2*P^144 + P^145 + 
    2*P^146 + 2*P^147 + 2*P^148 + 2*P^149 + P^150 + 2*P^151 + P^152 + 2*P^153 + P^154 + P^155 + P^156 + P^157 + 2*P^158 + 
    P^159 + 2*P^160 + P^161 + 2*P^162 + P^163 + P^164 + P^165 + P^166 + 2*P^167 + P^168 + 2*P^169 + P^170 + P^171 + P^172 + 
    P^173 + 2*P^174 + P^175 + 2*P^176 + P^177 + P^178 + P^181 + P^182 + 2*P^183 + P^184 + P^185 + P^188 + P^189 + 2*P^190 + 
    P^191 + P^192 + P^197 + P^198 + P^199 + P^204 + P^205 + P^206 + P^213 + P^214 + P^215)/((1 - P^3)*(1 - P^85)*(1 - P^139))}, 
 {3, (P^7 + P^9 + P^14 + P^16 + P^21 + 2*P^23 + P^25 + 2*P^30 + 2*P^32 + P^34 + 2*P^37 + 3*P^39 + P^41 + 2*P^44 + 3*P^46 + 
    2*P^48 + P^50 + 2*P^51 + 3*P^53 + 3*P^55 + P^57 + P^58 + 3*P^60 + 3*P^62 + 3*P^64 + P^65 + P^66 + 2*P^67 + 3*P^69 + 
    3*P^71 + 2*P^73 + 2*P^74 + P^75 + 3*P^76 + 3*P^78 + 3*P^80 + 2*P^81 + P^82 + 3*P^83 + 3*P^85 + 3*P^87 + 2*P^88 + 2*P^89 + 
    3*P^90 + P^91 + 2*P^92 + 2*P^94 + 2*P^95 + 3*P^96 + 3*P^97 + P^98 + 2*P^99 + 2*P^101 + P^102 + 3*P^103 + 3*P^104 + 
    3*P^105 + 2*P^106 + P^107 + P^108 + P^109 + 2*P^110 + 2*P^111 + 3*P^112 + 3*P^113 + 2*P^114 + P^115 + P^116 + P^117 + 
    2*P^118 + 2*P^119 + 3*P^120 + 3*P^121 + P^122 + P^123 + 2*P^125 + 2*P^126 + 3*P^127 + 3*P^128 + P^129 + 2*P^130 + 3*P^132 + 
    P^133 + 3*P^134 + 2*P^135 + P^136 + 3*P^137 + 3*P^139 + 3*P^141 + 2*P^142 + 2*P^143 + 3*P^144 + 3*P^146 + 3*P^148 + 
    2*P^150 + 2*P^151 + P^152 + 3*P^153 + 3*P^155 + 3*P^157 + P^158 + P^159 + 2*P^160 + 3*P^162 + 3*P^164 + P^166 + 2*P^167 + 
    3*P^169 + 3*P^171 + P^173 + P^174 + 2*P^176 + 3*P^178 + P^180 + 2*P^183 + 3*P^185 + 2*P^187 + 2*P^192 + 2*P^194 + P^196 + 
    P^199 + 2*P^201 + P^203 + 2*P^208 + P^210 + P^215)/((1 - P^3)*(1 - P^85)*(1 - P^139))}, 
 {3, (P^5 + P^12 + P^16 + P^18 + P^21 + P^23 + 2*P^25 + P^28 + P^30 + 2*P^32 + P^34 + P^35 + P^37 + 2*P^39 + 2*P^41 + P^42 + 
    P^43 + P^44 + 2*P^46 + 2*P^48 + P^49 + P^50 + P^51 + 2*P^53 + 2*P^55 + P^56 + 2*P^57 + P^58 + P^59 + 2*P^60 + 3*P^62 + 
    2*P^64 + P^65 + 2*P^66 + 2*P^67 + 3*P^69 + 2*P^71 + P^72 + 2*P^73 + 2*P^74 + P^75 + 3*P^76 + 3*P^78 + P^79 + 2*P^80 + 
    P^81 + 2*P^82 + 3*P^83 + P^84 + 3*P^85 + P^86 + 2*P^87 + P^88 + 2*P^89 + 2*P^90 + P^91 + 3*P^92 + P^93 + 3*P^94 + P^95 + 
    2*P^96 + P^97 + 2*P^98 + 3*P^99 + 2*P^100 + 2*P^101 + P^102 + 2*P^103 + 2*P^104 + 2*P^105 + 2*P^106 + 2*P^107 + 2*P^108 + 
    P^109 + P^110 + 2*P^111 + 2*P^112 + 2*P^113 + 2*P^114 + 2*P^115 + 2*P^116 + P^117 + 2*P^118 + 2*P^119 + 2*P^120 + 2*P^121 + 
    2*P^122 + 3*P^123 + P^124 + 2*P^125 + P^126 + 2*P^127 + P^128 + 2*P^129 + 3*P^130 + P^131 + 2*P^132 + P^133 + 2*P^134 + 
    2*P^135 + 2*P^136 + 3*P^137 + P^138 + 3*P^139 + P^140 + 2*P^141 + P^142 + 2*P^143 + 2*P^144 + P^145 + 3*P^146 + 3*P^148 + 
    P^149 + 2*P^150 + P^151 + P^152 + 3*P^153 + 3*P^155 + P^156 + 2*P^157 + P^158 + P^159 + 2*P^160 + 3*P^162 + 2*P^164 + 
    P^165 + 2*P^166 + P^167 + 2*P^169 + 2*P^171 + P^172 + 2*P^173 + P^174 + 2*P^176 + 2*P^178 + 2*P^180 + P^181 + P^182 + 
    P^183 + P^185 + 2*P^187 + P^189 + P^190 + P^192 + 2*P^194 + P^196 + P^197 + P^199 + P^201 + P^203 + P^206 + P^210 + P^213 + 
    P^217)/((1 - P^3)*(1 - P^85)*(1 - P^139))}};
Generating52=ToExpression[Import["./SUtreeData/Generating52.mml","MathML"]];
Generating53=ToExpression[Import["./SUtreeData/Generating53.mml","MathML"]];
Generating54={{1, (1 + P^19 + P^23 + P^27 + P^34 + P^38 + P^42 + P^46 + P^50 + P^53 + P^54 + P^57 + P^58 + P^61 + P^68 + P^69 + P^72 + P^73 + 
    P^76 + P^77 + P^80 + P^81 + P^85 + P^87 + P^89 + P^91 + P^95 + P^96 + P^100 + P^102 + P^104 + P^106 + P^108 + P^110 + 
    P^112 + P^114 + P^116 + P^120 + P^121 + P^125 + P^127 + P^129 + P^131 + P^135 + P^136 + P^139 + P^140 + P^143 + P^144 + 
    P^147 + P^148 + P^155 + P^158 + P^159 + P^162 + P^163 + P^166 + P^170 + P^174 + P^178 + P^182 + P^189 + P^193 + P^197 + 
    P^216)/((1 - P^3)*(1 - P^65)*(1 - P^151))}, 
 {1, (P^19 + P^23 + P^27 + P^34 + P^38 + P^42 + P^46 + P^50 + P^53 + P^54 + P^57 + P^58 + P^61 + P^65 + P^68 + P^69 + P^72 + 
    P^73 + P^76 + P^77 + P^80 + P^81 + P^85 + P^87 + P^89 + P^91 + P^95 + P^96 + P^100 + P^102 + P^104 + P^106 + P^108 + P^110 + 
    P^112 + P^114 + P^116 + P^120 + P^121 + P^125 + P^127 + P^129 + P^131 + P^135 + P^136 + P^139 + P^140 + P^143 + P^144 + 
    P^147 + P^148 + P^151 + P^155 + P^158 + P^159 + P^162 + P^163 + P^166 + P^170 + P^174 + P^178 + P^182 + P^189 + P^193 + 
    P^197)/((1 - P^3)*(1 - P^65)*(1 - P^151))}, 
 {1, (P^19 + P^23 + P^27 + P^34 + P^38 + P^42 + P^46 + P^50 + P^53 + P^54 + P^57 + P^58 + P^61 + P^65 + P^68 + P^69 + P^72 + 
    P^73 + P^76 + P^77 + P^80 + P^81 + P^85 + P^87 + P^89 + P^91 + P^95 + P^96 + P^100 + P^102 + P^104 + P^106 + P^108 + P^110 + 
    P^112 + P^114 + P^116 + P^120 + P^121 + P^125 + P^127 + P^129 + P^131 + P^135 + P^136 + P^139 + P^140 + P^143 + P^144 + 
    P^147 + P^148 + P^151 + P^155 + P^158 + P^159 + P^162 + P^163 + P^166 + P^170 + P^174 + P^178 + P^182 + P^189 + P^193 + 
    P^197)/((1 - P^3)*(1 - P^65)*(1 - P^151))}, 
 {3, (P^8 + P^10 + P^12 + P^20 + P^24 + P^25 + P^27 + P^28 + P^29 + P^31 + P^32 + P^33 + P^35 + P^37 + 2*P^39 + P^41 + P^42 + 
    2*P^43 + P^44 + P^46 + P^47 + P^48 + P^50 + P^51 + P^52 + 2*P^54 + P^55 + P^56 + 2*P^58 + 2*P^59 + P^60 + P^61 + 2*P^62 + 
    2*P^63 + P^64 + P^65 + 2*P^66 + P^67 + P^68 + P^69 + 2*P^70 + P^71 + P^72 + P^73 + 2*P^74 + P^76 + P^77 + 2*P^78 + P^79 + 
    P^80 + 2*P^81 + 2*P^82 + P^83 + P^84 + P^85 + 2*P^86 + P^87 + 2*P^88 + P^89 + P^90 + P^91 + P^92 + 2*P^93 + P^94 + 2*P^95 + 
    P^96 + 2*P^97 + 2*P^99 + P^100 + 3*P^101 + 2*P^103 + 2*P^105 + P^107 + P^108 + P^109 + 2*P^110 + P^111 + 2*P^112 + P^113 + 
    2*P^114 + P^115 + 2*P^116 + P^117 + 2*P^118 + 2*P^120 + P^121 + 3*P^122 + P^124 + P^125 + 2*P^126 + P^127 + P^128 + P^129 + 
    2*P^130 + P^131 + 2*P^132 + P^133 + P^134 + P^135 + P^136 + 2*P^137 + P^139 + P^140 + 2*P^141 + P^142 + P^143 + 2*P^144 + 
    2*P^145 + P^146 + P^147 + 2*P^148 + 2*P^149 + P^150 + P^151 + 2*P^152 + P^153 + P^154 + P^155 + 2*P^156 + P^157 + P^159 + 
    P^160 + P^161 + 2*P^163 + P^164 + P^165 + 2*P^167 + P^168 + P^169 + P^170 + 2*P^171 + P^172 + P^174 + P^175 + P^176 + 
    P^178 + P^179 + P^180 + P^182 + P^183 + P^184 + P^186 + P^188 + P^190 + P^194 + P^198 + P^199 + P^201 + P^203 + P^205)/
   ((1 - P^3)*(1 - P^65)*(1 - P^151))}, {3, (P^2 + 2*P^18 + P^21 + 2*P^22 + P^25 + 2*P^26 + P^29 + 2*P^33 + P^36 + 2*P^37 + 
    P^40 + 2*P^41 + P^44 + 2*P^45 + P^48 + 2*P^49 + 3*P^52 + 2*P^53 + P^55 + 3*P^56 + 2*P^57 + P^59 + 3*P^60 + P^63 + 2*P^64 + 
    2*P^67 + 2*P^68 + P^70 + 3*P^71 + 2*P^72 + P^74 + 3*P^75 + 2*P^76 + P^78 + 3*P^79 + 2*P^80 + P^82 + P^83 + 2*P^84 + 2*P^86 + 
    P^87 + 2*P^88 + P^89 + 2*P^90 + P^91 + P^93 + 2*P^94 + 2*P^95 + P^97 + P^98 + 2*P^99 + 2*P^101 + P^102 + 2*P^103 + P^104 + 
    2*P^105 + P^106 + 2*P^107 + P^108 + 2*P^109 + P^110 + 2*P^111 + P^112 + 2*P^113 + P^114 + 2*P^115 + P^116 + P^118 + 
    2*P^119 + 2*P^120 + P^122 + P^123 + 2*P^124 + 2*P^126 + P^127 + 2*P^128 + P^129 + 2*P^130 + P^131 + P^133 + 2*P^134 + 
    2*P^135 + P^137 + 3*P^138 + 2*P^139 + P^141 + 3*P^142 + 2*P^143 + P^145 + 3*P^146 + 2*P^147 + P^149 + 2*P^150 + P^153 + 
    2*P^154 + 3*P^157 + 2*P^158 + P^160 + 3*P^161 + 2*P^162 + P^164 + 3*P^165 + P^168 + 2*P^169 + P^172 + 2*P^173 + P^176 + 
    2*P^177 + P^180 + 2*P^181 + P^184 + 2*P^188 + P^191 + 2*P^192 + P^195 + 2*P^196 + P^199 + P^215)/
   ((1 - P^3)*(1 - P^65)*(1 - P^151))}, {3, (P^8 + P^12 + P^16 + P^18 + P^22 + P^23 + P^26 + P^27 + P^30 + 2*P^31 + 2*P^35 + 
    P^37 + 2*P^39 + P^41 + P^42 + P^43 + P^45 + 2*P^46 + P^47 + P^49 + 2*P^50 + P^52 + P^53 + 2*P^54 + P^56 + 2*P^57 + 2*P^58 + 
    P^60 + 2*P^61 + 2*P^62 + P^64 + 2*P^65 + 2*P^66 + P^68 + 2*P^69 + 2*P^70 + P^71 + P^72 + P^73 + P^74 + P^75 + 2*P^76 + 
    P^77 + P^78 + P^79 + 3*P^80 + P^81 + 3*P^84 + 2*P^85 + P^86 + 2*P^88 + 2*P^89 + P^90 + P^91 + P^92 + 2*P^93 + P^94 + 
    2*P^95 + 2*P^97 + P^98 + 3*P^99 + 2*P^101 + 3*P^103 + 2*P^105 + 2*P^107 + P^108 + 2*P^109 + P^110 + P^111 + P^112 + P^113 + 
    2*P^114 + P^115 + 2*P^116 + 2*P^118 + P^119 + 3*P^120 + P^122 + 3*P^124 + P^125 + P^126 + 3*P^128 + 2*P^129 + P^130 + 
    2*P^132 + 2*P^133 + P^134 + P^135 + P^136 + 2*P^137 + P^138 + 2*P^139 + P^140 + P^141 + P^142 + 2*P^143 + P^144 + P^146 + 
    3*P^147 + 2*P^148 + P^150 + 2*P^151 + 2*P^152 + P^154 + 2*P^155 + P^156 + P^157 + P^158 + 2*P^159 + P^161 + P^162 + 
    2*P^163 + P^165 + P^166 + 2*P^167 + P^169 + P^170 + 2*P^171 + P^173 + P^174 + P^175 + P^177 + 2*P^178 + P^181 + 2*P^182 + 
    2*P^186 + P^188 + P^190 + P^192 + P^196 + P^197 + P^201 + P^205 + P^209)/((1 - P^3)*(1 - P^65)*(1 - P^151))}, 
 {3, (P^8 + 2*P^15 + 2*P^19 + 2*P^23 + P^27 + P^30 + P^31 + 2*P^34 + P^35 + 2*P^38 + P^39 + 3*P^42 + 3*P^46 + 2*P^49 + 3*P^50 + 
    2*P^53 + 2*P^54 + 3*P^57 + P^58 + 3*P^61 + P^62 + P^64 + 3*P^65 + P^66 + 2*P^68 + 3*P^69 + P^70 + 2*P^72 + 2*P^73 + 3*P^76 + 
    3*P^77 + P^80 + 3*P^81 + 2*P^83 + P^84 + 2*P^85 + 2*P^87 + P^88 + P^89 + 3*P^91 + 2*P^92 + P^93 + 2*P^95 + 2*P^96 + P^97 + 
    P^98 + P^99 + 2*P^100 + P^101 + 2*P^102 + P^103 + 2*P^104 + 2*P^106 + 3*P^108 + 3*P^110 + 3*P^112 + P^114 + 2*P^116 + 
    2*P^117 + P^118 + P^119 + P^120 + 2*P^121 + 2*P^123 + P^124 + 3*P^125 + 2*P^127 + P^128 + 2*P^129 + 2*P^131 + 2*P^132 + 
    P^133 + 2*P^135 + 2*P^136 + P^137 + 3*P^139 + 2*P^140 + 3*P^143 + 3*P^144 + 2*P^147 + P^148 + P^150 + 3*P^151 + P^152 + 
    2*P^154 + 3*P^155 + 2*P^158 + 3*P^159 + 2*P^162 + 2*P^163 + 2*P^166 + P^167 + 3*P^170 + P^171 + 3*P^174 + 3*P^178 + P^181 + 
    P^182 + 2*P^185 + P^186 + 2*P^189 + 2*P^193 + P^197 + P^201 + P^205 + P^212)/((1 - P^3)*(1 - P^65)*(1 - P^151))}, 
 {3, (P^5 + P^12 + P^16 + P^20 + P^21 + P^24 + P^25 + P^28 + P^29 + P^31 + P^32 + P^35 + 2*P^36 + 2*P^39 + P^40 + 2*P^43 + 
    P^44 + P^46 + 2*P^47 + P^48 + P^50 + 2*P^51 + P^52 + P^54 + 2*P^55 + P^56 + 2*P^58 + 2*P^59 + P^60 + 2*P^62 + 2*P^63 + 
    P^65 + 2*P^66 + 2*P^67 + P^69 + 2*P^70 + P^71 + 2*P^73 + 3*P^74 + P^75 + P^77 + 3*P^78 + P^79 + P^80 + P^81 + 2*P^82 + 
    P^83 + P^84 + 2*P^85 + P^86 + P^87 + P^88 + 2*P^89 + P^90 + P^91 + 2*P^92 + 2*P^93 + P^94 + P^96 + 2*P^97 + 2*P^98 + P^99 + 
    P^100 + P^101 + P^102 + P^103 + P^104 + 2*P^105 + P^106 + 2*P^107 + P^108 + 2*P^109 + P^110 + P^111 + P^112 + P^113 + 
    2*P^114 + P^115 + P^116 + P^117 + 2*P^118 + 2*P^119 + P^120 + P^121 + 2*P^122 + P^123 + P^124 + P^125 + 2*P^126 + P^127 + 
    P^128 + 2*P^129 + P^130 + P^131 + P^132 + 2*P^133 + P^134 + 2*P^136 + 2*P^137 + P^138 + 2*P^140 + 3*P^141 + P^142 + P^144 + 
    2*P^145 + P^146 + P^147 + 2*P^148 + 2*P^149 + P^151 + 2*P^152 + 2*P^153 + P^155 + 2*P^156 + P^157 + P^159 + 3*P^160 + 
    P^161 + P^163 + 2*P^164 + P^165 + 2*P^167 + 2*P^168 + 2*P^171 + P^172 + 2*P^175 + P^176 + P^178 + P^179 + P^180 + P^182 + 
    P^183 + P^186 + P^187 + P^190 + P^191 + P^194 + P^195 + P^198 + P^199 + P^202 + P^209)/((1 - P^3)*(1 - P^65)*(1 - P^151))}, 
 {3, (P^5 + P^9 + P^13 + P^20 + 2*P^24 + 3*P^28 + 3*P^32 + 2*P^36 + 2*P^39 + P^40 + 3*P^43 + P^44 + 3*P^47 + 3*P^51 + P^54 + 
    3*P^55 + 2*P^58 + 3*P^59 + 3*P^62 + 3*P^63 + 3*P^66 + 2*P^67 + 2*P^70 + P^71 + 2*P^73 + 2*P^74 + P^75 + 3*P^77 + 2*P^78 + 
    3*P^81 + 3*P^82 + 2*P^85 + 3*P^86 + P^88 + P^89 + 3*P^90 + 2*P^92 + 3*P^94 + 3*P^96 + 2*P^98 + 3*P^100 + P^101 + P^102 + 
    P^104 + 2*P^105 + P^106 + 2*P^107 + 2*P^109 + 3*P^111 + 3*P^113 + 3*P^115 + 3*P^117 + 2*P^119 + 3*P^121 + P^122 + P^123 + 
    3*P^125 + 2*P^126 + 2*P^129 + 3*P^130 + P^132 + P^133 + 3*P^134 + 2*P^136 + P^137 + P^138 + 2*P^140 + 2*P^141 + 3*P^144 + 
    3*P^145 + 3*P^148 + 3*P^149 + 3*P^152 + 2*P^153 + 3*P^156 + P^157 + 3*P^160 + P^163 + 3*P^164 + 2*P^167 + 3*P^168 + 
    2*P^171 + P^172 + 3*P^175 + 3*P^179 + 3*P^183 + 2*P^187 + P^191 + P^194 + 2*P^198 + 2*P^202 + P^206)/
   ((1 - P^3)*(1 - P^65)*(1 - P^151))}, {3, (P^7 + P^14 + P^17 + P^18 + P^21 + P^22 + P^25 + P^26 + P^30 + P^32 + P^33 + P^34 + 
    P^36 + P^37 + P^38 + P^40 + 2*P^41 + P^44 + 2*P^45 + 2*P^48 + 2*P^49 + P^51 + 2*P^52 + 2*P^53 + P^55 + 2*P^56 + P^57 + 
    P^59 + 2*P^60 + P^61 + P^63 + 2*P^64 + P^65 + P^66 + 2*P^67 + 2*P^68 + P^69 + P^70 + 2*P^71 + P^72 + P^74 + 3*P^75 + 
    2*P^76 + P^78 + 2*P^79 + 2*P^80 + P^82 + 2*P^83 + 2*P^84 + P^85 + P^86 + P^87 + P^88 + P^89 + 2*P^90 + P^91 + P^92 + P^93 + 
    3*P^94 + P^95 + P^96 + 2*P^98 + P^99 + 2*P^100 + P^101 + 2*P^102 + P^103 + P^104 + P^105 + P^106 + 2*P^107 + P^108 + 
    2*P^109 + P^110 + 2*P^111 + P^112 + P^113 + P^114 + 2*P^115 + P^116 + P^117 + 2*P^119 + P^120 + P^121 + P^122 + 2*P^123 + 
    2*P^124 + P^125 + P^126 + 2*P^127 + 2*P^128 + P^129 + P^130 + P^131 + P^132 + P^133 + 2*P^134 + P^135 + P^136 + P^137 + 
    3*P^138 + P^139 + P^141 + 3*P^142 + 2*P^143 + P^145 + 2*P^146 + P^147 + P^149 + 2*P^150 + P^151 + P^152 + 2*P^153 + 
    2*P^154 + P^156 + 2*P^157 + 2*P^158 + P^160 + 2*P^161 + 2*P^162 + P^164 + P^165 + P^166 + P^168 + 2*P^169 + P^170 + P^172 + 
    2*P^173 + P^176 + 2*P^177 + P^180 + P^181 + P^183 + P^184 + P^185 + P^187 + P^188 + P^191 + P^192 + P^195 + P^196 + P^200 + 
    P^204 + P^211)/((1 - P^3)*(1 - P^65)*(1 - P^151))}, 
 {3, (P^8 + P^12 + P^16 + P^18 + P^20 + P^22 + P^26 + P^27 + 2*P^31 + P^33 + 2*P^35 + P^37 + 2*P^39 + P^41 + P^42 + P^43 + 
    P^45 + 2*P^46 + P^47 + P^49 + 2*P^50 + P^51 + P^52 + P^53 + 2*P^54 + P^56 + P^57 + 2*P^58 + P^60 + P^61 + 2*P^62 + P^64 + 
    2*P^65 + 2*P^66 + P^67 + P^68 + 2*P^69 + 2*P^70 + P^71 + P^72 + P^73 + P^74 + P^75 + 2*P^76 + P^77 + P^78 + P^79 + 3*P^80 + 
    P^81 + P^82 + 3*P^84 + P^85 + P^86 + 2*P^88 + 2*P^89 + P^90 + P^91 + P^92 + 2*P^93 + P^94 + 2*P^95 + 2*P^97 + 3*P^99 + 
    3*P^101 + 3*P^103 + 2*P^105 + 2*P^107 + P^108 + 2*P^109 + P^110 + P^111 + P^112 + P^113 + 2*P^114 + P^115 + 2*P^116 + 
    2*P^118 + 3*P^120 + 2*P^122 + 3*P^124 + P^125 + 2*P^126 + 3*P^128 + P^129 + P^130 + 2*P^132 + 2*P^133 + P^134 + P^135 + 
    P^136 + 2*P^137 + P^138 + 2*P^139 + P^140 + P^141 + P^142 + 2*P^143 + P^144 + P^146 + 2*P^147 + 2*P^148 + P^150 + 2*P^151 + 
    2*P^152 + P^153 + P^154 + 2*P^155 + P^156 + P^157 + P^158 + 2*P^159 + P^160 + P^161 + P^162 + 2*P^163 + P^165 + 2*P^167 + 
    P^169 + P^170 + 2*P^171 + P^173 + P^174 + P^175 + P^177 + 2*P^178 + 2*P^182 + P^184 + 2*P^186 + P^188 + P^190 + P^192 + 
    P^194 + P^196 + P^201 + P^205 + P^209)/((1 - P^3)*(1 - P^65)*(1 - P^151))}, 
 {3, (P^6 + P^13 + P^17 + P^19 + P^21 + P^23 + P^25 + P^27 + P^29 + P^32 + P^33 + P^34 + P^36 + P^37 + P^38 + 2*P^40 + P^42 + 
    2*P^44 + P^46 + P^47 + 2*P^48 + P^50 + P^51 + 2*P^52 + P^53 + P^54 + P^55 + P^56 + P^57 + P^58 + 2*P^59 + P^60 + P^61 + 
    2*P^63 + P^64 + P^65 + P^66 + 2*P^67 + 2*P^68 + P^69 + P^70 + P^71 + P^72 + P^73 + 2*P^74 + 2*P^75 + P^76 + P^77 + P^78 + 
    2*P^79 + P^80 + 2*P^81 + P^82 + 2*P^83 + 2*P^85 + P^86 + 2*P^87 + 2*P^89 + P^90 + 2*P^91 + 2*P^93 + P^94 + 2*P^95 + P^96 + 
    P^97 + P^98 + P^99 + 2*P^100 + P^101 + 2*P^102 + 2*P^104 + 3*P^106 + 3*P^108 + 3*P^110 + 2*P^112 + 2*P^114 + P^115 + 
    2*P^116 + P^117 + P^118 + P^119 + P^120 + 2*P^121 + P^122 + 2*P^123 + 2*P^125 + P^126 + 3*P^127 + 2*P^129 + P^130 + 
    2*P^131 + P^133 + P^134 + 2*P^135 + P^136 + 2*P^137 + P^138 + P^139 + P^140 + 2*P^141 + 2*P^142 + P^143 + P^144 + P^145 + 
    P^146 + P^147 + P^148 + 2*P^149 + P^150 + P^151 + P^152 + 2*P^153 + P^154 + P^155 + P^156 + 2*P^157 + P^158 + P^159 + 
    P^160 + 2*P^161 + P^162 + P^163 + P^164 + P^165 + P^166 + 2*P^168 + P^169 + P^170 + 2*P^172 + P^174 + 2*P^176 + P^178 + 
    P^179 + P^180 + P^183 + P^184 + P^185 + P^187 + P^189 + P^191 + P^193 + P^195 + P^197 + P^199 + P^203 + P^210)/
   ((1 - P^3)*(1 - P^65)*(1 - P^151))}, {3, (P^9 + P^13 + P^16 + P^17 + P^20 + 2*P^24 + 2*P^28 + 2*P^32 + P^35 + 2*P^36 + P^39 + 
    2*P^40 + 2*P^43 + P^44 + 3*P^47 + P^48 + P^50 + 3*P^51 + P^54 + 3*P^55 + 2*P^58 + 2*P^59 + 3*P^62 + 2*P^63 + 3*P^66 + 
    2*P^67 + P^69 + 3*P^70 + 2*P^71 + P^73 + 2*P^74 + P^75 + 2*P^77 + 2*P^78 + P^79 + 2*P^81 + 2*P^82 + P^84 + 2*P^85 + 3*P^86 + 
    P^88 + P^89 + 2*P^90 + 2*P^92 + P^93 + 2*P^94 + 3*P^96 + P^97 + 2*P^98 + 2*P^100 + P^101 + 2*P^102 + P^103 + 2*P^104 + 
    P^105 + P^106 + P^107 + P^108 + 2*P^109 + P^110 + 2*P^111 + 2*P^113 + 2*P^115 + 3*P^117 + P^118 + 2*P^119 + 2*P^121 + 
    P^122 + P^123 + P^124 + 2*P^125 + 2*P^126 + P^128 + 2*P^129 + 3*P^130 + P^132 + 2*P^133 + 2*P^134 + P^136 + 2*P^137 + 
    2*P^138 + 2*P^140 + 2*P^141 + P^142 + 2*P^144 + 2*P^145 + 3*P^148 + 2*P^149 + 3*P^152 + 2*P^153 + P^155 + 3*P^156 + P^157 + 
    P^159 + 3*P^160 + P^163 + 3*P^164 + P^167 + 2*P^168 + 2*P^171 + 2*P^172 + 2*P^175 + P^176 + 3*P^179 + 2*P^183 + P^186 + 
    2*P^187 + P^190 + P^191 + P^194 + P^198 + P^202 + P^206 + P^210)/((1 - P^3)*(1 - P^65)*(1 - P^151))}, 
 {3, (P^7 + P^11 + P^15 + P^19 + P^20 + P^24 + P^26 + P^28 + 2*P^30 + 2*P^34 + P^35 + 2*P^38 + P^39 + P^41 + P^42 + P^43 + 
    2*P^45 + P^46 + P^47 + 2*P^49 + P^50 + P^51 + 2*P^53 + P^54 + P^55 + 2*P^57 + P^58 + P^59 + P^60 + 2*P^61 + P^62 + 2*P^64 + 
    2*P^65 + P^66 + 2*P^68 + 3*P^69 + P^70 + P^72 + 2*P^73 + P^74 + P^75 + P^76 + 2*P^77 + P^78 + 2*P^79 + P^80 + P^81 + P^82 + 
    2*P^83 + 2*P^84 + P^86 + 2*P^87 + 3*P^88 + P^90 + P^91 + 3*P^92 + P^94 + 3*P^96 + P^97 + 2*P^98 + 2*P^100 + P^101 + 
    2*P^102 + P^103 + P^104 + P^105 + P^106 + 2*P^107 + P^108 + 2*P^109 + 2*P^111 + 3*P^113 + 2*P^115 + 3*P^117 + P^118 + 
    2*P^119 + 2*P^121 + P^122 + 2*P^123 + P^124 + P^125 + P^126 + 2*P^127 + 2*P^128 + P^130 + 2*P^131 + 3*P^132 + P^135 + 
    3*P^136 + P^137 + P^138 + P^139 + 2*P^140 + P^141 + P^142 + P^143 + P^144 + P^145 + 2*P^146 + 2*P^147 + P^148 + 2*P^150 + 
    2*P^151 + P^152 + 2*P^154 + 2*P^155 + P^156 + 2*P^158 + 2*P^159 + P^160 + 2*P^162 + P^163 + P^164 + 2*P^166 + P^167 + 
    P^169 + 2*P^170 + P^171 + P^173 + P^174 + P^175 + 2*P^177 + P^179 + 2*P^181 + 2*P^185 + P^186 + P^189 + P^190 + P^193 + 
    P^194 + P^198 + P^200 + P^204 + P^208)/((1 - P^3)*(1 - P^65)*(1 - P^151))}, 
 {3, (P^7 + P^11 + P^12 + P^19 + P^23 + P^26 + 2*P^27 + P^30 + 2*P^31 + P^34 + P^35 + 2*P^38 + P^39 + P^41 + 2*P^42 + P^43 + 
    P^45 + 2*P^46 + P^49 + 2*P^50 + 2*P^53 + 2*P^54 + 2*P^57 + 2*P^58 + P^60 + 3*P^61 + 2*P^62 + P^64 + 3*P^65 + P^66 + P^68 + 
    3*P^69 + P^70 + P^72 + 2*P^73 + P^74 + P^75 + 2*P^76 + P^77 + P^79 + 3*P^80 + 2*P^81 + P^83 + 2*P^84 + 2*P^85 + 2*P^87 + 
    2*P^88 + 2*P^89 + P^91 + P^92 + 2*P^93 + P^94 + 2*P^95 + P^96 + P^97 + P^98 + 2*P^99 + 2*P^100 + P^101 + P^102 + P^103 + 
    P^104 + P^105 + P^106 + P^107 + P^108 + P^109 + 2*P^110 + P^111 + 2*P^112 + P^113 + 2*P^114 + P^115 + 2*P^116 + P^117 + 
    P^118 + P^119 + 2*P^120 + 2*P^121 + P^122 + P^123 + 2*P^124 + P^125 + P^127 + 2*P^128 + 2*P^129 + 2*P^131 + 2*P^132 + 
    2*P^133 + P^135 + 2*P^136 + P^137 + P^138 + P^139 + P^140 + P^142 + 3*P^143 + 2*P^144 + P^146 + 3*P^147 + 2*P^148 + P^150 + 
    3*P^151 + P^152 + P^154 + 3*P^155 + P^156 + P^158 + 2*P^159 + 2*P^162 + 2*P^163 + 2*P^166 + 2*P^167 + P^169 + 2*P^170 + 
    P^171 + P^173 + 2*P^174 + P^177 + 2*P^178 + P^181 + 2*P^182 + P^185 + P^186 + P^189 + P^190 + P^193 + P^197 + P^200 + 
    P^201 + P^204 + P^205)/((1 - P^3)*(1 - P^65)*(1 - P^151))}, 
 {3, (P^11 + P^12 + P^15 + P^16 + P^19 + P^23 + P^26 + P^27 + P^30 + P^31 + 2*P^34 + P^35 + 2*P^38 + P^39 + 2*P^42 + P^43 + 
    P^45 + 2*P^46 + P^47 + 2*P^49 + 2*P^50 + 2*P^53 + 2*P^54 + 2*P^57 + P^58 + P^60 + 3*P^61 + P^62 + P^64 + 3*P^65 + P^66 + 
    2*P^68 + 3*P^69 + P^70 + 2*P^72 + 3*P^73 + P^74 + P^76 + P^77 + P^78 + P^79 + 2*P^80 + P^81 + 2*P^83 + 2*P^84 + 2*P^85 + 
    2*P^87 + 2*P^88 + P^89 + P^91 + 2*P^92 + P^93 + P^94 + 2*P^95 + 2*P^96 + P^97 + P^98 + P^99 + 2*P^100 + P^101 + 2*P^102 + 
    P^103 + 2*P^104 + P^105 + 2*P^106 + P^107 + P^108 + P^109 + P^110 + P^111 + P^112 + P^113 + P^114 + P^115 + 2*P^116 + 
    2*P^117 + P^118 + P^119 + P^120 + 2*P^121 + P^122 + 2*P^123 + P^124 + P^125 + 2*P^127 + 2*P^128 + 2*P^129 + 2*P^131 + 
    2*P^132 + P^133 + 2*P^135 + 3*P^136 + P^137 + P^139 + 2*P^140 + P^141 + P^142 + 2*P^143 + P^144 + P^146 + 3*P^147 + P^148 + 
    P^150 + 3*P^151 + P^152 + 2*P^154 + 3*P^155 + P^156 + 2*P^158 + 2*P^159 + 2*P^162 + 2*P^163 + 2*P^166 + P^167 + 2*P^170 + 
    P^171 + P^173 + 2*P^174 + P^175 + P^177 + 2*P^178 + P^181 + P^182 + 2*P^185 + P^186 + 2*P^189 + P^190 + P^193 + P^197 + 
    P^204 + P^205 + P^209)/((1 - P^3)*(1 - P^65)*(1 - P^151))}, 
 {3, (P^7 + P^9 + P^11 + P^22 + P^24 + 2*P^26 + P^28 + 2*P^30 + P^32 + 2*P^34 + P^36 + P^38 + P^40 + 2*P^41 + P^42 + P^43 + 
    2*P^45 + P^47 + 2*P^49 + P^51 + 2*P^53 + P^55 + P^56 + 2*P^57 + P^58 + P^59 + 2*P^60 + 2*P^61 + P^62 + P^63 + 2*P^64 + 
    2*P^65 + P^66 + P^67 + 2*P^68 + P^69 + P^70 + P^71 + P^72 + P^73 + 2*P^75 + P^76 + P^77 + P^78 + 2*P^79 + 2*P^80 + P^81 + 
    P^82 + 2*P^83 + 2*P^84 + P^85 + P^86 + P^87 + 2*P^88 + 2*P^90 + 3*P^92 + 3*P^94 + 3*P^96 + 3*P^98 + 2*P^100 + 2*P^102 + 
    P^103 + P^104 + P^105 + 2*P^107 + 3*P^109 + 3*P^111 + 3*P^113 + 3*P^115 + 3*P^117 + 3*P^119 + 2*P^121 + 2*P^123 + P^124 + 
    P^125 + P^126 + 2*P^127 + 2*P^128 + P^129 + P^130 + P^131 + 2*P^132 + 2*P^134 + 2*P^136 + 2*P^138 + P^139 + P^140 + P^141 + 
    2*P^142 + 2*P^143 + P^144 + P^145 + 2*P^146 + 2*P^147 + P^148 + P^149 + 2*P^150 + 2*P^151 + P^152 + P^153 + 2*P^154 + 
    P^155 + P^156 + 2*P^158 + P^160 + 2*P^162 + P^164 + P^165 + 2*P^166 + P^167 + P^168 + 2*P^169 + P^170 + P^171 + 2*P^173 + 
    P^175 + 2*P^177 + P^179 + 2*P^181 + P^183 + 2*P^185 + P^187 + P^189 + P^196 + P^198 + 2*P^200 + P^202 + P^204)/
   ((1 - P^3)*(1 - P^65)*(1 - P^151))}, {3, (P^4 + P^11 + P^15 + P^19 + 2*P^23 + 2*P^27 + P^30 + 2*P^31 + P^34 + P^35 + 3*P^38 + 
    3*P^42 + P^45 + 3*P^46 + P^49 + 2*P^50 + 2*P^53 + 2*P^54 + 3*P^57 + 2*P^58 + 3*P^61 + 2*P^62 + P^64 + 3*P^65 + P^66 + P^68 + 
    2*P^69 + 3*P^72 + 3*P^73 + 2*P^76 + 3*P^77 + P^79 + 2*P^80 + 2*P^81 + P^83 + 2*P^84 + 2*P^85 + 2*P^87 + P^88 + 2*P^89 + 
    3*P^91 + P^92 + 2*P^93 + 2*P^95 + P^96 + P^97 + P^98 + 2*P^99 + 2*P^100 + P^102 + 3*P^104 + 3*P^106 + 3*P^108 + 2*P^110 + 
    2*P^112 + P^113 + 2*P^114 + P^115 + 2*P^116 + P^117 + P^118 + P^119 + 2*P^120 + 2*P^121 + P^123 + 2*P^124 + 3*P^125 + 
    P^127 + P^128 + 2*P^129 + 2*P^131 + P^132 + 2*P^133 + 3*P^135 + P^136 + 3*P^139 + 3*P^140 + 2*P^143 + 2*P^144 + P^146 + 
    3*P^147 + 2*P^148 + P^150 + 3*P^151 + P^152 + P^154 + 3*P^155 + P^158 + 3*P^159 + 2*P^162 + 2*P^163 + 3*P^166 + 2*P^167 + 
    3*P^170 + 3*P^174 + P^177 + 2*P^178 + P^181 + 2*P^182 + P^185 + P^186 + P^189 + 2*P^193 + 2*P^197 + 2*P^201 + P^208)/
   ((1 - P^3)*(1 - P^65)*(1 - P^151))}, {3, (P^5 + P^15 + P^18 + P^19 + P^22 + P^23 + P^24 + P^26 + P^28 + P^32 + P^33 + P^34 + 
    P^36 + P^37 + P^38 + P^39 + P^41 + P^42 + P^43 + P^45 + P^46 + P^47 + 2*P^49 + P^50 + P^51 + P^52 + 2*P^53 + P^54 + P^55 + 
    P^56 + 2*P^57 + P^58 + P^59 + P^60 + P^61 + P^62 + P^63 + P^64 + P^65 + P^66 + 2*P^67 + 2*P^68 + P^69 + P^71 + 2*P^72 + 
    2*P^73 + P^74 + P^75 + 2*P^76 + 2*P^77 + P^78 + P^79 + P^80 + 2*P^81 + P^82 + P^83 + P^84 + 2*P^85 + 2*P^86 + P^87 + P^88 + 
    2*P^90 + P^91 + 2*P^92 + 2*P^94 + 2*P^95 + 2*P^96 + P^98 + P^99 + 2*P^100 + P^101 + P^102 + P^103 + P^104 + 2*P^105 + 
    P^106 + 2*P^107 + P^108 + 2*P^109 + P^110 + 2*P^111 + P^112 + 2*P^113 + 2*P^115 + P^116 + 2*P^117 + P^119 + P^120 + 
    2*P^121 + P^122 + P^123 + P^124 + 2*P^125 + 2*P^126 + P^127 + P^128 + P^129 + 2*P^130 + P^131 + P^132 + 2*P^134 + 2*P^135 + 
    2*P^136 + P^138 + 2*P^139 + 2*P^140 + P^141 + P^142 + 2*P^143 + 2*P^144 + P^145 + P^146 + P^147 + P^148 + P^149 + P^150 + 
    P^151 + P^152 + P^153 + 2*P^154 + P^155 + P^156 + P^157 + 2*P^158 + P^159 + P^160 + P^161 + 2*P^162 + P^163 + P^164 + 
    P^165 + P^166 + P^167 + P^168 + P^169 + P^170 + P^171 + P^173 + P^174 + P^175 + P^177 + P^178 + P^179 + P^181 + P^183 + 
    P^184 + P^185 + P^188 + P^189 + P^192 + P^193 + P^194 + P^196 + P^198 + P^202 + P^212)/((1 - P^3)*(1 - P^65)*(1 - P^151))}, 
 {3, (P^5 + P^12 + P^16 + P^20 + P^21 + P^24 + P^25 + P^28 + P^29 + P^31 + P^32 + P^33 + P^35 + P^36 + 2*P^39 + P^40 + 2*P^43 + 
    P^44 + P^46 + 2*P^47 + P^48 + P^50 + P^51 + P^52 + 2*P^54 + 2*P^55 + P^56 + 2*P^58 + 2*P^59 + P^60 + 2*P^62 + 2*P^63 + 
    P^64 + P^65 + 2*P^66 + P^67 + P^69 + 2*P^70 + P^71 + 2*P^73 + 3*P^74 + P^75 + P^77 + 3*P^78 + P^79 + P^80 + P^81 + 2*P^82 + 
    P^83 + P^84 + P^85 + P^86 + P^87 + 2*P^88 + 2*P^89 + P^90 + P^91 + 2*P^92 + 2*P^93 + P^94 + P^95 + P^96 + 2*P^97 + P^99 + 
    P^100 + 2*P^101 + P^102 + P^103 + P^104 + 2*P^105 + P^106 + 2*P^107 + P^108 + 2*P^109 + P^110 + P^111 + P^112 + P^113 + 
    2*P^114 + P^115 + 2*P^116 + P^117 + 2*P^118 + P^120 + P^121 + 3*P^122 + P^123 + P^124 + P^125 + 2*P^126 + P^127 + P^128 + 
    P^129 + P^130 + P^131 + 2*P^132 + 2*P^133 + P^134 + 2*P^136 + 2*P^137 + P^138 + 2*P^140 + 3*P^141 + P^142 + P^144 + 
    2*P^145 + P^146 + P^147 + 2*P^148 + 2*P^149 + P^150 + P^151 + 2*P^152 + P^153 + P^155 + 2*P^156 + P^157 + P^159 + 2*P^160 + 
    P^161 + 2*P^163 + 2*P^164 + P^165 + 2*P^167 + 2*P^168 + 2*P^171 + P^172 + 2*P^175 + P^176 + P^178 + P^179 + P^180 + P^182 + 
    P^183 + P^184 + P^186 + P^190 + P^191 + P^194 + P^195 + P^198 + P^199 + P^202 + P^209)/((1 - P^3)*(1 - P^65)*(1 - P^151))}, 
 {3, (P^6 + P^13 + P^17 + P^19 + P^21 + P^23 + P^25 + P^27 + P^29 + P^31 + P^32 + P^33 + P^36 + P^37 + P^38 + 2*P^40 + P^42 + 
    2*P^44 + P^46 + P^47 + 2*P^48 + P^50 + P^51 + P^52 + P^53 + P^54 + 2*P^55 + P^56 + P^57 + P^58 + 2*P^59 + P^60 + P^61 + 
    P^62 + 2*P^63 + P^64 + P^65 + P^66 + 2*P^67 + P^68 + P^69 + P^70 + P^71 + P^72 + P^73 + 2*P^74 + 2*P^75 + P^76 + P^77 + 
    P^78 + 2*P^79 + P^80 + 2*P^81 + P^82 + P^83 + 2*P^85 + P^86 + 2*P^87 + 3*P^89 + P^90 + 2*P^91 + 2*P^93 + P^94 + 2*P^95 + 
    P^96 + P^97 + P^98 + P^99 + 2*P^100 + P^101 + 2*P^102 + 2*P^104 + 3*P^106 + 3*P^108 + 3*P^110 + 2*P^112 + 2*P^114 + P^115 + 
    2*P^116 + P^117 + P^118 + P^119 + P^120 + 2*P^121 + P^122 + 2*P^123 + 2*P^125 + P^126 + 2*P^127 + 2*P^129 + P^130 + 
    2*P^131 + 2*P^133 + P^134 + 2*P^135 + P^136 + 2*P^137 + P^138 + P^139 + P^140 + 2*P^141 + 2*P^142 + P^143 + P^144 + P^145 + 
    P^146 + P^147 + 2*P^148 + 2*P^149 + P^150 + P^151 + P^152 + 2*P^153 + P^155 + P^156 + 2*P^157 + P^158 + P^159 + P^160 + 
    P^161 + P^162 + P^163 + 2*P^164 + P^165 + P^166 + 2*P^168 + P^169 + P^170 + 2*P^172 + P^174 + 2*P^176 + P^178 + P^179 + 
    P^180 + P^182 + P^183 + P^184 + P^187 + P^189 + P^191 + P^193 + P^195 + P^197 + P^199 + P^203 + P^210)/
   ((1 - P^3)*(1 - P^65)*(1 - P^151))}, {3, (P^10 + P^14 + P^15 + P^17 + P^19 + P^21 + P^25 + P^29 + P^30 + P^32 + P^33 + P^34 + 
    P^36 + P^37 + P^38 + P^40 + P^41 + P^42 + 2*P^44 + P^45 + P^46 + 2*P^48 + P^49 + P^50 + P^51 + 2*P^52 + P^53 + P^55 + P^56 + 
    P^57 + 2*P^59 + P^60 + P^61 + 2*P^63 + 2*P^64 + P^65 + P^66 + 2*P^67 + 2*P^68 + P^69 + P^70 + 2*P^71 + 2*P^72 + P^73 + 
    P^74 + P^75 + P^76 + P^77 + 2*P^78 + 2*P^79 + P^81 + P^82 + 3*P^83 + P^85 + P^86 + 2*P^87 + P^88 + P^89 + P^90 + 2*P^91 + 
    P^92 + 2*P^93 + P^94 + P^95 + P^96 + P^97 + 2*P^98 + P^99 + 2*P^100 + P^101 + 2*P^102 + P^103 + 2*P^104 + P^105 + 2*P^106 + 
    2*P^108 + 2*P^110 + 2*P^112 + P^113 + 2*P^114 + P^115 + P^116 + P^117 + P^118 + 2*P^119 + P^120 + 2*P^121 + P^122 + 
    2*P^123 + 2*P^125 + P^126 + 3*P^127 + P^129 + P^130 + 2*P^131 + P^132 + P^133 + 2*P^134 + 2*P^135 + P^136 + P^137 + P^138 + 
    2*P^139 + P^140 + 2*P^141 + P^142 + 2*P^145 + 2*P^146 + P^147 + 2*P^149 + 2*P^150 + P^151 + P^152 + 2*P^153 + 2*P^154 + 
    P^155 + P^156 + 2*P^157 + P^158 + P^159 + P^160 + 2*P^161 + P^162 + P^164 + P^165 + P^166 + P^168 + P^169 + P^170 + 
    2*P^172 + P^173 + P^174 + 2*P^176 + P^177 + P^180 + P^181 + P^183 + P^184 + P^185 + P^187 + P^188 + P^189 + P^191 + P^193 + 
    P^195 + P^203 + P^207 + P^208)/((1 - P^3)*(1 - P^65)*(1 - P^151))}, 
 {3, (P^7 + P^14 + P^17 + P^18 + P^21 + P^22 + P^25 + P^26 + P^29 + P^30 + P^33 + P^34 + P^36 + P^37 + P^38 + P^40 + 2*P^41 + 
    P^44 + 2*P^45 + 2*P^48 + 2*P^49 + P^51 + 2*P^52 + P^53 + P^55 + 3*P^56 + P^57 + P^59 + 2*P^60 + P^61 + 2*P^63 + 2*P^64 + 
    P^65 + 2*P^67 + 2*P^68 + P^69 + P^70 + 2*P^71 + P^72 + P^74 + 3*P^75 + 2*P^76 + P^78 + 2*P^79 + 2*P^80 + P^82 + 2*P^83 + 
    P^84 + P^85 + P^86 + 2*P^87 + P^88 + P^89 + 2*P^90 + P^91 + P^92 + P^93 + 2*P^94 + P^95 + P^96 + 2*P^97 + 2*P^98 + P^99 + 
    P^100 + P^101 + 2*P^102 + P^103 + P^104 + P^105 + P^106 + 2*P^107 + P^108 + 2*P^109 + P^110 + 2*P^111 + P^112 + P^113 + 
    P^114 + P^115 + P^116 + P^117 + 2*P^118 + 2*P^119 + P^120 + P^122 + 2*P^123 + 2*P^124 + P^125 + P^126 + 2*P^127 + P^128 + 
    P^129 + P^130 + 2*P^131 + P^132 + P^133 + 2*P^134 + P^135 + P^136 + P^137 + 3*P^138 + P^139 + P^141 + 3*P^142 + 2*P^143 + 
    P^145 + 2*P^146 + P^147 + 2*P^149 + 2*P^150 + P^151 + 2*P^153 + 2*P^154 + P^156 + 2*P^157 + 2*P^158 + P^160 + 2*P^161 + 
    P^162 + P^164 + 2*P^165 + P^166 + P^168 + 2*P^169 + P^170 + P^172 + 2*P^173 + P^176 + 2*P^177 + 2*P^180 + P^181 + P^184 + 
    P^185 + P^187 + P^188 + P^191 + P^192 + P^195 + P^196 + P^200 + P^204 + P^211)/((1 - P^3)*(1 - P^65)*(1 - P^151))}, 
 {3, (P^6 + P^10 + P^11 + P^21 + 2*P^25 + P^26 + 2*P^29 + P^30 + 2*P^33 + P^34 + P^37 + P^38 + 2*P^40 + P^41 + P^42 + 2*P^44 + 
    P^45 + 2*P^48 + P^49 + 2*P^52 + P^53 + P^55 + 2*P^56 + P^57 + 2*P^59 + 3*P^60 + P^61 + 2*P^63 + 3*P^64 + P^65 + 2*P^67 + 
    2*P^68 + P^69 + P^71 + P^72 + P^73 + 2*P^74 + 2*P^75 + 2*P^78 + 3*P^79 + P^80 + 2*P^82 + 3*P^83 + P^84 + P^86 + 3*P^87 + 
    P^88 + P^89 + 2*P^91 + P^92 + 2*P^93 + P^94 + 2*P^95 + P^96 + 2*P^97 + P^98 + P^99 + P^100 + 2*P^101 + 2*P^102 + P^104 + 
    2*P^106 + 2*P^108 + P^109 + 2*P^110 + P^111 + 2*P^112 + P^113 + 2*P^114 + P^115 + 2*P^116 + P^117 + 2*P^118 + P^119 + 
    P^120 + P^121 + 2*P^122 + 2*P^123 + 2*P^126 + 3*P^127 + P^128 + P^130 + 3*P^131 + P^132 + P^133 + 2*P^135 + P^136 + 
    2*P^137 + P^138 + 2*P^141 + 3*P^142 + P^143 + 2*P^145 + 3*P^146 + P^147 + 2*P^149 + 3*P^150 + P^151 + 2*P^153 + 2*P^154 + 
    P^155 + 2*P^157 + P^158 + 2*P^161 + P^162 + P^164 + 2*P^165 + P^166 + 2*P^168 + 2*P^169 + P^170 + 2*P^172 + P^173 + 
    2*P^176 + P^177 + 2*P^180 + P^181 + 2*P^184 + P^185 + P^188 + P^189 + P^195 + 2*P^199 + P^200 + P^203 + P^204)/
   ((1 - P^3)*(1 - P^65)*(1 - P^151))}, {3, (P + P^17 + 2*P^20 + P^21 + 2*P^24 + P^25 + 2*P^28 + P^32 + 2*P^35 + P^36 + 2*P^39 + 
    P^40 + 2*P^43 + P^44 + 2*P^47 + P^48 + 3*P^51 + P^52 + 2*P^54 + 3*P^55 + P^56 + 2*P^58 + 3*P^59 + 2*P^62 + P^63 + 2*P^66 + 
    P^67 + 2*P^69 + 3*P^70 + P^71 + 2*P^73 + 3*P^74 + P^75 + 2*P^77 + 3*P^78 + P^79 + 2*P^81 + 2*P^82 + P^83 + P^85 + 2*P^86 + 
    P^87 + 2*P^88 + P^89 + 2*P^90 + 2*P^92 + P^93 + P^94 + 2*P^96 + 2*P^97 + P^98 + P^100 + 2*P^101 + P^102 + 2*P^103 + P^104 + 
    2*P^105 + P^106 + 2*P^107 + P^108 + 2*P^109 + P^110 + 2*P^111 + P^112 + 2*P^113 + P^114 + 2*P^115 + 2*P^117 + P^118 + 
    P^119 + 2*P^121 + 2*P^122 + P^123 + P^125 + 2*P^126 + P^127 + 2*P^128 + P^129 + 2*P^130 + 2*P^132 + P^133 + P^134 + 
    2*P^136 + 3*P^137 + P^138 + 2*P^140 + 3*P^141 + P^142 + 2*P^144 + 3*P^145 + P^146 + 2*P^148 + 2*P^149 + 2*P^152 + P^153 + 
    3*P^156 + P^157 + 2*P^159 + 3*P^160 + P^161 + 2*P^163 + 3*P^164 + 2*P^167 + P^168 + 2*P^171 + P^172 + 2*P^175 + P^176 + 
    2*P^179 + P^180 + 2*P^183 + P^187 + 2*P^190 + P^191 + 2*P^194 + P^195 + 2*P^198 + P^214)/
   ((1 - P^3)*(1 - P^65)*(1 - P^151))}, {3, (P^5 + P^15 + P^18 + P^19 + P^22 + P^23 + P^24 + P^26 + P^28 + P^30 + P^32 + P^34 + 
    P^36 + P^37 + P^38 + P^39 + P^41 + P^42 + P^43 + P^45 + P^46 + P^47 + 2*P^49 + P^50 + P^51 + P^52 + 2*P^53 + P^54 + P^55 + 
    P^56 + 2*P^57 + P^58 + P^59 + P^60 + P^61 + P^62 + P^63 + 2*P^64 + P^65 + P^66 + P^67 + 2*P^68 + P^69 + P^71 + 2*P^72 + 
    2*P^73 + P^74 + P^75 + 2*P^76 + 2*P^77 + P^78 + P^79 + P^80 + 2*P^81 + P^82 + P^83 + P^84 + P^85 + 2*P^86 + P^87 + 2*P^88 + 
    2*P^90 + P^91 + 2*P^92 + 2*P^94 + P^95 + 2*P^96 + 2*P^98 + P^99 + 2*P^100 + P^101 + P^102 + P^103 + P^104 + 2*P^105 + 
    P^106 + 2*P^107 + P^108 + 2*P^109 + P^110 + 2*P^111 + P^112 + 2*P^113 + 2*P^115 + 2*P^117 + 2*P^119 + P^120 + 2*P^121 + 
    P^122 + P^123 + P^124 + 2*P^125 + 2*P^126 + P^127 + P^128 + 2*P^130 + P^131 + 2*P^132 + 2*P^134 + 2*P^135 + 2*P^136 + 
    P^138 + 2*P^139 + 2*P^140 + P^141 + P^142 + 2*P^143 + 2*P^144 + P^145 + P^146 + P^147 + P^148 + P^149 + 2*P^150 + P^151 + 
    P^152 + 2*P^154 + P^155 + P^156 + P^157 + 2*P^158 + P^159 + P^160 + P^161 + 2*P^162 + P^163 + P^164 + P^165 + P^166 + 
    P^167 + P^168 + P^169 + P^170 + P^171 + P^173 + P^174 + P^175 + P^177 + P^178 + P^179 + 2*P^181 + P^183 + P^185 + P^188 + 
    P^189 + P^192 + P^193 + P^194 + P^196 + P^198 + P^202 + P^212)/((1 - P^3)*(1 - P^65)*(1 - P^151))}, 
 {3, (P^3 + P^13 + P^17 + P^21 + 2*P^22 + 2*P^26 + 2*P^30 + P^32 + P^34 + P^36 + 2*P^37 + P^40 + 2*P^41 + P^44 + 2*P^45 + P^47 + 
    P^48 + 2*P^49 + P^51 + P^52 + 2*P^53 + P^55 + 2*P^56 + 2*P^57 + P^59 + 2*P^60 + 2*P^61 + P^63 + 2*P^64 + P^65 + P^66 + 
    P^67 + P^68 + P^70 + 3*P^71 + 2*P^72 + P^74 + 3*P^75 + 2*P^76 + 3*P^79 + 2*P^80 + P^81 + 2*P^83 + 2*P^84 + P^85 + P^86 + 
    2*P^88 + P^89 + 3*P^90 + 2*P^92 + P^93 + 3*P^94 + P^96 + 3*P^98 + P^99 + P^100 + P^102 + 2*P^103 + P^104 + 2*P^105 + P^106 + 
    2*P^107 + P^108 + 2*P^109 + P^110 + 2*P^111 + 2*P^113 + 3*P^115 + 2*P^117 + 3*P^119 + P^120 + P^121 + 3*P^123 + 2*P^124 + 
    P^125 + P^127 + 2*P^128 + P^129 + 2*P^130 + 2*P^132 + P^133 + 3*P^134 + P^137 + 3*P^138 + 2*P^139 + P^141 + 3*P^142 + 
    2*P^143 + 2*P^146 + 2*P^147 + P^148 + P^149 + 2*P^150 + P^151 + P^152 + P^153 + 2*P^154 + P^156 + P^157 + 2*P^158 + P^160 + 
    2*P^161 + 2*P^162 + P^164 + 2*P^165 + 2*P^166 + P^168 + 2*P^169 + P^172 + 2*P^173 + P^176 + 2*P^177 + P^179 + 2*P^181 + 
    P^183 + P^185 + P^187 + P^191 + 2*P^192 + 2*P^196 + 2*P^200 + P^210)/((1 - P^3)*(1 - P^65)*(1 - P^151))}, 
 {3, (P^4 + P^14 + P^18 + P^20 + P^22 + P^23 + P^24 + P^27 + P^28 + P^31 + P^33 + 2*P^35 + P^37 + P^38 + P^39 + P^41 + P^42 + 
    P^43 + P^45 + P^46 + P^47 + P^48 + P^49 + P^50 + P^51 + P^52 + P^53 + 2*P^54 + P^55 + P^56 + P^57 + 2*P^58 + P^59 + P^60 + 
    P^61 + 2*P^62 + P^64 + P^65 + 2*P^66 + P^67 + P^68 + P^69 + P^70 + P^71 + 2*P^72 + 2*P^73 + P^74 + P^75 + 2*P^76 + 2*P^77 + 
    P^78 + 2*P^80 + 2*P^81 + 2*P^82 + 2*P^84 + P^85 + 2*P^86 + P^88 + P^89 + 2*P^90 + 2*P^91 + P^92 + P^93 + P^94 + 2*P^95 + 
    P^96 + 2*P^97 + 2*P^99 + 2*P^101 + 2*P^103 + P^104 + 2*P^105 + P^106 + 2*P^107 + P^108 + 2*P^109 + P^110 + 2*P^111 + P^112 + 
    P^113 + P^114 + P^115 + 2*P^116 + P^117 + 2*P^118 + 2*P^120 + P^121 + 2*P^122 + 2*P^124 + P^125 + 2*P^126 + 2*P^128 + 
    P^129 + 2*P^130 + P^131 + P^132 + P^133 + P^134 + 2*P^135 + P^136 + P^137 + P^138 + 2*P^139 + 2*P^140 + P^141 + P^142 + 
    2*P^143 + 2*P^144 + P^145 + P^147 + 2*P^148 + P^149 + P^150 + P^151 + 2*P^152 + P^153 + P^154 + P^155 + P^156 + P^157 + 
    P^158 + 2*P^159 + P^160 + P^161 + P^162 + 2*P^163 + P^164 + P^165 + P^166 + 2*P^167 + P^169 + P^170 + P^171 + P^173 + 
    P^174 + P^175 + P^177 + P^178 + P^179 + P^180 + P^182 + P^184 + P^186 + P^188 + P^190 + P^192 + P^193 + P^194 + P^197 + 
    P^198 + P^201 + P^211)/((1 - P^3)*(1 - P^65)*(1 - P^151))}, 
 {3, (P^6 + P^10 + P^14 + P^21 + P^22 + P^25 + P^26 + 2*P^29 + P^30 + 2*P^33 + P^34 + 2*P^37 + P^40 + 2*P^41 + 2*P^44 + 2*P^45 + 
    2*P^48 + P^49 + 2*P^52 + P^53 + P^55 + 3*P^56 + P^57 + P^59 + 3*P^60 + P^61 + 2*P^63 + 3*P^64 + P^65 + 2*P^67 + 2*P^68 + 
    2*P^71 + 2*P^72 + P^74 + 2*P^75 + 2*P^76 + 2*P^78 + 2*P^79 + P^80 + 2*P^82 + 3*P^83 + P^84 + P^86 + 2*P^87 + P^88 + P^89 + 
    2*P^90 + 2*P^91 + P^92 + P^93 + P^94 + 2*P^95 + P^96 + 2*P^97 + P^98 + P^99 + 2*P^101 + P^102 + 2*P^103 + 2*P^105 + P^106 + 
    2*P^107 + P^108 + P^109 + P^110 + P^111 + 2*P^112 + P^113 + 2*P^114 + P^115 + 2*P^116 + P^117 + 2*P^118 + P^119 + P^120 + 
    2*P^122 + 2*P^123 + 2*P^124 + 2*P^126 + 2*P^127 + P^128 + P^130 + 2*P^131 + P^132 + P^133 + 2*P^134 + 2*P^135 + P^137 + 
    2*P^138 + 2*P^139 + P^141 + 2*P^142 + P^143 + 2*P^145 + 3*P^146 + P^147 + 2*P^149 + 3*P^150 + P^151 + 2*P^153 + 2*P^154 + 
    2*P^157 + 2*P^158 + 2*P^161 + P^162 + P^164 + 3*P^165 + P^166 + P^168 + 3*P^169 + P^172 + 2*P^173 + 2*P^176 + P^177 + 
    2*P^180 + P^181 + 2*P^184 + P^185 + P^188 + P^192 + P^195 + P^196 + P^199 + P^200 + P^203 + P^207)/
   ((1 - P^3)*(1 - P^65)*(1 - P^151))}, {3, (P^12 + P^13 + P^16 + 2*P^17 + P^21 + P^27 + P^28 + P^31 + 2*P^32 + P^35 + 2*P^36 + 
    P^39 + 2*P^40 + P^43 + 2*P^44 + P^46 + 2*P^47 + 2*P^48 + P^50 + 2*P^51 + P^52 + P^54 + 2*P^55 + P^58 + 2*P^59 + P^61 + 
    2*P^62 + 2*P^63 + P^65 + 3*P^66 + 2*P^67 + P^69 + 3*P^70 + 2*P^71 + P^73 + 3*P^74 + 2*P^75 + P^78 + 2*P^79 + P^80 + 2*P^81 + 
    P^83 + P^84 + 3*P^85 + P^86 + P^88 + 3*P^89 + 2*P^90 + 2*P^93 + 2*P^94 + P^95 + P^96 + P^97 + 2*P^98 + P^99 + 2*P^100 + 
    P^101 + 2*P^102 + P^103 + 2*P^104 + P^105 + 2*P^106 + P^107 + 2*P^108 + 2*P^110 + P^112 + 2*P^114 + 2*P^115 + P^116 + 
    P^117 + P^118 + 2*P^119 + P^120 + 2*P^121 + P^122 + 2*P^123 + P^124 + 2*P^125 + P^127 + P^128 + 3*P^129 + P^130 + P^132 + 
    3*P^133 + 2*P^134 + P^136 + 3*P^137 + 2*P^138 + 2*P^141 + 2*P^142 + P^143 + P^144 + P^145 + P^147 + 2*P^148 + 2*P^149 + 
    P^151 + 3*P^152 + 2*P^153 + P^155 + 3*P^156 + 2*P^157 + P^159 + 2*P^160 + P^161 + P^163 + 2*P^164 + P^167 + 2*P^168 + 
    P^171 + 2*P^172 + P^174 + P^175 + 2*P^176 + P^178 + P^179 + P^182 + 2*P^183 + P^186 + 2*P^187 + P^190 + 2*P^191 + P^195 + 
    P^205 + P^206 + P^210)/((1 - P^3)*(1 - P^65)*(1 - P^151))}, 
 {3, (P^2 + P^15 + P^19 + 2*P^21 + P^23 + 2*P^25 + 2*P^29 + P^33 + P^34 + 2*P^36 + P^38 + 2*P^40 + P^42 + 2*P^44 + P^46 + 
    2*P^48 + P^49 + P^50 + 2*P^52 + P^53 + P^54 + 2*P^55 + 2*P^56 + P^57 + 2*P^59 + 2*P^60 + P^61 + 2*P^63 + P^64 + P^65 + 
    P^67 + P^68 + P^69 + 2*P^70 + 2*P^71 + P^72 + P^73 + 2*P^74 + 2*P^75 + P^76 + P^77 + 2*P^78 + 2*P^79 + P^81 + 2*P^82 + 
    3*P^83 + P^85 + 3*P^87 + 2*P^89 + 3*P^91 + P^92 + 2*P^93 + P^95 + P^96 + 2*P^97 + 2*P^98 + P^100 + 3*P^102 + 3*P^104 + 
    3*P^106 + 3*P^108 + 3*P^110 + 3*P^112 + 2*P^114 + 2*P^116 + P^117 + 2*P^118 + P^119 + P^121 + 2*P^122 + 3*P^123 + P^125 + 
    3*P^127 + 2*P^129 + 3*P^131 + P^132 + 2*P^133 + P^135 + P^136 + 2*P^137 + 2*P^138 + P^139 + P^140 + 2*P^141 + 2*P^142 + 
    P^143 + P^144 + 2*P^145 + 2*P^146 + 2*P^149 + 2*P^150 + P^151 + 2*P^153 + P^154 + P^155 + 2*P^157 + P^158 + P^159 + 
    2*P^160 + 2*P^161 + P^162 + 2*P^164 + 2*P^165 + P^166 + 2*P^168 + P^170 + 2*P^172 + P^174 + 2*P^176 + P^178 + 2*P^180 + 
    P^181 + P^184 + P^185 + P^189 + 2*P^191 + P^193 + 2*P^195 + 2*P^199 + P^212)/((1 - P^3)*(1 - P^65)*(1 - P^151))}, 
 {3, (P^10 + P^12 + P^14 + P^16 + P^20 + P^24 + P^27 + P^28 + P^29 + P^31 + P^33 + 2*P^35 + P^37 + 2*P^39 + P^41 + 2*P^43 + 
    P^44 + P^45 + P^46 + P^47 + P^48 + 2*P^50 + P^51 + P^52 + 2*P^54 + P^55 + P^56 + 2*P^58 + P^59 + P^60 + P^61 + 2*P^62 + 
    P^63 + P^64 + P^65 + 2*P^66 + P^67 + P^68 + 2*P^69 + 2*P^70 + P^71 + P^72 + 2*P^73 + 2*P^74 + P^76 + P^77 + 2*P^78 + P^80 + 
    P^81 + 2*P^82 + P^83 + 2*P^84 + P^85 + 2*P^86 + P^87 + 2*P^88 + P^89 + P^90 + P^91 + P^92 + 2*P^93 + 2*P^95 + P^96 + 
    3*P^97 + 2*P^99 + 3*P^101 + 3*P^103 + 3*P^105 + 2*P^107 + P^109 + P^110 + P^111 + 2*P^112 + P^113 + 2*P^114 + 2*P^116 + 
    P^117 + 3*P^118 + 2*P^120 + 3*P^122 + 2*P^124 + 2*P^126 + P^127 + 2*P^128 + P^129 + 2*P^130 + P^131 + 2*P^132 + P^133 + 
    P^134 + P^135 + 2*P^136 + 2*P^137 + P^139 + P^140 + 2*P^141 + P^143 + 2*P^144 + 2*P^145 + P^146 + P^147 + 2*P^148 + P^149 + 
    P^150 + P^151 + 2*P^152 + P^153 + P^154 + 2*P^155 + 2*P^156 + P^157 + 2*P^159 + P^160 + P^161 + 2*P^163 + P^164 + P^165 + 
    2*P^167 + P^169 + 2*P^171 + P^172 + P^173 + P^174 + P^175 + P^176 + P^178 + P^179 + P^180 + P^182 + P^184 + 2*P^186 + 
    P^188 + 2*P^190 + P^194 + P^198 + P^203 + P^205 + P^207)/((1 - P^3)*(1 - P^65)*(1 - P^151))}, 
 {3, (P^7 + P^8 + P^12 + P^22 + P^23 + P^26 + 2*P^27 + P^30 + 2*P^31 + P^34 + 2*P^35 + P^38 + P^39 + P^41 + 2*P^42 + P^43 + 
    P^45 + 2*P^46 + P^49 + 2*P^50 + P^53 + 2*P^54 + P^56 + 2*P^57 + 2*P^58 + P^60 + 3*P^61 + 2*P^62 + P^64 + 3*P^65 + 2*P^66 + 
    P^68 + 2*P^69 + P^70 + P^72 + P^73 + P^74 + P^75 + 3*P^76 + P^77 + P^79 + 3*P^80 + 2*P^81 + P^83 + 3*P^84 + 2*P^85 + 
    2*P^88 + 2*P^89 + P^90 + P^91 + P^92 + 2*P^93 + P^94 + 2*P^95 + P^96 + 2*P^97 + P^98 + 2*P^99 + P^101 + P^102 + 2*P^103 + 
    P^104 + P^105 + P^106 + P^107 + P^108 + P^109 + 2*P^110 + P^111 + 2*P^112 + P^113 + 2*P^114 + P^115 + 2*P^116 + P^117 + 
    2*P^118 + P^119 + 2*P^120 + P^122 + P^123 + 3*P^124 + P^125 + P^127 + 3*P^128 + 2*P^129 + 2*P^132 + 2*P^133 + P^134 + 
    P^135 + P^136 + P^137 + P^138 + 2*P^139 + P^140 + P^142 + 3*P^143 + 2*P^144 + P^146 + 3*P^147 + 2*P^148 + P^150 + 3*P^151 + 
    2*P^152 + P^154 + 2*P^155 + P^156 + P^158 + 2*P^159 + P^162 + 2*P^163 + P^165 + 2*P^166 + 2*P^167 + P^169 + 2*P^170 + 
    P^171 + P^173 + 2*P^174 + P^177 + 2*P^178 + P^181 + 2*P^182 + P^185 + 2*P^186 + P^190 + P^196 + P^197 + P^200 + 2*P^201 + 
    P^205)/((1 - P^3)*(1 - P^65)*(1 - P^151))}, 
 {3, (P^12 + P^14 + 2*P^16 + P^18 + P^20 + P^27 + P^29 + 2*P^31 + P^33 + 2*P^35 + P^37 + 2*P^39 + P^41 + 2*P^43 + P^45 + P^46 + 
    2*P^47 + P^48 + P^49 + 2*P^50 + P^51 + P^52 + 2*P^54 + P^56 + 2*P^58 + P^60 + P^61 + 2*P^62 + P^63 + P^64 + 2*P^65 + 
    2*P^66 + P^67 + P^68 + 2*P^69 + 2*P^70 + P^71 + P^72 + 2*P^73 + 2*P^74 + P^75 + P^76 + P^77 + 2*P^78 + 2*P^80 + 2*P^82 + 
    2*P^84 + P^85 + P^86 + P^87 + 2*P^88 + 2*P^89 + P^90 + P^91 + P^92 + 2*P^93 + 2*P^95 + 3*P^97 + 3*P^99 + 3*P^101 + 3*P^103 + 
    3*P^105 + 3*P^107 + 2*P^109 + P^111 + P^112 + P^113 + 2*P^114 + 2*P^116 + 3*P^118 + 3*P^120 + 3*P^122 + 3*P^124 + 2*P^126 + 
    2*P^128 + P^129 + P^130 + P^131 + 2*P^132 + 2*P^133 + P^134 + P^135 + 2*P^136 + 2*P^137 + P^138 + P^139 + P^140 + 2*P^141 + 
    P^143 + P^144 + P^145 + P^146 + P^147 + 2*P^148 + P^149 + P^150 + 2*P^151 + 2*P^152 + P^153 + P^154 + 2*P^155 + 2*P^156 + 
    P^157 + P^158 + 2*P^159 + P^160 + P^161 + 2*P^163 + P^165 + 2*P^167 + P^169 + 2*P^171 + P^173 + P^174 + 2*P^175 + P^176 + 
    P^178 + P^180 + 2*P^182 + P^184 + 2*P^186 + P^188 + 2*P^190 + P^192 + P^194 + P^205 + P^207 + P^209)/
   ((1 - P^3)*(1 - P^65)*(1 - P^151))}, {3, (P^6 + 2*P^16 + 2*P^20 + 2*P^24 + P^25 + P^29 + P^31 + P^33 + 2*P^35 + P^37 + 
    2*P^39 + P^40 + 2*P^43 + P^44 + 2*P^47 + P^48 + 2*P^50 + 2*P^51 + P^52 + 2*P^54 + 2*P^55 + P^56 + 2*P^58 + P^59 + P^60 + 
    2*P^62 + P^63 + P^64 + P^65 + 2*P^66 + P^67 + P^68 + 2*P^69 + 2*P^70 + 2*P^73 + 3*P^74 + P^75 + 2*P^77 + 3*P^78 + P^79 + 
    3*P^82 + P^83 + 2*P^84 + 2*P^86 + P^87 + 2*P^88 + P^89 + P^91 + 2*P^92 + 3*P^93 + P^95 + P^96 + 3*P^97 + 2*P^99 + 3*P^101 + 
    2*P^103 + 2*P^105 + P^106 + 2*P^107 + P^108 + 2*P^109 + P^110 + 2*P^111 + P^112 + 2*P^113 + P^114 + P^116 + P^117 + 
    3*P^118 + P^120 + 3*P^122 + P^123 + 2*P^124 + 3*P^126 + P^127 + 2*P^128 + P^130 + P^131 + 2*P^132 + 2*P^133 + P^135 + 
    2*P^136 + 3*P^137 + 2*P^140 + 3*P^141 + P^142 + 2*P^144 + 3*P^145 + P^146 + P^148 + P^149 + P^150 + P^151 + 2*P^152 + 
    P^153 + 2*P^155 + 2*P^156 + P^157 + 2*P^159 + 2*P^160 + P^161 + 2*P^163 + P^164 + P^165 + 2*P^167 + P^168 + P^169 + 
    2*P^171 + P^172 + 2*P^175 + P^176 + 2*P^179 + P^180 + P^182 + P^184 + 2*P^186 + 2*P^190 + 2*P^194 + P^195 + P^199 + P^203 + 
    P^213)/((1 - P^3)*(1 - P^65)*(1 - P^151))}, 
 {3, (P^7 + P^11 + P^15 + P^20 + P^22 + P^24 + P^26 + P^28 + 2*P^30 + P^32 + 2*P^34 + 2*P^38 + P^39 + P^41 + P^42 + P^43 + 
    2*P^45 + P^46 + P^47 + 2*P^49 + P^51 + 2*P^53 + P^54 + P^55 + P^56 + 2*P^57 + P^58 + P^59 + P^60 + 2*P^61 + P^62 + P^63 + 
    2*P^64 + 2*P^65 + P^66 + 2*P^68 + 2*P^69 + P^70 + P^72 + 2*P^73 + P^74 + P^75 + P^76 + 2*P^77 + P^78 + 2*P^79 + P^80 + 
    P^81 + P^82 + 2*P^83 + 2*P^84 + P^86 + P^87 + 3*P^88 + 2*P^90 + P^91 + 3*P^92 + 2*P^94 + 3*P^96 + 2*P^98 + 2*P^100 + P^101 + 
    2*P^102 + P^103 + P^104 + P^105 + P^106 + 2*P^107 + P^108 + 2*P^109 + 2*P^111 + 3*P^113 + 3*P^115 + 3*P^117 + 2*P^119 + 
    2*P^121 + P^122 + 2*P^123 + P^124 + P^125 + P^126 + 2*P^127 + 2*P^128 + P^130 + P^131 + 3*P^132 + P^134 + P^135 + 3*P^136 + 
    P^137 + P^138 + P^139 + 2*P^140 + P^141 + P^142 + P^143 + P^144 + P^145 + 2*P^146 + 2*P^147 + P^148 + P^149 + 2*P^150 + 
    2*P^151 + P^152 + 2*P^154 + P^155 + P^156 + 2*P^158 + P^159 + P^160 + 2*P^162 + P^163 + P^164 + P^165 + 2*P^166 + P^167 + 
    P^169 + 2*P^170 + P^171 + P^173 + P^174 + P^175 + 2*P^177 + P^179 + 2*P^181 + P^183 + 2*P^185 + P^189 + P^190 + P^194 + 
    P^196 + P^198 + P^200 + P^204 + P^208)/((1 - P^3)*(1 - P^65)*(1 - P^151))}, 
 {3, (P^9 + P^11 + P^13 + P^18 + P^22 + 2*P^26 + P^28 + 2*P^30 + P^32 + P^34 + P^36 + P^37 + P^38 + P^40 + P^41 + P^42 + P^43 + 
    P^44 + 2*P^45 + P^47 + 2*P^49 + P^51 + P^52 + 2*P^53 + P^55 + P^56 + 2*P^57 + P^59 + 2*P^60 + 2*P^61 + P^62 + P^63 + 
    2*P^64 + P^65 + P^66 + P^67 + 2*P^68 + P^69 + P^70 + 2*P^71 + 2*P^72 + P^73 + 2*P^75 + P^76 + P^77 + 2*P^79 + 2*P^80 + 
    P^81 + P^82 + P^83 + 2*P^84 + P^85 + 2*P^86 + P^87 + 2*P^88 + P^89 + 2*P^90 + 2*P^92 + 3*P^94 + 2*P^96 + 3*P^98 + P^99 + 
    2*P^100 + 2*P^102 + P^103 + 2*P^104 + P^105 + P^106 + P^107 + 2*P^109 + 3*P^111 + 3*P^113 + 3*P^115 + 2*P^117 + 3*P^119 + 
    P^120 + 2*P^121 + 2*P^123 + P^124 + P^125 + P^126 + P^127 + 2*P^128 + P^129 + 2*P^130 + P^131 + 2*P^132 + P^133 + 2*P^134 + 
    P^135 + P^136 + 2*P^138 + P^139 + P^140 + 2*P^142 + 2*P^143 + P^144 + P^145 + 2*P^146 + 2*P^147 + P^148 + P^149 + 2*P^150 + 
    P^151 + P^152 + P^153 + 2*P^154 + P^155 + P^156 + P^157 + 2*P^158 + P^160 + P^161 + 2*P^162 + P^164 + P^165 + 2*P^166 + 
    P^168 + P^169 + P^170 + P^171 + P^172 + 2*P^173 + P^175 + 2*P^177 + P^179 + 2*P^181 + P^183 + P^185 + P^187 + P^188 + 
    P^189 + P^192 + P^196 + P^200 + P^202 + P^204 + P^206)/((1 - P^3)*(1 - P^65)*(1 - P^151))}, 
 {3, (P^13 + P^14 + P^15 + P^17 + P^18 + P^19 + P^28 + P^29 + P^30 + P^32 + P^33 + P^34 + P^36 + P^37 + P^38 + P^40 + P^41 + 
    P^42 + P^44 + P^45 + P^46 + P^47 + 2*P^48 + 2*P^49 + P^50 + P^51 + P^52 + P^53 + P^55 + P^56 + P^57 + P^59 + P^60 + P^61 + 
    P^62 + 2*P^63 + 2*P^64 + P^65 + P^66 + 2*P^67 + 2*P^68 + P^69 + P^70 + 2*P^71 + 2*P^72 + P^73 + P^74 + 2*P^75 + 2*P^76 + 
    P^77 + P^79 + P^80 + 2*P^81 + P^82 + P^83 + P^85 + 2*P^86 + 2*P^87 + P^88 + P^89 + 2*P^90 + 2*P^91 + P^92 + P^94 + P^95 + 
    2*P^96 + P^97 + 2*P^98 + P^99 + 2*P^100 + P^101 + 2*P^102 + P^103 + 2*P^104 + P^105 + 2*P^106 + P^107 + 2*P^108 + P^109 + 
    P^110 + P^111 + P^112 + P^113 + P^115 + P^116 + 2*P^117 + P^118 + 2*P^119 + P^120 + 2*P^121 + P^122 + 2*P^123 + P^124 + 
    2*P^125 + P^126 + P^127 + P^129 + 2*P^130 + 2*P^131 + P^132 + P^133 + 2*P^134 + 2*P^135 + P^136 + P^137 + 2*P^138 + 
    2*P^139 + P^140 + P^142 + P^143 + P^144 + P^145 + P^146 + P^147 + P^148 + 2*P^149 + 2*P^150 + P^151 + P^152 + 2*P^153 + 
    2*P^154 + P^155 + P^156 + 2*P^157 + 2*P^158 + P^159 + P^160 + P^161 + P^162 + P^164 + P^165 + P^166 + P^168 + P^169 + 
    P^170 + P^172 + P^173 + P^174 + P^175 + P^176 + P^177 + P^179 + P^180 + P^181 + P^183 + P^184 + P^185 + P^187 + P^188 + 
    P^189 + (I/193)*P^190 + P^191 + P^192 + P^193 + P^206 + P^207 + P^208)/((1 - P^3)*(1 - P^65)*(1 - P^151))}, 
 {3, (P^10 + P^11 + P^15 + P^17 + P^21 + 2*P^25 + 2*P^29 + P^30 + P^33 + P^34 + P^36 + P^37 + P^38 + P^40 + P^41 + P^42 + 
    2*P^44 + P^45 + P^46 + 2*P^48 + P^49 + P^51 + 2*P^52 + P^53 + P^55 + 2*P^56 + P^57 + 2*P^59 + 2*P^60 + P^61 + 2*P^63 + 
    2*P^64 + P^65 + 2*P^67 + 2*P^68 + P^69 + P^70 + 2*P^71 + 2*P^72 + P^73 + P^74 + P^75 + P^77 + 2*P^78 + 3*P^79 + P^82 + 
    3*P^83 + P^84 + P^85 + P^86 + 3*P^87 + P^88 + P^89 + 2*P^91 + P^92 + 2*P^93 + P^94 + P^95 + P^96 + 2*P^97 + 2*P^98 + P^99 + 
    P^100 + P^101 + 2*P^102 + P^103 + 2*P^104 + P^105 + 2*P^106 + 2*P^108 + 2*P^110 + 2*P^112 + P^113 + 2*P^114 + P^115 + 
    P^116 + P^117 + 2*P^118 + 2*P^119 + P^120 + P^121 + P^122 + 2*P^123 + P^125 + P^126 + 3*P^127 + P^128 + P^129 + P^130 + 
    3*P^131 + P^132 + P^133 + P^134 + 2*P^135 + P^136 + P^137 + P^138 + P^139 + P^140 + 2*P^141 + 2*P^142 + 2*P^145 + 3*P^146 + 
    P^147 + 2*P^149 + 2*P^150 + P^151 + 2*P^153 + 2*P^154 + P^155 + P^156 + 2*P^157 + P^158 + P^160 + 2*P^161 + P^162 + P^164 + 
    2*P^165 + P^166 + P^168 + P^169 + P^170 + 2*P^172 + P^173 + P^174 + 2*P^176 + P^177 + 2*P^180 + P^181 + P^184 + P^185 + 
    P^187 + P^188 + P^189 + P^191 + P^195 + P^199 + P^203 + P^204 + P^208)/((1 - P^3)*(1 - P^65)*(1 - P^151))}, 
 {3, (P^6 + P^10 + P^14 + P^18 + P^22 + P^25 + P^26 + 2*P^29 + P^30 + 2*P^33 + 3*P^37 + P^40 + 2*P^41 + 2*P^44 + 2*P^45 + 
    2*P^48 + P^49 + 3*P^52 + P^53 + 3*P^56 + P^57 + P^59 + 3*P^60 + P^61 + 2*P^63 + 3*P^64 + 2*P^67 + 3*P^68 + 2*P^71 + 2*P^72 + 
    P^74 + 2*P^75 + 2*P^76 + 2*P^78 + 2*P^79 + P^80 + 2*P^82 + 2*P^83 + P^84 + 3*P^86 + 2*P^87 + P^88 + 2*P^90 + 2*P^91 + P^92 + 
    P^93 + P^94 + 2*P^95 + 2*P^97 + P^98 + 3*P^99 + 2*P^101 + 2*P^103 + 2*P^105 + P^106 + 2*P^107 + P^108 + P^109 + P^110 + 
    P^111 + 2*P^112 + P^113 + 2*P^114 + P^115 + 2*P^116 + 2*P^118 + P^119 + 3*P^120 + 2*P^122 + P^123 + 2*P^124 + 2*P^126 + 
    P^127 + P^128 + 3*P^130 + 2*P^131 + P^132 + 2*P^134 + 2*P^135 + P^137 + 2*P^138 + 2*P^139 + P^141 + 2*P^142 + P^143 + 
    2*P^145 + 3*P^146 + P^147 + 2*P^149 + 3*P^150 + 2*P^153 + 3*P^154 + 2*P^157 + 2*P^158 + 3*P^161 + P^162 + 3*P^165 + P^166 + 
    P^168 + 3*P^169 + P^172 + 2*P^173 + 2*P^176 + P^177 + 2*P^180 + P^181 + 2*P^184 + 2*P^188 + 2*P^192 + P^196 + P^199 + 
    P^200 + P^203 + P^207)/((1 - P^3)*(1 - P^65)*(1 - P^151))}, 
 {3, (P^9 + P^10 + P^14 + P^19 + P^23 + P^24 + P^27 + P^28 + P^29 + P^31 + P^32 + P^33 + P^36 + P^37 + P^38 + P^40 + P^41 + 
    P^42 + P^43 + P^44 + P^45 + P^46 + P^47 + P^48 + P^50 + P^51 + P^52 + P^53 + P^54 + P^55 + P^56 + P^57 + 2*P^58 + P^59 + 
    P^60 + P^61 + 2*P^62 + 2*P^63 + P^64 + P^65 + P^66 + 2*P^67 + P^68 + P^69 + P^70 + 2*P^71 + 2*P^72 + P^73 + 2*P^76 + 
    2*P^77 + 2*P^78 + P^80 + 2*P^81 + 2*P^82 + P^83 + 2*P^85 + 2*P^86 + 2*P^87 + P^89 + 2*P^90 + 2*P^91 + P^92 + P^93 + P^94 + 
    2*P^95 + P^96 + P^97 + P^98 + 2*P^99 + 2*P^100 + P^101 + P^102 + P^103 + 2*P^104 + P^105 + P^106 + P^107 + P^108 + P^109 + 
    P^110 + P^111 + 2*P^112 + P^113 + 2*P^114 + P^115 + 2*P^116 + P^117 + P^118 + P^119 + 2*P^120 + 2*P^121 + P^122 + P^124 + 
    2*P^125 + 2*P^126 + P^127 + 2*P^129 + 2*P^130 + 2*P^131 + P^133 + 2*P^134 + 2*P^135 + P^136 + P^138 + 2*P^139 + 2*P^140 + 
    P^141 + P^143 + 2*P^144 + 2*P^145 + P^146 + P^147 + 2*P^148 + 2*P^149 + P^150 + P^151 + P^152 + 2*P^153 + P^154 + P^155 + 
    P^156 + P^157 + P^158 + P^159 + P^160 + P^161 + P^162 + P^163 + P^164 + P^165 + P^166 + P^167 + P^168 + P^169 + P^170 + 
    P^171 + P^172 + P^173 + P^174 + P^175 + P^176 + P^178 + P^179 + P^180 + P^182 + P^183 + P^184 + P^187 + P^188 + P^189 + 
    P^193 + P^197 + P^198 + P^202 + P^203 + P^207)/((1 - P^3)*(1 - P^65)*(1 - P^151))}, 
 {3, (P^9 + P^13 + P^14 + P^18 + P^19 + P^23 + P^27 + P^28 + P^29 + P^32 + P^33 + P^34 + P^36 + P^37 + P^38 + P^40 + P^41 + 
    P^42 + P^43 + P^44 + P^45 + P^46 + P^47 + P^48 + P^49 + P^50 + P^51 + P^52 + P^53 + P^54 + P^55 + P^56 + P^57 + P^58 + 
    P^59 + P^60 + P^61 + P^62 + 2*P^63 + P^64 + P^65 + P^66 + 2*P^67 + 2*P^68 + P^69 + P^70 + 2*P^71 + 2*P^72 + P^73 + P^75 + 
    2*P^76 + 2*P^77 + P^78 + P^80 + 2*P^81 + 2*P^82 + P^83 + 2*P^85 + 2*P^86 + 2*P^87 + P^89 + 2*P^90 + 2*P^91 + P^92 + P^94 + 
    2*P^95 + 2*P^96 + P^97 + P^98 + P^99 + 2*P^100 + P^101 + 2*P^102 + P^103 + 2*P^104 + P^105 + P^106 + P^107 + P^108 + P^109 + 
    P^110 + P^111 + 2*P^112 + P^113 + P^114 + P^115 + 2*P^116 + 2*P^117 + P^118 + P^119 + P^120 + 2*P^121 + P^122 + P^123 + 
    P^124 + 2*P^125 + 2*P^126 + P^127 + 2*P^129 + 2*P^130 + 2*P^131 + P^133 + 2*P^134 + 2*P^135 + P^136 + 2*P^138 + 2*P^139 + 
    2*P^140 + P^143 + 2*P^144 + 2*P^145 + P^146 + P^147 + P^148 + 2*P^149 + P^150 + P^151 + P^152 + 2*P^153 + 2*P^154 + P^155 + 
    P^156 + P^157 + 2*P^158 + P^159 + P^160 + P^161 + P^162 + P^163 + P^164 + P^165 + P^166 + P^168 + P^169 + P^170 + P^171 + 
    P^172 + P^173 + P^174 + P^175 + P^176 + P^178 + P^179 + P^180 + P^183 + P^184 + P^185 + P^187 + P^188 + P^189 + P^192 + 
    P^193 + P^197 + P^202 + P^206 + P^207)/((1 - P^3)*(1 - P^65)*(1 - P^151))}, 
 {3, (P^8 + P^9 + P^13 + P^21 + P^23 + P^25 + P^27 + P^28 + P^29 + P^31 + P^32 + P^33 + P^35 + P^36 + P^39 + 2*P^40 + P^42 + 
    P^43 + 2*P^44 + P^46 + P^47 + P^48 + P^50 + P^51 + P^52 + P^54 + 2*P^55 + P^56 + P^57 + P^58 + 2*P^59 + P^60 + P^61 + 
    2*P^62 + 2*P^63 + P^64 + P^65 + 2*P^66 + 2*P^67 + P^69 + 2*P^70 + 2*P^71 + P^74 + 2*P^75 + P^76 + 2*P^77 + P^78 + P^79 + 
    P^80 + 2*P^81 + 2*P^82 + P^83 + P^84 + 2*P^85 + P^86 + P^87 + 3*P^89 + P^90 + 2*P^91 + 2*P^93 + P^94 + 2*P^95 + P^96 + 
    2*P^97 + P^98 + P^99 + P^100 + P^101 + 2*P^102 + P^103 + 2*P^104 + 2*P^106 + 2*P^108 + 2*P^110 + P^111 + 2*P^112 + P^113 + 
    2*P^114 + P^115 + 2*P^116 + P^117 + 2*P^118 + P^119 + P^120 + P^121 + P^122 + 2*P^123 + P^124 + 2*P^125 + P^126 + P^127 + 
    P^128 + 2*P^129 + P^130 + P^131 + 3*P^133 + P^134 + P^135 + 2*P^137 + 2*P^138 + P^139 + P^140 + P^141 + P^142 + P^143 + 
    2*P^144 + 2*P^145 + P^146 + P^147 + 2*P^148 + 2*P^149 + P^150 + P^151 + 2*P^152 + 2*P^153 + P^155 + P^156 + 2*P^157 + 
    P^159 + P^160 + P^161 + P^163 + 2*P^164 + P^165 + P^166 + P^167 + 2*P^168 + P^170 + P^171 + 2*P^172 + P^174 + P^175 + 
    P^176 + P^178 + P^179 + P^180 + P^182 + P^183 + P^184 + P^186 + P^187 + P^191 + P^195 + P^197 + P^199 + P^201 + P^202 + 
    P^206)/((1 - P^3)*(1 - P^65)*(1 - P^151))}, 
 {3, (P^8 + P^9 + P^10 + P^23 + P^24 + P^25 + P^27 + P^28 + P^29 + P^31 + P^32 + P^33 + P^35 + P^36 + P^37 + P^39 + P^40 + 
    P^41 + P^42 + P^43 + P^44 + P^46 + P^47 + P^48 + P^50 + P^51 + P^52 + P^54 + P^55 + P^56 + P^57 + 2*P^58 + 2*P^59 + P^60 + 
    P^61 + 2*P^62 + 2*P^63 + P^64 + P^65 + 2*P^66 + 2*P^67 + P^68 + P^69 + P^70 + P^71 + P^72 + P^73 + P^74 + P^76 + 2*P^77 + 
    2*P^78 + P^79 + P^80 + 2*P^81 + 2*P^82 + P^83 + P^84 + 2*P^85 + 2*P^86 + P^87 + P^89 + P^90 + 2*P^91 + P^92 + 2*P^93 + 
    P^94 + 2*P^95 + P^96 + 2*P^97 + P^98 + 2*P^99 + P^100 + P^101 + P^103 + P^104 + P^105 + P^106 + P^107 + 2*P^108 + P^109 + 
    2*P^110 + P^111 + 2*P^112 + P^113 + 2*P^114 + P^115 + 2*P^116 + P^117 + 2*P^118 + P^119 + 2*P^120 + P^121 + P^122 + P^124 + 
    2*P^125 + 2*P^126 + P^127 + P^128 + 2*P^129 + 2*P^130 + P^131 + P^133 + P^134 + 2*P^135 + P^136 + P^137 + P^139 + 2*P^140 + 
    2*P^141 + P^142 + P^143 + 2*P^144 + 2*P^145 + P^146 + P^147 + 2*P^148 + 2*P^149 + P^150 + P^151 + 2*P^152 + 2*P^153 + 
    P^154 + P^155 + P^156 + P^157 + P^159 + P^160 + P^161 + P^163 + P^164 + P^165 + P^166 + 2*P^167 + 2*P^168 + P^169 + P^170 + 
    P^171 + P^172 + P^174 + P^175 + P^176 + P^178 + P^179 + P^180 + P^182 + P^183 + (1 + I/195)*P^184 + P^186 + P^187 + P^188 + 
    P^197 + P^198 + P^199 + P^201 + P^202 + P^203)/((1 - P^3)*(1 - P^65)*(1 - P^151))}, 
 {3, (P^10 + 2*P^14 + 2*P^18 + P^22 + P^25 + 2*P^29 + 3*P^33 + 3*P^37 + 3*P^41 + P^44 + 2*P^45 + 3*P^48 + 2*P^49 + 3*P^52 + 
    P^53 + 3*P^56 + P^59 + 3*P^60 + 2*P^63 + 3*P^64 + 3*P^67 + 3*P^68 + 3*P^71 + 3*P^72 + 2*P^75 + 2*P^76 + P^78 + P^79 + 
    2*P^80 + 3*P^82 + P^83 + P^84 + 3*P^86 + 2*P^87 + 2*P^90 + 3*P^91 + P^93 + P^94 + 3*P^95 + 2*P^97 + 3*P^99 + 3*P^101 + 
    3*P^103 + 3*P^105 + 2*P^107 + 2*P^109 + P^110 + 2*P^111 + P^112 + P^114 + P^115 + 3*P^116 + 2*P^118 + 3*P^120 + 3*P^122 + 
    2*P^124 + 3*P^126 + P^127 + P^128 + 3*P^130 + 2*P^131 + 3*P^134 + 3*P^135 + 2*P^138 + 3*P^139 + P^141 + 2*P^142 + 2*P^143 + 
    P^145 + 2*P^146 + 2*P^149 + 3*P^150 + 3*P^153 + 3*P^154 + 3*P^157 + 2*P^158 + 3*P^161 + P^162 + 3*P^165 + 3*P^169 + P^172 + 
    3*P^173 + P^176 + 2*P^177 + 2*P^180 + 3*P^184 + 3*P^188 + 2*P^192 + P^196 + P^203 + P^207 + P^211)/
   ((1 - P^3)*(1 - P^65)*(1 - P^151))}, {3, (P^4 + P^14 + P^18 + P^20 + P^22 + P^23 + P^24 + P^27 + P^28 + P^31 + P^32 + P^33 + 
    P^35 + P^37 + P^38 + P^39 + P^41 + P^42 + P^43 + P^45 + P^46 + P^47 + P^48 + P^49 + P^50 + P^51 + P^52 + P^53 + 2*P^54 + 
    P^55 + P^56 + P^57 + 2*P^58 + P^59 + P^60 + P^61 + 2*P^62 + P^63 + P^64 + P^65 + P^66 + P^67 + P^68 + P^69 + P^70 + P^71 + 
    2*P^72 + 2*P^73 + P^74 + P^75 + 2*P^76 + 2*P^77 + P^78 + 2*P^80 + 2*P^81 + 2*P^82 + P^84 + P^85 + 2*P^86 + P^87 + P^88 + 
    P^89 + 2*P^90 + 2*P^91 + P^92 + P^93 + P^94 + 2*P^95 + P^96 + P^97 + 2*P^99 + P^100 + 2*P^101 + 2*P^103 + P^104 + 2*P^105 + 
    P^106 + 2*P^107 + P^108 + 2*P^109 + P^110 + 2*P^111 + P^112 + P^113 + P^114 + P^115 + 2*P^116 + P^117 + P^118 + 2*P^120 + 
    2*P^121 + 2*P^122 + 2*P^124 + P^125 + 2*P^126 + P^128 + P^129 + 2*P^130 + 2*P^131 + P^132 + P^133 + P^134 + 2*P^135 + 
    P^136 + P^137 + P^138 + 2*P^139 + 2*P^140 + P^141 + P^142 + 2*P^143 + 2*P^144 + P^145 + P^147 + 2*P^148 + 2*P^149 + P^150 + 
    P^151 + P^152 + P^153 + P^154 + P^155 + P^156 + P^157 + P^158 + 2*P^159 + P^160 + P^161 + P^162 + 2*P^163 + P^164 + P^165 + 
    P^166 + 2*P^167 + P^169 + P^170 + P^171 + P^173 + P^174 + P^175 + P^177 + P^178 + P^179 + P^180 + P^182 + P^183 + P^184 + 
    P^188 + P^190 + P^192 + P^193 + P^194 + P^197 + P^198 + P^201 + P^211)/((1 - P^3)*(1 - P^65)*(1 - P^151))}, 
 {3, (P^9 + P^13 + P^16 + P^17 + P^20 + P^21 + P^24 + P^28 + P^31 + 2*P^32 + P^35 + 2*P^36 + P^39 + 2*P^40 + 2*P^43 + P^44 + 
    3*P^47 + P^48 + P^50 + 3*P^51 + P^52 + P^54 + 2*P^55 + 2*P^58 + 2*P^59 + 2*P^62 + 2*P^63 + P^65 + 3*P^66 + 2*P^67 + P^69 + 
    3*P^70 + 2*P^71 + P^73 + 2*P^74 + P^75 + 2*P^77 + 2*P^78 + P^79 + 2*P^81 + 2*P^82 + P^83 + P^84 + 2*P^85 + P^86 + P^88 + 
    2*P^89 + 2*P^90 + 2*P^92 + 2*P^93 + 2*P^94 + P^96 + P^97 + 2*P^98 + P^99 + 2*P^100 + P^101 + 2*P^102 + P^103 + 2*P^104 + 
    P^105 + P^106 + P^107 + P^108 + 2*P^109 + P^110 + 2*P^111 + 2*P^113 + P^114 + 2*P^115 + P^117 + P^118 + 2*P^119 + P^120 + 
    2*P^121 + P^122 + P^123 + P^124 + 2*P^125 + 2*P^126 + P^127 + P^128 + 2*P^129 + P^130 + P^132 + 3*P^133 + 2*P^134 + P^136 + 
    2*P^137 + 2*P^138 + 2*P^140 + 2*P^141 + P^142 + 2*P^144 + 2*P^145 + 2*P^148 + 2*P^149 + P^151 + 3*P^152 + 2*P^153 + P^155 + 
    3*P^156 + P^157 + P^159 + 3*P^160 + P^161 + P^163 + 2*P^164 + P^167 + 2*P^168 + 2*P^171 + 2*P^172 + 2*P^175 + P^176 + 
    2*P^179 + P^182 + 2*P^183 + P^186 + 2*P^187 + P^190 + P^191 + P^194 + P^195 + P^202 + P^206 + P^210)/
   ((1 - P^3)*(1 - P^65)*(1 - P^151))}, {3, (P^8 + P^12 + P^13 + P^17 + P^21 + P^25 + P^27 + P^28 + P^29 + P^31 + P^32 + P^35 + 
    2*P^36 + P^39 + 2*P^40 + P^42 + P^43 + 2*P^44 + P^46 + P^47 + P^48 + P^50 + 2*P^51 + P^52 + P^54 + 2*P^55 + P^56 + P^58 + 
    2*P^59 + P^60 + P^61 + 2*P^62 + 2*P^63 + P^65 + 2*P^66 + 2*P^67 + P^69 + 3*P^70 + 2*P^71 + 2*P^74 + 2*P^75 + P^76 + P^77 + 
    P^78 + P^79 + P^80 + 2*P^81 + P^82 + P^83 + P^84 + 3*P^85 + P^86 + P^87 + P^88 + 3*P^89 + P^90 + P^91 + 2*P^93 + P^94 + 
    P^95 + P^96 + 2*P^97 + 2*P^98 + P^99 + P^100 + P^101 + 2*P^102 + P^103 + 2*P^104 + 2*P^106 + 2*P^108 + 2*P^110 + P^111 + 
    2*P^112 + P^113 + 2*P^114 + P^115 + P^116 + P^117 + 2*P^118 + 2*P^119 + P^120 + P^121 + P^122 + 2*P^123 + P^124 + 2*P^125 + 
    P^127 + P^128 + 3*P^129 + P^130 + P^131 + P^132 + 3*P^133 + P^134 + 3*P^137 + 2*P^138 + P^139 + P^141 + P^142 + P^143 + 
    2*P^144 + 2*P^145 + P^146 + P^147 + 2*P^148 + 2*P^149 + P^151 + 2*P^152 + 2*P^153 + P^155 + 2*P^156 + 2*P^157 + P^159 + 
    2*P^160 + P^161 + P^163 + 2*P^164 + P^165 + P^167 + 2*P^168 + P^170 + P^171 + 2*P^172 + P^174 + P^175 + P^176 + P^178 + 
    P^179 + P^180 + P^182 + P^183 + P^186 + 2*P^187 + 2*P^191 + P^195 + P^199 + P^201 + P^205 + P^206)/
   ((1 - P^3)*(1 - P^65)*(1 - P^151))}, {3, (P^3 + P^16 + P^19 + P^20 + P^22 + P^23 + P^24 + P^26 + P^27 + P^30 + P^31 + P^34 + 
    P^35 + P^37 + P^38 + P^39 + P^41 + P^42 + P^43 + P^45 + P^46 + P^47 + P^49 + 2*P^50 + P^51 + 2*P^53 + 2*P^54 + P^55 + P^56 + 
    2*P^57 + 2*P^58 + P^60 + 2*P^61 + P^62 + P^64 + 2*P^65 + P^66 + P^68 + 2*P^69 + P^70 + P^71 + 2*P^72 + 2*P^73 + P^74 + 
    P^75 + 2*P^76 + 2*P^77 + P^78 + P^79 + 2*P^80 + P^81 + P^82 + P^83 + 2*P^84 + P^85 + P^86 + P^87 + 2*P^88 + P^89 + P^90 + 
    P^91 + 2*P^92 + P^93 + P^94 + P^95 + P^96 + P^97 + P^98 + 2*P^99 + P^100 + P^101 + P^102 + 2*P^103 + P^104 + 2*P^105 + 
    P^106 + 2*P^107 + P^108 + 2*P^109 + P^110 + 2*P^111 + P^112 + 2*P^113 + P^114 + P^115 + P^116 + P^117 + P^118 + P^119 + 
    2*P^120 + P^121 + P^122 + P^123 + 2*P^124 + P^125 + P^126 + P^127 + 2*P^128 + P^129 + P^130 + P^131 + 2*P^132 + P^133 + 
    P^134 + P^135 + 2*P^136 + P^137 + P^138 + 2*P^139 + 2*P^140 + P^141 + P^142 + 2*P^143 + 2*P^144 + P^145 + P^146 + 2*P^147 + 
    P^148 + P^150 + 2*P^151 + P^152 + P^154 + 2*P^155 + P^156 + 2*P^158 + 2*P^159 + P^160 + P^161 + 2*P^162 + 2*P^163 + P^165 + 
    2*P^166 + P^167 + P^169 + P^170 + P^171 + P^173 + P^174 + P^175 + P^177 + P^178 + P^179 + P^181 + 2*P^182 + P^186 + P^189 + 
    P^190 + P^192 + P^193 + P^194 + P^196 + P^197 + P^200 + P^213)/((1 - P^3)*(1 - P^65)*(1 - P^151))}, 
 {3, (P^11 + 2*P^15 + P^16 + P^19 + P^20 + P^26 + 2*P^30 + P^31 + 2*P^34 + P^35 + 2*P^38 + P^39 + 2*P^42 + P^43 + P^45 + 
    2*P^46 + P^47 + 2*P^49 + 2*P^50 + P^51 + 2*P^53 + P^54 + 2*P^57 + P^58 + P^60 + 2*P^61 + P^62 + 2*P^64 + 3*P^65 + P^66 + 
    2*P^68 + 3*P^69 + P^70 + 2*P^72 + 3*P^73 + P^74 + P^76 + 2*P^77 + P^78 + P^79 + P^80 + P^81 + P^82 + 2*P^83 + 2*P^84 + 
    2*P^87 + 3*P^88 + P^89 + P^91 + 3*P^92 + P^93 + P^94 + 2*P^96 + P^97 + 2*P^98 + P^99 + 2*P^100 + P^101 + 2*P^102 + P^103 + 
    2*P^104 + P^105 + 2*P^106 + P^107 + P^108 + P^109 + P^110 + P^111 + P^112 + 2*P^113 + P^114 + P^115 + 2*P^117 + P^118 + 
    2*P^119 + P^120 + 2*P^121 + P^122 + 2*P^123 + P^124 + P^125 + P^126 + 2*P^127 + 2*P^128 + 2*P^131 + 3*P^132 + P^133 + 
    2*P^135 + 3*P^136 + P^137 + P^139 + 3*P^140 + P^141 + P^142 + P^143 + P^144 + P^146 + 2*P^147 + P^148 + 2*P^150 + 3*P^151 + 
    P^152 + 2*P^154 + 3*P^155 + P^156 + 2*P^158 + 2*P^159 + P^160 + 2*P^162 + P^163 + 2*P^166 + P^167 + 2*P^170 + P^171 + 
    P^173 + 2*P^174 + P^175 + P^177 + P^178 + 2*P^181 + P^182 + 2*P^185 + P^186 + 2*P^189 + P^190 + P^193 + P^194 + P^204 + 
    P^208 + P^209)/((1 - P^3)*(1 - P^65)*(1 - P^151))}, 
 {3, (P^4 + 2*P^17 + 2*P^21 + P^23 + 2*P^25 + P^27 + P^31 + P^32 + P^35 + 2*P^36 + P^38 + 2*P^40 + P^42 + 2*P^44 + P^46 + 
    2*P^48 + P^50 + 2*P^51 + 2*P^52 + P^54 + 2*P^55 + 2*P^56 + P^57 + P^58 + 2*P^59 + P^61 + P^62 + 2*P^63 + P^65 + 2*P^66 + 
    2*P^67 + 2*P^70 + 2*P^71 + P^72 + P^73 + 2*P^74 + 2*P^75 + P^76 + P^77 + 2*P^78 + 2*P^79 + P^80 + P^81 + 2*P^83 + P^84 + 
    3*P^85 + 2*P^87 + 3*P^89 + P^91 + 3*P^93 + 2*P^94 + P^95 + P^97 + 2*P^98 + P^99 + 2*P^100 + 2*P^102 + 3*P^104 + 3*P^106 + 
    3*P^108 + 3*P^110 + 3*P^112 + 3*P^114 + P^116 + 2*P^118 + 2*P^119 + P^120 + P^121 + 2*P^123 + P^124 + 3*P^125 + 2*P^127 + 
    3*P^129 + P^131 + 3*P^133 + 2*P^134 + P^135 + 2*P^137 + 2*P^138 + P^139 + P^140 + 2*P^141 + 2*P^142 + P^143 + P^144 + 
    2*P^145 + 2*P^146 + P^147 + P^148 + P^149 + P^151 + P^152 + 2*P^153 + P^155 + 2*P^156 + 2*P^157 + P^159 + 2*P^160 + 
    2*P^161 + P^162 + P^163 + 2*P^164 + P^166 + P^167 + 2*P^168 + P^170 + 2*P^172 + P^174 + 2*P^176 + P^178 + 2*P^180 + P^182 + 
    P^183 + 2*P^187 + 2*P^191 + P^193 + 2*P^195 + P^197 + P^201 + P^214)/((1 - P^3)*(1 - P^65)*(1 - P^151))}, 
 {3, (P^3 + P^16 + P^19 + P^20 + P^22 + P^23 + P^24 + P^26 + P^27 + P^30 + 2*P^34 + P^35 + P^37 + P^38 + P^39 + P^41 + P^42 + 
    P^43 + P^45 + P^46 + P^47 + P^49 + 2*P^50 + P^51 + 2*P^53 + 2*P^54 + P^55 + P^56 + 2*P^57 + 2*P^58 + P^60 + 2*P^61 + P^62 + 
    P^64 + 2*P^65 + P^66 + P^68 + 2*P^69 + P^70 + P^71 + 2*P^72 + 2*P^73 + P^74 + P^75 + 2*P^76 + 2*P^77 + P^78 + P^79 + 
    2*P^80 + P^81 + P^82 + P^83 + 2*P^84 + P^85 + P^86 + P^87 + 2*P^88 + P^89 + P^90 + P^91 + 2*P^92 + P^93 + P^94 + P^95 + 
    2*P^96 + P^97 + P^98 + P^99 + P^100 + P^101 + P^102 + 2*P^103 + P^104 + 2*P^105 + P^106 + 2*P^107 + P^108 + 2*P^109 + 
    P^110 + 2*P^111 + P^112 + 2*P^113 + P^114 + P^115 + P^116 + 2*P^117 + P^118 + P^119 + P^120 + P^121 + P^122 + P^123 + 
    2*P^124 + P^125 + P^126 + P^127 + 2*P^128 + P^129 + P^130 + P^131 + 2*P^132 + P^133 + P^134 + P^135 + 2*P^136 + P^137 + 
    P^138 + 2*P^139 + 2*P^140 + P^141 + P^142 + 2*P^143 + 2*P^144 + P^145 + P^146 + 2*P^147 + P^148 + P^150 + 2*P^151 + P^152 + 
    P^154 + 2*P^155 + P^156 + 2*P^158 + 2*P^159 + P^160 + P^161 + 2*P^162 + 2*P^163 + P^165 + 2*P^166 + P^167 + P^169 + P^170 + 
    P^171 + P^173 + P^174 + P^175 + P^177 + P^178 + P^179 + P^181 + P^182 + P^185 + P^186 + P^189 + P^190 + P^192 + P^193 + 
    P^194 + P^196 + P^197 + P^200 + P^213)/((1 - P^3)*(1 - P^65)*(1 - P^151))}, 
 {3, (P^11 + P^13 + P^15 + P^17 + P^18 + P^22 + P^26 + P^28 + P^30 + P^32 + P^33 + P^34 + P^36 + P^37 + P^38 + P^40 + P^41 + 
    P^42 + P^44 + 2*P^45 + P^46 + P^47 + P^48 + 2*P^49 + P^51 + P^52 + 2*P^53 + P^55 + P^56 + P^57 + P^59 + 2*P^60 + P^61 + 
    P^62 + P^63 + 2*P^64 + P^65 + P^66 + 2*P^67 + 2*P^68 + P^69 + P^70 + 2*P^71 + 2*P^72 + P^73 + P^74 + 2*P^75 + P^76 + P^77 + 
    2*P^79 + P^80 + P^81 + P^82 + P^83 + 2*P^84 + P^85 + 2*P^86 + P^87 + P^88 + P^89 + 2*P^90 + P^91 + P^92 + 3*P^94 + P^95 + 
    2*P^96 + 2*P^98 + P^99 + 2*P^100 + P^101 + 2*P^102 + P^103 + 2*P^104 + P^105 + 2*P^106 + P^107 + P^108 + P^109 + 2*P^111 + 
    2*P^113 + 3*P^115 + P^116 + 2*P^117 + 2*P^119 + P^120 + 2*P^121 + P^122 + 2*P^123 + P^124 + P^125 + P^126 + P^127 + 
    2*P^128 + P^129 + 2*P^130 + P^131 + P^132 + P^133 + 2*P^134 + 2*P^135 + P^136 + P^137 + 2*P^138 + P^139 + P^140 + 2*P^142 + 
    P^143 + P^144 + P^145 + 2*P^146 + P^147 + P^148 + P^149 + 2*P^150 + P^151 + P^152 + 2*P^153 + 2*P^154 + P^155 + P^156 + 
    2*P^157 + 2*P^158 + P^160 + P^161 + 2*P^162 + P^164 + P^165 + P^166 + P^168 + P^169 + P^170 + P^172 + 2*P^173 + P^174 + 
    P^175 + 2*P^177 + P^179 + P^181 + P^183 + P^184 + P^185 + P^187 + P^188 + P^189 + P^191 + P^192 + P^196 + P^204 + P^206 + 
    P^208)/((1 - P^3)*(1 - P^65)*(1 - P^151))}};
Generating55=ToExpression[Import["./SUtreeData/Generating55.mml","MathML"]];
Generating56=ToExpression[Import["./SUtreeData/Generating56.mml","MathML"]];
Generating57=0;
Generating58=0;
Generating59=ToExpression[Import["./SUtreeData/Generating59.mml","MathML"]];
Generating60=ToExpression[Import["./SUtreeData/Generating60.mml","MathML"]];
Generating61=ToExpression[Import["./SUtreeData/Generating61.mml","MathML"]];

GeneratingList={
Generating01,
Generating02,
Generating03,
Generating04,
Generating05,
Generating06,
Generating07,
Generating08,
Generating09,
Generating10,
Generating11,
Generating12,
Generating13,
Generating14,
Generating15,
Generating16,
Generating17,
Generating18,
Generating19,
Generating20,
Generating21,
Generating22,
Generating23,
Generating24,
Generating25,
Generating26,
Generating27,
Generating28,
Generating29,
Generating30,
Generating31,
Generating32,
Generating33,
Generating34,
Generating35,
Generating36,
Generating37,
Generating38,
Generating39,
Generating40,
Generating41,
Generating42,
Generating43,
Generating44,
Generating45,
Generating46,
Generating47,
Generating48,
Generating49,
Generating50,
Generating51,
Generating52,
Generating53,
Generating54,
Generating55,
Generating56,
Generating57,
Generating58,
Generating59,
Generating60,
Generating61
};


(* Obtaining the correct group number from the name or from the GAP numbers: *)
GroupNumber[GroupName_]:=(
ClearAll[RunNumbXXX,OutXYZ];
RunNumbXXX=1;
While[StringFreeQ[GroupNames[[RunNumbXXX]],GroupName][[1]]==True&&RunNumbXXX<=Length[GroupNames],
RunNumbXXX++
];
If[RunNumbXXX==Length[GroupNames]+1,
OutXYZ="Group not in list!!!",
OutXYZ=RunNumbXXX
];
Return[OutXYZ]
);

GroupNumber[gNum_,jNum_]:=(
ClearAll[localRUN,gListLOCAL,jListLOCAL,intersectLOCAL];
gListLOCAL={};
jListLOCAL={};
For[localRUN=1,localRUN<=61,
If[gNum==GroupOrders[[localRUN,1]],AppendTo[gListLOCAL,localRUN];];
If[jNum==jNumbers[[localRUN,1]],AppendTo[jListLOCAL,localRUN];];
localRUN++];
intersectLOCAL=Intersection[gListLOCAL,jListLOCAL][[1]];
Return[intersectLOCAL];
);


(* GroupOrders: *)
FinGroupOrder[NumberOrName_]:=If[StringQ[NumberOrName]==True,Return[GroupOrders[[GroupNumber[NumberOrName],1]]],Return[GroupOrders[[NumberOrName,1]]]];


(* GroupNames: *)
GroupName[Number_]:=Return[GroupNames[[Number]]];
GroupName[gNum_,jNum_]:=Return[GroupNames[[GroupNumber[gNum,jNum]]]];


(* jNumbers: *)
jNumber[NumberOrName_]:=If[StringQ[NumberOrName]==True,Return[jNumbers[[GroupNumber[NumberOrName],1]]],Return[jNumbers[[NumberOrName,1]]]];



(* Numerical group elements from name, number, or GAP numbers: *)
Group[NumberOrName_]:=If[StringQ[NumberOrName]==True,Return[GroupImport[[GroupNumber[NumberOrName]]]],Return[GroupImport[[NumberOrName]]]];
Group[gNum_,jNum_]:=GroupImport[[GroupNumber[gNum,jNum]]];


(* Molien function from name, number, or GAP numbers: *)
Molien[NumberOrName_]:=If[StringQ[NumberOrName]==True,Return[MolienFuncList[[GroupNumber[NumberOrName]]]],Return[MolienFuncList[[NumberOrName]]]];
Molien[gNum_,jNum_]:=Molien[GroupNumber[gNum,jNum]];


(* Primary invariants from name, number, or GAP numbers: *)
PrimInv[NumberOrName_]:=If[StringQ[NumberOrName]==True,Return[DenominatorInvariantList[[GroupNumber[NumberOrName]]]],Return[DenominatorInvariantList[[NumberOrName]]]];
PrimInv[gNum_,jNum_]:=DenominatorInvariantList[[GroupNumber[gNum,jNum]]];


(* Secondary invariants from name, number, or GAP numbers: *)
SecInv[NumberOrName_]:=If[StringQ[NumberOrName]==True,Return[NumeratorInvariantList[[GroupNumber[NumberOrName]]]],Return[NumeratorInvariantList[[NumberOrName]]]];
SecInv[gNum_,jNum_]:=NumeratorInvariantList[[GroupNumber[gNum,jNum]]];


(* Syzygies from name, number, or GAP numbers: *)
Syzygy[NumberOrName_]:=If[StringQ[NumberOrName]==True,Return[SyzygyList[[GroupNumber[NumberOrName]]]],Return[SyzygyList[[NumberOrName]]]];
Syzygy[gNum_,jNum_]:=SyzygyList[[GroupNumber[gNum,jNum]]];


(* Generating function of complex spherical harmonics *)(* from Prog theoretical physics Vol 39 T.Kayama (1968) p850 *)
GXXX[a1_,a2_,b_,p_,q_]:=(x[1]-x[2] a1)^(-q-1) (x[1]-x[2] a1-x[3] a2)^(p+1) (X[3] (x[1]-x[2] a1)+(x[1] X[1]+x[2] X[2]) a2+(X[1] a1+X[2]) (x[1]-x[2] a1-x[3] a2) b)^q;


(* all possible polynomials in a1 a2 b for p,q-term in generating function *)
LXXX[p_,q_]:=Apply[List,Expand[Sum[a1^t a2^s b^r,{r,0,q},{s,0,p},{t,0,p+r-s}]]] 


(* expansion in a1 is too much but does not matter *)
SXXX[p_,q_]:=Expand[Normal[Series[GXXX[a1,a2,b,p,q],{a1,0,p+q},{b,0,q},{a2,0,p}]]] 


(* further auxiliary function: *)
all0={b->0,a1->0,a2->0};
BXXX[p_,q_]:=Module[{res,i,cc},(* local variables: res, i, cc *)
lisi=cc LXXX[p,q];
expXXX=cc SXXX[p,q];res=Table[Coefficient[expXXX, lisi[[i]]]/.all0,{i,1,Length[lisi]}]
] 


(* corresponding scalar product *)
SPme[dual_,here_]:=Module[{res},res=dual here;res=Expand[res]//.{d[x[a_],n_]^p_.:>d[x[a],n*p],d[X[a_],n_]^p_.:>d[X[a],n*p],c_. d[x[a_,n_]]:>D[c,{x[a],n}],c_. d[X[a_,n_]]:>D[c,{X[a],n}]}]


(* returns a normalized (p,q)-basis *)
CoInvF2[p_,q_: 0]:=Module[{i},rspace=BXXX[p,q];dspace=rspace/.{x[a_]^pa_.:>d[x[a,pa]],X[a_]^pa_.:>d[X[a,pa]]};normy=Table[1/Sqrt[SPme[dspace[[i]],rspace[[i]]]],{i,1,Length[rspace]}];Rspace=rspace normy;Dspace=dspace normy;Rspace];


(* returns an internal normalized basis for polynomials of degree nDEG *)
NormBasisINT[nDEG_]:=CoInvF2[nDEG]


(* returns a normalized basis for polynomials of degree nDEG *)
NormBasis[nDEG_]:=(CoInvF2[nDEG]//.{x[1]->x,x[2]->y,x[3]->z})


(* returns a normalized (p,q)-basis: *)
pqBasis[pDEG_,qDEG_]:=(CoInvF2[pDEG,qDEG]//.{x[1]->x,x[2]->y,x[3]->z,X[1]->xc,X[2]->yc,X[3]->zc})


(* dualize the normalized basis *)
dualize[NORMbas_]:=NORMbas/.{x[a_]^pa_.:>d[x[a,pa]],X[a_]^pa_.:>d[X[a,pa]]}


(* Find an invariant polynomial corresponding to a given VEV: *)
InvFromVEV[nDEG_,VEVasList_]:=(
Return[Expand[(NormBasis[nDEG].VEVasList)]];
);


(* Find an invariant polynomial corresponding to a given (p,q)-VEV: *)
pqInvFromVEV[{pDEG_,qDEG_},VEVasList_]:=(
Return[Expand[(pqBasis[pDEG,qDEG].VEVasList)]];
);


(* Find a VEV from an invariant polynomial: *)
VEVFromInv[nDEG_,InvPoly_]:=(
ClearAll[InvNOWXXX0,InvNOWXXX,BasisNOWXXX,dualBasisNOWXXX,oulistXXX,dummy];
InvNOWXXX0=InvPoly//.{x->dummy[1],y->dummy[2],z->dummy[3]};
InvNOWXXX=InvNOWXXX0//.{dummy[1]->x[1],dummy[2]->x[2],dummy[3]->x[3]};
BasisNOWXXX=NormBasisINT[nDEG];
dualBasisNOWXXX=dualize[BasisNOWXXX];
oulistXXX={};
For[nXYZ=1,nXYZ<=Length[dualBasisNOWXXX],
AppendTo[oulistXXX,SPme[dualBasisNOWXXX[[nXYZ]],InvNOWXXX]];
nXYZ++];
Return[oulistXXX];
);


(* Find a VEV from an invariant (p,q)-polynomial: *)
pqVEVFromInv[{pDEG_,qDEG_},InvPoly_]:=(
ClearAll[InvNOWXXX0,InvNOWXXX,BasisNOWXXX,dualBasisNOWXXX,oulistXXX,dummy];
InvNOWXXX0=InvPoly//.{x->dummy[1],y->dummy[2],z->dummy[3],xc->dummy[4],yc->dummy[5],zc->dummy[6]};
InvNOWXXX=InvNOWXXX0//.{dummy[1]->x[1],dummy[2]->x[2],dummy[3]->x[3],dummy[4]->X[1],dummy[5]->X[2],dummy[6]->X[3]};
BasisNOWXXX=CoInvF2[pDEG,qDEG];
dualBasisNOWXXX=dualize[BasisNOWXXX];
oulistXXX={};
For[nXYZ=1,nXYZ<=Length[dualBasisNOWXXX],
AppendTo[oulistXXX,SPme[dualBasisNOWXXX[[nXYZ]],InvNOWXXX]];
nXYZ++];
Return[oulistXXX];
);


(* Deliver the Generating functions of a certain group: *)
GenFunction[NumberOrName_]:=If[StringQ[NumberOrName]==True,Return[GeneratingList[[GroupNumber[NumberOrName]]]],Return[GeneratingList[[NumberOrName]]]];
GenFunction[gNum_,jNum_]:=GenFunction[GroupNumber[gNum,jNum]];


(* Translates a polynomial into a suitable list: *)
TranslatePoly[poly_]:=(
ClearAll[outLIST];
outLIST={};
For[i89=1,i89<=Length[poly],
ClearAll[elnow];
elnow=poly[[i89]];
If[Length[elnow]==0,
(* then *)
If[(elnow//.{P->2})==1,AppendTo[outLIST,{0,1}],AppendTo[outLIST,{1,1}]],
(* else *)
If[(elnow//.{P->1})==1,
AppendTo[outLIST,{Exponent[elnow,P],1}],
AppendTo[outLIST,{Exponent[elnow[[2]],P],elnow[[1]]}]
];
];
i89++];
Return[outLIST]
)


(* SO (3) and SU (3) Taylor expansions: *)
TaylorSO3[GenFuncList_,limit00_]:=(
ClearAll[outNOW];
outNOW={};
For[i19=1,i19<=Length[GenFuncList],
AppendTo[outNOW,{GenFuncList[[i19,1]],Normal[Series[(1-P^2)GenFuncList[[i19,2]],{P,0,limit00}]]}];
i19++];
Return[outNOW]
)
TaylorSU3[GenFuncList_,limit00_]:=(
ClearAll[outNOW];
outNOW={};
For[i19=1,i19<=Length[GenFuncList],
AppendTo[outNOW,{GenFuncList[[i19,1]],Normal[Series[GenFuncList[[i19,2]],{P,0,limit00}]]}];
i19++];
Return[outNOW]
)


(* Sorting of the representations: *)
SortingReps[GenFuncListTaylored_]:=(
ClearAll[RepNumber,DimList,DimListSIMP,MaxDim,RepSortList];
RepNumber=Length[GenFuncListTaylored];
RepSortList={};
DimList={};
For[j34=1,j34<=Length[GenFuncListTaylored],
AppendTo[DimList,GenFuncListTaylored[[j34,1]]];
j34++];
DimListSIMP={};
For[j35=1,j35<=Length[DimList],
If[MemberQ[DimListSIMP,DimList[[j35]]]==False,AppendTo[DimListSIMP,DimList[[j35]]]];
j35++];
MaxDim=Max[DimList];
RepSortList={};
For[j78=1,j78<=Length[DimListSIMP],
ClearAll[counter];
counter=0;
For[j79=1,j79<=Length[DimList],
If[DimList[[j79]]==DimListSIMP[[j78]],counter++];
If[DimList[[j79]]==DimListSIMP[[j78]],AppendTo[RepSortList,{{GenFuncListTaylored[[j79,1]],counter},TranslatePoly[GenFuncListTaylored[[j79,2]]]}]];
j79++];
j78++];
Return[RepSortList]
)


(* Set an external limit on the cutoff of the Taylor expansion: *)
TaylorLim=50;


(* Dimension of the SO (3) representation l: *)
diml[l_]:=2l+1


(* Branching rules for breaking from SO (3): internal function *)
BranchingSO3intern[lnumber_,GenFuncList_]:=(
ClearAll[RepSO3,SortedList,BranchList];
RepSO3=diml[lnumber];
SortedList=SortingReps[TaylorSO3[GenFuncList,TaylorLim]];
BranchList={lnumber,RepSO3};
For[k89=1,k89<=Length[SortedList],
For[k10=1,k10<=Length[SortedList[[k89,2]]],
ClearAll[countNOW];
countNOW=SortedList[[k89,2,k10,2]];
If[SortedList[[k89,2,k10,1]]==lnumber,
For[app01=1,app01<=countNOW,
AppendTo[BranchList,SortedList[[k89,1]]];
app01++];
];
k10++];
k89++];
Return[BranchList]
)


(* Branching rules for breaking from SO (3): *)
BranchingSO3[l01_,NumberOrName_]:=If[StringQ[NumberOrName]==True,Return[BranchingSO3intern[l01,GenFunction[GroupNumber[NumberOrName]]]],Return[BranchingSO3intern[l01,GenFunction[NumberOrName]]]];
BranchingSO3[l01_,gNum_,jNum_]:=BranchingSO3[l01,GroupNumber[gNum,jNum]];

BranchingSU3[{p01_,q01_},NumberOrName_]:=If[StringQ[NumberOrName]==True,Return[pqBranchings[{p01,q01},GroupNumber[NumberOrName]]],Return[pqBranchings[{p01,q01},NumberOrName]]];
BranchingSU3[{p01_,q01_},gNum_,jNum_]:=BranchingSU3[{p01,q01},GroupNumber[gNum,jNum]];


(* Dimension of a (p,q)-rep: *)
pqDIM[p_,q_]:=(1+p)(1+q)(2+p+q)/2


(* List (p,q)-reps and their dimensions: *)
pqReps[limit_]:=Module[{p,q,pqCands,pqSort,i},
ClearAll[pqCands,pqSort];
pqCands={};
For[q=0,q<=limit,
For[p=0,p<=limit,
If[pqDIM[p,q]<=limit,
If[MemberQ[pqCands,{{q,p},pqDIM[p,q]}]==False,
AppendTo[pqCands,{{p,q},pqDIM[p,q]}]
]];
p++];
q++];
pqSort=Sort[pqCands,#1[[2]]<=#2[[2]]&];
Return[pqSort]
]


(* Cases of (p,q) up to a certain dimension: *)
pqCases[limit_]:=Module[{CasesList,i,SortedList},
CasesList={};
SortedList=pqReps[limit];
For[i=1,i<=Length[SortedList],
AppendTo[CasesList,SortedList[[i,1]]];
i++];
Return[CasesList]
];


(* Weight of the different irreps (NOTE: Alex also conjugates chi[[q+1,i]], as otherwise the series expansion yields unphysical results:): *)
nRep[p_,q_,R_,chi_]:=ComplexExpand[Sum[chi[[1,i]]* chi[[p+1,i]]Conjugate[chi[[q+1,i]]]*
Conjugate[chi[[R+1,i]]],{i,1,Length[chi[[1]]]}]/Sum[chi[[1,i]],{i,1,Length[chi[[1]]]}]]


(* B-function (generating function): *)
BXXX[i_,3,x0_,Generating_]:=Generating[[i,2]]/.P-> x0


(* F-function [Eq. (C .10)]: *)
FXXX[Rep_,P0_,Q0_,chi_,Generating_]:= ComplexExpand[(1-P0 Q0) Sum[nRep[p0,q0,Rep,chi]BXXX[p0,3,P0,Generating]BXXX[q0,3,Q0,Generating], {p0,1,Length[chi[[1]]]},{q0,1,Length[chi[[1]]]}]]


(* Sorting of the subgroup-reps: *)
SortingSubReps[GenFuncList_]:=Module[{counter,RepNumber,DimList,DimListSIMP,MaxDim,RepSortList},
ClearAll[RepNumber,DimList,DimListSIMP,MaxDim,RepSortList];
RepNumber=Length[GenFuncList];
RepSortList={};
DimList={};
For[j34=1,j34<=Length[GenFuncList],
AppendTo[DimList,GenFuncList[[j34,1]]];
j34++];
DimListSIMP={};
For[j35=1,j35<=Length[DimList],
If[MemberQ[DimListSIMP,DimList[[j35]]]==False,AppendTo[DimListSIMP,DimList[[j35]]]];
j35++];
MaxDim=Max[DimList];
RepSortList={};
For[j78=1,j78<=Length[DimListSIMP],
ClearAll[counter];
counter=0;
For[j79=1,j79<=Length[DimList],
If[DimList[[j79]]==DimListSIMP[[j78]],counter++];
If[DimList[[j79]]==DimListSIMP[[j78]],AppendTo[RepSortList,{{GenFuncList[[j79,1]],counter},GenFuncList[[j79,2]]}]];
j79++];
j78++];
Return[RepSortList]
]


(* Import the data for the Character Tables: *)
ToExpression[Import["./SUtreeData/SizesCClasses_MathRead.dat","Table"]];
For[i98=1,i98<=61,
ToExpression[Import["./SUtreeData/CharacterTables_MathRead.dat",{"Text","Words",i98}]];
i98++];


(* Bring the tables in a form that involves the sizes of the classes: *)
CharTablesNo={};
For[l78=1,l78<=61,
ClearAll[CharPiece,gHERE,jHERE];
{gHERE,jHERE}={FinGroupOrder[l78],jNumber[l78]};
CharPiece=PrependTo[CharTab[gHERE,jHERE],Sizes[gHERE,jHERE]];
AppendTo[CharTablesNo,CharPiece];
l78++];


(* Primary invariants from name, number, or GAP numbers: *)
CharacterTable[NumberOrName_]:=If[StringQ[NumberOrName]==True,Return[CharTablesNo[[GroupNumber[NumberOrName]]]],Return[CharTablesNo[[NumberOrName]]]];
CharacterTable[gNum_,jNum_]:=CharTablesNo[[GroupNumber[gNum,jNum]]];


(* Branching rules for breaking from SU (3): internal function *)
pqBranchings[{p01_,q01_},GroupNumberHERE_]:=Module[{caseHere,CharHere,GenHere,properRep,NumReps,k01,ResLISTH,xxNOW,numNOWxyz,k02a,SeriesLIMIT},
caseHere={p01,q01};
CharHere=CharacterTable[GroupNumberHERE];
GenHere=GenFunction[GroupNumberHERE];
NumReps=Length[GenHere];
ResLISTH={caseHere,pqDIM[p01,q01]};
For[k01=1,k01<=NumReps,
ClearAll[properRep,xxNOW];
properRep=SortingSubReps[GenHere][[k01,1]];
SeriesLIMIT=Max[{p01,q01,p01*q01,p01^2,q01^2}];
xxNOW=Expand[ComplexExpand[Pvar Qvar Normal[Series[ComplexExpand[FXXX[k01,Pvar,Qvar,CharHere,GenHere]],{Pvar,0,SeriesLIMIT},{Qvar,0,SeriesLIMIT}]]]];
numNOWxyz=FullSimplify[Coefficient[xxNOW,Pvar^(caseHere[[1]]+1) Qvar^(caseHere[[2]]+1),1]];
For[k02a=1,k02a<=numNOWxyz,
AppendTo[ResLISTH,properRep];
k02a++];
k01++];
Return[ResLISTH]
]


(* Branching rules for breaking from SU (3): *)
BranchingSU3[{p01_,q01_},NumberOrName_]:=If[StringQ[NumberOrName]==True,Return[pqBranchings[{p01,q01},GroupNumber[NumberOrName]]],Return[pqBranchings[{p01,q01},NumberOrName]]];
BranchingSU3[{p01_,q01_},gNum_,jNum_]:=BranchingSU3[{p01,q01},GroupNumber[gNum,jNum]];


(* Collection of all Representations of a certain group: internal function *)
RepCollection[GroupNO_]:=Module[{counter,RepNumber,DimList,DimListSIMP,MaxDim,RepSortList,CharTabSHORT,CharTable},
ClearAll[RepNumber,DimList,DimListSIMP,MaxDim,RepSortList];
CharTable=CharacterTable[GroupNO];
CharTabSHORT=Drop[CharTable,1];
RepNumber=Length[CharTabSHORT];
RepSortList={};
DimList={};
For[j34=1,j34<=Length[CharTabSHORT],
AppendTo[DimList,CharTabSHORT[[j34,1]]];
j34++];
DimListSIMP={};
For[j35=1,j35<=Length[DimList],
If[MemberQ[DimListSIMP,DimList[[j35]]]==False,AppendTo[DimListSIMP,DimList[[j35]]]];
j35++];
MaxDim=Max[DimList];
RepSortList={};
For[j78=1,j78<=Length[DimListSIMP],
ClearAll[counter];
counter=0;
For[j79=1,j79<=Length[DimList],
If[DimList[[j79]]==DimListSIMP[[j78]],counter++];
If[DimList[[j79]]==DimListSIMP[[j78]],AppendTo[RepSortList,{CharTabSHORT[[j79,1]],counter}]];
j79++];
j78++];
Return[RepSortList]
]


(* Finite irreps: *)
FiniteIrreps[NumberOrName_]:=If[StringQ[NumberOrName]==True,Return[RepCollection[GroupNumber[NumberOrName]]],Return[RepCollection[NumberOrName]]];
FiniteIrreps[gNum_,jNum_]:=FiniteIrreps[GroupNumber[gNum,jNum]];


(* Coefficients of the CG-Series: *)
munutauCoeffPos[Rep1pos_,Rep2pos_,ResFinalpos_,GroupNumb_]:=Module[{charDIMS,charLENGTH,ordHERE,charRED,ACTUALcoeff},
charDIMS=CharacterTable[GroupNumb][[1]];
charLENGTH=Length[CharacterTable[GroupNumb][[1]]];
charRED=Drop[CharacterTable[GroupNumb],1];
ordHERE=FinGroupOrder[GroupNumb];
ACTUALcoeff=ComplexExpand[Sum[charDIMS[[irun]]*charRED[[Rep1pos,irun]]*charRED[[Rep2pos,irun]]*Conjugate[charRED[[ResFinalpos,irun]]],{irun,1,charLENGTH}]/ordHERE];
Return[ACTUALcoeff]
]


(* Kronecker products: internal function *)
CGSeries[Rep1_,Rep2_,GroupNumber_]:=Module[
{RepLIST,Pos1,Pos2,coeffLIST,k54,lengthHERE,scalProd,k78},
RepLIST=RepCollection[GroupNumber];
Pos1=Position[RepLIST,Rep1][[1]];
Pos2=Position[RepLIST,Rep2][[1]];
lengthHERE=Length[RepLIST];
coeffLIST={};
For[k54=1,k54<=lengthHERE,
AppendTo[coeffLIST,munutauCoeffPos[Pos1,Pos2,k54,GroupNumber]];
k54++];
scalProd={};
For[k78=1,k78<=lengthHERE,
AppendTo[scalProd,{coeffLIST[[k78,1]],RepLIST[[k78]]}];
k78++];
Return[{Rep1,Rep2,scalProd}];
]


(* Kronecker products: *)
Kronecker[Rep1_,Rep2_,NumberOrName_]:=If[StringQ[NumberOrName]==True,CGSeries[Rep1,Rep2,GroupNumber[NumberOrName]],Return[CGSeries[Rep1,Rep2,NumberOrName]]];
Kronecker[Rep1_,Rep2_,gNum_,jNum_]:=Kronecker[Rep1,Rep2,GroupNumber[gNum,jNum]];


(* Final message: *)
Print["Program loaded."]


End[ ]

EndPackage[ ]



